//=============================================================================
// VisuStella MZ - Core Engine
// VisuMZ_0_CoreEngine.js
//=============================================================================

var Imported = Imported || {};
Imported.VisuMZ_0_CoreEngine = true;

var VisuMZ = VisuMZ || {};
VisuMZ.CoreEngine = VisuMZ.CoreEngine || {};
VisuMZ.CoreEngine.version = 1.59;

//=============================================================================
 /*:
 * @target MZ
 * @plugindesc [RPG Maker MZ] [Tier 0] [Version 1.59] [CoreEngine]
 * @author VisuStella
 * @url http://www.yanfly.moe/wiki/Core_Engine_VisuStella_MZ
 *
 * @help
 * ============================================================================
 * Introduction
 * ============================================================================
 *
 * The Core Engine plugin is designed to fix any bugs that may have slipped
 * past RPG Maker MZ's source code and to give game devs more control over
 * RPG Maker MZ's various features, ranging from mechanics to aesthetics to
 * quality of life improvements.
 *
 * Features include all (but not limited to) the following:
 *
 * * Bug fixes for the problems existing in the RPG Maker MZ base code.
 * * Failsafes added for Script Call related event commands.
 * * Lots of Quality of Life Settings that can be activated through the
 *   Plugin Parameters.
 * * Control over the various Text Colors used throughout the game.
 * * Change up the maximum amount of gold carried, give it an icon attached to
 *   the label, and include text for overlap specifics.
 * * Preload images as the game boots up.
 * * Add specific background images for menus found throughout the game.
 * * A button assist window will appear at the top or bottom of the screen,
 *   detailing which buttons do what when inside a menu. This feature can be
 *   turned off.
 * * Choose which in-game battler parameters to display inside menus (ie ATK,
 *   DEF, AGI, etc.) and determine their maximum values, along with plenty of
 *   notetags to give more control over parameter, x-parameter, s-parameter
 *   bonuses through equipment, states, and other trait objects.
 * * Control over how the UI objects appear (such as the menu button, cancel
 *   button, left/right actor switch buttons).
 * * Reposition actors and enemies if the battle resolution is larger.
 * * Allow class names and nicknames to support text codes when displayed.
 * * Determine how windows behave in the game, if they will mask other windows,
 *   their line height properties, and more.
 *
 * ============================================================================
 * Requirements
 * ============================================================================
 *
 * This plugin is made for RPG Maker MZ. This will not work in other iterations
 * of RPG Maker.
 *
 * ------ Tier 0 ------
 *
 * This plugin is a Tier 0 plugin. Place it under other plugins of lower tier
 * value on your Plugin Manager list (ie: 0, 1, 2, 3, 4, 5). This is to ensure
 * that your plugins will have the best compatibility with the rest of the
 * VisuStella MZ Plugin library.
 *
 * ============================================================================
 * Important Changes: Bug Fixes
 * ============================================================================
 *
 * This plugin also serves to fix various bugs found in RPG Maker MZ that have
 * been unaddressed or not yet taken care of. The following is a list of bugs
 * that have been fixed by this plugin:
 *
 * ---
 *
 * Attack Skill Trait
 *
 * Enemies are unaffected by the Attack Skill Trait. This means if they have
 * an Attack action, they will always use Attack over and over even if their
 * Attack Skill Trait has been changed. This plugin will change it up so that
 * the Attack skill will comply with whatever their Attack Skill Trait's skill
 * is set to.
 *
 * ---
 *
 * Auto Battle Actor Skill Usage
 *
 * If an actor with Auto Battle has access to a skill but not have any access
 * to that skill's type, that actor will still be able to use the skill during
 * Auto Battle despite the fact that the actor cannot use that skill during
 * manual input.
 *
 * ---
 * 
 * Auto Battle Attack Seal Bypass
 * 
 * By default, if the attack skill is sealed via a trait and an actor has
 * auto-battle, the action can still be used via auto-battle. This is now fixed
 * and actors should not be able to attack via auto-battle if their attack
 * ability is sealed.
 * 
 * ---
 * 
 * Auto Battle Lock Up
 * 
 * If an auto battle Actor fights against an enemy whose DEF/MDF is too high,
 * they will not use any actions at all. This can cause potential game freezing
 * and softlocks. This plugin will change that and have them default to a
 * regular Attack.
 * 
 * ---
 * 
 * Gamepad Repeat Input
 * 
 * Cleared inputs on gamepads do not have a downtime and will trigger the
 * following input frame. The causes problems with certain RPG Maker MZ menus
 * where the inputs have to be cleared as the next immediate frame will have
 * them inputted again. This plugin changes it so that whenever inputs are
 * cleared, there is a downtime equal to the keyboard clear frames before the
 * gamepad input is registered once more.
 * 
 * ---
 * 
 * Invisible Battle Sprites
 * 
 * If you removed a party member during battle and added that exact party
 * member back into the same slot, their sprite would appear invisible. The
 * VisuStella Core Engine will fix this problem and prevent it from happening.
 * 
 * ---
 * 
 * Instant Text Discrepancy for Window_Message
 * 
 * Window_Message displays text differently when it draws letters one by one
 * versus when the text is displayed instantly. This isn't noticeable with the
 * default font, but it's very visible when using something like Arial. The
 * error is due to Bitmap.measureTextWidth yielding a rounded value per letter
 * versus per word. The Core Engine will provide a bug fix that will single out
 * the cause and make it so that only Window_Message will not utilize any round
 * number values when determining the width of each letter, whether or not it
 * is shown instantly. This change will only affect Window_Message and not any
 * other window in order to prevent unintended side effects.
 * 
 * This can be disabled through the Plugin Parameters:
 * 
 * Plugin Parameters > QoL Settings > Misc > Font Width Fix
 * 
 * ---
 *
 * Move Picture, Origin Differences
 *
 * If a Show Picture event command is made with an Origin setting of
 * "Upper Left" and a Move Picture event command is made afterwards with an
 * Origin setting of "Center", RPG Maker MZ would originally have it instantly
 * jump into the new origin setting without making a clean transition between
 * them. This plugin will create that clean transition between origins.
 *
 * ---
 * 
 * Overly-Protective Substitute
 * 
 * When an ally with critical health is being targeted by a friendly non-
 * Certain Hit skill (such as a heal or buff) and another ally has the
 * substitute state, the other ally would "protect" the originally targeted
 * ally and take the heal or buff.
 * 
 * The new changed behavior is that now, substitute will not trigger for any
 * actions whose scope targets allies.
 * 
 * ---
 * 
 * Status Window Name Vertical Cutoffs
 * 
 * In the battle status windows, whenever actor names are displayed, the bitmap
 * used to display their name text do not extend vertically all the way,
 * causing letters like lowercase "Q" and "G" to be cut off, making them hard
 * to distinguish from one another. The Core Engine will remedy this by
 * extending the bitmap to allow enough room. Fix made by Irina.
 * 
 * ---
 * 
 * Termination Clear Effects
 * 
 * In RPG Maker MZ, requesting an animation while transitioning between
 * scenes, such as going from the map scene to the battle scene, can cause
 * crashes. This is because the animation queue does not take off immediately
 * and will likely register incorrect targets for the scene. This plugin will
 * forcefully clear any registered animations and balloon effects when
 * terminating a scene in order to prevent crashes.
 * 
 * ---
 * 
 * Timer Sprite
 * 
 * By default, RPG Maker MZ adds Sprite_Timer into its spriteset, either for
 * maps or for battles. There is one major problem with this: when spritesets
 * are affected by filters, zooms, and/or blurs, this hinders how readable the
 * timer sprite is, making the information perceived by the player to be much
 * harder than it needs to be. The Core Engine adds the sprite to the parent
 * scene instead of the spriteset to ensure it's unobscured by anything else.
 * 
 * ---
 * 
 * Unusable Battle Items
 * 
 * If any party member is able to use an item in battle, then all party members
 * are able to use said item, even if that party member is supposed to be
 * unable to use that item. This is now changed so that battle items are
 * checked on an individual basis and not on a party-wide basis.
 * 
 * ---
 * 
 * Window Arrows Sprite Tearing
 * 
 * If a window object in RPG Maker MZ were to have an odd number for width size
 * then the arrow elements found for the window would be positioned on a half
 * pixel, giving it a blurry look and also have sprite tearing issues. This is
 * now fixed by rounding the number to the nearest whole number.
 * 
 * ---
 * 
 * Window Client Area Scaling Bug
 * 
 * If the window has a scale value different from 1.0, the client area (the
 * interactable parts) will not scale properly and appear clipped out. This
 * is now fixed by adjusting the client area to the window's scale values and
 * rounding upward to the nearest whole number.
 * 
 * ---
 * 
 * Window Skin Bleeding
 * 
 * This bug is fixed in the core scripts for RPG Maker MZ v1.3.0+.
 * 
 * Since the v1.2.0 update, Window.prototype._refreshBack's frame value has
 * been set from 96 to 95. This results in the window skin bleeding past the
 * window's intended borders. The Core Engine now reverts this change to
 * prevent the bleeding effect from happening.
 * 
 * ---
 *
 * ============================================================================
 * Major Changes: New Hard-Coded Features
 * ============================================================================
 *
 * This plugin adds some new hard-coded features to RPG Maker MZ's functions.
 * The following is a list of them.
 *
 * ---
 *
 * Scroll-Linked Pictures
 *
 * - If a Parallax has a ! at the start of its filename, it is bound to the map
 * scrolling. The same thing now happens with pictures. If a Picture has a ! at
 * the start of its filename, it is bound to the map's scrolling as well.
 *
 * ---
 *
 * Movement Route Scripts
 *
 * - If code in a Movement Route Script command fails, instead of crashing the
 * game, it will now act as if nothing happened except to display the cause of
 * the error inside the console.
 *
 * ---
 * 
 * Script Call Failsafes
 * 
 * - If code found in Conditional Branches, Control Variables, and/or Script
 * Calls fail to activate, instead of crashing the game, it will now act as if
 * nothing happened except to display the cause of the error inside the
 * console.
 * 
 * ---
 * 
 * Digit Grouping
 * 
 * - There exists an option to change how numbers are displayed and converted
 * in your game. This option can be enabled or disabled by going into the
 * Plugin Manager > VisuMZ_0_OptionsCore > Quality of Life Settings >
 * Digit Grouping and toggling on/off whichever ones you want.
 * 
 * - Digit Grouping will follow the rules of whatever country/locale the Plugin
 * Parameters are set to. If it's to default 'en-US', then 1234567.123456 will
 * become 1,234,567.123456. Set it to 'es-ES' and it becomes 1.234.567,123456
 * instead.
 * 
 * - This uses JavaScript's Number.toLocaleString() function and will therefore
 * follow whatever rules it has. This means if there are trailing zeroes at the
 * end of a decimal, it will cut them off. Numbers like 123.45000 will become
 * 123.45 instead. Excess numbers past 6 decimal places will be rounded. A
 * number like 0.123456789 will become 0.123457 instead.
 * 
 * - Numbers in between [ and ], < and > will be excluded from digit grouping
 * in order for text codes to be preserved accurately. \I[1234] will remain as
 * \I[1234].
 * 
 * - If you would like to enter in a number without digit grouping, surround it
 * with {{ and }}. Typing in {{1234567890}} will yield 1234567890.
 * 
 * ---
 * 
 * Show Scrolling Text, additional functionality
 * 
 * The event command "Show Scrolling Text" now has additional functionality as
 * long as the VisuStella MZ Core Engine is installed. If the game dev inserts
 * "// Script Call" (without the quotes) inside the scrolling text, then the
 * entirity of the Show Scrolling Text event command will be ran as a giant
 * script call event command.
 * 
 * The reason why this functionality is added is because the "Script..." event
 * command contains only 12 lines maximum. This means for any script call
 * larger than 12 lines of code cannot be done by normal means as each script
 * call is ran as a separate instance.
 * 
 * By repurposing the "Show Scrolling Text" event command to be able to
 * function as an extended "Script..." event command, such a thing is now
 * possible with less hassle and more lines to code with.
 * 
 * This effect does not occur if the Show Scrolling Text event command does not
 * have "// Script Call" in its contents.
 * 
 * ---
 *
 * ============================================================================
 * Notetags
 * ============================================================================
 *
 * The following are notetags that have been added through this plugin. These
 * notetags will not work with your game if this plugin is OFF or not present.
 *
 * === Actors ===
 *
 * Parameter limits can be adjusted in the Plugin Parameters, but this won't
 * lift the ability to change the values of an actor's initial or max level
 * past the editor's limits. Instead, this must be done through the usage of
 * notetags to accomplish the feat.
 *
 * ---
 *
 * <Max Level: x>
 *
 * - Used for: Actor Notetags
 * - Replace 'x' with an integer to determine the actor's max level.
 * - This allows you to go over the database limit of 99.
 * - If this notetag isn't used, default to the actor's database value.
 *
 * ---
 *
 * <Initial Level: x>
 *
 * - Used for: Actor Notetags
 * - Replace 'x' with an integer to determine the actor's initial level.
 * - This allows you to go over the database limit of 99.
 * - If this notetag isn't used, default to the actor's database value.
 *
 * ---
 *
 * === Classes ===
 *
 * As actor levels can now surpass 99 due to the notetag system, there may be
 * some skills you wish certain classes can learn upon reaching higher levels
 * past 99, too.
 *
 * ---
 * 
 * <Learn At Level: x>
 *
 * - Used for: Class Skill Learn Notetags
 * - Replace 'x' with an integer to determine the level this class will learn
 *   the associated skill at.
 * - This allows you to go over the database limit of 99.
 * - If this notetag isn't used, default to the class's database value.
 *
 * ---
 *
 * === Enemies ===
 *
 * Enemies are now given levels. The levels don't do anything except to serve
 * as a container for a number value. This way, levels can be used in damage
 * formulas (ie. a.atk - b.level) without causing any errors. To give enemies
 * levels, use the notetags below. These notetags also allow you to adjust the
 * base parameters, EXP, and Gold past the database limitations.
 *
 * ---
 *
 * <Level: x>
 *
 * - Used for: Enemy Notetags
 * - Replace 'x' with an integer to determine the enemy's level.
 * - If no level is declared, the level will default to 1.
 *
 * ---
 *
 * <param: x>
 *
 * - Used for: Enemy Notetags
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to alter.
 *   - This notetag does NOT work with X Parameters, S Parameters, or any
 *     custom parameters. This notetag ONLY works with the base parameters.
 * - Replace 'x' with an integer to set an enemy's 'param' base value.
 * - This will overwrite the enemy's database value and can exceed the original
 *   value limitation in the database.
 * - If these notetags aren't used, default to the enemy's database value.
 *
 * ---
 *
 * <EXP: x>
 * <Gold: x>
 *
 * - Used for: Enemy Notetags
 * - Replace 'x' with an integer to determine the enemy's EXP or Gold values.
 * - This will overwrite the enemy's database value and can exceed the original
 *   value limitation in the database.
 * - If these notetags aren't used, default to the enemy's database value.
 *
 * ---
 * 
 * === Animations ===
 * 
 * Animations in RPG Maker MZ are done by Effekseer and the animation system
 * has been revamped. However, the animations are only centered on the targets
 * now, and cannot be attached to the head or foot. Insert these tags into
 * the names of the animations in the database to adjust their positions.
 * 
 * ---
 * 
 * <Head>
 * <Foot>
 * 
 * - Used for: Animation Name Tags
 * - Will set the animation to anchor on top of the sprite (if <Head> is used)
 *   or at the bottom of the sprite (if <Foot> is used).
 * 
 * ---
 * 
 * <Anchor X: x>
 * <Anchor Y: y>
 * 
 * <Anchor: x, y>
 * 
 * - Used for: Animation Name Tags
 * - Will anchor the animation at a specific point within the sprite based on
 *   the 'x' and 'y' values.
 * - Replace 'x' and 'y' with numeric values representing their positions based
 *   on a rate where 0.0 is the furthest left/up (x, y respectively) to 1.0 for
 *   the furthest right/down (x, y respectively).
 * 
 * Examples:
 * 
 * <Anchor X: 0.4>
 * <Anchor Y: 0.8>
 * 
 * <Anchor: 0.2, 0.9>
 * 
 * ---
 * 
 * <Offset X: +x>
 * <Offset X: -x>
 * <Offset Y: +y>
 * <Offset Y: -y>
 * 
 * <Offset: +x, +y>
 * <Offset: -x, -y>
 * 
 * - Used for: Animation Name Tags
 * - Will anchor the animation to be offset by an exact number of pixels.
 * - This does the same the editor does, except it lets you input values
 *   greater than 999 and lower than -999.
 * - Replace 'x' and 'y' with numeric values the exact number of pixels to
 *   offset the animation's x and y coordinates by.
 * 
 * Examples:
 * 
 * <Offset X: +20>
 * <Offset Y: -50>
 * 
 * <Offset: +10, -30>
 * 
 * ---
 * 
 * <Mirror Offset X>
 * <No Mirror Offset X>
 * 
 * - Used for: Animation Name Tags
 * - If an animation is mirrored, you can choose to have the animation's Offset
 *   X value be mirrored, too (or not at all).
 * - If no name tag is discovered, this will use the setting found in the
 *   Plugin Parameters > QoL Settings > Misc > Ani: Mirror Offset X setting.
 * 
 * ---
 * 
 * <Rate: x>
 * 
 * - Used for: MV Animation Name Tags
 * - Allows you to adjust the update for this MV Animation.
 *   - Does NOT work with Effekseer animations.
 * - The lower the number, the faster.
 * - Replace 'x' with a number representing the animation update rate.
 *   - Default rate: 4.
 *   - Minimum rate: 1.
 *   - Maximum rate: 10.
 * 
 * ---
 *
 * === Quality of Life ===
 *
 * By default, RPG Maker MZ does not offer an encounter step minimum after a
 * random encounter has finished. This means that one step immediately after
 * finishing a battle, the player can immediately enter another battle. The
 * Quality of Life improvement: Minimum Encounter Steps allows you to set a
 * buffer range between battles for the player to have some breathing room.
 *
 * ---
 *
 * <Minimum Encounter Steps: x>
 *
 * - Used for: Map Notetags
 * - Replace 'x' with the minimum number of steps before the player enters a
 *   random encounter on that map.
 * - If this notetag is not used, then the minimum encounter steps for the map
 *   will default to Quality of Life Settings => Encounter Rate Min.
 *
 * ---
 *
 * Tile shadows are automatically added to certain tiles in the map editor.
 * These tile shadows may or may not fit some types of maps. You can turn them
 * on/off with the Quality of Life Plugin Parameters or you can override the
 * settings with the following notetags:
 *
 * ---
 *
 * <Show Tile Shadows>
 * <Hide Tile Shadows>
 *
 * - Used for: Map Notetags
 * - Use the respective notetag for the function you wish to achieve.
 * - If this notetag is not used, then the minimum encounter steps for the map
 *   will default to Quality of Life Settings => No Tile Shadows.
 *
 * ---
 *
 * === Basic, X, and S Parameters ===
 *
 * A battler's parameters, or stats as some devs know them as, are the values
 * that determine how a battler performs. These settings allow you to alter
 * behaviors and give boosts to trait objects in a more controlled manner.
 *
 * ---
 *
 * <param Plus: +x>
 * <param Plus: -x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'param' plus value when calculating totals.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'x' with an integer on how much to adjust the parameter by.
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <param Rate: x%>
 * <param Rate: x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Changes 'param' rate to 'x' to alter the total 'param' value.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <param Flat: +x>
 * <param Flat: -x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'param' plus value when calculating totals.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'x' with an integer on how much to adjust the parameter by.
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <param Max: x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Sets max caps for the 'param' to be 'x'. If there are multiple max caps
 *   available to the unit, then the highest will be selected.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'x' with an integer to determine what the max cap should be.
 *
 * ---
 *
 * <xparam Plus: +x%>
 * <xparam Plus: -x%>
 *
 * <xparam Plus: +x.x>
 * <xparam Plus: -x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'xparam' plus value when calculating totals.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <xparam Rate: x%>
 * <xparam Rate: x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Changes 'param' rate to 'x' to alter the total 'xparam' value.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <xparam Flat: +x%>
 * <xparam Flat: -x%>
 *
 * <xparam Flat: +x.x>
 * <xparam Flat: -x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'xparam' plus value when calculating totals.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <sparam Plus: +x%>
 * <sparam Plus: -x%>
 *
 * <sparam Plus: +x.x>
 * <sparam Plus: -x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'sparam' plus value when calculating totals.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   S Parameter => Formula.
 *
 * ---
 *
 * <sparam Rate: x%>
 * <sparam Rate: x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Changes 'param' rate to 'x' to alter the total 'sparam' value.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   S Parameter => Formula.
 *
 * ---
 *
 * <sparam Flat: +x%>
 * <sparam Flat: -x%>
 *
 * <sparam Flat: +x.x>
 * <sparam Flat: -x.x>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Adds or subtracts 'x' to 'sparam' plus value when calculating totals.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'x' with a percentage (ie. 150%) or a rate (ie. 1.5).
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   S Parameter => Formula.
 *
 * === JavaScript Notetags: Basic, X, and S Parameters ===
 *
 * The following are notetags made for users with JavaScript knowledge. These
 * notetags are primarily aimed at Basic, X, and S Parameters.
 *
 * ---
 *
 * <JS param Plus: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'param' plus value.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   plus amount for the parameter's total calculation.
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <JS param Rate: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'param' rate value.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   param rate amount for the parameter's total calculation.
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <JS param Flat: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'param' flat value.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   flat bonus amount for the parameter's total calculation.
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   Basic Parameter => Formula.
 *
 * ---
 *
 * <JS param Max: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to determine what the max cap for 'param' should be. If there
 *   are multiple max caps available to the unit, then the highest is selected.
 * - Replace 'param' with 'MaxHP', 'MaxMP', 'ATK', 'DEF', 'MAT', 'MDF', 'AGI',
 *   or 'LUK' to determine which parameter to modify.
 * - Replace 'code' with JavaScript code to determine the max cap for the
 *   desired parameter.
 *
 * ---
 *
 * <JS xparam Plus: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'xparam' plus value.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   plus amount for the X parameter's total calculation.
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <JS xparam Rate: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'xparam' rate value.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   param rate amount for the X parameter's total calculation.
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <JS xparam Flat: code>
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'xparam' flat value.
 * - Replace 'xparam' with 'HIT', 'EVA', 'CRI', 'CEV', 'MEV', 'MRF', 'CNT',
 *   'HRG', 'MRG', 'TRG' to determine which X parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   flat bonus amount for the X parameter's total calculation.
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   X Parameter => Formula.
 *
 * ---
 *
 * <JS sparam Plus: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'sparam' plus value.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   plus amount for the S parameter's total calculation.
 * - This is used to calculate the 'plus' portion in the Parameter Settings =>
 *   S Parameter => Formula.
 *
 * ---
 *
 * <JS sparam Rate: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'sparam' rate value.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   param rate amount for the S parameter's total calculation.
 * - This is used to calculate the 'paramRate' portion in Parameter Settings =>
 *   S Parameter => Formula.
 *
 * ---
 *
 * <JS sparam Flat: code>
 *
 * - Used for: Actor, Class, Weapon, Armor, Enemy, State Notetags
 * - Runs 'code' to change the 'sparam' flat value.
 * - Replace 'sparam' with 'TGR', 'GRD', 'REC', 'PHA', 'MCR', 'TCR', 'PDR',
 *   'MDR', 'FDR', 'EXR' to determine which S parameter to modify.
 * - Replace 'code' with JavaScript code to determine how much to change the
 *   flat bonus amount for the S parameter's total calculation.
 * - This is used to calculate the 'flatBonus' portion in Parameter Settings =>
 *   S Parameter => Formula.
 *
 * ---
 * 
 * === Battle Setting-Related Notetags ===
 * 
 * These tags will change the settings for battle regardless of how the battle
 * system is set up normally. Insert these tags in either the noteboxes of maps
 * or the names of troops for them to take effect. If both are present for a
 * specific battle, then priority goes to the setting found in the troop name.
 * 
 * ---
 * 
 * <FV>
 * <Front View>
 * <Battle View: FV>
 * <Battle View: Front View>
 * 
 * - Used for: Map Notetags, Troop Name Tags, and Troop Comment Tags
 * - Changes the perspective of battle to front view for this specific map or
 *   battle.
 * - Make sure you have the enemy image files available in the img/enemies/
 *   folder as they will used instead of the "sv_enemies" graphics.
 * - If using Troop Comment Tags, then as long as the tag appears in a comment
 *   found on any of the Troop's pages (even if they don't run), the tag will
 *   be considered in effect.
 * 
 * ---
 * 
 * <SV>
 * <Side View>
 * <Battle View: SV>
 * <Battle View: Side View>
 * 
 * - Used for: Map Notetags, Troop Name Tags, and Troop Comment Tags
 * - Changes the perspective of battle to side view for this specific map or
 *   battle.
 * - Make sure you have the enemy image files available in the img/sv_enemies/
 *   folder as they will used instead of the "enemies" graphics.
 * - Make sure your actors have "sv_actor" graphics attached to them.
 * - If using Troop Comment Tags, then as long as the tag appears in a comment
 *   found on any of the Troop's pages (even if they don't run), the tag will
 *   be considered in effect.
 * 
 * ---
 * 
 * <DTB>
 * <Battle System: DTB>
 * 
 * - Used for: Map Notetags, Troop Name Tags, and Troop Comment Tags
 * - Changes the battle system to the default battle system (DTB).
 * - If using Troop Comment Tags, then as long as the tag appears in a comment
 *   found on any of the Troop's pages (even if they don't run), the tag will
 *   be considered in effect.
 * 
 * ---
 * 
 * <TPB Active>
 * <ATB Active>
 * <Battle System: TPB Active>
 * <Battle System: ATB Active>
 * 
 * <TPB Wait>
 * <ATB Wait>
 * <Battle System: TPB Wait>
 * <Battle System: ATB Wait>
 * 
 * - Used for: Map Notetags, Troop Name Tags, and Troop Comment Tags
 * - Changes the battle system to the time progress battle system (TPB) or
 *   active turn battle system (ATB) if you have VisuMZ_2_BattleSystemATB
 *   installed for the game project.
 * - If using Troop Comment Tags, then as long as the tag appears in a comment
 *   found on any of the Troop's pages (even if they don't run), the tag will
 *   be considered in effect.
 * 
 * ---
 * 
 * <BTB>
 * <Battle System: BTB>
 * 
 * <CTB>
 * <Battle System: CTB>
 * 
 * <ETB>
 * <Battle System: ETB>
 * 
 * <FTB>
 * <Battle System: FTB>
 * 
 * <OTB>
 * <Battle System: OTB>
 * 
 * <PTB>
 * <Battle System: PTB>
 * 
 * <STB>
 * <Battle System: STB>
 * 
 * - Used for: Map Notetags, Troop Name Tags, and Troop Comment Tags
 * - Changes the battle system to the respective battle system as long as you
 *   have those plugins installed in the current project.
 * - If using Troop Comment Tags, then as long as the tag appears in a comment
 *   found on any of the Troop's pages (even if they don't run), the tag will
 *   be considered in effect.
 * 
 * ---
 *
 * ============================================================================
 * Plugin Commands
 * ============================================================================
 *
 * The following are Plugin Commands that come with this plugin. They can be
 * accessed through the Plugin Command event command.
 *
 * ---
 * 
 * === Animation Commands ===
 * 
 * ---
 * 
 * Animation: Play at Coordinate
 * - Plays an animation on the screen at a specific x, y coordinate even if
 *   there is no sprite attached.
 * 
 *   Animation ID:
 *   - Plays this animation.
 * 
 *   Coordinates:
 * 
 *     X:
 *     Y:
 *     - X/Y coordinate used for the animation.
 *       You may use JavaScript code.
 * 
 *   Mirror Animation?:
 *   - Mirror the animation?
 * 
 *   Mute Animation?:
 *   - Mute the animation?
 * 
 * ---
 * 
 * === Export Plugin Commands ===
 * 
 * ---
 * 
 * Export: All Maps Text
 * - PLAY TEST ONLY. Exports all of the text from all maps,
 *   their events, event pages, and any associated Common Events.
 * 
 *   - Exports 'Show Text' event commands.
 *   - Exports 'Show Choices' event commands.
 *   - Exports 'Show Scrolling Text' event commands.
 *   - Exports 'Comments' event commands.
 *   - Only the raw text will be exported.
 *   - Only usable during Play Test.
 * 
 * ---
 * 
 * Export: All Troops Text
 * - PLAY TEST ONLY. Exports all of the text from all troops,
 *   their event pages, and any associated Common Events.
 * 
 *   - Exports 'Show Text' event commands.
 *   - Exports 'Show Choices' event commands.
 *   - Exports 'Show Scrolling Text' event commands.
 *   - Exports 'Comments' event commands.
 *   - Only the raw text will be exported.
 *   - Only usable during Play Test.
 * 
 * ---
 * 
 * Export: Current Map Text
 * - PLAY TEST ONLY. Exports all of the text on the current map,
 *   its events, the event pages, and any associated Common Events.
 * 
 *   - Exports 'Show Text' event commands.
 *   - Exports 'Show Choices' event commands.
 *   - Exports 'Show Scrolling Text' event commands.
 *   - Exports 'Comments' event commands.
 *   - Only the raw text will be exported.
 *   - Only usable during Play Test.
 *   - If not in battle, this Plugin Command will not work.
 * 
 * ---
 * 
 * Export: Current Troop Text
 * - PLAY TEST ONLY. Exports all of the text on the current troop,
 *   the troop's event pages, and any associated Common Events.
 * 
 *   - Exports 'Show Text' event commands.
 *   - Exports 'Show Choices' event commands.
 *   - Exports 'Show Scrolling Text' event commands.
 *   - Exports 'Comments' event commands.
 *   - Only the raw text will be exported.
 *   - Only usable during Play Test.
 *   - If not in battle, this Plugin Command will not work.
 * 
 * ---
 * 
 * === Game Plugin Commands ===
 * 
 * ---
 *
 * Game: Open URL
 * - Opens a website URL from the game.
 *
 *   URL:
 *   - Where do you want to take the player?
 *
 * ---
 * 
 * === Gold Plugin Commands ===
 * 
 * ---
 *
 * Gold: Gain/Lose
 * - Allows you to give/take more gold than the event editor limit.
 *
 *   Value:
 *   - How much gold should the player gain/lose?
 *   - Use negative values to remove gold.
 *
 * ---
 * 
 * === Map Plugin Commands ===
 * 
 * ---
 * 
 * Map: Once Parallel
 * - Plays a Common Event parallel to the event once without repeating itself
 *   when done.
 * - Map only!
 * 
 *   Common Event ID:
 *   - The ID of the parallel Common Event to play.
 *   - Does NOT repeat itself when finished.
 *   - When exiting map scene or changing maps, all Once Parallels are cleared.
 *   - Once Parallels are not retained upon reentering the scene or map.
 *   - Once Parallels are not stored in memory and cannot be saved.
 * 
 * ---
 * 
 * === Picture Plugin Commands ===
 * 
 * ---
 * 
 * Picture: Coordinates Mode
 * - Play Test Mode only! Gets the coordinates of a specific picture as you
 *   move it across the screen.
 * 
 *   Picture ID: 
 *   - The ID of the pictures to track the coordinates of.
 * 
 * ---
 *
 * Picture: Easing Type
 * - Changes the easing type to a number of options.
 *
 *   Picture ID:
 *   - Which picture do you wish to apply this easing to?
 *
 *   Easing Type:
 *   - Select which easing type you wish to apply.
 *
 *   Instructions:
 *   - Insert this Plugin Command after a "Move Picture" event command.
 *   - Turn off "Wait for Completion" in the "Move Picture" event.
 *   - You may have to add in your own "Wait" event command after.
 *
 * ---
 * 
 * Picture: Erase All
 * - Erases all pictures on the screen because it's extremely tedious to do it
 *   one by one.
 * 
 * ---
 * 
 * Picture: Erase Range
 * - Erases all pictures within a range of numbers because it's extremely
 *   tedious to do it one by one.
 * 
 *   Starting ID:
 *   - The starting ID of the pictures to erase.
 * 
 *   Ending ID:
 *   - The ending ID of the pictures to erase.
 * 
 * ---
 * 
 * Picture: Show Icon
 * - Shows an icon instead of a picture image.
 * - The picture icon can be controlled like any other picture.
 * 
 *   General:
 *
 *     Picture ID Number:
 *     - What is the ID of the picture you wish to show at?
 *     - Use a number between 1 and 100.
 *     - You may use JavaScript code.
 *
 *     Icon Index:
 *     - Select the icon index to use for this picture.
 *     - You may use JavaScript code.
 *
 *     Smooth Icon?:
 *     - This will make the icon smoothed out or pixelated.
 * 
 *   Picture Settings:
 * 
 *     Position:
 *
 *       Origin:
 *       - What is the origin of this picture icon?
 *         - Upper Left
 *         - Center
 *
 *       Position X:
 *       - X coordinate of the picture.
 *       - You may use JavaScript code.
 *
 *       Position Y:
 *       - Y coordinate of the picture.
 *       - You may use JavaScript code.
 * 
 *     Scale:
 *
 *       Width %:
 *       - Horizontal scale of the picture.
 *       - You may use JavaScript code.
 *       - 100 is 100%
 *
 *       Height %:
 *       - Vertical scale of the picture.
 *       - You may use JavaScript code.
 *       - 100 is 100%
 * 
 *     Blend:
 *
 *       Opacity:
 *       - Insert a number to determine opacity level.
 *       - Use a number between 0 and 255.
 *       - You may use JavaScript code.
 *
 *       Blend Mode:
 *       - What kind of blend mode do you wish to apply to the picture?
 * 
 * ---
 * 
 * === Screen Shake Plugin Commands ===
 * 
 * ---
 * 
 * Screen Shake: Custom:
 * - Creates a custom screen shake effect and also sets the following uses of
 *   screen shake to this style.
 * 
 *   Shake Style:
 *   - Select shake style type.
 *   - Original
 *   - Random
 *   - Horizontal
 *   - Vertical
 * 
 *   Power:
 *   - Power level for screen shake.
 * 
 *   Speed:
 *   - Speed level for screen shake.
 * 
 *   Duration:
 *   - Duration of screenshake.
 *   - You can use code as well.
 * 
 *   Wait for Completion:
 *   - Wait until completion before moving onto the next event?
 * 
 * ---
 * 
 * === Switch Plugin Commands ===
 * 
 * ---
 * 
 * Switches: Randomize ID(s)
 * - Select specific Switch ID's to randomize ON/OFF.
 * 
 *   Switch ID(s):
 *   - Select which Switch ID(s) to toggle.
 * 
 *   Chance for ON:
 *   - Chance out of 100 that determines the switches to be ON.
 * 
 * ---
 *
 * Switches: Randomize Range
 * - Select specific Switch ID Range to randomize ON/OFF.
 * - The ratio determines the ON/OFF distribution.
 *
 *   Starting ID:
 *   - The starting ID of the Switch to toggle.
 *
 *   Ending ID:
 *   - The ending ID of the Switch to toggle.
 *
 *   Chance for ON:
 *   - Chance out of 100 that determines the switches to be ON.
 *
 * ---
 *
 * Switches: Toggle ID(s)
 * - Select specific Switch ID's to toggle ON/OFF.
 * - ON becomes OFF. OFF becomes ON.
 *
 *   Switch ID(s):
 *   - Select which Switch ID(s) to toggle.
 *
 * ---
 *
 * Switches: Toggle Range
 * - Select specific Switch ID Range to toggle ON/OFF.
 * - ON becomes OFF. OFF becomes ON.
 *
 *   Starting ID:
 *   - The starting ID of the Switch to toggle.
 *
 *   Ending ID:
 *   - The ending ID of the Switch to toggle.
 *
 * ---
 * 
 * === System Plugin Commands ===
 * 
 * ---
 *
 * System: Battle System Change
 * - Switch to a different battle system in-game.
 * - Some battle systems REQUIRE their specific plugins!
 *
 *   Change To:
 *   - Choose which battle system to switch to.
 *     - Database Default (Use game database setting)
 *     - -
 *     - DTB: Default Turn Battle
 *     - TPB Active: Time Progress Battle (Active)
 *     - TPB Wait: Time Progress Battle (Wait)
 *     - -
 *     - BTB: Brave Turn Battle (Req VisuMZ_2_BattleSystemBTB)
 *     - CTB: Charge Turn Battle (Req VisuMZ_2_BattleSystemCTB)
 *     - OTB: Order Turn Battle (Req VisuMZ_2_BattleSystemOTB)
 *     - STB: Standard Turn Battle (Req VisuMZ_2_BattleSystemSTB)
 *
 * ---
 * 
 * System: Load Images
 * - Allows you to (pre) load up images ahead of time.
 *
 *   img/animations/:
 *   img/battlebacks1/:
 *   img/battlebacks2/:
 *   img/enemies/:
 *   img/faces/:
 *   img/parallaxes/:
 *   img/pictures/:
 *   img/sv_actors/:
 *   img/sv_enemies/:
 *   img/system/:
 *   img/tilesets/:
 *   img/titles1/:
 *   img/titles2/:
 *   - Which files do you wish to load from this directory?
 * 
 * ---
 *
 * System: Main Font Size
 * - Set the game's main font size.
 *
 *   Change To:
 *   - Change the font size to this number.
 *
 * ---
 *
 * System: Side View Battle
 * - Switch between Front View or Side View for battle.
 *
 *   Change To:
 *   - Choose which view type to switch to.
 *
 * ---
 *
 * System: Window Padding
 * - Change the game's window padding amount.
 *
 *   Change To:
 *   - Change the game's standard window padding to this value.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Quality of Life Settings
 * ============================================================================
 *
 * A variety of (optional) settings and changes are added with the Core Engine
 * to improve the quality of life for both the game devs and players alike.
 *
 * ---
 *
 * Play Test
 * 
 *   New Game on Boot:
 *   - Automatically start a new game on Play Test?
 *   - Only enabled during Play Test.
 *
 *   No Play Test Mode:
 *   - Force the game to be out of Play Test mode when play testing.
 * 
 *   Open Console on Boot:
 *   - Open the Debug Console upon booting up your game?
 *   - Only enabled during Play Test.
 *
 *   F6: Toggle Sound:
 *   - F6 Key Function: Turn on all sound to 100% or to 0%, toggling between
 *     the two.
 *   - Only enabled during Play Test.
 *
 *   F7: Toggle Fast Mode:
 *   - F7 Key Function: Toggle fast mode.
 *   - Only enabled during Play Test.
 *
 *   New Game > Common Event:
 *   - Runs a common event each time a new game is started.
 *   - Only enabled during Play Test.
 *
 * ---
 * 
 * Battle Test
 * 
 *   Add Item Type:
 *   Add Weapon Type:
 *   Add Armor Type:
 *   - Add copies of each database item, weapon, and/or armor?
 *   - Effective only during battle test.
 * 
 *   Added Quantity:
 *   - Determines how many items are added during a battle test instead of
 *     the maximum amount.
 * 
 * ---
 *
 * Digit Grouping
 *
 *   Standard Text:
 *   - Make numbers like 1234567 appear like 1,234,567 for standard text
 *     inside windows?
 *
 *   Ex Text:
 *   - Make numbers like 1234567 appear like 1,234,567 for ex text,
 *     written through drawTextEx (like messages)?
 *
 *   Damage Sprites:
 *   - Make numbers like 1234567 appear like 1,234,567 for in-battle
 *     damage sprites?
 *
 *   Gauge Sprites:
 *   - Make numbers like 1234567 appear like 1,234,567 for visible gauge
 *     sprites such as HP, MP, and TP gauges?
 * 
 *   Country/Locale
 *   - Base the digit grouping on which country/locale?
 *   - This will follow all of the digit grouping rules found here:
 *     https://www.w3schools.com/JSREF/jsref_tolocalestring_number.asp
 *
 * ---
 *
 * Player Benefit
 *
 *   Encounter Rate Min:
 *   - Minimum number of steps the player can take without any
 *     random encounters.
 *
 *   Escape Always:
 *   - If the player wants to escape a battle, let them escape the battle
 *     with 100% chance.
 *
 *   Accuracy Formula:
 *   - Accuracy formula calculation change to
 *     Skill Hit% * (User HIT - Target EVA) for better results.
 *
 *   Accuracy Boost:
 *   - Boost HIT and EVA rates in favor of the player.
 *
 *   Level Up -> Full HP:
 *   Level Up -> Full MP:
 *   - Recovers full HP or MP when an actor levels up.
 *
 * ---
 * 
 * Picture-Related
 * 
 *   Anti-Zoom Pictures:
 *   - If on, prevents pictures from being affected by zoom.
 * 
 *   Picture Containers > Detach in Battle:
 *   - If detached, picture container will be separated from the spriteset
 *     while on the battle scene.
 *   - This will prevent any visual effects that alter the entire spriteset
 *     from affecting the detached picture container.
 * 
 *   Picture Containers > Detach in Map:
 *   - If detached, picture container will be separated from the spriteset
 *     while on the map scene.
 *   - This will prevent any visual effects that alter the entire spriteset
 *     from affecting the detached picture container.
 * 
 * ---
 *
 * Misc
 * 
 *   Animation: Mirror Offset X:
 *   - When animations are mirrored, mirror their Offset X values, too.
 *   - The animation name tags <Mirror Offset X> and <No Mirror Offset X> will
 *     override this effect for that specific animation.
 *
 *   Font Shadows:
 *   - If on, text uses shadows instead of outlines.
 *
 *   Font Smoothing:
 *   - If on, smoothes fonts shown in-game.
 * 
 *   Font Width Fix:
 *   - Fixes the font width issue with instant display non-monospaced fonts
 *     in the Message Window.
 *
 *   Key Item Protection:
 *   - If on, prevents Key Items from being able to be sold and from being
 *     able to be consumed.
 *
 *   Modern Controls:
 *   - If on, allows usage of the Home/End buttons.
 *   - Home would scroll to the first item on a list.
 *   - End would scroll to the last item on a list.
 *   - Shift + Up would page up.
 *   - Shift + Down would page down.
 *
 *   MV Animation Rate:
 *   - Adjusts the rate at which MV animations play.
 *   - Default: 4.
 *   - Lower for faster.
 *   - Higher for slower.
 * 
 *   NewGame > CommonEvent:
 *   - Runs a common event each time a new game during any session is started.
 *   - Applies to all types of sessions, play test or not.
 *
 *   No Tile Shadows:
 *   - Removes tile shadows from being displayed in-game.
 *
 *   Pixel Image Rendering:
 *   - If on, pixelates the image rendering (for pixel games).
 *
 *   Require Focus?
 *   - Requires the game to be focused? If the game isn't focused, it will
 *     pause if it's not the active window.
 * 
 *   Shortcut Scripts:
 *   - Enables shortcut-based script variables and functions that can be used
 *     for script calls.
 *   - Shortcut list enabled for this is as follows:
 * 
 *     $commonEvent(id)
 *     - Queues a common event.
 *     - This does not interrupt the current event to run the desired common
 *       event. Any queued common events will run after the current event list
 *       has finished.
 *     - Replace 'id' with the ID of the common event you wish to queue.
 *     - Common events only run in the map scene and battle scene.
 * 
 *     $onceParallel(id)
 *     - Runs a common event in the background as a once parallel event.
 *     - Once parallel events will run in the background like a parallel
 *       process, except that it does not repeat after finishing.
 *     - Replace 'id' with the ID of the common event you wish to run.
 *     - Only works in the map scene and battle scene. Battle scene usage will
 *       require VisuMZ_1_BattleCore.
 * 
 *     $scene
 *     - Returns current scene.
 * 
 *     $spriteset
 *     - Returns current scene's spriteset if there is one.
 * 
 *     $subject
 *     - Returns last recorded identity of the battle's subject/user.
 * 
 *     $targets
 *     - Returns last recorded targets marked in battle.
 * 
 *     $target
 *     - Returns last recorded target marked in battle.
 *     - Works better with VisuMZ_1_BattleCore.
 * 
 *     $event
 *     - Returns currently initiated map event.
 *
 *   Smart Event Collision:
 *   - Makes events only able to collide with one another if they're
 *    'Same as characters' priority.
 * 
 *   Subfolder Name Purge:
 *   - Purge subfolder name from Plugin Parameters when reading data to let
 *     Plugin Commands work properly.
 *   - This is for plugins (such as the VisuMZ library) that utilize dynamic
 *     name registrations for Plugin Commands. Turn this on if you plan on
 *     using subfolders with VisuMZ plugins.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Battle System
 * ============================================================================
 * 
 * Choose which battle system to use for your game.
 * 
 * Some battle systems REQUIRE their specific plugins! This means if you do not
 * have the required battle system plugin installed, it will not change over.
 * The Core Engine plugin does not contain data for all of the battle systems
 * inside its code.
 * 
 * ---
 * 
 *   Database Default (Use game database setting)
 * 
 *   -
 * 
 *   DTB: Default Turn Battle
 *   TPB Active: Time Progress Battle (Active)
 *   TPB Wait: Time Progress Battle (Wait)
 * 
 *   -
 * 
 *   BTB: Brave Turn Battle (Req VisuMZ_2_BattleSystemBTB)
 *   CTB: Charge Turn Battle (Req VisuMZ_2_BattleSystemCTB)
 *   ETB: Energy Turn Battle (Req VisuMZ_2_BattleSystemETB)
 *   FTB: Free Turn Battle (Req VisuMZ_2_BattleSystemFTB)
 *   OTB: Order Turn Battle (Req VisuMZ_2_BattleSystemOTB)
 *   PTB: Press Turn Battle (Req VisuMZ_2_BattleSystemPTB)
 *   STB: Standard Turn Battle (Req VisuMZ_2_BattleSystemSTB)
 * 
 *   -
 * 
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Color Settings
 * ============================================================================
 *
 * These settings allow you, the game dev, to have more control over which
 * colors appear for what conditions found in the game. You can use regular
 * numbers to use the colors predetermined by the game's Window Skin or you
 * can use the #rrggbb format for a hex color code.
 * 
 * If the game's Window Skin is changed mid-game, the colors used will still be
 * based off the default Window Skin's colors. This is due to storing them in a
 * cache and preventing extra processing and reduces lag.
 *
 * You can find out what hex codes belong to which color from this website:
 * https://htmlcolorcodes.com/
 *
 * ---
 *
 * Basic Colors
 * - These are colors that almost never change and are used globally throughout
 *   the in-game engine.
 *
 *   Normal:
 *   System:
 *   Crisis:
 *   Death:
 *   Gauge Back:
 *   HP Gauge:
 *   MP Gauge:
 *   MP Cost:
 *   Power Up:
 *   Power Down:
 *   CT Gauge:
 *   TP Gauge:
 *   Pending Color:
 *   EXP Gauge:
 *   MaxLv Gauge:
 *   - Use #rrggbb for custom colors or regular numbers
 *   for text colors from the Window Skin.
 *
 * ---
 *
 * Alpha Colors:
 * - These are colors that have a bit of transparency to them and are specified
 *   by the 'rgba(red, green, blue, alpha)' format.
 * - Replace 'red' with a number between 0-255 (integer).
 * - Replace 'green' with a number between 0-255 (integer).
 * - Replace 'blue' with a number between 0-255 (integer).
 * - Replace 'alpha' with a number between 0 and 1 (decimal).
 * 
 *   Window Font Outline:
 *   Gauge Number Outline:
 *   Dim Color:
 *   Item Back Color:
 *   - Colors with a bit of alpha settings.
 *   - Format rgba(0-255, 0-255, 0-255, 0-1)
 *
 * ---
 *
 * Conditional Colors:
 * - These require a bit of JavaScript knowledge. These determine what colors
 *   to use under which situations and uses such as different values of HP, MP,
 *   TP, for comparing equipment, and determine damage popup colors.
 * 
 *   JS: Actor HP Color:
 *   JS: Actor MP Color:
 *   JS: Actor TP Color:
 *   - Code used for determining what HP, MP, or TP color to use for actors.
 *
 *   JS: Parameter Change:
 *   - Code used for determining whatcolor to use for parameter changes.
 *
 *   JS: Damage Colors:
 *   - Code used for determining what color to use for damage types.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Gold Settings
 * ============================================================================
 *
 * Gold is the main currency in RPG Maker MZ. The settings provided here will
 * determine how Gold appears in the game and certain behaviors Gold has.
 *
 * ---
 *
 * Gold Settings
 *
 *   Gold Max:
 *   - Maximum amount of Gold the party can hold.
 *   - Default 99999999
 *
 *   Gold Font Size:
 *   - Font size used for displaying Gold inside Gold Windows.
 *   - Default: 26
 *
 *   Gold Icon:
 *   - Icon used to represent Gold.
 *   - Use 0 for no icon.
 *
 *   Gold Overlap:
 *   - Text used too much Gold to fit in the window.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Image Loading
 * ============================================================================
 *
 * Not all images are loaded at once in-game. RPG Maker MZ uses asynchronous
 * loading which means images are loaded when needed. This may cause delays in
 * when you want certain images to appear. However, if an image is loaded
 * beforehand, they can be used immediately provided they aren't removed from
 * the image cache.
 *
 * ---
 *
 * Image Loading
 *
 *   img/animations/:
 *   img/battlebacks1/:
 *   img/battlebacks2/:
 *   img/enemies/:
 *   img/faces/:
 *   img/parallaxes/:
 *   img/pictures/:
 *   img/sv_actors/:
 *   img/sv_enemies/:
 *   img/system/:
 *   img/tilesets/:
 *   img/titles1/:
 *   img/titles2/:
 *   - Which files do you wish to load from this directory upon starting
 *     up the game?
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Keyboard Input Settings
 * ============================================================================
 *
 * Settings for the game that utilize keyboard input. These are primarily for
 * the name input scene (Scene_Name) and the number input event command. These
 * settings have only been tested on English keyboards and may or may not be
 * compatible with other languages, so please disable these features if they do
 * not fit in with your game.
 * 
 * If a controller is connected upon entering the name change scene, it will
 * use the default manual-entry mode instead of the keyboard-entry mode. If a
 * controller button is pressed during the keyboard-entry mode, it will
 * automatically switch to the manual-entry mode.
 * 
 * This plugin does not provide support for controllers that are undetected by
 * RPG Maker MZ's default controller support.
 *
 * ---
 * 
 * Controls
 * 
 *   WASD Movement:
 *   - Enables or disables WASD movement for your game project.
 *   - Moves the W page down button to E.
 * 
 *   R Button: Dash Toggle:
 *   - Enables or disables R button as an Always Dash option toggle.
 * 
 * ---
 *
 * Name Input
 * 
 *   Enable?:
 *   - Enables keyboard input for name entry.
 *   - Only tested with English keyboards.
 * 
 *   Default Mode:
 *   - Select default mode when entering the scene.
 *     - Default - Uses Arrow Keys to select letters.
 *     - Keyboard - Uses Keyboard to type in letters.
 * 
 *   QWERTY Layout:
 *   - Uses the QWERTY layout for manual entry.
 * 
 *   Keyboard Message:
 *   - The message displayed when allowing keyboard entry.
 *   - You may use text codes here.
 * 
 *   Banned Words:
 *   - Players cannot use these words for names.
 *   - These include words inside the names.
 *   - If a banned word is used, a buzzer sound will play.
 *
 * ---
 *
 * Number Input
 * 
 *   Enable?:
 *   - Enables keyboard input for number entry.
 *   - Only tested with English keyboards.
 *
 * ---
 * 
 * Button Assist
 * 
 *   Switch to Keyboard:
 *   - Text used to describe the keyboard switch.
 * 
 *   Switch To Manual:
 *   - Text used to describe the manual entry switch.
 * 
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Menu Background Settings
 * ============================================================================
 *
 * These settings in the Plugin Parameters allow you to adjust the background
 * images used for each of the scenes. The images will be taken from the game
 * project folders img/titles1/ and img/titles2/ to load into the game.
 *
 * These settings are only available to scenes found within the Main Menu, the
 * Shop scene, and the Actor Naming scene.
 *
 * ---
 *
 * Menu Background Settings:
 *
 *   Scene_Menu:
 *   Scene_Item:
 *   Scene_Skill:
 *   Scene_Equip:
 *   Scene_Status:
 *   Scene_Options:
 *   Scene_Save:
 *   Scene_Load:
 *   Scene_GameEnd:
 *   Scene_Shop:
 *   Scene_Name:
 *   - Individual background settings for the scene.
 *
 *   Scene_Unlisted
 *   - Individual background settings for any scenes that aren't listed above.
 *
 * ---
 *
 * Background Settings
 *
 *   Snapshop Opacity:
 *   - Snapshot opacity for the scene.
 *
 *   Background 1:
 *   - Filename used for the bottom background image.
 *   - Leave empty if you don't wish to use one.
 *
 *   Background 2:
 *   - Filename used for the upper background image.
 *   - Leave empty if you don't wish to use one.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Menu Button Assist Window
 * ============================================================================
 *
 * In most modern RPG's, there exist small windows on the screen which tell the
 * player what the control schemes are for that scene. This plugin gives you
 * the option to add that window to the menu scenes in the form of a Button
 * Assist Window.
 *
 * ---
 *
 * General
 * 
 *   Enable:
 *   - Enable the Menu Button Assist Window.
 * 
 *   Location:
 *   - Determine the location of the Button Assist Window.
 *   - Requires Plugin Parameters => UI => Side Buttons ON.
 *
 *   Background Type:
 *   - Select background type for this window.
 *
 * ---
 *
 * Text
 * 
 *   Text Format:
 *   - Format on how the buttons are displayed.
 *   - Text codes allowed. %1 - Key, %2 - Text
 * 
 *   Multi-Key Format:
 *   - Format for actions with multiple keys.
 *   - Text codes allowed. %1 - Key 1, %2 - Key 2
 * 
 *   OK Text:
 *   Cancel Text:
 *   Switch Actor Text:
 *   - Default text used to display these various actions.
 *
 * ---
 *
 * Keys
 * 
 *   Key: Unlisted Format:
 *   - If a key is not listed below, use this format.
 *   - Text codes allowed. %1 - Key
 * 
 *   Key: Up:
 *   Key: Down:
 *   Key: Left:
 *   Key: Right:
 *   Key: Shift:
 *   Key: Tab:
 *   Key: A through Z:
 *   - How this key is shown in-game.
 *   - Text codes allowed.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Menu Layout Settings
 * ============================================================================
 *
 * These settings allow you to rearrange the positions of the scenes accessible
 * from the Main Menu, the Shop scene, and the Actor Naming scene. This will
 * require you to have some JavaScript knowledge to make the windows work the
 * way you would like.
 *
 * ---
 *
 * Menu Layout Settings
 *
 *   Scene_Title:
 *   Scene_Menu:
 *   Scene_Item:
 *   Scene_Skill:
 *   Scene_Equip:
 *   Scene_Status:
 *   Scene_Options:
 *   Scene_Save:
 *   Scene_Load:
 *   Scene_GameEnd:
 *   Scene_Shop:
 *   Scene_Name:
 *   - Various options on adjusting the selected scene.
 *
 * ---
 *
 * Scene Window Settings
 *
 *   Background Type:
 *   - Selects the background type for the selected window.
 *   - Window
 *   - Dim
 *   - Transparent
 *
 *   JS: X, Y, W, H
 *   - Code used to determine the dimensions for the selected window.
 *
 * ---
 *
 * Scene_Title Settings
 * - The following are settings unique to Scene_Title.
 *
 * Title Screen
 *
 *   Document Title Format:
 *   - Format to display text in document title.
 *   - %1 - Main Title, %2 - Subtitle, %3 - Version
 *
 *   Subtitle:
 *   - Subtitle to be displayed under the title name.
 *   
 *   Version:
 *   - Version to be display in the title screen corner.
 *   
 *   JS: Draw Title:
 *   - Code used to draw the game title.
 *   
 *   JS: Draw Subtitle:
 *   - Code used to draw the game subtitle.
 *   
 *   JS: Draw Version:
 *   - Code used to draw the game version.
 *   
 *   Button Fade Speed:
 *   - Speed at which the buttons fade in at (1-255).
 *
 * ---
 *
 * Scene_GameEnd Settings
 * - The following are settings unique to Scene_GameEnd.
 *   
 *   Command Window List:
 *   - Window commands used by the title screen.
 *   - Add new commands here.
 *
 * ---
 *
 * Command Window List
 * - This is found under Scene_Title and Scene_GameEnd settings.
 *
 *   Symbol:
 *   - The symbol used for this command.
 * 
 *   STR: Text:
 *   - Displayed text used for this title command.
 *   - If this has a value, ignore the JS: Text version.
 * 
 *   JS: Text:
 *   - JavaScript code used to determine string used for the displayed name.
 * 
 *   JS: Show:
 *   - JavaScript code used to determine if the item is shown or not.
 * 
 *   JS: Enable:
 *   - JavaScript code used to determine if the item is enabled or not.
 * 
 *   JS: Ext:
 *   - JavaScript code used to determine any ext data that should be added.
 * 
 *   JS: Run Code:
 *   - JavaScript code that runs once this command is selected.
 * 
 * ---
 *
 * Title Picture Buttons:
 * - This is found under Scene_Title settings.
 * 
 *   Picture's Filename:
 *   - Filename used for the picture.
 *
 *   Button URL:
 *   - URL for the button to go to upon being clicked.
 *
 *   JS: Position:
 *   - JavaScript code that helps determine the button's Position.
 *
 *   JS: On Load:
 *   - JavaScript code that runs once this button bitmap is loaded.
 *
 *   JS: Run Code:
 *   - JavaScript code that runs once this button is pressed.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Parameter Settings
 * ============================================================================
 *
 * A battler's parameters, or stats as some devs know them as, are the values
 * that determine how a battler performs. These settings allow you to alter
 * their behaviors and give boosts to trait objects in a controlled manner.
 *
 * ---
 *
 * Parameter Settings
 *
 *   Displayed Parameters
 *   - A list of the parameters that will be displayed in-game.
 *   - Shown in the Equip Menu.
 *   - Shown in the Status Menu.
 *
 *   Extended Parameters
 *   - The list shown in extended scenes (for other VisuStella plugins).
 *
 * ---
 *
 * === Basic Parameters ===
 *
 * MHP - MaxHP
 * - This is the maximum health points value. The amount of health points (HP)
 * a battler has determines whether or not the battler is in a living state or
 * a dead state. If the HP value is above 0, then the battler is living. If it
 * is 0 or below, the battler is in a dead state unless the battler has a way
 * to counteract death (usually through immortality). When the battler takes
 * damage, it is usually dealt to the HP value and reduces it. If the battler
 * is healed, then the HP value is increased. The MaxHP value determines what's
 * the maximum amount the HP value can be held at, meaning the battler cannot
 * be healed past that point.
 *
 * MMP - MaxMP
 * - This is the maximum magic points value. Magic points (MP) are typically
 * used for the cost of skills and spells in battle. If the battler has enough
 * MP to fit the cost of the said skill, the battler is able to use the said
 * skill provided that all of the skill's other conditions are met. If not, the
 * battler is then unable to use the skill. Upon using a skill that costs MP,
 * the battler's MP is reduced. However, the battler's MP can be recovered and
 * results in a gain of MP. The MaxMP value determines what is the maximum
 * amount the MP value can be held at, meaning the battler cannot recover MP
 * past the MaxMP value.
 *
 * ATK - Attack
 * - This is the attack value of the battler. By default, this stat is used for
 * the purpose of damage calculations only, and is typically used to represent
 * the battler's physical attack power. Given normal damage formulas, higher
 * values mean higher damage output for physical attacks.
 *
 * DEF - Defense
 * - This is the defense value of the battler. By default, this stat is used
 * for the purpose of damage calculations only, and is typically used to
 * represent the battler's physical defense. Given normal damage formulas,
 * higher values mean less damage received from physical attacks.
 *
 * MAT - Magic Attack
 * - This is the magic attack value of the battler. By default, this stat is
 * used for the purpose of damage calculations only, and is typically used to
 * represent the battler's magical attack power. Given normal damage formulas,
 * higher values mean higher damage output for magical attacks.
 *
 * MDF - Magic Defense
 * - This is the magic defense value of the battler. By default, this stat is
 * used for the purpose of damage calculations only, and is typically used to
 * represent the battler's magical defense. Given normal damage formulas,
 * higher values mean less damage received from magical attacks.
 *
 * AGI - Agility
 * - This is the agility value of the battler. By default, this stat is used to
 * determine battler's position in the battle turn's order. Given a normal turn
 * calculation formula, the higher the value, the faster the battler is, and
 * the more likely the battler will have its turn earlier in a turn.
 *
 * LUK - Luck
 * - This is the luck value of the battler. By default, this stat is used to
 * affect the success rate of states, buffs, and debuffs applied by the battler
 * and received by the battler. If the user has a higher LUK value, the state,
 * buff, or debuff is more likely to succeed. If the target has a higher LUK
 * value, then the state, buff, or debuff is less likely to succeed.
 *
 * ---
 *
 * Basic Parameters
 *
 *   HP Crisis Rate:
 *   - HP Ratio at which a battler can be considered in crisis mode.
 *
 *   JS: Formula:
 *   - Formula used to determine the total value all 8 basic parameters:
 *   - MaxHP, MaxMP, ATK, DEF, MAT, MDF, AGI, LUK.
 *
 * Parameter Caps:
 *
 *   MaxHP Cap:
 *   MaxMP Cap:
 *   ATK Cap:
 *   DEF Cap:
 *   MAT Cap:
 *   MDF Cap:
 *   AGI Cap:
 *   LUK Cap:
 *   - Formula used to determine the selected parameter's cap.
 *   - These settings DO NOT raise the editor's maximum values. If you want to
 *     raise an enemy's maximum parameter value past their default cap, use the
 *     associated notetag for them instead.
 *
 * ---
 *
 * === X Parameters ===
 *
 * HIT - Hit Rate%
 * - This determines the physical hit success rate of the any physical action.
 * All physical attacks make a check through the HIT rate to see if the attack
 * will connect. If the HIT value passes the randomizer check, the attack will
 * connect. If the HIT value fails to pass the randomizer check, the attack
 * will be considered a MISS.
 *
 * EVA - Evasion Rate%
 * - This determines the physical evasion rate against any incoming physical
 * actions. If the HIT value passes, the action is then passed to the EVA check
 * through a randomizer check. If the randomizer check passes, the physical
 * attack is evaded and will fail to connect. If the randomizer check passes,
 * the attempt to evade the action will fail and the action connects.
 *
 * CRI - Critical Hit Rate%
 * - Any actions that enable Critical Hits will make a randomizer check with
 * this number. If the randomizer check passes, extra damage will be carried
 * out by the initiated action. If the randomizer check fails, no extra damage
 * will be added upon the action.
 *
 * CEV - Critical Evasion Rate%
 * - This value is put against the Critical Hit Rate% in a multiplicative rate.
 * If the Critical Hit Rate is 90% and the Critical Evasion Rate is
 * 20%, then the randomizer check will make a check against 72% as the values
 * are calculated by the source code as CRI * (1 - CEV), therefore, with values
 * as 0.90 * (1 - 0.20) === 0.72.
 *
 * MEV - Magic Evasion Rate%
 * - Where EVA is the evasion rate against physical actions, MEV is the evasion
 * rate against magical actions. As there is not magical version of HIT, the
 * MEV value will always be bit against when a magical action is initiated. If
 * the randomizer check passes for MEV, the magical action will not connect. If
 * the randomizer check fails for MEV, the magical action will connect.
 *
 * MRF - Magic Reflect Rate%
 * - If a magical action connects and passes, there is a chance the magical
 * action can be bounced back to the caster. That chance is the Magic Reflect
 * Rate. If the randomizer check for the Magic Reflect Rate passes, then the
 * magical action is bounced back to the caster, ignoring the caster's Magic
 * Evasion Rate. If the randomizer check for the Magic Reflect Rate fails, then
 * the magical action will connect with its target.
 *
 * CNT - Counter Attack Rate%
 * - If a physical action connects and passes, there is a chance the physical
 * action can be avoided and a counter attack made by the user will land on the
 * attacking unit. This is the Counter Attack Rate. If the randomizer check for
 * the Counter Attack Rate passes, the physical action is evaded and the target
 * will counter attack the user. If the randomizer check fails, the physical
 * action will connect to the target.
 *
 * HRG - HP% Regeneration
 * - During a battler's regeneration phase, the battler will regenerate this
 * percentage of its MaxHP as gained HP with a 100% success rate.
 *
 * MRG - MP% Regeneration
 * - During a battler's regeneration phase, the battler will regenerate this
 * percentage of its MaxMP as gained MP with a 100% success rate.
 *
 * TRG - TP% Regeneration
 * - During a battler's regeneration phase, the battler will regenerate this
 * percentage of its MaxTP as gained TP with a 100% success rate.
 *
 * ---
 *
 * X Parameters
 *
 *   JS: Formula:
 *   - Formula used to determine the total value all 10 X parameters:
 *   - HIT, EVA, CRI, CEV, MEV, MRF, CNT, HRG, MRG, TRG.
 *
 * Vocabulary
 *
 *   HIT:
 *   EVA:
 *   CRI:
 *   CEV:
 *   MEV:
 *   MRF:
 *   CNT:
 *   HRG:
 *   MRG:
 *   TRG:
 *   - In-game vocabulary used for the selected X Parameter.
 *
 * ---
 *
 * === S Parameters ===
 *
 * TGR - Target Rate
 * - Against the standard enemy, the Target Rate value determines the odds of
 * an enemy specifically targeting the user for a single target attack. At 0%,
 * the enemy will almost never target the user. At 100%, it will have normal
 * targeting opportunity. At 100%+, the user will have an increased chance of
 * being targeted.
 * *NOTE: For those using the Battle A.I. Core, any actions that have specific
 * target conditions will bypass the TGR rate.
 *
 * GRD - Guard Effect
 * - This is the effectiveness of guarding. This affects the guard divisor
 * value of 2. At 100% GRD, damage will become 'damage / (2 * 1.00)'. At 50%
 * GRD, damage will become 'damage / (2 * 0.50)'. At 200% GRD, damage will
 * become 'damage / (2 * 2.00)' and so forth.
 *
 * REC - Recovery Effect
 * - This is how effective heals are towards the user. The higher the REC rate,
 * the more the user is healed. If a spell were to heal for 100 and the user
 * has 300% REC, then the user is healed for 300 instead.
 *
 * PHA - Pharmacology
 * - This is how effective items are when used by the user. The higher the PHA
 * rate, the more effective the item effect. If the user is using a Potion that
 * recovers 100% on a target ally and the user has 300% PHA, then the target
 * ally will receive healing for 300 instead.
 *
 * MCR - MP Cost Rate
 * - This rate affects how much MP skills with an MP Cost will require to use.
 * If the user has 100% MCR, then the MP Cost will be standard. If the user has
 * 50% MCR, then all skills that cost MP will cost only half the required MP.
 * If the user has 200% MCR, then all skills will cost 200% their MP cost.
 *
 * TCR - TP Charge Rate
 * - This rate affects how much TP skills with an TP will charge when gaining
 * TP through various actions. At 100%, TP will charge normally. At 50%, TP
 * will charge at half speed. At 200%, TP will charge twice as fast.
 *
 * PDR - Physical Damage Rate
 * - This rate affects how much damage the user will take from physical damage.
 * If the user has 100% PDR, then the user takes the normal amount. If the user
 * has 50% PDR, then all physical damage dealt to the user is halved. If the
 * user has 200% PDR, then all physical damage dealt to the user is doubled.
 *
 * MDR - Magical Damage Rate
 * - This rate affects how much damage the user will take from magical damage.
 * If the user has 100% MDR, then the user takes the normal amount. If the user
 * has 50% MDR, then all magical damage dealt to the user is halved. If the
 * user has 200% MDR, then all magical damage dealt to the user is doubled.
 *
 * FDR - Floor Damage Rate
 * - On the field map, this alters how much damage the user will take when the
 * player walks over a tile that damages the party. The FDR value only affects
 * the damage dealt to the particular actor and not the whole party. If FDR is
 * at 100%, then the user takes the full damage. If FDR is at 50%, then only
 * half of the damage goes through. If FDR is at 200%, then floor damage is
 * doubled for that actor.
 *
 * EXR - Experience Rate
 * - This determines the amount of experience gain the user whenever the user
 * gains any kind of EXP. At 100% EXR, the rate of experience gain is normal.
 * At 50%, the experience gain is halved. At 200%, the experience gain for the
 * user is doubled.
 *
 * ---
 *
 * S Parameters
 *
 *   JS: Formula
 *   - Formula used to determine the total value all 10 S parameters:
 *   - TGR, GRD, REC, PHA, MCR, TCR, PDR, MDR, FDR, EXR.
 *
 * Vocabulary
 *
 *   TGR:
 *   GRD:
 *   REC:
 *   PHA:
 *   MCR:
 *   TCR:
 *   PDR:
 *   MDR:
 *   FDR:
 *   EXR:
 *   - In-game vocabulary used for the selected S Parameter.
 *
 * ---
 *
 * Icons
 * 
 *   Draw Icons?
 *   - Draw icons next to parameter names?
 *
 *   MaxHP, MaxMP, ATK, DEF, MAT, MDF, AGI, LUK:
 *   HIT, EVA, CRI, CEV, MEV, MRF, CNT, HRG, MRG, TRG:
 *   TGR, GRD, REC, PHA, MCR, TCR, PDR, MDR, FDR, EXR:
 *   - Icon used for the selected parameter.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Custom Parameters Settings
 * ============================================================================
 *
 * As of version 1.07, you can add Custom Parameters to your game if RPG Maker
 * MZ's default set of parameters isn't enough for you. These parameters can
 * have variable functionality depending on how you code it. More importantly,
 * these are compatible with the VisuStella MZ menus and the VisuStella Core
 * Engine's Parameters settings.
 * 
 * For clarification, these settings do NOT create brand-new parameters for you
 * to use and add to your game nor are the bonuses supported by other plugins
 * in the VisuStella MZ library. These settings exist to function as a bridge
 * for non-VisuStella MZ plugins that have created their own parameter values
 * and to show them inside VisuStella menus.
 *
 * ---
 *
 * Custom Parameter
 * 
 *   Parameter Name:
 *   - What's the parameter's name?
 *   - Used for VisuStella MZ menus.
 * 
 *   Abbreviation:
 *   - What abbreviation do you want to use for the parameter?
 *   - Do not use special characters. Avoid numbers if possible.
 * 
 *   Icon:
 *   - What icon do you want to use to represent this parameter?
 *   - Used for VisuStella MZ menus.
 * 
 *   Type:
 *   - What kind of number value will be returned with this parameter?
 *     - Integer (Whole Numbers Only)
 *     - Float (Decimals are Allowed)
 * 
 *   JS: Value:
 *   - Run this code when this parameter is to be returned.
 *
 * ---
 * 
 * Instructions on Adding Custom Parameters to VisuStella Menus
 * 
 * In the Core Engine and Elements and Status Menu Core plugins, there are
 * plugin parameter fields for you to insert the parameters you want displayed
 * and visible to the player.
 * 
 * Insert in those the abbreviation of the custom parameter. For example, if
 * you want to add the "Strength" custom parameter and the abbreviation is
 * "str", then add "str" to the Core Engine/Elements and Status Menu Core's
 * plugin parameter field for "Strength" to appear in-game. Case does not
 * matter here so you can insert "str" or "STR" and it will register all the
 * same to make them appear in-game.
 * 
 * ---
 * 
 * Instructions on Using Custom Parameters as Mechanics
 * 
 * If you want to use a custom parameter in, say, a damage formula, refer to
 * the abbreviation you have set for the custom parameter. For example, if you
 * want to call upon the "Strength" custom parameter's value and its set
 * abbreviation is "str", then refer to it as such. This is case sensitive.
 * 
 * An example damage formula would be something like the following if using
 * "str" for "Strength" and "con" for "Constitution":
 * 
 *   a.str - b.con
 * 
 * These values are attached to the Game_Battlerbase prototype class.
 * 
 * ---
 * 
 * Instructions on Setting Custom Parameter Values
 * 
 * This requires JavaScript knowledge. There is no way around it. Whatever code
 * you insert into the "JS: Value" field will return the value desired. The
 * 'user' variable will refer to the Game_Battlerbase prototype object in which
 * the information is to be drawn from.
 * 
 * Depending on the "type" you've set for the Custom Parameter, the returned
 * value will be rounded using Math.round for integers and left alone if set as
 * a float number.
 * 
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Screen Resolution Settings
 * ============================================================================
 *
 * Alter various properties to make the game look better for varying screen
 * resolutions. This is mostly for RPG Maker MZ version 1.3.0 and up where the
 * Troops tab has been updated to match the screen resolution settings found in
 * the System 2 Database tab.
 *
 * ---
 *
 * Troops
 * 
 *   Reposition Actors:
 *   - Update the position of actors in battle if the screen resolution
 *     has changed to become larger than 816x624.
 *   - Ignore if using the VisuStella MZ Battle Core.
 *   - When using the VisuStella MZ Battle Core, adjust the position through
 *     Battle Core > Parameters > Actor Battler Settings > JS: Home Position
 *
 *   Reposition Enemies:
 *   - Update the position of enemies in battle if the screen resolution
 *     has changed to become larger than 816x624.
 * 
 *     For MZ 1.3.0+?:
 *     - Both this parameter and its parent parameter need to be on when using
 *       RPG Maker MZ 1.3.0+.
 *     - If the Core Script is below 1.3.0, this setting is ignored. This does
 *       not take into account what version the editor is on. Pay attention to
 *       that as the plugin will not auto adjust for it.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Screen Shake Settings
 * ============================================================================
 *
 * Get more screen shake effects into your game!
 * 
 * These effects have been added by Aries of Sheratan!
 *
 * ---
 *
 * Settings
 * 
 *   Default Style:
 *   - The default style used for screen shakes.
 *   - Original
 *   - Random
 *   - Horizontal
 *   - Vertical
 * 
 *   JS: Original Style:
 *   JS: Random Style
 *   JS: Horizontal Style
 *   JS: Vertical Style
 *   - This code gives you control over screen shake for this screen
 *     shake style.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Title Command List Settings
 * ============================================================================
 *
 * This plugin parameter allows you to adjust the commands that appear on the
 * title screen. Some JavaScript knowledge is needed.
 *
 * ---
 *
 * Title Command
 * 
 *   Symbol:
 *   - The symbol used for this command.
 * 
 *   STR: Text:
 *   - Displayed text used for this title command.
 *   - If this has a value, ignore the JS: Text version.
 * 
 *   JS: Text:
 *   - JavaScript code used to determine string used for the displayed name.
 * 
 *   JS: Show:
 *   - JavaScript code used to determine if the item is shown or not.
 * 
 *   JS: Enable:
 *   - JavaScript code used to determine if the item is enabled or not.
 * 
 *   JS: Ext:
 *   - JavaScript code used to determine any ext data that should be added.
 * 
 *   JS: Run Code:
 *   - JavaScript code that runs once this command is selected.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Title Picture Buttons Settings
 * ============================================================================
 *
 * These allow you to insert picture buttons on your title screen that can
 * send users to various links on the internet when clicked.
 *
 * ---
 *
 * Settings
 * 
 *   Picture's Filename:
 *   - Filename used for the picture.
 * 
 *   Button URL:
 *   - URL for the button to go to upon being clicked.
 * 
 *   JS: Position:
 *   - JavaScript code that helps determine the button's Position.
 * 
 *   JS: On Load:
 *   - JavaScript code that runs once this button bitmap is loaded.
 * 
 *   JS: Run Code:
 *   - JavaScript code that runs once this button is pressed.
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: UI Settings
 * ============================================================================
 *
 * In previous iterations of RPG Maker, the Core Engine would allow you to
 * change the screen resolution. In MZ, that functionality is provided by
 * default but a number of UI settings still remain. These settings allow you
 * adjust how certain in-game objects and menus are displayed.
 *
 * ---
 *
 * UI Area
 *
 *   Fade Speed:
 *   - Default fade speed for transitions.
 *
 *   Box Margin:
 *   - Set the margin in pixels for the screen borders.
 *
 *   Command Window Width:
 *   - Sets the width for standard Command Windows.
 *
 *   Bottom Help Window:
 *   - Put the Help Window at the bottom of the screen?
 *
 *   Right Aligned Menus:
 *   - Put most command windows to the right side of the screen.
 *
 *   Show Buttons:
 *   - Show clickable buttons in your game?
 * 
 *     Show Cancel Button:
 *     Show Menu Button:
 *     Show Page Up/Down:
 *     Show Number Buttons:
 *     - Show/hide these respective buttons if the above is enabled.
 *     - If 'Show Buttons' is false, these will be hidden no matter what.
 *
 *   Button Area Height:
 *   - Sets the height for the button area.
 *
 *   Bottom Buttons:
 *   - Put the buttons at the bottom of the screen?
 *
 *   Side Buttons:
 *   - Push buttons to the side of the UI if there is room.
 *
 * ---
 *
 * Larger Resolutions
 *
 * ---
 *
 * Menu Objects
 *
 *   Level -> EXP Gauge:
 *   - Draw an EXP Gauge under the drawn level.
 *
 *   Parameter Arrow:
 *   - The arrow used to show changes in the parameter values.
 *
 * ---
 *
 * Text Code Support
 *
 *   Class Names:
 *   - Make class names support text codes?
 *
 *   Nicknames:
 *   - Make nicknames support text codes?
 *
 * ---
 *
 * ============================================================================
 * Plugin Parameters: Window Settings
 * ============================================================================
 *
 * Adjust the default settings of the windows in-game. This ranges from things
 * such as the line height (to better fit your font size) to the opacity level
 * (to fit your window skins).
 *
 * ---
 *
 * Window Defaults
 * 
 *   Line Height:
 *   - Default line height used for standard windows.
 * 
 *   Item Height Padding:
 *   - Default padding for selectable items.
 * 
 *   Item Padding:
 *   - Default line padding used for standard windows.
 * 
 *   Back Opacity:
 *   - Default back opacity used for standard windows.
 *   - As of version 1.3.0, this is no longer needed.
 *   - This will still work for lower versions.
 * 
 *   Translucent Opacity:
 *   - Default translucent opacity used for standard windows.
 * 
 *   Window Opening Speed:
 *   - Default open speed used for standard windows.
 *   - Default: 32 (Use a number between 0-255)
 * 
 *   Column Spacing:
 *   - Default column spacing for selectable windows.
 *   - Default: 8
 * 
 *   Row Spacing:
 *   - Default row spacing for selectable windows.
 *   - Default: 4
 *
 * ---
 * 
 * Selectable Items:
 * 
 *   Show Background?:
 *   - Selectable menu items have dark boxes behind them. Show them?
 * 
 *   Item Height Padding:
 *   - Default padding for selectable items.
 * 
 *   JS: Draw Background:
 *   - Code used to draw the background rectangle behind clickable menu objects
 * 
 * ---
 *
 * ============================================================================
 * Plugin Parameters: JS: Quick Functions
 * ============================================================================
 * 
 * WARNING: This feature is highly experimental! Use it at your own risk!
 * 
 * JavaScript Quick Functions allow you to quickly declare functions in the
 * global namespace for ease of access. It's so that these functions can be
 * used in Script Calls, Control Variable Script Inputs, Conditional Branch
 * Script Inputs, Damage Formulas, and more.
 * 
 * ---
 * 
 * JS: Quick Function
 * 
 *   Function Name:
 *   - The function's name in the global namespace.
 *   - Will not overwrite functions/variables of the same name.
 * 
 *   JS: Code:
 *   - Run this code when using the function.
 * 
 * ---
 * 
 * If you have a Function Name of "Example", then typing "Example()" in a
 * Script Call, Conditional Branch Script Input, or similar field will yield
 * whatever the code is instructed to return.
 * 
 * If a function or variable of a similar name already exists in the global
 * namespace, then the quick function will be ignored and not created.
 * 
 * If a quick function contains bad code that would otherwise crash the game,
 * a fail safe has been implemented to prevent it from doing so, display an
 * error log, and then return a 0 value.
 * 
 * ---
 *
 * ============================================================================
 * Terms of Use
 * ============================================================================
 *
 * 1. These plugins may be used in free or commercial games provided that they
 * have been acquired through legitimate means at VisuStella.com and/or any
 * other official approved VisuStella sources. Exceptions and special
 * circumstances that may prohibit usage will be listed on VisuStella.com.
 * 
 * 2. All of the listed coders found in the Credits section of this plugin must
 * be given credit in your games or credited as a collective under the name:
 * "VisuStella".
 * 
 * 3. You may edit the source code to suit your needs, so long as you do not
 * claim the source code belongs to you. VisuStella also does not take
 * responsibility for the plugin if any changes have been made to the plugin's
 * code, nor does VisuStella take responsibility for user-provided custom code
 * used for custom control effects including advanced JavaScript notetags
 * and/or plugin parameters that allow custom JavaScript code.
 * 
 * 4. You may NOT redistribute these plugins nor take code from this plugin to
 * use as your own. These plugins and their code are only to be downloaded from
 * VisuStella.com and other official/approved VisuStella sources. A list of
 * official/approved sources can also be found on VisuStella.com.
 *
 * 5. VisuStella is not responsible for problems found in your game due to
 * unintended usage, incompatibility problems with plugins outside of the
 * VisuStella MZ library, plugin versions that aren't up to date, nor
 * responsible for the proper working of compatibility patches made by any
 * third parties. VisuStella is not responsible for errors caused by any
 * user-provided custom code used for custom control effects including advanced
 * JavaScript notetags and/or plugin parameters that allow JavaScript code.
 *
 * 6. If a compatibility patch needs to be made through a third party that is
 * unaffiliated with VisuStella that involves using code from the VisuStella MZ
 * library, contact must be made with a member from VisuStella and have it
 * approved. The patch would be placed on VisuStella.com as a free download
 * to the public. Such patches cannot be sold for monetary gain, including
 * commissions, crowdfunding, and/or donations.
 *
 * ============================================================================
 * Credits
 * ============================================================================
 * 
 * If you are using this plugin, credit the following people in your game:
 *
 * Team VisuStella
 * * Yanfly
 * * Arisu
 * * Olivia
 * * Irina
 *
 * ============================================================================
 * Changelog
 * ============================================================================
 * 
 * Version 1.59: April 7, 2022
 * * Compatibility Update!
 * ** RPG Maker MZ 1.4.4 compatibility update!
 * *** "Shutdown" command should now be more compatible with other aspects of
 *     the client when running from Node JS client on other OS's.
 * 
 * Version 1.58: March 24, 2022
 * * Feature Update!
 * ** Plugin Commands now have separators for easier selection.
 * 
 * Version 1.57: March 3, 2022
 * * Compatibility Update!
 * ** The "Shutdown" command from the title screen should now be compatible
 *    with RPG Maker MZ 1.4.4 and up. Update made by Olivia.
 * 
 * Version 1.56: February 10, 2022
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New features added by Arisu and sponsored by Anon:
 * *** Plugin Parameters > QoL > Misc > Shortcut Scripts
 * **** Enables shortcut-based script variables and functions that can be used
 *      for script calls.
 * **** Shortcut list enabled for this is as follows:
 * ***** $commonEvent(id), $onceParallel(id), $scene, $spriteset, $subject, 
 *       $targets, $target, $event
 * ***** For more information on how to use them, review the help file.
 * 
 * Version 1.55: January 27, 2022
 * * Feature Update!
 * ** Once Parallels for the map are now able to update even while other events
 *    are running. Update made by Arisu.
 * 
 * Version 1.54: January 13, 2022
 * * Bug Fixes!
 * ** RPG Maker MZ Bug Fix!
 * *** Overly-Protective Substitute
 * *** When an ally with critical health is being targeted by a friendly non-
 *     Certain Hit skill (such as a heal or buff) and another ally has the
 *     substitute state, the other ally would "protect" the originally targeted
 *     ally and take the heal or buff.
 * *** The new changed behavior is that now, substitute will not trigger for
 *     any actions whose scope targets allies.
 * *** Fix made by Olivia.
 * * Documentation Update!
 * ** Added documentation for new MZ Bug: Overly-Protective Substitute.
 * * Feature Update!
 * ** Added a failsafe for those who did not update the plugin parameter
 *    settings and are using MV Animations.
 * 
 * Version 1.53: December 30, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Notetag added by Olivia:
 * *** <Rate: x>
 * **** Allows you to adjust the update for this MV Animation.
 * ***** Does NOT work with Effekseer animations.
 * **** The lower the number, the faster.
 * **** Replace 'x' with a number representing the animation update rate.
 * ***** Default rate: 4.
 * ***** Minimum rate: 1.
 * ***** Maximum rate: 10.
 * ** New Plugin Parameter added by Olivia:
 * *** Plugin Parameters > Qualify of Life Settings > MV Animation Rate
 * **** Adjusts the rate at which MV animations play.
 * **** Default: 4. Lower for faster. Higher for slower.
 * * Optimization Update!
 * ** MV Animations should run more optimized.
 * 
 * Version 1.52: December 16, 2021
 * * Compatibility Update!
 * ** RPG Maker MZ 1.4.0 compatibility update!
 * *** MV Animations played on screen level will now show up properly in the
 *     center of the screen.
 * 
 * Version 1.51: December 9, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug Fix!
 * *** In the battle status windows, whenever actor names are displayed, the
 *     bitmap used to display their name text do not extend vertically all the
 *     way, causing letters like lowercase "Q" and "G" to be cut off, making
 *     them hard to distinguish from one another. The Core Engine will remedy
 *     this by extending the bitmap to allow enough room. Fix made by Irina.
 * 
 * Version 1.50: November 4, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug Fix!
 * *** By default, if the attack skill is sealed via a trait and an actor has
 *     auto-battle, the action can still be used via auto-battle. This is now
 *     fixed and actors should not be able to attack via auto-battle if their
 *     attack ability is sealed. Fix made by Yanfly.
 * * Documentation Update!
 * ** Help file updated for new RPG Maker MZ bug fix.
 * 
 * Version 1.49: October 28, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Feature!
 * ** New Plugin Command added by Arisu and sponsored by Anon:
 * *** Map: Once Parallel
 * **** Plays a Common Event parallel to the event once without repeating
 *      itself when done. Map only!
 * **** When exiting map scene or changing maps, all Once Parallels are cleared
 * **** Once Parallels are not retained upon reentering the scene or map.
 * **** Once Parallels are not stored in memory and cannot be saved.
 * 
 * Version 1.48: October 21, 2021
 * * Feature Update!
 * ** Bitmap.blt function will now have source coordinates and destination X
 *    and Y coordinates rounded to prevent blurring. Update made by Olivia.
 * 
 * Version 1.47: October 14, 2021
 * * Bug Fixes!
 * ** Prevents Number Input window from having a NaN value due to holding down
 *    the fast forward key. Fix made by Arisu.
 * * Compatibility Update
 * ** Added compatibility functionality for future plugins.
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Feature!
 * ** New Plugin Parameter added by Yanfly:
 * *** Plugin Parameters > QoL Settings > Misc > Font Width Fix
 * **** Fixes the font width issue with non-monospaced fonts in the Message
 *      Window. This is now an optional fix.
 * 
 * Version 1.46: September 23, 2021
 * * Documentation Update!
 * ** Added line to Plugin Command: "System: Battle System Change":
 * *** Some battle systems REQUIRE their specific plugins!
 * ** Added lines to "Plugin Parameters: Battle System":
 * *** Some battle systems REQUIRE their specific plugins! This means if you do
 *     not have the required battle system plugin installed, it will not change
 *     over. The Core Engine plugin does not contain data for all of the battle
 *     systems inside its code.
 * 
 * Version 1.45: September 17, 2021
 * * Bug Fixes!
 * ** Fixed a problem with "Picture: Coordinates Mode" to properly utilize the
 *    correct picture ID. Fix made by Arisu.
 * ** RPG Maker MZ Bug Fix:
 * *** Instant Text Discrepancy for Window_Message
 * **** Window_Message displays text differently when it draws letters one by
 *      one versus when the text is displayed instantly. This isn't noticeable
 *      with the default font, but it's very visible when using something like
 *      Arial. The error is due to Bitmap.measureTextWidth yielding a rounded
 *      value per letter versus per word. The Core Engine will provide a bug
 *      fix that will single out the cause and make it so that only
 *      Window_Message will not utilize any round number values when
 *      determining the width of each letter, whether or not it is shown
 *      instantly. This change will only affect Window_Message and not any
 *      other window in order to prevent unintended side effects.
 * **** Fix made by Yanfly.
 * * Compatibility Update!
 * ** RPG Maker MZ 1.3.3 compatibility.
 * *** Updated how gauges are drawn.
 * * Documentation Update!
 * ** Help file updated for new RPG Maker MZ bug fix.
 * 
 * Version 1.44: August 20, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Command added by Irina and sponsored by Anon.
 * *** "Animation: Play at Coordinate"
 * **** Plays an animation on the screen at a specific x, y coordinate even if
 *      there is no sprite attached.
 * 
 * Version 1.43: July 23, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Command added by Irina and sponsored by Archeia!
 * *** "Picture: Coordinates Mode"
 * **** Play Test Mode only!
 * **** Gets the coordinates of a specific picture as you move it across the
 *      screen.
 * **** Helpful for those who don't want to do guess work on the screen
 *      coordinates when it comes to placing down pictures.
 * 
 * Version 1.42: July 16, 2021
 * * Documentation Update
 * ** Added text to "Plugin Parameters: Color Settings" for clarification:
 * *** If the game's Window Skin is changed mid-game, the colors used will
 *     still be based off the default Window Skin's colors. This is due to
 *     storing them in a cache and preventing extra processing and reduces lag.
 * 
 * Version 1.41: July 2, 2021
 * * Compatibility Update
 * ** Further compatibility update with RPG Maker MZ 1.3.0+.
 * * Documentation Update
 * ** Added extra notes to "Important Changes: Bug Fixes" section for the
 *    "Window Skin Bleeding" bug:
 * *** This bug is fixed in the core scripts for RPG Maker MZ v1.3.0+.
 * 
 * Version 1.40: June 25, 2021
 * * Compatibility Update
 * ** Compatibility update with RPG Maker MZ 1.3.0+.
 * * Documentation Update:
 * ** Plugin Parameters > Window Settings > Back Opacity
 * *** As of version 1.3.0, this is no longer needed.
 * *** This will still work for lower versions.
 * ** Help file updated for new features.
 * * Feature Updates!
 * ** Window Skin Bleeding fix updated to newest version.
 * * New Plugin Parameters added:
 * ** Plugin Parmaeters > Screen Resolution Settings
 * *** These settings have been moved from the UI settings to be its own thing.
 * **** This is mostly for RPG Maker MZ version 1.3.0 and up where the Troops
 *      tab has been updated to match the screen resolution settings found in
 *      the System 2 Database tab.
 * *** Reposition Enemies > For MZ 1.3.0+?
 * **** Both of these plugin parameters need to be set to true in order for the
 *      repositioning to work for MZ v1.3.0.
 * **** If the Core Script is below 1.3.0, this setting is ignored. This does
 *      not take into account what version the editor is on. Pay attention to
 *      that as the plugin will not auto adjust for it.
 * 
 * Version 1.39: June 18, 2021
 * * Bug Fixes!
 * ** Number Inputs should now work with the controller if keyboard Number
 *    Input is enabled. Fix made by Olivia.
 * ** RPG Maker Bug: Termination Clear Effects
 * *** In RPG Maker MZ, requesting an animation while transitioning between
 *     scenes, such as going from the map scene to the battle scene, can cause
 *     crashes. This is because the animation queue does not take off
 *     immediately and will likely register incorrect targets for the scene.
 *     This plugin will forcefully clear any registered animations and balloon
 *     effects when terminating a scene in order to prevent crashes.
 * * Documentation Update!
 * ** Help file updated for updated features.
 * * Feature Update!
 * ** <Battle View: x> Troop Name tags can now work with comment tags.
 * ** <Battle System: x> Troop Name tags can now work with comment tags.
 * *** Updates made by Irina.
 * 
 * Version 1.38: June 11, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Command added by Irina and sponsored by Caz!
 * *** Picture: Show Icon
 * **** Shows an icon instead of a picture image.
 * **** The picture icon can be controlled like any other picture.
 * 
 * Version 1.37: May 21, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Commands added by Arisu:
 * *** Switches: Randomize ID(s)
 * *** Switches: Randomize Range
 * *** Switches: Toggle ID(s)
 * *** Switches: Toggle Range
 * **** These Plugin Commands allow you to randomize the ON/OFF positions of
 *      switches or toggle them so that they flip their ON/OFF status.
 * 
 * Version 1.36: May 14, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Commands added by Irina:
 * *** Export: All Maps Text
 * *** Export: All Troops Text
 * *** Export: Current Map Text
 * *** Export: Current Troop Text
 * **** Play Test Only Plugin Commands. These Plugin Commands are used for
 *      extracting all messages, show choices, comments, and scrolling text to
 *      parse and export them as a TXT file. Useful for getting a game's script
 *      to a voice actor or voice actress.
 * 
 * Version 1.35: May 7, 2021
 * * Documentation Update!
 * ** Added the following text to "Parameter Settings" Plugin Parameters for
 *    extra clarity regarding Parameter Caps:
 * *** These settings DO NOT raise the editor's maximum values. If you want to
 *     raise an enemy's maximum parameter value past their default cap, use the
 *     associated notetag for them instead.
 * 
 * Version 1.34: April 23, 2021
 * * Bug Fixes!
 * ** For the vanilla Equip Status window, custom parameters with integer
 *    values will now show up as integers and not percentiles. Fix by Olivia.
 * * Documentation Update!
 * ** Added clarity to the <param: x> notetag for enemies.
 * *** This notetag does NOT work with X Parameters, S Parameters, or any
 *     custom parameters. This notetag ONLY works with the base parameters.
 * 
 * Version 1.33: April 9, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Window Skin Bleeding
 * *** Since the v1.2.0 update, Window.prototype._refreshBack's frame value has
 *     been set from 96 to 95. This results in the window skin bleeding past
 *     the window's intended borders. The Core Engine now reverts this change
 *     to prevent the bleeding effect from happening.
 * * Feature Update!
 * ** "Encounter Rate Minimum" now has a valid minimum value of 1. Update made
 *    by Olivia.
 * 
 * Version 1.32: April 2, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Parameters added by Yanfly:
 * *** Plugin Parameters > QoL Settings > Battle Test > Add Item Type
 * *** Plugin Parameters > QoL Settings > Battle Test > Add Weapon Type
 * *** Plugin Parameters > QoL Settings > Battle Test > Add Armor Type
 * *** Plugin Parameters > QoL Settings > Battle Test > Added Quantity
 * **** By default, RPG Maker MZ only adds 99 of items and not weapons or armor
 *      making it awkward for testing specific battle mechanics. These settings
 *      allow you to add in custom amounts of items, weapons, and/or armors if
 *      you so wish.
 * 
 * Version 1.31: March 26, 2021
 * * Feature Update!
 * ** Title screen buttons will now become fully opaque when hovered over them
 *    instead of only when pressed. Update made by Yanfly.
 * 
 * Version 1.30: March 19, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Invisible Battle Sprites
 * *** If you removed a party member during battle and added that exact party
 *     member back into the same slot, their sprite would appear invisible. The
 *     VisuStella Core Engine will fix this problem and prevent it from
 *     happening. Fix made by Olivia.
 * * Compatibility Update
 * ** Added compatibility functionality for future plugins.
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** New Plugin Parameter added by Arisu:
 * *** Plugin Parameters > QoL Settings > Misc > Ani: Mirror Offset
 * **** When animations are mirrored, mirror their Offset X values, too.
 * ** New animation name tags added by Arisu:
 * *** <Mirror Offset X> and <No Mirror Offset X>
 * **** If these text tags are placed in an animation's name, it will cause the
 *      offset X value to be mirrored when the animation is mirrored or have it
 *      ignored despite being mirrored.
 * 
 * Version 1.29: March 12, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Interactable window client area does not conform to the
 *    window's declared scale when the scale is anything but 1.0. This will now
 *    be fixed through this plugin. Fix made by Olivia.
 * * Documentation Update!
 * ** Added documentation for new RPG Maker MZ bug fixes!
 * ** Help file updated for updated features.
 * * Feature Update!
 * ** Name Input should be more controller-friendly. If a controller is
 *    connected upon entering the name change scene, it will use the default
 *    manual-entry mode instead of the keyboard-entry mode. If a controller
 *    button is pressed during the keyboard-entry mode, it will automatically
 *    switch to the manual-entry mode.
 * ** This plugin does not provide support for controllers that are undetected
 *    by RPG Maker MZ's default controller support.
 * ** This feature was already implemented since version 1.27 but wasn't
 *    documented so here we are. Update made by Irina.
 * 
 * Version 1.28: March 5, 2021
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: The arrows drawn by a window skin will no longer by
 *    placed on a half pixel when a window's size is an odd number. This would
 *    cause sprite tearing problems and look awful. Fix made by Irina.
 * * Documentation Update!
 * ** Added documentation for new RPG Maker MZ bug fixes!
 * 
 * Version 1.27: February 26, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * ** Moved "Show Scrolling Text, additional functionality" section from Bug
 *    Fixes to Major Changes as it was placed in the wrong section.
 * * New Features!
 * ** New Plugin Parameter added by Yanfly.
 * *** Plugin Parameters > Keyboard Input > Name Input > Banned Words
 * **** Insert words you don't want your players to use for character names.
 * 
 * Version 1.26: February 19, 2021
 * * Bug Fixes!
 * ** Certain Plugin Parameters no longer have settings that restrict them to
 *    a maximum of 1. Fix made by Arisu.
 * * Feature Update!
 * ** Changed the default value for a New Game > Common Event upon Play Testing
 *    to 0 to prevent confusion. Update made by Arisu.
 * 
 * Version 1.25: February 5, 2021
 * * Documentation Update!
 * ** Help file updated for new features.
 * * New Features!
 * ** Show Scrolling Text, additional functionality added by Arisu
 * *** The event command "Show Scrolling Text" now has additional functionality
 *     as long as the VisuStella MZ Core Engine is installed. If the game dev
 *     inserts "// Script Call" (without the quotes) inside the scrolling text,
 *     then the entirity of the Show Scrolling Text event command will be ran
 *     as a giant script call event command.
 * *** The reason why this functionality is added is because the "Script..."
 *     event command contains only 12 lines maximum. This means for any script
 *     call larger than 12 lines of code cannot be done by normal means as each
 *     script call is ran as a separate instance.
 * *** By repurposing the "Show Scrolling Text" event command to be able to
 *     function as an extended "Script..." event command, such a thing is now
 *     possible with less hassle and more lines to code with.
 * *** This effect does not occur if the Show Scrolling Text event command does
 *     not have "// Script Call" in its contents.
 * 
 * Version 1.24: January 29, 2021
 * * Documentation Update!
 * ** Plugin Parameters: Custom Parameters Settings added the following note:
 * *** For clarification, these settings do NOT create brand-new parameters for
 *     you to use and add to your game nor are the bonuses supported by other
 *     plugins in the VisuStella MZ library. These settings exist to function
 *     as a bridge for non-VisuStella MZ plugins that have created their own
 *     parameter values and to show them inside VisuStella menus.
 * * Feature Update!
 * ** Default JS Plugin Parameter for the Title Command: "Shutdown" now has a
 *    note in it that reads: "Do NOT use this command with mobile devices or
 *    browser games. All it does is cause the game to display a blank, black
 *    canvas which the player is unable to do anything with. It does NOT force
 *    close the browser tab nor the app."
 * *** This is also why this command is disabled by default for any non-NodeJS
 *     client deployed game versions.
 * ** Disabled some bug fixes made by the Core Engine for the default RMMZ code
 *    base since the 1.1.1 version now contains those very same fixes.
 * 
 * Version 1.23: January 22, 2021
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.22: January 15, 2021
 * * Documentation Update!
 * ** Added documentation for new RPG Maker MZ bug fixes!
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Sprite_Timer is added to the spriteset for the parent
 *    scene, making it affected by any filers, zooms, and/or blurs, hindering
 *    its readability.
 * 
 * Version 1.21: January 8, 2021
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * New Features!
 * ** New Plugin Parameters added by Arisu:
 * *** Plugin Parameters > Keyboard Input > Controls > WASD Movement
 * *** Plugin Parameters > Keyboard Input > Controls > R Button: Dash Toggle
 * 
 * Version 1.20: January 1, 2021
 * * Compatibility Update!
 * ** Added compatibility functionality for future plugins.
 * 
 * Version 1.19: December 25, 2020
 * * Documentation Update!
 * ** Added documentation for new feature(s) and feature updates!
 * * Bug Fixes!
 * ** Fixed typo inside of the comments inside the JS: Quick Functions.
 * * Feature Update!
 * ** Plugin Parameters > Color Settings > Outline Color is now renamed to
 *    Font Outline.
 * * New Features!
 * ** New Plugin Parameters added by Shaz!
 * *** Plugin Parameters > Color Settings > Gauge Number Outline
 * 
 * Version 1.18: December 18, 2020
 * * Bug Fixes!
 * ** Compatible string text from the Items and Equips Core will no longer
 *    register MaxHP and MaxMP as percentile values for the info window.
 * ** RPG Maker MZ Bug: Gamepads no longer go rapidfire after a cleared input.
 *    There is now a period of delay for gamepads after an input clear.
 * ** RPG Maker MZ Bug: Unusable items on an individual-actor basis will no
 *    longer be overwritten by party-based usability for battle. Fix by Yanfly.
 * ** RPG Maker MV animations will no longer crash for unplayable sound
 *    effects. Fix made by Yanfly.
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * ** Added documentation for new RPG Maker MZ bug fixes!
 * * New Features!
 * ** New Plugin Parameters added by Yanfly!
 * *** Plugin Parameters > Button Assist > Key: Shift
 * *** Plugin Parameters > Button Assist > Key: Tab
 * **** These let you assign text codes to the Shift and Tab buttons for the
 *      Button Assist windows.
 * *** Plugin Parameters > QoL Settings > Misc > NewGame > CommonEvent
 * **** For an all version (including non-play test) common event to start new
 *      games with.
 * 
 * Version 1.17: December 11, 2020
 * * Compatibility Update!
 * ** Added compatibility functionality for future plugins.
 * 
 * Version 1.16: December 4, 2020
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * Feature Update!
 * ** Button Assist Window for the change name scene will now default to "Tab"
 *    for switching between both modes. Update made by Yanfly.
 * * New Features!
 * ** New Plugin Parameter added by Yanfly:
 * *** Plugin Parameters > Keyboard Input > Default Mode
 * **** Select default mode when entering the scene.
 * 
 * Version 1.15: November 29, 2020
 * * Bug Fixes!
 * ** Pressing "Enter" in the change name scene while the actor's name is
 *    completely empty will no longer result in endless buzzer sounds. Fix made
 *    by Arisu.
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * Feature Update!
 * ** For the name change scene, the "Tab" key now also lets the user switch
 *    between the two modes. Update made by Yanfly.
 * * New Features!
 * ** Two new plugin parameters added to Keyboard Input:
 * *** "Switch To Keyboard" and "Switch To Manual"
 * **** These determine the text used for the button assist window when
 *      switching between the two modes. Update made by Yanfly.
 * **** Button Assist window now takes into consideration for these texts.
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.14: November 22, 2020
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * New Features!
 * ** New Plugin Command added by Yanfly!
 * *** System: Load Images
 * **** Allows you to (pre) load up images ahead of time.
 * 
 * Version 1.13: November 15, 2020
 * * Optimization Update!
 * ** Plugin should run more optimized.
 * 
 * Version 1.12: November 8, 2020
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * * Documentation Update!
 * ** Added documentation for new feature(s)!
 * * Feature Update!
 * ** Screen Shake Plugin Parameters and JS: Quick Function Plugin Parameters
 *    have been taken off experimental status.
 * * New Features!
 * ** New plugin parameters added by Arisu.
 * *** Plugin Parameters > Keyboard Input
 * **** Settings for the game that utilize keyboard input. These are primarily
 *      for the name input scene (Scene_Name) and the number input event
 *      command. These settings have only been tested on English keyboards and
 *      may or may not be compatible with other languages, so please disable
 *      these features if they do not fit in with your game.
 * 
 * Version 1.11: November 1, 2020
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * * Feature Update!
 * ** Bitmap smoothing now takes into consideration for rounding coordinates.
 *    Update made by Irina.
 * 
 * Version 1.10: October 25, 2020
 * * Feature Update!
 * ** Sprite animation location now adjusts position relative to the sprite's
 *    scale, too. Update made by Arisu.
 *
 * Version 1.09: October 18, 2020
 * * Bug Fixes!
 * ** RPG Maker MZ Bug: Auto Battle Lock Up. Fixed by Yanfly.
 * *** If an auto battle Actor fights against an enemy whose DEF/MDF is too
 *     high, they will not use any actions at all. This can cause potential
 *     game freezing and softlocks. This plugin will change that and have them
 *     default to a regular Attack.
 * * Compatibility Update!
 * ** Plugins should be more compatible with one another.
 * 
 * Version 1.08: October 11, 2020
 * * Feature Update!
 * ** Altered sprite bitmaps via the various draw functions will now be marked
 *    as modified and will automatically purge themselves from graphical memory
 *    upon a sprite's removal to free up more resources. Change made by Yanfly.
 * ** Picture Sprite Origin anchors are now tied to the Game_Picture show and
 *    move commands instead of the Game_Interpretter commands. Change by Arisu.
 * 
 * Version 1.07: October 4, 2020
 * * Documentation Update!
 * ** New documentation added for the new Plugin Parameter category:
 *    "Custom Parameters".
 * * New Features!
 * ** New Plugin Parameter "Custom Parameters" added by Yanfly.
 * *** Create custom parameters for your game! These will appear in
 *     VisuStella MZ menus.
 * 
 * Version 1.06: September 27, 2020
 * * Bug Fixes!
 * ** Battler evasion pose can now occur if there is a miss. These were made
 *    separate in RPG Maker MZ and misses didn't enable the evasion pose. Fix
 *    made by Olivia.
 * * New Features!
 * ** New notetags for Maps and name tags for Troops added by Yanfly!
 * *** <Frontview>, <Sideview> to change the battle view for that specific map,
 *     or troop regardless of what other settings are.
 * *** <DTB>, <TPB Active>, <TPB Wait> to change the battle system for that
 *     specific map or troop regardless of what other settings are.
 * 
 * Version 1.05: September 20, 2020
 * * Bug Fixes!
 * ** <Level: x> notetag for enemies is now fixed! Fix made by Arisu.
 * * Documentation Update!
 * ** Documentation added for the new "System: Battle System Change" Plugin
 *    Command and removed the old "System: Set Time Progress Battle".
 * * Feature Update!
 * ** The Plugin Command "System: Set Time Progress Battle" has been replaced
 *    with "System: Battle System Change" instead. This is to accommodate
 *    future plugins that allow for different battle systems. Added by Yanfly.
 * *** If you have previously used "System: Set Time Progress Battle", please
 *     replace them. We apologize for the inconvenience.
 * * New Features!
 * ** In the Core Engine's plugin parameters, you can now set the Battle System
 *    used. This will default to whatever is the game database's setting. This
 *    feature is used for the future when new battle systems are made. Feature
 *    added by Yanfly.
 * 
 * Version 1.04: September 13, 2020
 * * Documentation Update!
 * ** Added new documentation for the "Title Command List" and Title Picture
 *    Buttons" plugin parameters. They now have a dedicated section each.
 * * Feature Updates!
 * ** Moved the "Title Command List" and "Title Picture Buttons" parameters
 *    from the Menu Layout > Title settings. They were far too hidden away and
 *    users had a hard time finding them. Update made by Yanfly.
 * *** Users who have customized these settings before will need to readjust
 *     them again. We apologize for the inconvenience.
 * 
 * Version 1.03: September 6, 2020
 * * Bug Fixes!
 * ** Having QoL > Modern Controls disabled (why would you) used to prevent the
 *    down button from working. It works again. Fix made by Yanfly.
 * * New Feature!
 * ** Plugin default settings now come with a "Game End" option on the title
 *    screen. For those updating from version 1.02 or order, you can add this
 *    in by opening the Core Engine > Plugin Parameters > Menu Layout Settings
 *    > press "delete" on Scene_Title > open it up, then the new settings will
 *    fill in automatically.
 * * New Experimental Feature Added:
 * ** Screen Shake Settings added to the Plugin Parameters.
 * *** Screen Shake: Custom Plugin Command added!
 * *** Credit to Aries of Sheratan, who gave us permission to use her formula.
 * *** We'll be expanding on more screen shaking options in the future.
 * * Optimization Update
 * ** Digit Grouping now works more efficiently.
 * 
 * Version 1.02: August 30, 2020
 * * New Feature!
 * ** New Plugin Command: "Picture: Erase All". Added by Olivia.
 * *** Erases all pictures on the screen because it's extremely tedious to do
 *     it one by one.
 * ** New Plugin Command: "Picture: Erase Range"
 * *** Erases all pictures within a range of numbers because it's extremely
 *     tedious to do it one by one.
 * * Optimization Update
 * ** Added a more accurate means of parsing numbers for Digit Grouping.
 * ** Window_Base.prototype.textSizeEx now stores data to a cache.
 * * Documentation Update
 * ** Added a section to Major Changes: New Hard-Coded Features on
 *    Digit Grouping and explaining its intricacies.
 * ** Added a note to Plugin Parameters > UI > Reposition Actors to ignore the
 *    setting if using the Battle Core.
 * 
 * Version 1.01: August 23, 2020
 * * Bug Fixes!
 * ** Digit grouping fixed to allow text codes to detect values larger than
 *    1000. Fix made by Olivia and Yanfly.
 * ** Param Plus, Rate, Flat notetags fixed. Fix made by Yanfly.
 * * New Experimental Feature Added:
 * ** JS: Quick Functions found in the Plugin Parameters
 *
 * Version 1.00: August 20, 2020
 * * Finished Plugin!
 *
 * ============================================================================
 * End of Helpfile
 * ============================================================================
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Animation
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command AnimationPoint
 * @text Animation: Play at Coordinate
 * @desc Plays an animation on the screen at a specific x, y
 * coordinate even if there is no sprite attached.
 *
 * @arg AnimationID:num
 * @text Animation ID
 * @parent Animation
 * @type animation
 * @desc Plays this animation.
 * @default 1
 * 
 * @arg Coordinates
 *
 * @arg pointX:eval
 * @text X
 * @parent Coordinates
 * @desc X coordinate used for the animation.
 * You may use JavaScript code.
 * @default Graphics.width / 2
 *
 * @arg pointY:eval
 * @text Y
 * @parent Coordinates
 * @desc Y coordinate used for the animation.
 * You may use JavaScript code.
 * @default Graphics.height / 2
 *
 * @arg Mirror:eval
 * @text Mirror Animation?
 * @parent Animation
 * @type boolean
 * @on Mirror
 * @off Normal
 * @desc Mirror the animation?
 * @default false
 *
 * @arg Mute:eval
 * @text Mute Animation?
 * @parent Animation
 * @type boolean
 * @on Mute
 * @off Normal
 * @desc Mute the animation?
 * @default false
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Export
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command ExportAllMapText
 * @text Export: All Maps Text
 * @desc PLAY TEST ONLY. Exports all of the text from all maps,
 * their events, event pages, and any associated Common Events.
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command ExportAllTroopText
 * @text Export: All Troops Text
 * @desc PLAY TEST ONLY. Exports all of the text from all troops,
 * their event pages, and any associated Common Events.
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command ExportCurMapText
 * @text Export: Current Map Text
 * @desc PLAY TEST ONLY. Exports all of the text on the current map,
 * its events, the event pages, and any associated Common Events.
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command ExportCurTroopText
 * @text Export: Current Troop Text
 * @desc PLAY TEST ONLY. Exports all of the text on the current troop,
 * the troop's event pages, and any associated Common Events.
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Game
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command OpenURL
 * @text Game: Open URL
 * @desc Opens a website URL from the game.
 *
 * @arg URL:str
 * @text URL
 * @desc Where do you want to take the player?
 * @default https://www.google.com/
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Gold
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command GoldChange
 * @text Gold: Gain/Lose
 * @desc Allows you to give/take more gold than the event editor limit.
 *
 * @arg value:eval
 * @text Value
 * @desc How much gold should the player gain/lose?
 * Use negative values to remove gold. You may use JS.
 * @default 0
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Map
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command MapOnceParallel
 * @text Map: Once Parallel
 * @desc Plays a Common Event parallel to the event once without
 * repeating itself when done. Map only!
 *
 * @arg CommonEventID:num
 * @text Common Event ID
 * @type common_event
 * @desc The ID of the parallel Common Event to play.
 * Does NOT repeat itself when finished.
 * @default 1
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Picture
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command PictureCoordinatesMode
 * @text Picture: Coordinates Mode
 * @desc Play Test Mode only! Gets the coordinates of a specific
 * picture as you move it across the screen.
 *
 * @arg PictureID:num
 * @text Picture ID
 * @type number
 * @min 1
 * @max 100
 * @desc The ID of the pictures to track the coordinates of.
 * @default 1
 *
 * @ --------------------------------------------------------------------------
 *
 * @command PictureEasingType
 * @text Picture: Easing Type
 * @desc Changes the easing type to a number of options.
 *
 * @arg pictureId:num
 * @text Picture ID
 * @type number
 * @min 1
 * @max 100
 * @desc Which picture do you wish to apply this easing to?
 * @default 1
 *
 * @arg easingType:str
 * @text Easing Type
 * @type combo
 * @option Linear
 * @option InSine
 * @option OutSine
 * @option InOutSine
 * @option InQuad
 * @option OutQuad
 * @option InOutQuad
 * @option InCubic
 * @option OutCubic
 * @option InOutCubic
 * @option InQuart
 * @option OutQuart
 * @option InOutQuart
 * @option InQuint
 * @option OutQuint
 * @option InOutQuint
 * @option InExpo
 * @option OutExpo
 * @option InOutExpo
 * @option InCirc
 * @option OutCirc
 * @option InOutCirc
 * @option InBack
 * @option OutBack
 * @option InOutBack
 * @option InElastic
 * @option OutElastic
 * @option InOutElastic
 * @option InBounce
 * @option OutBounce
 * @option InOutBounce
 * @desc Select which easing type you wish to apply.
 * @default Linear
 *
 * @arg LineBreak
 * @text ------------------------
 * @default --------------------------------
 *
 * @arg Instructions1
 * @text Instructions
 * @default Insert this Plugin Command after
 *
 * @arg Instructions2
 * @text -
 * @default a "Move Picture" event command.
 * 
 * @arg Instructions3
 * @text -
 * @default Turn off "Wait for Completion"
 *
 * @arg Instructions4
 * @text -
 * @default in the "Move Picture" event.
 *
 * @arg Instructions5
 * @text -
 * @default You may have to add in your own
 *
 * @arg Instructions6
 * @text -
 * @default "Wait" event command after.
 *
 * @ --------------------------------------------------------------------------
 *
 * @command PictureEraseAll
 * @text Picture: Erase All
 * @desc Erases all pictures on the screen because it's extremely
 * tedious to do it one by one.
 *
 * @ --------------------------------------------------------------------------
 *
 * @command PictureEraseRange
 * @text Picture: Erase Range
 * @desc Erases all pictures within a range of numbers because it's
 * extremely tedious to do it one by one.
 *
 * @arg StartID:num
 * @text Starting ID
 * @type number
 * @min 1
 * @max 100
 * @desc The starting ID of the pictures to erase.
 * @default 1
 *
 * @arg EndingID:num
 * @text Ending ID
 * @type number
 * @min 1
 * @max 100
 * @desc The ending ID of the pictures to erase.
 * @default 100
 *
 * @ --------------------------------------------------------------------------
 * 
 * @command PictureShowIcon
 * @text Picture: Show Icon
 * @desc Shows an icon instead of a picture image.
 * The picture icon can be controlled like any other picture.
 * 
 * @arg General
 * 
 * @arg PictureID:eval
 * @text Picture ID Number
 * @parent General
 * @desc What is the ID of the picture you wish to show at? Use a
 * number between 1 and 100. You may use JavaScript code.
 * @default 1
 * 
 * @arg IconIndex:eval
 * @text Icon Index
 * @parent General
 * @desc Select the icon index to use for this picture.
 * You may use JavaScript code.
 * @default 23
 *
 * @arg Smooth:eval
 * @text Smooth Icon?
 * @parent General
 * @type boolean
 * @on Smooth
 * @off Pixelate
 * @desc This will make the icon smoothed out or pixelated.
 * @default false
 * 
 * @arg PictureSettings
 * @text Picture Settings
 *
 * @arg Settings:struct
 * @text Settings
 * @parent PictureSettings
 * @type struct<ShowPicture>
 * @desc Alter the settings for how the picture will be shown.
 * @default {"Position":"","Origin:num":"0","PositionX:eval":"0","PositionY:eval":"0","Scale":"","ScaleX:eval":"100","ScaleY:eval":"100","Blend":"","Opacity:eval":"255","BlendMode:num":"0"}
 * 
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_ScreenShake
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command ScreenShake
 * @text Screen Shake: Custom
 * @desc Creates a custom screen shake effect and also sets
 * the following uses of screen shake to this style.
 *
 * @arg Type:str
 * @text Shake Style
 * @type select
 * @option Original
 * @value original
 * @option Random
 * @value random
 * @option Horizontal
 * @value horizontal
 * @option Vertical
 * @value vertical
 * @desc Select shake style type.
 * @default random
 *
 * @arg Power:num
 * @text Power
 * @type number
 * @min 1
 * @max 9
 * @desc Power level for screen shake.
 * @default 5
 *
 * @arg Speed:num
 * @text Speed
 * @type number
 * @min 1
 * @max 9
 * @desc Speed level for screen shake.
 * @default 5
 *
 * @arg Duration:eval
 * @text Duration
 * @desc Duration of screenshake.
 * You can use code as well.
 * @default 60
 *
 * @arg Wait:eval
 * @text Wait for Completion
 * @parent Duration:eval
 * @type boolean
 * @on Wait
 * @off Don't Wait
 * @desc Wait until completion before moving onto the next event?
 * @default true
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_Switch
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SwitchRandomizeOne
 * @text Switches: Randomize ID(s)
 * @desc Select specific Switch ID's to randomize ON/OFF.
 *
 * @arg IDs:arraynum
 * @text Switch ID(s)
 * @type switch[]
 * @desc Select which Switch ID(s) to toggle.
 * @default ["1"]
 *
 * @arg Chance:num
 * @text Chance for ON
 * @type number
 * @min 1
 * @max 100
 * @desc Chance out of 100 that determines the switches to be ON.
 * @default 50
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SwitchRandomizeRange
 * @text Switches: Randomize Range
 * @desc Select specific Switch ID Range to randomize ON/OFF.
 * The ratio determines the ON/OFF distribution.
 *
 * @arg StartID:num
 * @text Starting ID
 * @type switch
 * @desc The starting ID of the Switch to toggle.
 * @default 1
 *
 * @arg EndingID:num
 * @text Ending ID
 * @type switch
 * @desc The ending ID of the Switch to toggle.
 * @default 20
 *
 * @arg Chance:num
 * @text Chance for ON
 * @type number
 * @min 1
 * @max 100
 * @desc Chance out of 100 that determines the switches to be ON.
 * @default 50
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SwitchToggleOne
 * @text Switches: Toggle ID(s)
 * @desc Select specific Switch ID's to toggle ON/OFF.
 * ON becomes OFF. OFF becomes ON.
 *
 * @arg IDs:arraynum
 * @text Switch ID(s)
 * @type switch[]
 * @desc Select which Switch ID(s) to toggle.
 * @default ["1"]
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SwitchToggleRange
 * @text Switches: Toggle Range
 * @desc Select specific Switch ID Range to toggle ON/OFF.
 * ON becomes OFF. OFF becomes ON.
 *
 * @arg StartID:num
 * @text Starting ID
 * @type switch
 * @desc The starting ID of the Switch to toggle.
 * @default 1
 *
 * @arg EndingID:num
 * @text Ending ID
 * @type switch
 * @desc The ending ID of the Switch to toggle.
 * @default 20
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_System
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SystemSetBattleSystem
 * @text System: Battle System Change
 * @desc Switch to a different battle system in-game.
 * Some battle systems REQUIRE their specific plugins!
 *
 * @arg option:str
 * @text Change To
 * @type select
 * @option Database Default (Use game database setting)
 * @value database
 * @option -
 * @value database
 * @option DTB: Default Turn Battle
 * @value dtb
 * @option TPB Active: Time Progress Battle (Active)
 * @value tpb active
 * @option TPB Wait: Time Progress Battle (Wait)
 * @value tpb wait
 * @option -
 * @value database
 * @option BTB: Brave Turn Battle (Req VisuMZ_2_BattleSystemBTB)
 * @value btb
 * @option CTB: Charge Turn Battle (Req VisuMZ_2_BattleSystemCTB)
 * @value ctb
 * @option ETB: Energy Turn Battle (Req VisuMZ_2_BattleSystemETB)
 * @value etb
 * @option FTB: Free Turn Battle (Req VisuMZ_2_BattleSystemFTB)
 * @value ftb
 * @option OTB: Order Turn Battle (Req VisuMZ_2_BattleSystemOTB)
 * @value otb
 * @option PTB: Press Turn Battle (Req VisuMZ_2_BattleSystemPTB)
 * @value ptb
 * @option STB: Standard Turn Battle (Req VisuMZ_2_BattleSystemSTB)
 * @value stb
 * @desc Choose which battle system to switch to.
 * @default database
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SystemLoadImages
 * @text System: Load Images
 * @desc Allows you to (pre) load up images ahead of time.
 *
 * @arg animations:arraystr
 * @text img/animations/
 * @type file[]
 * @dir img/animations/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg battlebacks1:arraystr
 * @text img/battlebacks1/
 * @type file[]
 * @dir img/battlebacks1/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg battlebacks2:arraystr
 * @text img/battlebacks2/
 * @type file[]
 * @dir img/battlebacks2/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg characters:arraystr
 * @text img/characters/
 * @type file[]
 * @dir img/characters/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg enemies:arraystr
 * @text img/enemies/
 * @type file[]
 * @dir img/enemies/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg faces:arraystr
 * @text img/faces/
 * @type file[]
 * @dir img/faces/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg parallaxes:arraystr
 * @text img/parallaxes/
 * @type file[]
 * @dir img/parallaxes/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg pictures:arraystr
 * @text img/pictures/
 * @type file[]
 * @dir img/pictures/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg sv_actors:arraystr
 * @text img/sv_actors/
 * @type file[]
 * @dir img/sv_actors/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg sv_enemies:arraystr
 * @text img/sv_enemies/
 * @type file[]
 * @dir img/sv_enemies/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg system:arraystr
 * @text img/system/
 * @type file[]
 * @dir img/system/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg tilesets:arraystr
 * @text img/tilesets/
 * @type file[]
 * @dir img/tilesets/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg titles1:arraystr
 * @text img/titles1/
 * @type file[]
 * @dir img/titles1/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @arg titles2:arraystr
 * @text img/titles2/
 * @type file[]
 * @dir img/titles2/
 * @desc Which files do you wish to load from this directory?
 * @default []
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SystemSetFontSize
 * @text System: Main Font Size
 * @desc Set the game's main font size.
 *
 * @arg option:num
 * @text Change To
 * @type number
 * @min 1
 * @desc Change the font size to this number.
 * @default 26
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SystemSetSideView
 * @text System: Side View Battle
 * @desc Switch between Front View or Side View for battle.
 *
 * @arg option:str
 * @text Change To
 * @type select
 * @option Front View
 * @value Front View
 * @option Side View
 * @value Side View
 * @option Toggle
 * @value Toggle
 * @desc Choose which view type to switch to.
 * @default Toggle
 *
 * @ --------------------------------------------------------------------------
 *
 * @command SystemSetWindowPadding
 * @text System: Window Padding
 * @desc Change the game's window padding amount.
 *
 * @arg option:num
 * @text Change To
 * @type number
 * @min 1
 * @desc Change the game's standard window padding to this value.
 * Default: 12
 * @default 12
 *
 * @ --------------------------------------------------------------------------
 *
 * @command Separator_End
 * @text -
 * @desc -
 *
 * @ --------------------------------------------------------------------------
 *
 * @ ==========================================================================
 * @ Plugin Parameters
 * @ ==========================================================================
 *
 * @param BreakHead
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param CoreEngine
 * @default Plugin Parameters
 * @param ATTENTION
 * @default READ THE HELP FILE
 *
 * @param BreakSettings
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param QoL:struct
 * @text Quality of Life Settings
 * @type struct<QoLSettings>
 * @desc Quality of Life settings for both developers and players.
 * @default {"PlayTest":"","NewGameBoot:eval":"false","ForceNoPlayTest:eval":"false","OpenConsole:eval":"true","F6key:eval":"true","F7key:eval":"true","NewGameCommonEvent:num":"0","DigitGrouping":"","DigitGroupingStandardText:eval":"true","DigitGroupingExText:eval":"true","DigitGroupingDamageSprites:eval":"true","DigitGroupingGaugeSprites:eval":"true","DigitGroupingLocale:str":"en-US","PlayerBenefit":"","EncounterRateMinimum:num":"10","EscapeAlways:eval":"true","ImprovedAccuracySystem:eval":"true","AccuracyBoost:eval":"true","LevelUpFullHp:eval":"true","LevelUpFullMp:eval":"true","Misc":"","AntiZoomPictures:eval":"true","AutoStretch:str":"stretch","FontShadows:eval":"false","FontSmoothing:eval":"true","KeyItemProtect:eval":"true","ModernControls:eval":"true","NoTileShadows:eval":"true","PixelateImageRendering:eval":"false","RequireFocus:eval":"true","SmartEventCollisionPriority:eval":"true"}
 * 
 * @param BattleSystem:str
 * @text Battle System
 * @type select
 * @option Database Default (Use game database setting)
 * @value database
 * @option -
 * @value database
 * @option DTB: Default Turn Battle
 * @value dtb
 * @option TPB Active: Time Progress Battle (Active)
 * @value tpb active
 * @option TPB wait: Time Progress Battle (Wait)
 * @value tpb wait
 * @option -
 * @value database
 * @option BTB: Brave Turn Battle (Req VisuMZ_2_BattleSystemBTB)
 * @value btb
 * @option CTB: Charge Turn Battle (Req VisuMZ_2_BattleSystemCTB)
 * @value ctb
 * @option ETB: Energy Turn Battle (Req VisuMZ_2_BattleSystemETB)
 * @value etb
 * @option FTB: Free Turn Battle (Req VisuMZ_2_BattleSystemFTB)
 * @value ftb
 * @option OTB: Order Turn Battle (Req VisuMZ_2_BattleSystemOTB)
 * @value otb
 * @option PTB: Press Turn Battle (Req VisuMZ_2_BattleSystemPTB)
 * @value ptb
 * @option STB: Standard Turn Battle (Req VisuMZ_2_BattleSystemSTB)
 * @value stb
 * @desc Choose which battle system to use for your game.
 * Some battle systems REQUIRE their specific plugins!
 * @default database
 *
 * @param Color:struct
 * @text Color Settings
 * @type struct<Color>
 * @desc Change the colors used for in-game text.
 * @default {"BasicColors":"","ColorNormal:str":"0","ColorSystem:str":"16","ColorCrisis:str":"17","ColorDeath:str":"18","ColorGaugeBack:str":"19","ColorHPGauge1:str":"20","ColorHPGauge2:str":"21","ColorMPGauge1:str":"22","ColorMPGauge2:str":"23","ColorMPCost:str":"23","ColorPowerUp:str":"24","ColorPowerDown:str":"25","ColorCTGauge1:str":"26","ColorCTGauge2:str":"27","ColorTPGauge1:str":"28","ColorTPGauge2:str":"29","ColorTPCost:str":"29","ColorPending:str":"#2a847d","ColorExpGauge1:str":"30","ColorExpGauge2:str":"31","ColorMaxLvGauge1:str":"14","ColorMaxLvGauge2:str":"6","AlphaColors":"","OutlineColor:str":"rgba(0, 0, 0, 0.6)","DimColor1:str":"rgba(0, 0, 0, 0.6)","DimColor2:str":"rgba(0, 0, 0, 0)","ItemBackColor1:str":"rgba(32, 32, 32, 0.5)","ItemBackColor2:str":"rgba(0, 0, 0, 0.5)","ConditionalColors":"","ActorHPColor:func":"\"// Set the variables used in this function.\\nlet actor = arguments[0];\\n\\n// Check if the actor exists. If not, return normal.\\nif (!actor) {\\n    return this.normalColor();\\n\\n// If the actor is dead, return death color.\\n} else if (actor.isDead()) {\\n    return this.deathColor();\\n\\n// If the actor is dying, return crisis color.\\n} else if (actor.isDying()) {\\n    return this.crisisColor();\\n\\n// Otherwise, return the normal color.\\n} else {\\n    return this.normalColor();\\n}\"","ActorMPColor:func":"\"// Set the variables used in this function.\\nlet actor = arguments[0];\\n\\n// Check if the actor exists. If not, return normal.\\nif (!actor) {\\n    return this.normalColor();\\n\\n// If MP rate is below 25%, return crisis color.\\n} else if (actor.mpRate() < 0.25) {\\n    return this.crisisColor();\\n\\n// Otherwise, return the normal color.\\n} else {\\n    return this.normalColor();\\n}\"","ActorTPColor:func":"\"// Set the variables used in this function.\\nlet actor = arguments[0];\\n\\n// Check if the actor exists. If not, return normal.\\nif (!actor) {\\n    return this.normalColor();\\n\\n// If TP rate is below 25%, return crisis color.\\n} else if (actor.tpRate() < 0.25) {\\n    return this.crisisColor();\\n\\n// Otherwise, return the normal color.\\n} else {\\n    return this.normalColor();\\n}\"","ParamChange:func":"\"// Set the variables used in this function.\\nlet change = arguments[0];\\n\\n// If a positive change, use power up color.\\nif (change > 0) {\\n    return this.powerUpColor();\\n\\n// If a negative change, use power down color.\\n} else if (change < 0) {\\n    return this.powerDownColor();\\n\\n// Otherwise, return the normal color.\\n} else {\\n    return this.normalColor();\\n}\"","DamageColor:func":"\"// Set the variables used in this function.\\nlet colorType = arguments[0];\\n\\n// Check the value of the color type\\n// and return an appropriate color.\\nswitch (colorType) {\\n\\n    case 0: // HP damage\\n        return \\\"#ffffff\\\";\\n\\n    case 1: // HP recover\\n        return \\\"#b9ffb5\\\";\\n\\n    case 2: // MP damage\\n        return \\\"#bb88bb\\\";\\n\\n    case 3: // MP recover\\n        return \\\"#80b0ff\\\";\\n\\n    default:\\n        return \\\"#808080\\\";\\n}\""}
 *
 * @param Gold:struct
 * @text Gold Settings
 * @type struct<Gold>
 * @desc Change up how gold operates and is displayed in-game.
 * @default {"GoldMax:num":"999999999","GoldFontSize:num":"24","GoldIcon:num":"314","GoldOverlap:str":"A Lot","ItemStyle:eval":"true"}
 *
 * @param ImgLoad:struct
 * @text Image Loading
 * @type struct<ImgLoad>
 * @desc Game images that will be loaded upon booting up the game.
 * Use this responsibly!!!
 * @default {"animations:arraystr":"[]","battlebacks1:arraystr":"[]","battlebacks2:arraystr":"[]","characters:arraystr":"[]","enemies:arraystr":"[]","faces:arraystr":"[]","parallaxes:arraystr":"[]","pictures:arraystr":"[]","sv_actors:arraystr":"[]","sv_enemies:arraystr":"[]","system:arraystr":"[\"Balloon\",\"IconSet\"]","tilesets:arraystr":"[]","titles1:arraystr":"[]","titles2:arraystr":"[]"}
 *
 * @param KeyboardInput:struct
 * @text Keyboard Input
 * @type struct<KeyboardInput>
 * @desc Settings for the game that utilize keyboard input.
 * @default {"Controls":"","WASD:eval":"false","DashToggleR:eval":"false","NameInput":"","EnableNameInput:eval":"true","DefaultMode:str":"keyboard","QwertyLayout:eval":"true","NameInputMessage:eval":"\"Type in this character's name.\\nPress \\\\c[5]ENTER\\\\c[0] when you're done.\\n\\n-or-\\n\\nPress \\\\c[5]arrow keys\\\\c[0]/\\\\c[5]TAB\\\\c[0] to switch\\nto manual character entry.\\n\\nPress \\\\c[5]ESC\\\\c[0]/\\\\c[5]TAB\\\\c[0] to use to keyboard.\"","NumberInput":"","EnableNumberInput:eval":"true","ButtonAssist":"","Keyboard:str":"Keyboard","Manual:str":"Manual"}
 *
 * @param MenuBg:struct
 * @text Menu Background Settings
 * @type struct<MenuBg>
 * @desc Change how menu backgrounds look for each scene.
 * @default {"Scene_Menu:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Item:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Skill:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Equip:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Status:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Options:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Save:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Load:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_GameEnd:struct":"{\"SnapshotOpacity:num\":\"128\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Shop:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Name:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}","Scene_Unlisted:struct":"{\"SnapshotOpacity:num\":\"192\",\"BgFilename1:str\":\"\",\"BgFilename2:str\":\"\"}"}
 *
 * @param ButtonAssist:struct
 * @text Menu Button Assist Window
 * @type struct<ButtonAssist>
 * @desc Settings pertaining to the Button Assist window found in in-game menus.
 * @default {"General":"","Enable:eval":"true","Location:str":"bottom","BgType:num":"0","Text":"","TextFmt:str":"%1:%2","MultiKeyFmt:str":"%1/%2","OkText:str":"Select","CancelText:str":"Back","SwitchActorText:str":"Switch Ally","Keys":"","KeyUnlisted:str":"\\}❪%1❫\\{","KeyUP:str":"^","KeyDOWN:str":"v","KeyLEFT:str":"<<","KeyRIGHT:str":">>","KeySHIFT:str":"\\}❪SHIFT❫\\{","KeyTAB:str":"\\}❪TAB❫\\{","KeyA:str":"A","KeyB:str":"B","KeyC:str":"C","KeyD:str":"D","KeyE:str":"E","KeyF:str":"F","KeyG:str":"G","KeyH:str":"H","KeyI:str":"I","KeyJ:str":"J","KeyK:str":"K","KeyL:str":"L","KeyM:str":"M","KeyN:str":"N","KeyO:str":"O","KeyP:str":"P","KeyQ:str":"Q","KeyR:str":"R","KeyS:str":"S","KeyT:str":"T","KeyU:str":"U","KeyV:str":"V","KeyW:str":"W","KeyX:str":"X","KeyY:str":"Y","KeyZ:str":"Z"}
 *
 * @param MenuLayout:struct
 * @text Menu Layout Settings
 * @type struct<MenuLayout>
 * @desc Change how menu layouts look for each scene.
 * @default {"Title:struct":"{\"TitleScreen\":\"\",\"DocumentTitleFmt:str\":\"%1: %2 - Version %3\",\"Subtitle:str\":\"Subtitle\",\"Version:str\":\"0.00\",\"drawGameTitle:func\":\"\\\"const x = 20;\\\\nconst y = Graphics.height / 4;\\\\nconst maxWidth = Graphics.width - x * 2;\\\\nconst text = $dataSystem.gameTitle;\\\\nconst bitmap = this._gameTitleSprite.bitmap;\\\\nbitmap.fontFace = $gameSystem.mainFontFace();\\\\nbitmap.outlineColor = \\\\\\\"black\\\\\\\";\\\\nbitmap.outlineWidth = 8;\\\\nbitmap.fontSize = 72;\\\\nbitmap.drawText(text, x, y, maxWidth, 48, \\\\\\\"center\\\\\\\");\\\"\",\"drawGameSubtitle:func\":\"\\\"const x = 20;\\\\nconst y = Graphics.height / 4 + 72;\\\\nconst maxWidth = Graphics.width - x * 2;\\\\nconst text = Scene_Title.subtitle;\\\\nconst bitmap = this._gameTitleSprite.bitmap;\\\\nbitmap.fontFace = $gameSystem.mainFontFace();\\\\nbitmap.outlineColor = \\\\\\\"black\\\\\\\";\\\\nbitmap.outlineWidth = 6;\\\\nbitmap.fontSize = 48;\\\\nbitmap.drawText(text, x, y, maxWidth, 48, \\\\\\\"center\\\\\\\");\\\"\",\"drawGameVersion:func\":\"\\\"const bitmap = this._gameTitleSprite.bitmap;\\\\nconst x = 0;\\\\nconst y = Graphics.height - 20;\\\\nconst width = Math.round(Graphics.width / 4);\\\\nconst height = 20;\\\\nconst c1 = ColorManager.dimColor1();\\\\nconst c2 = ColorManager.dimColor2();\\\\nconst text = 'Version ' + Scene_Title.version;\\\\nbitmap.gradientFillRect(x, y, width, height, c1, c2);\\\\nbitmap.fontFace = $gameSystem.mainFontFace();\\\\nbitmap.outlineColor = \\\\\\\"black\\\\\\\";\\\\nbitmap.outlineWidth = 3;\\\\nbitmap.fontSize = 16;\\\\nbitmap.drawText(text, x + 4, y, Graphics.width, height, \\\\\\\"left\\\\\\\");\\\"\",\"CommandRect:func\":\"\\\"const offsetX = $dataSystem.titleCommandWindow.offsetX;\\\\nconst offsetY = $dataSystem.titleCommandWindow.offsetY;\\\\nconst rows = this.commandWindowRows();\\\\nconst width = this.mainCommandWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nconst x = (Graphics.boxWidth - width) / 2 + offsetX;\\\\nconst y = Graphics.boxHeight - height - 96 + offsetY;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ButtonFadeSpeed:num\":\"4\"}","MainMenu:struct":"{\"CommandWindow\":\"\",\"CommandBgType:num\":\"0\",\"CommandRect:func\":\"\\\"const width = this.mainCommandWidth();\\\\nconst height = this.mainAreaHeight() - this.goldWindowRect().height;\\\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\\\nconst y = this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"GoldWindow\":\"\",\"GoldBgType:num\":\"0\",\"GoldRect:func\":\"\\\"const rows = 1;\\\\nconst width = this.mainCommandWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\\\nconst y = this.mainAreaBottom() - height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusWindow\":\"\",\"StatusBgType:num\":\"0\",\"StatusRect:func\":\"\\\"const width = Graphics.boxWidth - this.mainCommandWidth();\\\\nconst height = this.mainAreaHeight();\\\\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\\\\nconst y = this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","ItemMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const x = 0;\\\\nconst y = this.helpAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.helpAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"CategoryWindow\":\"\",\"CategoryBgType:num\":\"0\",\"CategoryRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst rows = 1;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ItemWindow\":\"\",\"ItemBgType:num\":\"0\",\"ItemRect:func\":\"\\\"const x = 0;\\\\nconst y = this._categoryWindow.y + this._categoryWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaBottom() - y;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ActorWindow\":\"\",\"ActorBgType:num\":\"0\",\"ActorRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","SkillMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const x = 0;\\\\nconst y = this.helpAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.helpAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"SkillTypeWindow\":\"\",\"SkillTypeBgType:num\":\"0\",\"SkillTypeRect:func\":\"\\\"const rows = 3;\\\\nconst width = this.mainCommandWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\\\nconst y = this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusWindow\":\"\",\"StatusBgType:num\":\"0\",\"StatusRect:func\":\"\\\"const width = Graphics.boxWidth - this.mainCommandWidth();\\\\nconst height = this._skillTypeWindow.height;\\\\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\\\\nconst y = this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ItemWindow\":\"\",\"ItemBgType:num\":\"0\",\"ItemRect:func\":\"\\\"const x = 0;\\\\nconst y = this._statusWindow.y + this._statusWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight() - this._statusWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ActorWindow\":\"\",\"ActorBgType:num\":\"0\",\"ActorRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","EquipMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const x = 0;\\\\nconst y = this.helpAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.helpAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusWindow\":\"\",\"StatusBgType:num\":\"0\",\"StatusRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst width = this.statusWidth();\\\\nconst height = this.mainAreaHeight();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"CommandWindow\":\"\",\"CommandBgType:num\":\"0\",\"CommandRect:func\":\"\\\"const x = this.statusWidth();\\\\nconst y = this.mainAreaTop();\\\\nconst rows = 1;\\\\nconst width = Graphics.boxWidth - this.statusWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"SlotWindow\":\"\",\"SlotBgType:num\":\"0\",\"SlotRect:func\":\"\\\"const commandWindowRect = this.commandWindowRect();\\\\nconst x = this.statusWidth();\\\\nconst y = commandWindowRect.y + commandWindowRect.height;\\\\nconst width = Graphics.boxWidth - this.statusWidth();\\\\nconst height = this.mainAreaHeight() - commandWindowRect.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ItemWindow\":\"\",\"ItemBgType:num\":\"0\",\"ItemRect:func\":\"\\\"return this.slotWindowRect();\\\"\"}","StatusMenu:struct":"{\"ProfileWindow\":\"\",\"ProfileBgType:num\":\"0\",\"ProfileRect:func\":\"\\\"const width = Graphics.boxWidth;\\\\nconst height = this.profileHeight();\\\\nconst x = 0;\\\\nconst y = this.mainAreaBottom() - height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusWindow\":\"\",\"StatusBgType:num\":\"0\",\"StatusRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.statusParamsWindowRect().y - y;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusParamsWindow\":\"\",\"StatusParamsBgType:num\":\"0\",\"StatusParamsRect:func\":\"\\\"const width = this.statusParamsWidth();\\\\nconst height = this.statusParamsHeight();\\\\nconst x = 0;\\\\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusEquipWindow\":\"\",\"StatusEquipBgType:num\":\"0\",\"StatusEquipRect:func\":\"\\\"const width = Graphics.boxWidth - this.statusParamsWidth();\\\\nconst height = this.statusParamsHeight();\\\\nconst x = this.statusParamsWidth();\\\\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","OptionsMenu:struct":"{\"OptionsWindow\":\"\",\"OptionsBgType:num\":\"0\",\"OptionsRect:func\":\"\\\"const n = Math.min(this.maxCommands(), this.maxVisibleCommands());\\\\nconst width = 400;\\\\nconst height = this.calcWindowHeight(n, true);\\\\nconst x = (Graphics.boxWidth - width) / 2;\\\\nconst y = (Graphics.boxHeight - height) / 2;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","SaveMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst rows = 1;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.calcWindowHeight(rows, false);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ListWindow\":\"\",\"ListBgType:num\":\"0\",\"ListRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop() + this._helpWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight() - this._helpWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","LoadMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst rows = 1;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.calcWindowHeight(rows, false);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"ListWindow\":\"\",\"ListBgType:num\":\"0\",\"ListRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop() + this._helpWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight() - this._helpWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","GameEnd:struct":"{\"CommandList:arraystruct\":\"[\\\"{\\\\\\\"Symbol:str\\\\\\\":\\\\\\\"toTitle\\\\\\\",\\\\\\\"TextStr:str\\\\\\\":\\\\\\\"Untitled\\\\\\\",\\\\\\\"TextJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return TextManager.toTitle;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"ShowJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return true;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"EnableJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return true;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"ExtJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return null;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"CallHandlerJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"SceneManager._scene.commandToTitle();\\\\\\\\\\\\\\\"\\\\\\\"}\\\",\\\"{\\\\\\\"Symbol:str\\\\\\\":\\\\\\\"cancel\\\\\\\",\\\\\\\"TextStr:str\\\\\\\":\\\\\\\"Untitled\\\\\\\",\\\\\\\"TextJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return TextManager.cancel;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"ShowJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return true;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"EnableJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return true;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"ExtJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"return null;\\\\\\\\\\\\\\\"\\\\\\\",\\\\\\\"CallHandlerJS:func\\\\\\\":\\\\\\\"\\\\\\\\\\\\\\\"SceneManager._scene.popScene();\\\\\\\\\\\\\\\"\\\\\\\"}\\\"]\",\"CommandBgType:num\":\"0\",\"CommandRect:func\":\"\\\"const rows = 2;\\\\nconst width = this.mainCommandWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nconst x = (Graphics.boxWidth - width) / 2;\\\\nconst y = (Graphics.boxHeight - height) / 2;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","ShopMenu:struct":"{\"HelpWindow\":\"\",\"HelpBgType:num\":\"0\",\"HelpRect:func\":\"\\\"const wx = 0;\\\\nconst wy = this.helpAreaTop();\\\\nconst ww = Graphics.boxWidth;\\\\nconst wh = this.helpAreaHeight();\\\\nreturn new Rectangle(wx, wy, ww, wh);\\\"\",\"GoldWindow\":\"\",\"GoldBgType:num\":\"0\",\"GoldRect:func\":\"\\\"const rows = 1;\\\\nconst width = this.mainCommandWidth();\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nconst x = Graphics.boxWidth - width;\\\\nconst y = this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"CommandWindow\":\"\",\"CommandBgType:num\":\"0\",\"CommandRect:func\":\"\\\"const x = 0;\\\\nconst y = this.mainAreaTop();\\\\nconst rows = 1;\\\\nconst width = this._goldWindow.x;\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"DummyWindow\":\"\",\"DummyBgType:num\":\"0\",\"DummyRect:func\":\"\\\"const x = 0;\\\\nconst y = this._commandWindow.y + this._commandWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.mainAreaHeight() - this._commandWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"NumberWindow\":\"\",\"NumberBgType:num\":\"0\",\"NumberRect:func\":\"\\\"const x = 0;\\\\nconst y = this._dummyWindow.y;\\\\nconst width = Graphics.boxWidth - this.statusWidth();\\\\nconst height = this._dummyWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"StatusWindow\":\"\",\"StatusBgType:num\":\"0\",\"StatusRect:func\":\"\\\"const width = this.statusWidth();\\\\nconst height = this._dummyWindow.height;\\\\nconst x = Graphics.boxWidth - width;\\\\nconst y = this._dummyWindow.y;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"BuyWindow\":\"\",\"BuyBgType:num\":\"0\",\"BuyRect:func\":\"\\\"const x = 0;\\\\nconst y = this._dummyWindow.y;\\\\nconst width = Graphics.boxWidth - this.statusWidth();\\\\nconst height = this._dummyWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"CategoryWindow\":\"\",\"CategoryBgType:num\":\"0\",\"CategoryRect:func\":\"\\\"const x = 0;\\\\nconst y = this._dummyWindow.y;\\\\nconst rows = 1;\\\\nconst width = Graphics.boxWidth;\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"SellWindow\":\"\",\"SellBgType:num\":\"0\",\"SellRect:func\":\"\\\"const x = 0;\\\\nconst y = this._categoryWindow.y + this._categoryWindow.height;\\\\nconst width = Graphics.boxWidth;\\\\nconst height =\\\\n    this.mainAreaHeight() -\\\\n    this._commandWindow.height -\\\\n    this._categoryWindow.height;\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}","NameMenu:struct":"{\"EditWindow\":\"\",\"EditBgType:num\":\"0\",\"EditRect:func\":\"\\\"const rows = 9;\\\\nconst inputWindowHeight = this.calcWindowHeight(rows, true);\\\\nconst padding = $gameSystem.windowPadding();\\\\nconst width = 600;\\\\nconst height = Math.min(ImageManager.faceHeight + padding * 2, this.mainAreaHeight() - inputWindowHeight);\\\\nconst x = (Graphics.boxWidth - width) / 2;\\\\nconst y = (this.mainAreaHeight() - (height + inputWindowHeight)) / 2 + this.mainAreaTop();\\\\nreturn new Rectangle(x, y, width, height);\\\"\",\"InputWindow\":\"\",\"InputBgType:num\":\"0\",\"InputRect:func\":\"\\\"const x = this._editWindow.x;\\\\nconst y = this._editWindow.y + this._editWindow.height;\\\\nconst rows = 9;\\\\nconst width = this._editWindow.width;\\\\nconst height = this.calcWindowHeight(rows, true);\\\\nreturn new Rectangle(x, y, width, height);\\\"\"}"}
 *
 * @param Param:struct
 * @text Parameter Settings
 * @type struct<Param>
 * @desc Change up the limits of parameters and how they're calculated.
 * @default {"DisplayedParams:arraystr":"[\"ATK\",\"DEF\",\"MAT\",\"MDF\",\"AGI\",\"LUK\"]","ExtDisplayedParams:arraystr":"[\"MaxHP\",\"MaxMP\",\"ATK\",\"DEF\",\"MAT\",\"MDF\",\"AGI\",\"LUK\"]","BasicParameters":"","CrisisRate:num":"0.25","BasicParameterFormula:func":"\"// Determine the variables used in this calculation.\\nlet paramId = arguments[0];\\nlet base = this.paramBase(paramId);\\nlet plus = this.paramPlus(paramId);\\nlet paramRate = this.paramRate(paramId);\\nlet buffRate = this.paramBuffRate(paramId);\\nlet flatBonus = this.paramFlatBonus(paramId);\\n\\n// Formula to determine total parameter value.\\nlet value = (base + plus) * paramRate * buffRate + flatBonus;\\n\\n// Determine the limits\\nconst maxValue = this.paramMax(paramId);\\nconst minValue = this.paramMin(paramId);\\n\\n// Final value\\nreturn Math.round(value.clamp(minValue, maxValue));\"","BasicParamCaps":"","BasicActorParamCaps":"","BasicActorParamMax0:str":"9999","BasicActorParamMax1:str":"9999","BasicActorParamMax2:str":"999","BasicActorParamMax3:str":"999","BasicActorParamMax4:str":"999","BasicActorParamMax5:str":"999","BasicActorParamMax6:str":"999","BasicActorParamMax7:str":"999","BasicEnemyParamCaps":"","BasicEnemyParamMax0:str":"999999","BasicEnemyParamMax1:str":"9999","BasicEnemyParamMax2:str":"999","BasicEnemyParamMax3:str":"999","BasicEnemyParamMax4:str":"999","BasicEnemyParamMax5:str":"999","BasicEnemyParamMax6:str":"999","BasicEnemyParamMax7:str":"999","XParameters":"","XParameterFormula:func":"\"// Determine the variables used in this calculation.\\nlet xparamId = arguments[0];\\nlet base = this.traitsSum(Game_BattlerBase.TRAIT_XPARAM, xparamId);\\nlet plus = this.xparamPlus(xparamId);\\nlet paramRate = this.xparamRate(xparamId);\\nlet flatBonus = this.xparamFlatBonus(xparamId);\\n\\n// Formula to determine total parameter value.\\nlet value = (base + plus) * paramRate + flatBonus;\\n\\n// Final value\\nreturn value;\"","XParamVocab":"","XParamVocab0:str":"Hit","XParamVocab1:str":"Evasion","XParamVocab2:str":"Critical Rate","XParamVocab3:str":"Critical Evade","XParamVocab4:str":"Magic Evade","XParamVocab5:str":"Magic Reflect","XParamVocab6:str":"Counter","XParamVocab7:str":"HP Regen","XParamVocab8:str":"MP Regen","XParamVocab9:str":"TP Regen","SParameters":"","SParameterFormula:func":"\"// Determine the variables used in this calculation.\\nlet sparamId = arguments[0];\\nlet base = this.traitsPi(Game_BattlerBase.TRAIT_SPARAM, sparamId);\\nlet plus = this.sparamPlus(sparamId);\\nlet paramRate = this.sparamRate(sparamId);\\nlet flatBonus = this.sparamFlatBonus(sparamId);\\n\\n// Formula to determine total parameter value.\\nlet value = (base + plus) * paramRate + flatBonus;\\n\\n// Final value\\nreturn value;\"","SParamVocab":"","SParamVocab0:str":"Aggro","SParamVocab1:str":"Guard","SParamVocab2:str":"Recovery","SParamVocab3:str":"Item Effect","SParamVocab4:str":"MP Cost","SParamVocab5:str":"TP Charge","SParamVocab6:str":"Physical DMG","SParamVocab7:str":"Magical DMG","SParamVocab8:str":"Floor DMG","SParamVocab9:str":"EXP Gain","Icons":"","DrawIcons:eval":"true","IconParam0:str":"84","IconParam1:str":"165","IconParam2:str":"76","IconParam3:str":"81","IconParam4:str":"101","IconParam5:str":"133","IconParam6:str":"140","IconParam7:str":"87","IconXParam0:str":"102","IconXParam1:str":"82","IconXParam2:str":"78","IconXParam3:str":"82","IconXParam4:str":"171","IconXParam5:str":"222","IconXParam6:str":"77","IconXParam7:str":"72","IconXParam8:str":"72","IconXParam9:str":"72","IconSParam0:str":"5","IconSParam1:str":"128","IconSParam2:str":"72","IconSParam3:str":"176","IconSParam4:str":"165","IconSParam5:str":"164","IconSParam6:str":"76","IconSParam7:str":"79","IconSParam8:str":"141","IconSParam9:str":"73"}
 *
 * @param CustomParam:arraystruct
 * @text Custom Parameters
 * @parent Param:struct
 * @type struct<CustomParam>[]
 * @desc Create custom parameters for your game!
 * These will appear in VisuStella MZ menus.
 * @default ["{\"ParamName:str\":\"Strength\",\"Abbreviation:str\":\"str\",\"Icon:num\":\"77\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.atk * 0.75) + (user.def * 0.25);\\\"\"}","{\"ParamName:str\":\"Dexterity\",\"Abbreviation:str\":\"dex\",\"Icon:num\":\"82\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.agi * 0.75) + (user.atk * 0.25);\\\"\"}","{\"ParamName:str\":\"Constitution\",\"Abbreviation:str\":\"con\",\"Icon:num\":\"81\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.def * 0.75) + (user.mdf * 0.25);\\\"\"}","{\"ParamName:str\":\"Intelligence\",\"Abbreviation:str\":\"int\",\"Icon:num\":\"79\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.mat * 0.75) + (user.mdf * 0.25);\\\"\"}","{\"ParamName:str\":\"Wisdom\",\"Abbreviation:str\":\"wis\",\"Icon:num\":\"72\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.mdf * 0.75) + (user.luk * 0.25);\\\"\"}","{\"ParamName:str\":\"Charisma\",\"Abbreviation:str\":\"cha\",\"Icon:num\":\"84\",\"Type:str\":\"integer\",\"ValueJS:json\":\"\\\"// Declare Constants\\\\nconst user = this;\\\\n\\\\n// Calculations\\\\nreturn (user.luk * 0.75) + (user.agi * 0.25);\\\"\"}"]
 *
 * @param ScreenResolution:struct
 * @text Screen Resolution Settings
 * @type struct<ScreenResolution>
 * @desc Alter various properties to make the game look better for varying screen resolutions.
 * @default {"Troops":"","RepositionActors:eval":"true","RepositionEnemies:eval":"true","RepositionEnemies130:eval":"false"}
 *
 * @param ScreenShake:struct
 * @text Screen Shake Settings
 * @type struct<ScreenShake>
 * @desc Get more screen shake effects into your game!
 * @default {"DefaultStyle:str":"random","originalJS:func":"\"// Calculation\\nthis.x += Math.round($gameScreen.shake());\"","randomJS:func":"\"// Calculation\\n// Original Formula by Aries of Sheratan\\nconst power = $gameScreen._shakePower * 0.75;\\nconst speed = $gameScreen._shakeSpeed * 0.60;\\nconst duration = $gameScreen._shakeDuration;\\nthis.x += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);\\nthis.y += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);\"","horzJS:func":"\"// Calculation\\n// Original Formula by Aries of Sheratan\\nconst power = $gameScreen._shakePower * 0.75;\\nconst speed = $gameScreen._shakeSpeed * 0.60;\\nconst duration = $gameScreen._shakeDuration;\\nthis.x += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);\"","vertJS:func":"\"// Calculation\\n// Original Formula by Aries of Sheratan\\nconst power = $gameScreen._shakePower * 0.75;\\nconst speed = $gameScreen._shakeSpeed * 0.60;\\nconst duration = $gameScreen._shakeDuration;\\nthis.y += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);\""}
 *
 * @param TitleCommandList:arraystruct
 * @text Title Command List
 * @type struct<Command>[]
 * @desc Window commands used by the title screen.
 * Add new commands here.
 * @default ["{\"Symbol:str\":\"newGame\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.newGame;\\\"\",\"ShowJS:func\":\"\\\"return true;\\\"\",\"EnableJS:func\":\"\\\"return true;\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager._scene.commandNewGame();\\\"\"}","{\"Symbol:str\":\"continue\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.continue_;\\\"\",\"ShowJS:func\":\"\\\"return true;\\\"\",\"EnableJS:func\":\"\\\"return DataManager.isAnySavefileExists();\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager._scene.commandContinue();\\\"\"}","{\"Symbol:str\":\"options\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.options;\\\"\",\"ShowJS:func\":\"\\\"return true;\\\"\",\"EnableJS:func\":\"\\\"return true;\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager._scene.commandOptions();\\\"\"}","{\"Symbol:str\":\"shutdown\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.gameEnd;\\\"\",\"ShowJS:func\":\"\\\"return Utils.isNwjs();\\\"\",\"EnableJS:func\":\"\\\"return true;\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager.exit();\\\\n\\\\n// Note!\\\\n// Do NOT use this command with mobile devices or\\\\n// browser games. All it does is cause the game to\\\\n// display a blank, black canvas which the player\\\\n// is unable to do anything with. It does NOT force\\\\n// close the browser tab nor the app.\\\"\"}"]
 *
 * @param TitlePicButtons:arraystruct
 * @text Title Picture Buttons
 * @type struct<TitlePictureButton>[]
 * @desc Buttons that can be inserted into the title screen.
 * Add new title buttons here.
 * @default []
 *
 * @param UI:struct
 * @text UI Settings
 * @type struct<UI>
 * @desc Change up various in-game UI aspects.
 * @default {"UIArea":"","FadeSpeed:num":"24","BoxMargin:num":"4","CommandWidth:num":"240","BottomHelp:eval":"false","RightMenus:eval":"true","ShowButtons:eval":"true","cancelShowButton:eval":"true","menuShowButton:eval":"true","pagedownShowButton:eval":"true","numberShowButton:eval":"true","ButtonHeight:num":"52","BottomButtons:eval":"false","SideButtons:eval":"true","MenuObjects":"","LvExpGauge:eval":"true","ParamArrow:str":"→","TextCodeSupport":"","TextCodeClassNames:eval":"true","TextCodeNicknames:eval":"true"}
 *
 * @param Window:struct
 * @text Window Settings
 * @type struct<Window>
 * @desc Adjust various in-game window settings.
 * @default {"WindowDefaults":"","EnableMasking:eval":"false","LineHeight:num":"36","SelectableItems":"","ShowItemBackground:eval":"true","ItemHeight:num":"8","DrawItemBackgroundJS:func":"\"const rect = arguments[0];\\nconst c1 = ColorManager.itemBackColor1();\\nconst c2 = ColorManager.itemBackColor2();\\nconst x = rect.x;\\nconst y = rect.y;\\nconst w = rect.width;\\nconst h = rect.height;\\nthis.contentsBack.gradientFillRect(x, y, w, h, c1, c2, true);\\nthis.contentsBack.strokeRect(x, y, w, h, c1);\"","ItemPadding:num":"8","BackOpacity:num":"192","TranslucentOpacity:num":"160","OpenSpeed:num":"32","ColSpacing:num":"8","RowSpacing:num":"4"}
 *
 * @param jsQuickFunc:arraystruct
 * @text JS: Quick Functions
 * @type struct<jsQuickFunc>[]
 * @desc Create quick JavaScript functions available from the
 * global namespace. Use with caution and moderation!!!
 * @default ["{\"FunctionName:str\":\"Example\",\"CodeJS:json\":\"\\\"// Insert this as a function anywhere you can input code\\\\n// such as Script Calls or Conditional Branch Scripts.\\\\n\\\\n// Process Code\\\\nreturn 'Example';\\\"\"}","{\"FunctionName:str\":\"Bad  Code  Name\",\"CodeJS:json\":\"\\\"// If a function name has spaces in them, the spaces will\\\\n// be removed. \\\\\\\"Bad  Code  Name\\\\\\\" becomes \\\\\\\"BadeCodeName\\\\\\\".\\\\n\\\\n// Process Code\\\\nOhNoItsBadCode()\\\\n\\\\n// If a function has bad code, a fail safe will catch the\\\\n// error and display it in the console.\\\"\"}","{\"FunctionName:str\":\"RandomNumber\",\"CodeJS:json\":\"\\\"// This generates a random number from 0 to itself.\\\\n// Example: RandomNumber(10)\\\\n\\\\n// Process Code\\\\nconst number = (arguments[0] || 0) + 1;\\\\nreturn Math.floor(number * Math.random());\\\"\"}","{\"FunctionName:str\":\"RandomBetween\",\"CodeJS:json\":\"\\\"// This generates a random number between two arguments.\\\\n// Example: RandomNumber(5, 10)\\\\n\\\\n// Process Code\\\\nlet min = Math.min(arguments[0] || 0, arguments[1] || 0);\\\\nlet max = Math.max(arguments[0] || 0, arguments[1] || 0);\\\\nreturn Math.floor(Math.random() * (max - min + 1) + min);\\\"\"}","{\"FunctionName:str\":\"RandomFrom\",\"CodeJS:json\":\"\\\"// Selects a number from the list of inserted numbers.\\\\n// Example: RandomFrom(5, 10, 15, 20)\\\\n\\\\n// Process Code\\\\nreturn arguments[Math.randomInt(arguments.length)];\\\"\"}"]
 *
 * @param BreakEnd1
 * @text --------------------------
 * @default ----------------------------------
 *
 * @param End Of
 * @default Plugin Parameters
 *
 * @param BreakEnd2
 * @text --------------------------
 * @default ----------------------------------
 *
 */
/* ----------------------------------------------------------------------------
 * Quality of Life Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~QoLSettings:
 *
 * @param PlayTest
 * @text Play Test
 *
 * @param NewGameBoot:eval
 * @text New Game on Boot
 * @parent PlayTest
 * @type boolean
 * @on Start New Game
 * @off Keep Title Screen
 * @desc Automatically start a new game on Play Test?
 * Only enabled during Play Test.
 * @default false
 *
 * @param ForceNoPlayTest:eval
 * @text No Play Test Mode
 * @parent PlayTest
 * @type boolean
 * @on Cancel Play Test
 * @off Keep Play Test
 * @desc Force the game to be out of Play Test mode when play testing.
 * @default false
 *
 * @param OpenConsole:eval
 * @text Open Console on Boot
 * @parent PlayTest
 * @type boolean
 * @on Open
 * @off Don't Open
 * @desc Open the Debug Console upon booting up your game?
 * Only enabled during Play Test.
 * @default true
 *
 * @param F6key:eval
 * @text F6: Toggle Sound
 * @parent PlayTest
 * @type boolean
 * @on Enable
 * @off Don't
 * @desc F6 Key Function: Turn on all sound to 100% or to 0%,
 * toggling between the two.
 * @default true
 *
 * @param F7key:eval
 * @text F7: Toggle Fast Mode
 * @parent PlayTest
 * @type boolean
 * @on Enable
 * @off Don't
 * @desc F7 Key Function: Toggle fast mode.
 * @default true
 *
 * @param NewGameCommonEvent:num
 * @text NewGame > CommonEvent
 * @parent PlayTest
 * @type common_event
 * @desc Runs a common event each time a new game during play test
 * session is started.
 * @default 0
 *
 * @param BattleTest
 * @text Battle Test
 *
 * @param BTestItems:eval
 * @text Add Item Type
 * @parent BattleTest
 * @type boolean
 * @on Add
 * @off Don't
 * @desc Add copies of each database item?
 * Effective only during battle test.
 * @default true
 *
 * @param BTestWeapons:eval
 * @text Add Weapon Type
 * @parent BattleTest
 * @type boolean
 * @on Add
 * @off Don't
 * @desc Add copies of each database weapon?
 * Effective only during battle test.
 * @default true
 *
 * @param BTestArmors:eval
 * @text Add Armor Type
 * @parent BattleTest
 * @type boolean
 * @on Add
 * @off Don't
 * @desc Add copies of each database armor?
 * Effective only during battle test.
 * @default true
 *
 * @param BTestAddedQuantity:num
 * @text Added Quantity
 * @parent BattleTest
 * @type number
 * @min 1
 * @desc Determines how many items are added during a battle test instead of the maximum amount.
 * @default 90
 *
 * @param DigitGrouping
 * @text Digit Grouping
 *
 * @param DigitGroupingStandardText:eval
 * @text Standard Text
 * @parent DigitGrouping
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Make numbers like 1234567 appear like 1,234,567 for
 * standard text inside windows?
 * @default true
 *
 * @param DigitGroupingExText:eval
 * @text Ex Text
 * @parent DigitGrouping
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Make numbers like 1234567 appear like 1,234,567 for
 * ex text, written through drawTextEx (like messages)?
 * @default true
 *
 * @param DigitGroupingDamageSprites:eval
 * @text Damage Sprites
 * @parent DigitGrouping
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Make numbers like 1234567 appear like 1,234,567 for
 * in-battle damage sprites?
 * @default true
 *
 * @param DigitGroupingGaugeSprites:eval
 * @text Gauge Sprites
 * @parent DigitGrouping
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Make numbers like 1234567 appear like 1,234,567 for
 * visible gauge sprites such as HP, MP, and TP gauges?
 * @default true
 *
 * @param DigitGroupingLocale:str
 * @text Country/Locale
 * @parent DigitGrouping
 * @type combo
 * @option ar-SA
 * @option bn-BD
 * @option bn-IN
 * @option cs-CZ
 * @option da-DK
 * @option de-AT
 * @option de-CH
 * @option de-DE
 * @option el-GR
 * @option en-AU
 * @option en-CA
 * @option en-GB
 * @option en-IE
 * @option en-IN
 * @option en-NZ
 * @option en-US
 * @option en-ZA
 * @option es-AR
 * @option es-CL
 * @option es-CO
 * @option es-ES
 * @option es-MX
 * @option es-US
 * @option fi-FI
 * @option fr-BE
 * @option fr-CA
 * @option fr-CH
 * @option fr-FR
 * @option he-IL
 * @option hi-IN
 * @option hu-HU
 * @option id-ID
 * @option it-CH
 * @option it-IT
 * @option jp-JP
 * @option ko-KR
 * @option nl-BE
 * @option nl-NL
 * @option no-NO
 * @option pl-PL
 * @option pt-BR
 * @option pt-PT
 * @option ro-RO
 * @option ru-RU
 * @option sk-SK
 * @option sv-SE
 * @option ta-IN
 * @option ta-LK
 * @option th-TH
 * @option tr-TR
 * @option zh-CN
 * @option zh-HK
 * @option zh-TW
 * @desc Base the digit grouping on which country/locale?
 * @default en-US
 *
 * @param PlayerBenefit
 * @text Player Benefit
 *
 * @param EncounterRateMinimum:num
 * @text Encounter Rate Min
 * @parent PlayerBenefit
 * @min 1
 * @desc Minimum number of steps the player can take without any random encounters.
 * @default 10
 *
 * @param EscapeAlways:eval
 * @text Escape Always
 * @parent PlayerBenefit
 * @type boolean
 * @on Always
 * @off Default
 * @desc If the player wants to escape a battle, let them escape the battle with 100% chance.
 * @default true
 *
 * @param ImprovedAccuracySystem:eval
 * @text Accuracy Formula
 * @parent PlayerBenefit
 * @type boolean
 * @on Improve
 * @off Default
 * @desc Accuracy formula calculation change to
 * Skill Hit% * (User HIT - Target EVA) for better results.
 * @default true
 *
 * @param AccuracyBoost:eval
 * @text Accuracy Boost
 * @parent PlayerBenefit
 * @type boolean
 * @on Boost
 * @off Default
 * @desc Boost HIT and EVA rates in favor of the player.
 * @default true
 *
 * @param LevelUpFullHp:eval
 * @text Level Up -> Full HP
 * @parent PlayerBenefit
 * @type boolean
 * @on Heal
 * @off Default
 * @desc Recovers full HP when an actor levels up.
 * @default true
 *
 * @param LevelUpFullMp:eval
 * @text Level Up -> Full MP
 * @parent PlayerBenefit
 * @type boolean
 * @on Heal
 * @off Default
 * @desc Recovers full MP when an actor levels up.
 * @default true
 *
 * @param Pictures
 * @text Picture-Related
 *
 * @param AntiZoomPictures:eval
 * @text Anti-Zoom Pictures
 * @parent Pictures
 * @type boolean
 * @on Anti-Zoom
 * @off Normal
 * @desc If on, prevents pictures from being affected by zoom.
 * @default true
 * 
 * @param PictureContainers
 * @text Picture Containers
 * @parent Pictures
 *
 * @param DetachBattlePictureContainer:eval
 * @text Detach in Battle
 * @parent PictureContainers
 * @type boolean
 * @on Detach
 * @off Normal
 * @desc If detached, picture container will be separated from
 * the spriteset while on the battle scene.
 * @default false
 *
 * @param DetachMapPictureContainer:eval
 * @text Detach in Map
 * @parent PictureContainers
 * @type boolean
 * @on Detach
 * @off Normal
 * @desc If detached, picture container will be separated from
 * the spriteset while on the map scene.
 * @default false
 *
 * @param Misc
 * @text Misc
 *
 * @param AnimationMirrorOffset:eval
 * @text Ani: Mirror Offset
 * @parent Misc
 * @type boolean
 * @on Mirror
 * @off Don't Mirror
 * @desc When animations are mirrored,
 * mirror their Offset X values, too.
 * @default false
 *
 * @param AutoStretch:str
 * @text Auto-Stretch
 * @parent Misc
 * @type select
 * @option Default
 * @value default
 * @option Stretch
 * @value stretch
 * @option Normal
 * @value normal
 * @desc Automatically stretch the game to fit the size of the client?
 * @default default
 *
 * @param FontShadows:eval
 * @text Font Shadows
 * @parent Misc
 * @type boolean
 * @on Shadows
 * @off Outlines
 * @desc If on, text uses shadows instead of outlines.
 * @default false
 *
 * @param FontSmoothing:eval
 * @text Font Smoothing
 * @parent Misc
 * @type boolean
 * @on Smooth
 * @off None
 * @desc If on, smoothes fonts shown in-game.
 * @default true
 *
 * @param FontWidthFix:eval
 * @text Font Width Fix
 * @parent Misc
 * @type boolean
 * @on Fix
 * @off Default
 * @desc Fixes the font width issue with instant display
 * non-monospaced fonts in the Message Window.
 * @default true
 *
 * @param KeyItemProtect:eval
 * @text Key Item Protection
 * @parent Misc
 * @type boolean
 * @on Unsellable
 * @off Sellable
 * @desc If on, prevents Key Items from being able to be sold and from being able to be consumed.
 * @default true
 *
 * @param ModernControls:eval
 * @text Modern Controls
 * @parent Misc
 * @type boolean
 * @on Enable
 * @off Default
 * @desc If on, allows usage of the Home/End buttons as well as other modern configs. Affects other VisuStella plugins.
 * @default true
 *
 * @param MvAnimationRate:num
 * @text MV Animation Rate
 * @parent Misc
 * @min 1
 * @max 10
 * @desc Adjusts the rate at which MV animations play.
 * Default: 4. Lower for faster. Higher for slower.
 * @default 4
 *
 * @param NewGameCommonEventAll:num
 * @text NewGame > CommonEvent
 * @parent Misc
 * @type common_event
 * @desc Runs a common event each time a new game during any session is started.
 * @default 0
 *
 * @param NoTileShadows:eval
 * @text No Tile Shadows
 * @parent Misc
 * @type boolean
 * @on Disable Tile Shadows
 * @off Default
 * @desc Removes tile shadows from being displayed in-game.
 * @default false
 *
 * @param PixelateImageRendering:eval
 * @text Pixel Image Rendering
 * @parent Misc
 * @type boolean
 * @on Pixelate
 * @off Smooth
 * @desc If on, pixelates the image rendering (for pixel games).
 * @default false
 *
 * @param RequireFocus:eval
 * @text Require Focus?
 * @parent Misc
 * @type boolean
 * @on Require
 * @off No Requirement
 * @desc Requires the game to be focused? If the game isn't
 * focused, it will pause if it's not the active window.
 * @default true
 *
 * @param ShortcutScripts:eval
 * @text Shortcut Scripts
 * @parent Misc
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Enables shortcut-based scripts.
 * View the helpfile for more information.
 * @default true
 *
 * @param SmartEventCollisionPriority:eval
 * @text Smart Event Collision
 * @parent Misc
 * @type boolean
 * @on Only Same Level
 * @off Default
 * @desc Makes events only able to collide with one another if they're 'Same as characters' priority.
 * @default true
 *
 * @param SubfolderParse:eval
 * @text Subfolder Name Purge
 * @parent Misc
 * @type boolean
 * @on Purge Subfolders Names
 * @off Don't Purge Name
 * @desc Purge subfolder name from Plugin Parameters when reading
 * data to let Plugin Commands work properly.
 * @default true
 *
 */
/* ----------------------------------------------------------------------------
 * Color Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Color:
 *
 * @param BasicColors
 * @text Basic Colors
 *
 * @param ColorNormal:str
 * @text Normal
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 0
 *
 * @param ColorSystem:str
 * @text System
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 16
 *
 * @param ColorCrisis:str
 * @text Crisis
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 17
 *
 * @param ColorDeath:str
 * @text Death
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 18
 *
 * @param ColorGaugeBack:str
 * @text Gauge Back
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 19
 *
 * @param ColorHPGauge1:str
 * @text HP Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 20
 *
 * @param ColorHPGauge2:str
 * @text HP Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 21
 *
 * @param ColorMPGauge1:str
 * @text MP Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 22
 *
 * @param ColorMPGauge2:str
 * @text MP Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 23
 *
 * @param ColorMPCost:str
 * @text MP Cost
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 23
 *
 * @param ColorPowerUp:str
 * @text Power Up
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 24
 *
 * @param ColorPowerDown:str
 * @text Power Down
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 25
 *
 * @param ColorCTGauge1:str
 * @text CT Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 26
 *
 * @param ColorCTGauge2:str
 * @text CT Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 27
 *
 * @param ColorTPGauge1:str
 * @text TP Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 28
 *
 * @param ColorTPGauge2:str
 * @text TP Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 29
 *
 * @param ColorTPCost:str
 * @text TP Cost
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 29
 *
 * @param ColorPending:str
 * @text Pending Color
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default #2a847d
 *
 * @param ColorExpGauge1:str
 * @text EXP Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 30
 *
 * @param ColorExpGauge2:str
 * @text EXP Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 31
 *
 * @param ColorMaxLvGauge1:str
 * @text MaxLv Gauge 1
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 14
 *
 * @param ColorMaxLvGauge2:str
 * @text MaxLv Gauge 2
 * @parent BasicColors
 * @desc Use #rrggbb for custom colors or regular numbers
 * for text colors from the Window Skin.
 * @default 6
 *
 * @param AlphaColors
 * @text Alpha Colors
 *
 * @param OutlineColor:str
 * @text Window Font Outline
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(0, 0, 0, 0.6)
 *
 * @param OutlineColorGauge:str
 * @text Gauge Number Outline
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(0, 0, 0, 1.0)
 *
 * @param DimColor1:str
 * @text Dim Color 1
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(0, 0, 0, 0.6)
 *
 * @param DimColor2:str
 * @text Dim Color 2
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(0, 0, 0, 0)
 *
 * @param ItemBackColor1:str
 * @text Item Back Color 1
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(32, 32, 32, 0.5)
 *
 * @param ItemBackColor2:str
 * @text Item Back Color 2
 * @parent AlphaColors
 * @desc Colors with a bit of alpha settings.
 * Format rgba(0-255, 0-255, 0-255, 0-1)
 * @default rgba(0, 0, 0, 0.5)
 *
 * @param ConditionalColors
 * @text Conditional Colors
 *
 * @param ActorHPColor:func
 * @text JS: Actor HP Color
 * @type note
 * @parent ConditionalColors
 * @desc Code used for determining what HP color to use for actors.
 * @default "// Set the variables used in this function.\nlet actor = arguments[0];\n\n// Check if the actor exists. If not, return normal.\nif (!actor) {\n    return this.normalColor();\n\n// If the actor is dead, return death color.\n} else if (actor.isDead()) {\n    return this.deathColor();\n\n// If the actor is dying, return crisis color.\n} else if (actor.isDying()) {\n    return this.crisisColor();\n\n// Otherwise, return the normal color.\n} else {\n    return this.normalColor();\n}"
 *
 * @param ActorMPColor:func
 * @text JS: Actor MP Color
 * @type note
 * @parent ConditionalColors
 * @desc Code used for determining what MP color to use for actors.
 * @default "// Set the variables used in this function.\nlet actor = arguments[0];\n\n// Check if the actor exists. If not, return normal.\nif (!actor) {\n    return this.normalColor();\n\n// If MP rate is below 25%, return crisis color.\n} else if (actor.mpRate() < 0.25) {\n    return this.crisisColor();\n\n// Otherwise, return the normal color.\n} else {\n    return this.normalColor();\n}"
 *
 * @param ActorTPColor:func
 * @text JS: Actor TP Color
 * @type note
 * @parent ConditionalColors
 * @desc Code used for determining what TP color to use for actors.
 * @default "// Set the variables used in this function.\nlet actor = arguments[0];\n\n// Check if the actor exists. If not, return normal.\nif (!actor) {\n    return this.normalColor();\n\n// If TP rate is below 25%, return crisis color.\n} else if (actor.tpRate() < 0.25) {\n    return this.crisisColor();\n\n// Otherwise, return the normal color.\n} else {\n    return this.normalColor();\n}"
 *
 * @param ParamChange:func
 * @text JS: Parameter Change
 * @type note
 * @parent ConditionalColors
 * @desc Code used for determining whatcolor to use for parameter changes.
 * @default "// Set the variables used in this function.\nlet change = arguments[0];\n\n// If a positive change, use power up color.\nif (change > 0) {\n    return this.powerUpColor();\n\n// If a negative change, use power down color.\n} else if (change < 0) {\n    return this.powerDownColor();\n\n// Otherwise, return the normal color.\n} else {\n    return this.normalColor();\n}"
 *
 * @param DamageColor:func
 * @text JS: Damage Colors
 * @type note
 * @parent ConditionalColors
 * @desc Code used for determining what color to use for damage types.
 * @default "// Set the variables used in this function.\nlet colorType = arguments[0];\n\n// Check the value of the color type\n// and return an appropriate color.\nswitch (colorType) {\n\n    case 0: // HP damage\n        return \"#ffffff\";\n\n    case 1: // HP recover\n        return \"#b9ffb5\";\n\n    case 2: // MP damage\n        return \"#bb88bb\";\n\n    case 3: // MP recover\n        return \"#80b0ff\";\n\n    default:\n        return \"#808080\";\n}"
 */
/* ----------------------------------------------------------------------------
 * Gold Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Gold:
 *
 * @param GoldMax:num
 * @text Gold Max
 * @type num
 * @min 1
 * @desc Maximum amount of Gold the party can hold.
 * Default 99999999
 * @default 99999999
 *
 * @param GoldFontSize:num
 * @text Gold Font Size
 * @type number
 * @min 1
 * @desc Font size used for displaying Gold inside Gold Windows.
 * Default: 26
 * @default 24
 *
 * @param GoldIcon:num
 * @text Gold Icon
 * @desc Icon used to represent Gold.
 * Use 0 for no icon.
 * @default 314
 *
 * @param GoldOverlap:str
 * @text Gold Overlap
 * @desc Text used too much Gold to fit in the window.
 * @default A Lot
 *
 * @param ItemStyle:eval
 * @text Item Style
 * @type boolean
 * @on Enable
 * @off Normal
 * @desc Draw gold in the item style?
 * ie: Icon, Label, Value
 * @default true
 *
 */
/* ----------------------------------------------------------------------------
 * Image Loading Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ImgLoad:
 *
 * @param animations:arraystr
 * @text img/animations/
 * @type file[]
 * @dir img/animations/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param battlebacks1:arraystr
 * @text img/battlebacks1/
 * @type file[]
 * @dir img/battlebacks1/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param battlebacks2:arraystr
 * @text img/battlebacks2/
 * @type file[]
 * @dir img/battlebacks2/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param characters:arraystr
 * @text img/characters/
 * @type file[]
 * @dir img/characters/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param enemies:arraystr
 * @text img/enemies/
 * @type file[]
 * @dir img/enemies/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param faces:arraystr
 * @text img/faces/
 * @type file[]
 * @dir img/faces/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param parallaxes:arraystr
 * @text img/parallaxes/
 * @type file[]
 * @dir img/parallaxes/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param pictures:arraystr
 * @text img/pictures/
 * @type file[]
 * @dir img/pictures/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param sv_actors:arraystr
 * @text img/sv_actors/
 * @type file[]
 * @dir img/sv_actors/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param sv_enemies:arraystr
 * @text img/sv_enemies/
 * @type file[]
 * @dir img/sv_enemies/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param system:arraystr
 * @text img/system/
 * @type file[]
 * @dir img/system/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default ["Balloon","IconSet"]
 *
 * @param tilesets:arraystr
 * @text img/tilesets/
 * @type file[]
 * @dir img/tilesets/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param titles1:arraystr
 * @text img/titles1/
 * @type file[]
 * @dir img/titles1/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 * @param titles2:arraystr
 * @text img/titles2/
 * @type file[]
 * @dir img/titles2/
 * @desc Which files do you wish to load from this directory upon
 * starting up the game?
 * @default []
 *
 */
/* ----------------------------------------------------------------------------
 * Keyboard Input Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~KeyboardInput:
 *
 * @param Controls
 *
 * @param WASD:eval
 * @text WASD Movement
 * @parent Controls
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Enables or disables WASD movement for your game project.
 * Moves the W page down button to E.
 * @default false
 *
 * @param DashToggleR:eval
 * @text R Button: Dash Toggle
 * @parent Controls
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Enables or disables R button as an Always Dash option toggle.
 * @default false
 *
 * @param NameInput
 * @text Name Input
 *
 * @param EnableNameInput:eval
 * @text Enable?
 * @parent NameInput
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Enables keyboard input for name entry.
 * Only tested with English keyboards.
 * @default true
 * 
 * @param DefaultMode:str
 * @text Default Mode
 * @parent NameInput
 * @type select
 * @option Default - Uses Arrow Keys to select letters.
 * @value default
 * @option Keyboard - Uses Keyboard to type in letters.
 * @value keyboard
 * @desc Select default mode when entering the scene.
 * @default keyboard
 *
 * @param QwertyLayout:eval
 * @text QWERTY Layout
 * @parent NameInput
 * @type boolean
 * @on QWERTY Layout
 * @off ABCDEF Layout
 * @desc Uses the QWERTY layout for manual entry.
 * @default true
 *
 * @param NameInputMessage:eval
 * @text Keyboard Message
 * @parent NameInput
 * @type note
 * @desc The message displayed when allowing keyboard entry.
 * You may use text codes here.
 * @default "Type in this character's name.\nPress \\c[5]ENTER\\c[0] when you're done.\n\n-or-\n\nPress \\c[5]arrow keys\\c[0]/\\c[5]TAB\\c[0] to switch\nto manual character entry.\n\nPress \\c[5]ESC\\c[0]/\\c[5]TAB\\c[0] to use to keyboard."
 * 
 * @param BannedWords:arraystr
 * @text Banned Words
 * @parent NameInput
 * @type string[]
 * @desc Players cannot use these words for names.
 * These include words inside the names.
 * @default []
 *
 * @param NumberInput
 * @text Number Input
 *
 * @param EnableNumberInput:eval
 * @text Enable?
 * @parent NumberInput
 * @type boolean
 * @on Enable
 * @off Disable
 * @desc Enables keyboard input for number entry.
 * Only tested with English keyboards.
 * @default true
 *
 * @param ButtonAssist
 * @text Button Assist
 * 
 * @param Keyboard:str
 * @text Switch To Keyboard
 * @parent ButtonAssist
 * @desc Text used to describe the keyboard switch.
 * @default Keyboard
 * 
 * @param Manual:str
 * @text Switch To Manual
 * @parent ButtonAssist
 * @desc Text used to describe the manual entry switch.
 * @default Manual
 *
 */
/* ----------------------------------------------------------------------------
 * Menu Background Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~MenuBg:
 *
 * @param Scene_Menu:struct
 * @text Scene_Menu
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Item:struct
 * @text Scene_Item
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Skill:struct
 * @text Scene_Skill
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Equip:struct
 * @text Scene_Equip
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Status:struct
 * @text Scene_Status
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Options:struct
 * @text Scene_Options
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Save:struct
 * @text Scene_Save
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Load:struct
 * @text Scene_Load
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_GameEnd:struct
 * @text Scene_GameEnd
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"128","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Shop:struct
 * @text Scene_Shop
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Name:struct
 * @text Scene_Name
 * @type struct<BgSettings>
 * @desc The individual background settings for this scene.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 * @param Scene_Unlisted:struct
 * @text Scene_Unlisted
 * @type struct<BgSettings>
 * @desc The individual background settings for any scenes that aren't listed here.
 * @default {"SnapshotOpacity:num":"192","BgFilename1:str":"","BgFilename2:str":""}
 *
 */
/* ----------------------------------------------------------------------------
 * Background Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~BgSettings:
 *
 * @param SnapshotOpacity:num
 * @text Snapshop Opacity
 * @type number
 * @min 0
 * @max 255
 * @desc Snapshot opacity for the scene.
 * @default 192
 *
 * @param BgFilename1:str
 * @text Background 1
 * @type file
 * @dir img/titles1/
 * @desc Filename used for the bottom background image.
 * Leave empty if you don't wish to use one.
 * @default 
 *
 * @param BgFilename2:str
 * @text Background 2
 * @type file
 * @dir img/titles2/
 * @desc Filename used for the upper background image.
 * Leave empty if you don't wish to use one.
 * @default 
 *
 */
/* ----------------------------------------------------------------------------
 * Menu Button Assist Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ButtonAssist:
 *
 * @param General
 *
 * @param Enable:eval
 * @text Enable
 * @parent General
 * @type boolean
 * @on Use
 * @off Don't Use
 * @desc Enable the Menu Button Assist Window.
 * @default true
 *
 * @param Location:str
 * @text Location
 * @parent General
 * @type select
 * @option Top of Screen
 * @value top
 * @option Bottom of Screen
 * @value bottom
 * @desc Determine the location of the Button Assist Window.
 * Requires Plugin Parameters => UI => Side Buttons ON.
 * @default bottom
 *
 * @param BgType:num
 * @text Background Type
 * @parent General
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param Text
 *
 * @param TextFmt:str
 * @text Text Format
 * @parent Text
 * @desc Format on how the buttons are displayed.
 * Text codes allowed. %1 - Key, %2 - Text
 * @default %1:%2
 *
 * @param MultiKeyFmt:str
 * @text Multi-Key Format
 * @parent Text
 * @desc Format for actions with multiple keys.
 * Text codes allowed. %1 - Key 1, %2 - Key 2
 * @default %1/%2
 *
 * @param OkText:str
 * @text OK Text
 * @parent Text
 * @desc Default text used to display OK Key Action.
 * Text codes allowed.
 * @default Select
 *
 * @param CancelText:str
 * @text Cancel Text
 * @parent Text
 * @desc Default text used to display Cancel Key Action.
 * Text codes allowed.
 * @default Back
 *
 * @param SwitchActorText:str
 * @text Switch Actor Text
 * @parent Text
 * @desc Default text used to display Switch Actor Action.
 * Text codes allowed.
 * @default Switch Ally
 *
 * @param Keys
 *
 * @param KeyUnlisted:str
 * @text Key: Unlisted Format
 * @parent Keys
 * @desc If a key is not listed below, use this format.
 * Text codes allowed. %1 - Key
 * @default \}❪%1❫\{
 *
 * @param KeyUP:str
 * @text Key: Up
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default ^
 *
 * @param KeyDOWN:str
 * @text Key: Down
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default v
 *
 * @param KeyLEFT:str
 * @text Key: Left
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default <<
 *
 * @param KeyRIGHT:str
 * @text Key: Right
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default >>
 *
 * @param KeySHIFT:str
 * @text Key: Shift
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default \}❪SHIFT❫\{
 *
 * @param KeyTAB:str
 * @text Key: Tab
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default \}❪TAB❫\{
 *
 * @param KeyA:str
 * @text Key: A
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default A
 *
 * @param KeyB:str
 * @text Key: B
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default B
 *
 * @param KeyC:str
 * @text Key: C
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default C
 *
 * @param KeyD:str
 * @text Key: D
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default D
 *
 * @param KeyE:str
 * @text Key: E
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default E
 *
 * @param KeyF:str
 * @text Key: F
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default F
 *
 * @param KeyG:str
 * @text Key: G
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default G
 *
 * @param KeyH:str
 * @text Key: H
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default H
 *
 * @param KeyI:str
 * @text Key: I
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default I
 *
 * @param KeyJ:str
 * @text Key: J
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default J
 *
 * @param KeyK:str
 * @text Key: K
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default K
 *
 * @param KeyL:str
 * @text Key: L
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default L
 *
 * @param KeyM:str
 * @text Key: M
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default M
 *
 * @param KeyN:str
 * @text Key: N
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default N
 *
 * @param KeyO:str
 * @text Key: O
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default O
 *
 * @param KeyP:str
 * @text Key: P
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default P
 *
 * @param KeyQ:str
 * @text Key: Q
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default Q
 *
 * @param KeyR:str
 * @text Key: R
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default R
 *
 * @param KeyS:str
 * @text Key: S
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default S
 *
 * @param KeyT:str
 * @text Key: T
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default T
 *
 * @param KeyU:str
 * @text Key: U
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default U
 *
 * @param KeyV:str
 * @text Key: V
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default V
 *
 * @param KeyW:str
 * @text Key: W
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default W
 *
 * @param KeyX:str
 * @text Key: X
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default X
 *
 * @param KeyY:str
 * @text Key: Y
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default Y
 *
 * @param KeyZ:str
 * @text Key: Z
 * @parent Keys
 * @desc How this key is shown in-game.
 * Text codes allowed.
 * @default Z
 *
 */
/* ----------------------------------------------------------------------------
 * Menu Layout Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~MenuLayout:
 *
 * @param Title:struct
 * @text Scene_Title
 * @parent SceneSettings
 * @type struct<Title>
 * @desc Various options on adjusting the Title Scene.
 * @default {"TitleScreen":"","DocumentTitleFmt:str":"%1: %2 - Version %3","Subtitle:str":"Subtitle","Version:str":"0.00","drawGameTitle:func":"\"const x = 20;\\nconst y = Graphics.height / 4;\\nconst maxWidth = Graphics.width - x * 2;\\nconst text = $dataSystem.gameTitle;\\nconst bitmap = this._gameTitleSprite.bitmap;\\nbitmap.fontFace = $gameSystem.mainFontFace();\\nbitmap.outlineColor = \\\"black\\\";\\nbitmap.outlineWidth = 8;\\nbitmap.fontSize = 72;\\nbitmap.drawText(text, x, y, maxWidth, 48, \\\"center\\\");\"","drawGameSubtitle:func":"\"const x = 20;\\nconst y = Graphics.height / 4 + 72;\\nconst maxWidth = Graphics.width - x * 2;\\nconst text = Scene_Title.subtitle;\\nconst bitmap = this._gameTitleSprite.bitmap;\\nbitmap.fontFace = $gameSystem.mainFontFace();\\nbitmap.outlineColor = \\\"black\\\";\\nbitmap.outlineWidth = 6;\\nbitmap.fontSize = 48;\\nbitmap.drawText(text, x, y, maxWidth, 48, \\\"center\\\");\"","drawGameVersion:func":"\"const bitmap = this._gameTitleSprite.bitmap;\\nconst x = 0;\\nconst y = Graphics.height - 20;\\nconst width = Math.round(Graphics.width / 4);\\nconst height = 20;\\nconst c1 = ColorManager.dimColor1();\\nconst c2 = ColorManager.dimColor2();\\nconst text = 'Version ' + Scene_Title.version;\\nbitmap.gradientFillRect(x, y, width, height, c1, c2);\\nbitmap.fontFace = $gameSystem.mainFontFace();\\nbitmap.outlineColor = \\\"black\\\";\\nbitmap.outlineWidth = 3;\\nbitmap.fontSize = 16;\\nbitmap.drawText(text, x + 4, y, Graphics.width, height, \\\"left\\\");\"","CommandRect:func":"\"const offsetX = $dataSystem.titleCommandWindow.offsetX;\\nconst offsetY = $dataSystem.titleCommandWindow.offsetY;\\nconst rows = this.commandWindowRows();\\nconst width = this.mainCommandWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nconst x = (Graphics.boxWidth - width) / 2 + offsetX;\\nconst y = Graphics.boxHeight - height - 96 + offsetY;\\nreturn new Rectangle(x, y, width, height);\"","ButtonFadeSpeed:num":"4"}
 *
 * @param MainMenu:struct
 * @text Scene_Menu
 * @parent SceneSettings
 * @type struct<MainMenu>
 * @desc Various options on adjusting the Main Menu Scene.
 * @default {"CommandWindow":"","CommandBgType:num":"0","CommandRect:func":"\"const width = this.mainCommandWidth();\\nconst height = this.mainAreaHeight() - this.goldWindowRect().height;\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\nconst y = this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\"","GoldWindow":"","GoldBgType:num":"0","GoldRect:func":"\"const rows = 1;\\nconst width = this.mainCommandWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\nconst y = this.mainAreaBottom() - height;\\nreturn new Rectangle(x, y, width, height);\"","StatusWindow":"","StatusBgType:num":"0","StatusRect:func":"\"const width = Graphics.boxWidth - this.mainCommandWidth();\\nconst height = this.mainAreaHeight();\\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\\nconst y = this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param ItemMenu:struct
 * @text Scene_Item
 * @parent SceneSettings
 * @type struct<ItemMenu>
 * @desc Various options on adjusting the Item Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const x = 0;\\nconst y = this.helpAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.helpAreaHeight();\\nreturn new Rectangle(x, y, width, height);\"","CategoryWindow":"","CategoryBgType:num":"0","CategoryRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst rows = 1;\\nconst width = Graphics.boxWidth;\\nconst height = this.calcWindowHeight(rows, true);\\nreturn new Rectangle(x, y, width, height);\"","ItemWindow":"","ItemBgType:num":"0","ItemRect:func":"\"const x = 0;\\nconst y = this._categoryWindow.y + this._categoryWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaBottom() - y;\\nreturn new Rectangle(x, y, width, height);\"","ActorWindow":"","ActorBgType:num":"0","ActorRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight();\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param SkillMenu:struct
 * @text Scene_Skill
 * @parent SceneSettings
 * @type struct<SkillMenu>
 * @desc Various options on adjusting the Skill Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const x = 0;\\nconst y = this.helpAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.helpAreaHeight();\\nreturn new Rectangle(x, y, width, height);\"","SkillTypeWindow":"","SkillTypeBgType:num":"0","SkillTypeRect:func":"\"const rows = 3;\\nconst width = this.mainCommandWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\\nconst y = this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\"","StatusWindow":"","StatusBgType:num":"0","StatusRect:func":"\"const width = Graphics.boxWidth - this.mainCommandWidth();\\nconst height = this._skillTypeWindow.height;\\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\\nconst y = this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\"","ItemWindow":"","ItemBgType:num":"0","ItemRect:func":"\"const x = 0;\\nconst y = this._statusWindow.y + this._statusWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight() - this._statusWindow.height;\\nreturn new Rectangle(x, y, width, height);\"","ActorWindow":"","ActorBgType:num":"0","ActorRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight();\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param EquipMenu:struct
 * @text Scene_Equip
 * @parent SceneSettings
 * @type struct<EquipMenu>
 * @desc Various options on adjusting the Equip Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const x = 0;\\nconst y = this.helpAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.helpAreaHeight();\\nreturn new Rectangle(x, y, width, height);\"","StatusWindow":"","StatusBgType:num":"0","StatusRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst width = this.statusWidth();\\nconst height = this.mainAreaHeight();\\nreturn new Rectangle(x, y, width, height);\"","CommandWindow":"","CommandBgType:num":"0","CommandRect:func":"\"const x = this.statusWidth();\\nconst y = this.mainAreaTop();\\nconst rows = 1;\\nconst width = Graphics.boxWidth - this.statusWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nreturn new Rectangle(x, y, width, height);\"","SlotWindow":"","SlotBgType:num":"0","SlotRect:func":"\"const commandWindowRect = this.commandWindowRect();\\nconst x = this.statusWidth();\\nconst y = commandWindowRect.y + commandWindowRect.height;\\nconst width = Graphics.boxWidth - this.statusWidth();\\nconst height = this.mainAreaHeight() - commandWindowRect.height;\\nreturn new Rectangle(x, y, width, height);\"","ItemWindow":"","ItemBgType:num":"0","ItemRect:func":"\"return this.slotWindowRect();\""}
 *
 * @param StatusMenu:struct
 * @text Scene_Status
 * @parent SceneSettings
 * @type struct<StatusMenu>
 * @desc Various options on adjusting the Status Menu Scene.
 * @default {"ProfileWindow":"","ProfileBgType:num":"0","ProfileRect:func":"\"const width = Graphics.boxWidth;\\nconst height = this.profileHeight();\\nconst x = 0;\\nconst y = this.mainAreaBottom() - height;\\nreturn new Rectangle(x, y, width, height);\"","StatusWindow":"","StatusBgType:num":"0","StatusRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst width = Graphics.boxWidth;\\nconst height = this.statusParamsWindowRect().y - y;\\nreturn new Rectangle(x, y, width, height);\"","StatusParamsWindow":"","StatusParamsBgType:num":"0","StatusParamsRect:func":"\"const width = this.statusParamsWidth();\\nconst height = this.statusParamsHeight();\\nconst x = 0;\\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\\nreturn new Rectangle(x, y, width, height);\"","StatusEquipWindow":"","StatusEquipBgType:num":"0","StatusEquipRect:func":"\"const width = Graphics.boxWidth - this.statusParamsWidth();\\nconst height = this.statusParamsHeight();\\nconst x = this.statusParamsWidth();\\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param OptionsMenu:struct
 * @text Scene_Options
 * @parent SceneSettings
 * @type struct<OptionsMenu>
 * @desc Various options on adjusting the Options Menu Scene.
 * @default {"OptionsWindow":"","OptionsBgType:num":"0","OptionsRect:func":"\"const n = Math.min(this.maxCommands(), this.maxVisibleCommands());\\nconst width = 400;\\nconst height = this.calcWindowHeight(n, true);\\nconst x = (Graphics.boxWidth - width) / 2;\\nconst y = (Graphics.boxHeight - height) / 2;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param SaveMenu:struct
 * @text Scene_Save
 * @parent SceneSettings
 * @type struct<SaveMenu>
 * @desc Various options on adjusting the Save Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst rows = 1;\\nconst width = Graphics.boxWidth;\\nconst height = this.calcWindowHeight(rows, false);\\nreturn new Rectangle(x, y, width, height);\"","ListWindow":"","ListBgType:num":"0","ListRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop() + this._helpWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight() - this._helpWindow.height;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param LoadMenu:struct
 * @text Scene_Load
 * @parent SceneSettings
 * @type struct<LoadMenu>
 * @desc Various options on adjusting the Load Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst rows = 1;\\nconst width = Graphics.boxWidth;\\nconst height = this.calcWindowHeight(rows, false);\\nreturn new Rectangle(x, y, width, height);\"","ListWindow":"","ListBgType:num":"0","ListRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop() + this._helpWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight() - this._helpWindow.height;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param GameEnd:struct
 * @text Scene_GameEnd
 * @parent SceneSettings
 * @type struct<GameEnd>
 * @desc Various options on adjusting the Game End Scene.
 * @default {"CommandList:arraystruct":"[\"{\\\"Symbol:str\\\":\\\"toTitle\\\",\\\"TextStr:str\\\":\\\"Untitled\\\",\\\"TextJS:func\\\":\\\"\\\\\\\"return TextManager.toTitle;\\\\\\\"\\\",\\\"ShowJS:func\\\":\\\"\\\\\\\"return true;\\\\\\\"\\\",\\\"EnableJS:func\\\":\\\"\\\\\\\"return true;\\\\\\\"\\\",\\\"ExtJS:func\\\":\\\"\\\\\\\"return null;\\\\\\\"\\\",\\\"CallHandlerJS:func\\\":\\\"\\\\\\\"SceneManager._scene.commandToTitle();\\\\\\\"\\\"}\",\"{\\\"Symbol:str\\\":\\\"cancel\\\",\\\"TextStr:str\\\":\\\"Untitled\\\",\\\"TextJS:func\\\":\\\"\\\\\\\"return TextManager.cancel;\\\\\\\"\\\",\\\"ShowJS:func\\\":\\\"\\\\\\\"return true;\\\\\\\"\\\",\\\"EnableJS:func\\\":\\\"\\\\\\\"return true;\\\\\\\"\\\",\\\"ExtJS:func\\\":\\\"\\\\\\\"return null;\\\\\\\"\\\",\\\"CallHandlerJS:func\\\":\\\"\\\\\\\"SceneManager._scene.popScene();\\\\\\\"\\\"}\"]","CommandBgType:num":"0","CommandRect:func":"\"const rows = 2;\\nconst width = this.mainCommandWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nconst x = (Graphics.boxWidth - width) / 2;\\nconst y = (Graphics.boxHeight - height) / 2;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param ShopMenu:struct
 * @text Scene_Shop
 * @parent SceneSettings
 * @type struct<ShopMenu>
 * @desc Various options on adjusting the Shop Menu Scene.
 * @default {"HelpWindow":"","HelpBgType:num":"0","HelpRect:func":"\"const wx = 0;\\nconst wy = this.helpAreaTop();\\nconst ww = Graphics.boxWidth;\\nconst wh = this.helpAreaHeight();\\nreturn new Rectangle(wx, wy, ww, wh);\"","GoldWindow":"","GoldBgType:num":"0","GoldRect:func":"\"const rows = 1;\\nconst width = this.mainCommandWidth();\\nconst height = this.calcWindowHeight(rows, true);\\nconst x = Graphics.boxWidth - width;\\nconst y = this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\"","CommandWindow":"","CommandBgType:num":"0","CommandRect:func":"\"const x = 0;\\nconst y = this.mainAreaTop();\\nconst rows = 1;\\nconst width = this._goldWindow.x;\\nconst height = this.calcWindowHeight(rows, true);\\nreturn new Rectangle(x, y, width, height);\"","DummyWindow":"","DummyBgType:num":"0","DummyRect:func":"\"const x = 0;\\nconst y = this._commandWindow.y + this._commandWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height = this.mainAreaHeight() - this._commandWindow.height;\\nreturn new Rectangle(x, y, width, height);\"","NumberWindow":"","NumberBgType:num":"0","NumberRect:func":"\"const x = 0;\\nconst y = this._dummyWindow.y;\\nconst width = Graphics.boxWidth - this.statusWidth();\\nconst height = this._dummyWindow.height;\\nreturn new Rectangle(x, y, width, height);\"","StatusWindow":"","StatusBgType:num":"0","StatusRect:func":"\"const width = this.statusWidth();\\nconst height = this._dummyWindow.height;\\nconst x = Graphics.boxWidth - width;\\nconst y = this._dummyWindow.y;\\nreturn new Rectangle(x, y, width, height);\"","BuyWindow":"","BuyBgType:num":"0","BuyRect:func":"\"const x = 0;\\nconst y = this._dummyWindow.y;\\nconst width = Graphics.boxWidth - this.statusWidth();\\nconst height = this._dummyWindow.height;\\nreturn new Rectangle(x, y, width, height);\"","CategoryWindow":"","CategoryBgType:num":"0","CategoryRect:func":"\"const x = 0;\\nconst y = this._dummyWindow.y;\\nconst rows = 1;\\nconst width = Graphics.boxWidth;\\nconst height = this.calcWindowHeight(rows, true);\\nreturn new Rectangle(x, y, width, height);\"","SellWindow":"","SellBgType:num":"0","SellRect:func":"\"const x = 0;\\nconst y = this._categoryWindow.y + this._categoryWindow.height;\\nconst width = Graphics.boxWidth;\\nconst height =\\n    this.mainAreaHeight() -\\n    this._commandWindow.height -\\n    this._categoryWindow.height;\\nreturn new Rectangle(x, y, width, height);\""}
 *
 * @param NameMenu:struct
 * @text Scene_Name
 * @parent SceneSettings
 * @type struct<NameMenu>
 * @desc Various options on adjusting the Actor Rename Scene.
 * @default {"EditWindow":"","EditBgType:num":"0","EditRect:func":"\"const rows = 9;\\nconst inputWindowHeight = this.calcWindowHeight(rows, true);\\nconst padding = $gameSystem.windowPadding();\\nconst width = 600;\\nconst height = Math.min(ImageManager.faceHeight + padding * 2, this.mainAreaHeight() - inputWindowHeight);\\nconst x = (Graphics.boxWidth - width) / 2;\\nconst y = (this.mainAreaHeight() - (height + inputWindowHeight)) / 2 + this.mainAreaTop();\\nreturn new Rectangle(x, y, width, height);\"","InputWindow":"","InputBgType:num":"0","InputRect:func":"\"const x = this._editWindow.x;\\nconst y = this._editWindow.y + this._editWindow.height;\\nconst rows = 9;\\nconst width = this._editWindow.width;\\nconst height = this.calcWindowHeight(rows, true);\\nreturn new Rectangle(x, y, width, height);\""}
 *
 */
/* ----------------------------------------------------------------------------
 * Main Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~MainMenu:
 *
 * @param CommandWindow
 * @text Command Window
 *
 * @param CommandBgType:num
 * @text Background Type
 * @parent CommandWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CommandRect:func
 * @text JS: X, Y, W, H
 * @parent CommandWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = this.mainCommandWidth();\nconst height = this.mainAreaHeight() - this.goldWindowRect().height;\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\nconst y = this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param GoldWindow
 * @text Gold Window
 *
 * @param GoldBgType:num
 * @text Background Type
 * @parent GoldWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param GoldRect:func
 * @text JS: X, Y, W, H
 * @parent GoldWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const rows = 1;\nconst width = this.mainCommandWidth();\nconst height = this.calcWindowHeight(rows, true);\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\nconst y = this.mainAreaBottom() - height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusWindow
 * @text Status Window
 *
 * @param StatusBgType:num
 * @text Background Type
 * @parent StatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusRect:func
 * @text JS: X, Y, W, H
 * @parent StatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = Graphics.boxWidth - this.mainCommandWidth();\nconst height = this.mainAreaHeight();\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\nconst y = this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Item Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ItemMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.helpAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.helpAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param CategoryWindow
 * @text Category Window
 *
 * @param CategoryBgType:num
 * @text Background Type
 * @parent CategoryWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CategoryRect:func
 * @text JS: X, Y, W, H
 * @parent CategoryWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst rows = 1;\nconst width = Graphics.boxWidth;\nconst height = this.calcWindowHeight(rows, true);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ItemWindow
 * @text Item Window
 *
 * @param ItemBgType:num
 * @text Background Type
 * @parent ItemWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ItemRect:func
 * @text JS: X, Y, W, H
 * @parent ItemWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._categoryWindow.y + this._categoryWindow.height;\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaBottom() - y;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ActorWindow
 * @text Actor Window
 *
 * @param ActorBgType:num
 * @text Background Type
 * @parent ActorWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ActorRect:func
 * @text JS: X, Y, W, H
 * @parent ActorWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Skill Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~SkillMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.helpAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.helpAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param SkillTypeWindow
 * @text Skill Type Window
 *
 * @param SkillTypeBgType:num
 * @text Background Type
 * @parent SkillTypeWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param SkillTypeRect:func
 * @text JS: X, Y, W, H
 * @parent SkillTypeWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const rows = 3;\nconst width = this.mainCommandWidth();\nconst height = this.calcWindowHeight(rows, true);\nconst x = this.isRightInputMode() ? Graphics.boxWidth - width : 0;\nconst y = this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusWindow
 * @text Status Window
 *
 * @param StatusBgType:num
 * @text Background Type
 * @parent StatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusRect:func
 * @text JS: X, Y, W, H
 * @parent StatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = Graphics.boxWidth - this.mainCommandWidth();\nconst height = this._skillTypeWindow.height;\nconst x = this.isRightInputMode() ? 0 : Graphics.boxWidth - width;\nconst y = this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ItemWindow
 * @text Item Window
 *
 * @param ItemBgType:num
 * @text Background Type
 * @parent ItemWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ItemRect:func
 * @text JS: X, Y, W, H
 * @parent ItemWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._statusWindow.y + this._statusWindow.height;\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight() - this._statusWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ActorWindow
 * @text Actor Window
 *
 * @param ActorBgType:num
 * @text Background Type
 * @parent ActorWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ActorRect:func
 * @text JS: X, Y, W, H
 * @parent ActorWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Equip Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~EquipMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.helpAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.helpAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusWindow
 * @text Status Window
 *
 * @param StatusBgType:num
 * @text Background Type
 * @parent StatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusRect:func
 * @text JS: X, Y, W, H
 * @parent StatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst width = this.statusWidth();\nconst height = this.mainAreaHeight();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param CommandWindow
 * @text Command Window
 *
 * @param CommandBgType:num
 * @text Background Type
 * @parent CommandWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CommandRect:func
 * @text JS: X, Y, W, H
 * @parent CommandWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = this.statusWidth();\nconst y = this.mainAreaTop();\nconst rows = 1;\nconst width = Graphics.boxWidth - this.statusWidth();\nconst height = this.calcWindowHeight(rows, true);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param SlotWindow
 * @text Slot Window
 *
 * @param SlotBgType:num
 * @text Background Type
 * @parent SlotWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param SlotRect:func
 * @text JS: X, Y, W, H
 * @parent SlotWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const commandWindowRect = this.commandWindowRect();\nconst x = this.statusWidth();\nconst y = commandWindowRect.y + commandWindowRect.height;\nconst width = Graphics.boxWidth - this.statusWidth();\nconst height = this.mainAreaHeight() - commandWindowRect.height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ItemWindow
 * @text Item Window
 *
 * @param ItemBgType:num
 * @text Background Type
 * @parent ItemWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ItemRect:func
 * @text JS: X, Y, W, H
 * @parent ItemWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "return this.slotWindowRect();"
 *
 */
/* ----------------------------------------------------------------------------
 * Status Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~StatusMenu:
 *
 * @param ProfileWindow
 * @text Profile Window
 *
 * @param ProfileBgType:num
 * @text Background Type
 * @parent ProfileWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ProfileRect:func
 * @text JS: X, Y, W, H
 * @parent ProfileWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = Graphics.boxWidth;\nconst height = this.profileHeight();\nconst x = 0;\nconst y = this.mainAreaBottom() - height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusWindow
 * @text Status Window
 *
 * @param StatusBgType:num
 * @text Background Type
 * @parent StatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusRect:func
 * @text JS: X, Y, W, H
 * @parent StatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst width = Graphics.boxWidth;\nconst height = this.statusParamsWindowRect().y - y;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusParamsWindow
 * @text Parameters Window
 *
 * @param StatusParamsBgType:num
 * @text Background Type
 * @parent StatusParamsWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusParamsRect:func
 * @text JS: X, Y, W, H
 * @parent StatusParamsWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = this.statusParamsWidth();\nconst height = this.statusParamsHeight();\nconst x = 0;\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusEquipWindow
 * @text Equipment Window
 *
 * @param StatusEquipBgType:num
 * @text Background Type
 * @parent StatusEquipWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusEquipRect:func
 * @text JS: X, Y, W, H
 * @parent StatusEquipWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = Graphics.boxWidth - this.statusParamsWidth();\nconst height = this.statusParamsHeight();\nconst x = this.statusParamsWidth();\nconst y = this.mainAreaBottom() - this.profileHeight() - height;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Options Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~OptionsMenu:
 *
 * @param OptionsWindow
 * @text Options Window
 *
 * @param OptionsBgType:num
 * @text Background Type
 * @parent OptionsWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param OptionsRect:func
 * @text JS: X, Y, W, H
 * @parent OptionsWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const n = Math.min(this.maxCommands(), this.maxVisibleCommands());\nconst width = 400;\nconst height = this.calcWindowHeight(n, true);\nconst x = (Graphics.boxWidth - width) / 2;\nconst y = (Graphics.boxHeight - height) / 2;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Save Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~SaveMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst rows = 1;\nconst width = Graphics.boxWidth;\nconst height = this.calcWindowHeight(rows, false);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ListWindow
 * @text List Window
 *
 * @param ListBgType:num
 * @text Background Type
 * @parent ListWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ListRect:func
 * @text JS: X, Y, W, H
 * @parent ListWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop() + this._helpWindow.height;\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight() - this._helpWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Load Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~LoadMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst rows = 1;\nconst width = Graphics.boxWidth;\nconst height = this.calcWindowHeight(rows, false);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ListWindow
 * @text List Window
 *
 * @param ListBgType:num
 * @text Background Type
 * @parent ListWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param ListRect:func
 * @text JS: X, Y, W, H
 * @parent ListWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop() + this._helpWindow.height;\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight() - this._helpWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Game End Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~GameEnd:
 *
 * @param CommandList:arraystruct
 * @text Command Window List
 * @type struct<Command>[]
 * @desc Window commands used by the Game End screen.
 * Add new commands here.
 * @default ["{\"Symbol:str\":\"toTitle\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.toTitle;\\\"\",\"ShowJS:func\":\"\\\"return true;\\\"\",\"EnableJS:func\":\"\\\"return true;\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager._scene.commandToTitle();\\\"\"}","{\"Symbol:str\":\"cancel\",\"TextStr:str\":\"Untitled\",\"TextJS:func\":\"\\\"return TextManager.cancel;\\\"\",\"ShowJS:func\":\"\\\"return true;\\\"\",\"EnableJS:func\":\"\\\"return true;\\\"\",\"ExtJS:func\":\"\\\"return null;\\\"\",\"CallHandlerJS:func\":\"\\\"SceneManager._scene.popScene();\\\"\"}"]
 *
 * @param CommandBgType:num
 * @text Background Type
 * @parent CommandList:arraystruct
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CommandRect:func
 * @text JS: X, Y, W, H
 * @parent CommandList:arraystruct
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const rows = 2;\nconst width = this.mainCommandWidth();\nconst height = this.calcWindowHeight(rows, true);\nconst x = (Graphics.boxWidth - width) / 2;\nconst y = (Graphics.boxHeight - height) / 2;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Shop Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ShopMenu:
 *
 * @param HelpWindow
 * @text Help Window
 *
 * @param HelpBgType:num
 * @text Background Type
 * @parent HelpWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param HelpRect:func
 * @text JS: X, Y, W, H
 * @parent HelpWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const wx = 0;\nconst wy = this.helpAreaTop();\nconst ww = Graphics.boxWidth;\nconst wh = this.helpAreaHeight();\nreturn new Rectangle(wx, wy, ww, wh);"
 *
 * @param GoldWindow
 * @text Gold Window
 *
 * @param GoldBgType:num
 * @text Background Type
 * @parent GoldWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param GoldRect:func
 * @text JS: X, Y, W, H
 * @parent GoldWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const rows = 1;\nconst width = this.mainCommandWidth();\nconst height = this.calcWindowHeight(rows, true);\nconst x = Graphics.boxWidth - width;\nconst y = this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param CommandWindow
 * @text Command Window
 *
 * @param CommandBgType:num
 * @text Background Type
 * @parent CommandWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CommandRect:func
 * @text JS: X, Y, W, H
 * @parent CommandWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this.mainAreaTop();\nconst rows = 1;\nconst width = this._goldWindow.x;\nconst height = this.calcWindowHeight(rows, true);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param DummyWindow
 * @text Dummy Window
 *
 * @param DummyBgType:num
 * @text Background Type
 * @parent DummyWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param DummyRect:func
 * @text JS: X, Y, W, H
 * @parent DummyWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._commandWindow.y + this._commandWindow.height;\nconst width = Graphics.boxWidth;\nconst height = this.mainAreaHeight() - this._commandWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param NumberWindow
 * @text Number Window
 *
 * @param NumberBgType:num
 * @text Background Type
 * @parent NumberWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param NumberRect:func
 * @text JS: X, Y, W, H
 * @parent NumberWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._dummyWindow.y;\nconst width = Graphics.boxWidth - this.statusWidth();\nconst height = this._dummyWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param StatusWindow
 * @text Status Window
 *
 * @param StatusBgType:num
 * @text Background Type
 * @parent StatusWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param StatusRect:func
 * @text JS: X, Y, W, H
 * @parent StatusWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const width = this.statusWidth();\nconst height = this._dummyWindow.height;\nconst x = Graphics.boxWidth - width;\nconst y = this._dummyWindow.y;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param BuyWindow
 * @text Buy Window
 *
 * @param BuyBgType:num
 * @text Background Type
 * @parent BuyWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param BuyRect:func
 * @text JS: X, Y, W, H
 * @parent BuyWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._dummyWindow.y;\nconst width = Graphics.boxWidth - this.statusWidth();\nconst height = this._dummyWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param CategoryWindow
 * @text Category Window
 *
 * @param CategoryBgType:num
 * @text Background Type
 * @parent CategoryWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param CategoryRect:func
 * @text JS: X, Y, W, H
 * @parent CategoryWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._dummyWindow.y;\nconst rows = 1;\nconst width = Graphics.boxWidth;\nconst height = this.calcWindowHeight(rows, true);\nreturn new Rectangle(x, y, width, height);"
 *
 * @param SellWindow
 * @text Sell Window
 *
 * @param SellBgType:num
 * @text Background Type
 * @parent SellWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param SellRect:func
 * @text JS: X, Y, W, H
 * @parent SellWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = 0;\nconst y = this._categoryWindow.y + this._categoryWindow.height;\nconst width = Graphics.boxWidth;\nconst height =\n    this.mainAreaHeight() -\n    this._commandWindow.height -\n    this._categoryWindow.height;\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Name Menu Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~NameMenu:
 *
 * @param EditWindow
 * @text Edit Window
 *
 * @param EditBgType:num
 * @text Background Type
 * @parent EditWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param EditRect:func
 * @text JS: X, Y, W, H
 * @parent EditWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const rows = 9;\nconst inputWindowHeight = this.calcWindowHeight(rows, true);\nconst padding = $gameSystem.windowPadding();\nconst width = 600;\nconst height = Math.min(ImageManager.faceHeight + padding * 2, this.mainAreaHeight() - inputWindowHeight);\nconst x = (Graphics.boxWidth - width) / 2;\nconst y = (this.mainAreaHeight() - (height + inputWindowHeight)) / 2 + this.mainAreaTop();\nreturn new Rectangle(x, y, width, height);"
 *
 * @param InputWindow
 * @text Input Window
 *
 * @param InputBgType:num
 * @text Background Type
 * @parent InputWindow
 * @type select
 * @option 0 - Window
 * @value 0
 * @option 1 - Dim
 * @value 1
 * @option 2 - Transparent
 * @value 2
 * @desc Select background type for this window.
 * @default 0
 *
 * @param InputRect:func
 * @text JS: X, Y, W, H
 * @parent InputWindow
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const x = this._editWindow.x;\nconst y = this._editWindow.y + this._editWindow.height;\nconst rows = 9;\nconst width = this._editWindow.width;\nconst height = this.calcWindowHeight(rows, true);\nreturn new Rectangle(x, y, width, height);"
 *
 */
/* ----------------------------------------------------------------------------
 * Title Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Title:
 *
 * @param TitleScreen
 * @text Title Screen
 *
 * @param DocumentTitleFmt:str
 * @text Document Title Format
 * @parent TitleScreen
 * @desc Format to display text in document title.
 * %1 - Main Title, %2 - Subtitle, %3 - Version
 * @default %1: %2 - Version %3
 *
 * @param Subtitle:str
 * @text Subtitle
 * @parent TitleScreen
 * @desc Subtitle to be displayed under the title name.
 * @default Subtitle
 *
 * @param Version:str
 * @text Version
 * @parent TitleScreen
 * @desc Version to be display in the title screen corner.
 * @default 0.00
 *
 * @param drawGameTitle:func
 * @text JS: Draw Title
 * @type note
 * @parent TitleScreen
 * @desc Code used to draw the game title.
 * @default "const x = 20;\nconst y = Graphics.height / 4;\nconst maxWidth = Graphics.width - x * 2;\nconst text = $dataSystem.gameTitle;\nconst bitmap = this._gameTitleSprite.bitmap;\nbitmap.fontFace = $gameSystem.mainFontFace();\nbitmap.outlineColor = \"black\";\nbitmap.outlineWidth = 8;\nbitmap.fontSize = 72;\nbitmap.drawText(text, x, y, maxWidth, 48, \"center\");"
 *
 * @param drawGameSubtitle:func
 * @text JS: Draw Subtitle
 * @type note
 * @parent TitleScreen
 * @desc Code used to draw the game subtitle.
 * @default "const x = 20;\nconst y = Graphics.height / 4 + 72;\nconst maxWidth = Graphics.width - x * 2;\nconst text = Scene_Title.subtitle;\nconst bitmap = this._gameTitleSprite.bitmap;\nbitmap.fontFace = $gameSystem.mainFontFace();\nbitmap.outlineColor = \"black\";\nbitmap.outlineWidth = 6;\nbitmap.fontSize = 48;\nbitmap.drawText(text, x, y, maxWidth, 48, \"center\");"
 *
 * @param drawGameVersion:func
 * @text JS: Draw Version
 * @type note
 * @parent TitleScreen
 * @desc Code used to draw the game version.
 * @default "const bitmap = this._gameTitleSprite.bitmap;\nconst x = 0;\nconst y = Graphics.height - 20;\nconst width = Math.round(Graphics.width / 4);\nconst height = 20;\nconst c1 = ColorManager.dimColor1();\nconst c2 = ColorManager.dimColor2();\nconst text = 'Version ' + Scene_Title.version;\nbitmap.gradientFillRect(x, y, width, height, c1, c2);\nbitmap.fontFace = $gameSystem.mainFontFace();\nbitmap.outlineColor = \"black\";\nbitmap.outlineWidth = 3;\nbitmap.fontSize = 16;\nbitmap.drawText(text, x + 4, y, Graphics.width, height, \"left\");"
 *
 * @param CommandRect:func
 * @text JS: X, Y, W, H
 * @parent TitleScreen
 * @type note
 * @desc Code used to determine the dimensions for this window.
 * @default "const offsetX = $dataSystem.titleCommandWindow.offsetX;\nconst offsetY = $dataSystem.titleCommandWindow.offsetY;\nconst rows = this.commandWindowRows();\nconst width = this.mainCommandWidth();\nconst height = this.calcWindowHeight(rows, true);\nconst x = (Graphics.boxWidth - width) / 2 + offsetX;\nconst y = Graphics.boxHeight - height - 96 + offsetY;\nreturn new Rectangle(x, y, width, height);"
 *
 * @param ButtonFadeSpeed:num
 * @text Button Fade Speed
 * @parent TitleScreen
 * @type number
 * @min 1
 * @max 255
 * @desc Speed at which the buttons fade in at (1-255).
 * @default 4
 *
 */
/* ----------------------------------------------------------------------------
 * Parameter Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Param:
 *
 * @param DisplayedParams:arraystr
 * @text Displayed Parameters
 * @type combo[]
 * @option MaxHP
 * @option MaxMP
 * @option ATK
 * @option DEF
 * @option MAT
 * @option MDF
 * @option AGI
 * @option LUK
 * @option HIT
 * @option EVA
 * @option CRI
 * @option CEV
 * @option MEV
 * @option MRF
 * @option CNT
 * @option HRG
 * @option MRG
 * @option TRG
 * @option TGR
 * @option GRD
 * @option REC
 * @option PHA
 * @option MCR
 * @option TCR
 * @option PDR
 * @option MDR
 * @option FDR
 * @option EXR
 * @desc A list of the parameters that will be displayed in-game.
 * @default ["ATK","DEF","MAT","MDF","AGI","LUK"]
 *
 * @param ExtDisplayedParams:arraystr
 * @text Extended Parameters
 * @parent DisplayedParams:arraystr
 * @type combo[]
 * @option MaxHP
 * @option MaxMP
 * @option ATK
 * @option DEF
 * @option MAT
 * @option MDF
 * @option AGI
 * @option LUK
 * @option HIT
 * @option EVA
 * @option CRI
 * @option CEV
 * @option MEV
 * @option MRF
 * @option CNT
 * @option HRG
 * @option MRG
 * @option TRG
 * @option TGR
 * @option GRD
 * @option REC
 * @option PHA
 * @option MCR
 * @option TCR
 * @option PDR
 * @option MDR
 * @option FDR
 * @option EXR
 * @desc The list shown in extended scenes (for other VisuStella plugins).
 * @default ["MaxHP","MaxMP","ATK","DEF","MAT","MDF","AGI","LUK"]
 *
 * @param BasicParameters
 * @text Basic Parameters
 *
 * @param CrisisRate:num
 * @text HP Crisis Rate
 * @parent BasicParameters
 * @desc HP Ratio at which a battler can be considered in crisis mode.
 * @default 0.25
 *
 * @param BasicParameterFormula:func
 * @text JS: Formula
 * @parent BasicParameters
 * @type note
 * @desc Formula used to determine the total value all 8 basic parameters: MaxHP, MaxMP, ATK, DEF, MAT, MDF, AGI, LUK.
 * @default "// Determine the variables used in this calculation.\nlet paramId = arguments[0];\nlet base = this.paramBase(paramId);\nlet plus = this.paramPlus(paramId);\nlet paramRate = this.paramRate(paramId);\nlet buffRate = this.paramBuffRate(paramId);\nlet flatBonus = this.paramFlatBonus(paramId);\n\n// Formula to determine total parameter value.\nlet value = (base + plus) * paramRate * buffRate + flatBonus;\n\n// Determine the limits\nconst maxValue = this.paramMax(paramId);\nconst minValue = this.paramMin(paramId);\n\n// Final value\nreturn Math.round(value.clamp(minValue, maxValue));"
 *
 * @param BasicParamCaps
 * @text Parameter Caps
 * @parent BasicParameters
 *
 * @param BasicActorParamCaps
 * @text Actors
 * @parent BasicParamCaps
 *
 * @param BasicActorParamMax0:str
 * @text MaxHP Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine MaxHP cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 9999
 *
 * @param BasicActorParamMax1:str
 * @text MaxMP Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine MaxMP cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 9999
 *
 * @param BasicActorParamMax2:str
 * @text ATK Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine ATK cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicActorParamMax3:str
 * @text DEF Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine DEF cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicActorParamMax4:str
 * @text MAT Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine MAT cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicActorParamMax5:str
 * @text MDF Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine MDF cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicActorParamMax6:str
 * @text AGI Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine AGI cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicActorParamMax7:str
 * @text LUK Cap
 * @parent BasicActorParamCaps
 * @desc Formula used to determine LUK cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamCaps
 * @text Enemies
 * @parent BasicParamCaps
 *
 * @param BasicEnemyParamMax0:str
 * @text MaxHP Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine MaxHP cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999999
 *
 * @param BasicEnemyParamMax1:str
 * @text MaxMP Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine MaxMP cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 9999
 *
 * @param BasicEnemyParamMax2:str
 * @text ATK Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine ATK cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamMax3:str
 * @text DEF Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine DEF cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamMax4:str
 * @text MAT Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine MAT cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamMax5:str
 * @text MDF Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine MDF cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamMax6:str
 * @text AGI Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine AGI cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param BasicEnemyParamMax7:str
 * @text LUK Cap
 * @parent BasicEnemyParamCaps
 * @desc Formula used to determine LUK cap.
 * Use 0 if you don't want a cap for this parameter.
 * @default 999
 *
 * @param XParameters
 * @text X Parameters
 *
 * @param XParameterFormula:func
 * @text JS: Formula
 * @parent XParameters
 * @type note
 * @desc Formula used to determine the total value all 10 X parameters: HIT, EVA, CRI, CEV, MEV, MRF, CNT, HRG, MRG, TRG.
 * @default "// Determine the variables used in this calculation.\nlet xparamId = arguments[0];\nlet base = this.traitsSum(Game_BattlerBase.TRAIT_XPARAM, xparamId);\nlet plus = this.xparamPlus(xparamId);\nlet paramRate = this.xparamRate(xparamId);\nlet flatBonus = this.xparamFlatBonus(xparamId);\n\n// Formula to determine total parameter value.\nlet value = (base + plus) * paramRate + flatBonus;\n\n// Final value\nreturn value;"
 *
 * @param XParamVocab
 * @text Vocabulary
 * @parent XParameters
 *
 * @param XParamVocab0:str
 * @text HIT
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Hit
 *
 * @param XParamVocab1:str
 * @text EVA
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Evasion
 *
 * @param XParamVocab2:str
 * @text CRI
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Crit.Rate
 *
 * @param XParamVocab3:str
 * @text CEV
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Crit.Evade
 *
 * @param XParamVocab4:str
 * @text MEV
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Magic Evade
 *
 * @param XParamVocab5:str
 * @text MRF
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Magic Reflect
 *
 * @param XParamVocab6:str
 * @text CNT
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default Counter
 *
 * @param XParamVocab7:str
 * @text HRG
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default HP Regen
 *
 * @param XParamVocab8:str
 * @text MRG
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default MP Regen
 *
 * @param XParamVocab9:str
 * @text TRG
 * @parent XParamVocab
 * @desc The in-game vocabulary used for this X Parameter.
 * @default TP Regen
 *
 * @param SParameters
 * @text S Parameters
 *
 * @param SParameterFormula:func
 * @text JS: Formula
 * @parent SParameters
 * @type note
 * @desc Formula used to determine the total value all 10 S parameters: TGR, GRD, REC, PHA, MCR, TCR, PDR, MDR, FDR, EXR.
 * @default "// Determine the variables used in this calculation.\nlet sparamId = arguments[0];\nlet base = this.traitsPi(Game_BattlerBase.TRAIT_SPARAM, sparamId);\nlet plus = this.sparamPlus(sparamId);\nlet paramRate = this.sparamRate(sparamId);\nlet flatBonus = this.sparamFlatBonus(sparamId);\n\n// Formula to determine total parameter value.\nlet value = (base + plus) * paramRate + flatBonus;\n\n// Final value\nreturn value;"
 *
 * @param SParamVocab
 * @text Vocabulary
 * @parent SParameters
 *
 * @param SParamVocab0:str
 * @text TGR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Aggro
 *
 * @param SParamVocab1:str
 * @text GRD
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Guard
 *
 * @param SParamVocab2:str
 * @text REC
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Recovery
 *
 * @param SParamVocab3:str
 * @text PHA
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Item Effect
 *
 * @param SParamVocab4:str
 * @text MCR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default MP Cost
 *
 * @param SParamVocab5:str
 * @text TCR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default TP Charge
 *
 * @param SParamVocab6:str
 * @text PDR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Physical DMG
 *
 * @param SParamVocab7:str
 * @text MDR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Magical DMG
 *
 * @param SParamVocab8:str
 * @text FDR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default Floor DMG
 *
 * @param SParamVocab9:str
 * @text EXR
 * @parent SParamVocab
 * @desc The in-game vocabulary used for this S Parameter.
 * @default EXP Gain
 *
 * @param Icons
 * @text Icons
 *
 * @param DrawIcons:eval
 * @text Draw Icons?
 * @parent Icons
 * @type boolean
 * @on Draw
 * @off Don't Draw
 * @desc Draw icons next to parameter names?
 * @default true
 *
 * @param IconParam0:str
 * @text MaxHP
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 84
 *
 * @param IconParam1:str
 * @text MaxMP
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 165
 *
 * @param IconParam2:str
 * @text ATK
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 76
 *
 * @param IconParam3:str
 * @text DEF
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 81
 *
 * @param IconParam4:str
 * @text MAT
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 101
 *
 * @param IconParam5:str
 * @text MDF
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 133
 *
 * @param IconParam6:str
 * @text AGI
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 140
 *
 * @param IconParam7:str
 * @text LUK
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 87
 *
 * @param IconXParam0:str
 * @text HIT
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 102
 *
 * @param IconXParam1:str
 * @text EVA
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 82
 *
 * @param IconXParam2:str
 * @text CRI
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 78
 *
 * @param IconXParam3:str
 * @text CEV
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 82
 *
 * @param IconXParam4:str
 * @text MEV
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 171
 *
 * @param IconXParam5:str
 * @text MRF
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 222
 *
 * @param IconXParam6:str
 * @text CNT
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 77
 *
 * @param IconXParam7:str
 * @text HRG
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 72
 *
 * @param IconXParam8:str
 * @text MRG
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 72
 *
 * @param IconXParam9:str
 * @text TRG
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 72
 *
 * @param IconSParam0:str
 * @text TGR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 5
 *
 * @param IconSParam1:str
 * @text GRD
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 128
 *
 * @param IconSParam2:str
 * @text REC
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 72
 *
 * @param IconSParam3:str
 * @text PHA
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 176
 *
 * @param IconSParam4:str
 * @text MCR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 165
 *
 * @param IconSParam5:str
 * @text TCR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 164
 *
 * @param IconSParam6:str
 * @text PDR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 76
 *
 * @param IconSParam7:str
 * @text MDR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 79
 *
 * @param IconSParam8:str
 * @text FDR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 141
 *
 * @param IconSParam9:str
 * @text EXR
 * @parent Icons
 * @desc Icon used for this parameter.
 * @default 73
 *
 */
/* ----------------------------------------------------------------------------
 * Commands Struct
 * ----------------------------------------------------------------------------
 */
/*~struct~Command:
 *
 * @param Symbol:str
 * @text Symbol
 * @desc The symbol used for this command.
 * @default Symbol
 *
 * @param TextStr:str
 * @text STR: Text
 * @desc Displayed text used for this title command.
 * If this has a value, ignore the JS: Text version.
 * @default Untitled
 *
 * @param TextJS:func
 * @text JS: Text
 * @type note
 * @desc JavaScript code used to determine string used for the displayed name.
 * @default "return 'Text';"
 *
 * @param ShowJS:func
 * @text JS: Show
 * @type note
 * @desc JavaScript code used to determine if the item is shown or not.
 * @default "return true;"
 *
 * @param EnableJS:func
 * @text JS: Enable
 * @type note
 * @desc JavaScript code used to determine if the item is enabled or not.
 * @default "return true;"
 *
 * @param ExtJS:func
 * @text JS: Ext
 * @type note
 * @desc JavaScript code used to determine any ext data that should be added.
 * @default "return null;"
 *
 * @param CallHandlerJS:func
 * @text JS: Run Code
 * @type note
 * @desc JavaScript code that runs once this command is selected.
 * @default ""
 *
 */
/* ----------------------------------------------------------------------------
 * Title Picture Buttons
 * ----------------------------------------------------------------------------
 */
/*~struct~TitlePictureButton:
 *
 * @param PictureFilename:str
 * @text Picture's Filename
 * @type file
 * @dir img/pictures/
 * @desc Filename used for the picture.
 * @default 
 *
 * @param ButtonURL:str
 * @text Button URL
 * @desc URL for the button to go to upon being clicked.
 * @default https://www.google.com/
 *
 * @param PositionJS:func
 * @text JS: Position
 * @type note
 * @desc JavaScript code that helps determine the button's Position.
 * @default "this.x = Graphics.width - this.bitmap.width - 20;\nthis.y = Graphics.height - this.bitmap.height - 20;"
 *
 * @param OnLoadJS:func
 * @text JS: On Load
 * @type note
 * @desc JavaScript code that runs once this button bitmap is loaded.
 * @default "this.opacity = 0;\nthis.visible = true;"
 *
 * @param CallHandlerJS:func
 * @text JS: Run Code
 * @type note
 * @desc JavaScript code that runs once this button is pressed.
 * @default "const url = this._data.ButtonURL;\nVisuMZ.openURL(url);"
 *
 */
/* ----------------------------------------------------------------------------
 * UI Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~UI:
 *
 * @param UIArea
 * @text UI Area
 *
 * @param FadeSpeed:num
 * @text Fade Speed
 * @parent UIArea
 * @desc Default fade speed for transitions.
 * @default 24
 *
 * @param BoxMargin:num
 * @text Box Margin
 * @parent UIArea
 * @type number
 * @min 0
 * @desc Set the margin in pixels for the screen borders.
 * Default: 4
 * @default 4
 *
 * @param CommandWidth:num
 * @text Command Window Width
 * @parent UIArea
 * @type number
 * @min 1
 * @desc Sets the width for standard Command Windows.
 * Default: 240
 * @default 240
 *
 * @param BottomHelp:eval
 * @text Bottom Help Window
 * @parent UIArea
 * @type boolean
 * @on Bottom
 * @off Top
 * @desc Put the Help Window at the bottom of the screen?
 * @default false
 *
 * @param RightMenus:eval
 * @text Right Aligned Menus
 * @parent UIArea
 * @type boolean
 * @on Right
 * @off Left
 * @desc Put most command windows to the right side of the screen.
 * @default true
 *
 * @param ShowButtons:eval
 * @text Show Buttons
 * @parent UIArea
 * @type boolean
 * @on Show
 * @off Hide
 * @desc Show clickable buttons in your game?
 * This will affect all buttons.
 * @default true
 *
 * @param cancelShowButton:eval
 * @text Show Cancel Button
 * @parent ShowButtons:eval
 * @type boolean
 * @on Show
 * @off Hide
 * @desc Show cancel button?
 * If 'Show Buttons' is false, this will be hidden.
 * @default true
 *
 * @param menuShowButton:eval
 * @text Show Menu Button
 * @parent ShowButtons:eval
 * @type boolean
 * @on Show
 * @off Hide
 * @desc Show main menu button from the map scene?
 * If 'Show Buttons' is false, this will be hidden.
 * @default true
 *
 * @param pagedownShowButton:eval
 * @text Show Page Up/Down
 * @parent ShowButtons:eval
 * @type boolean
 * @on Show
 * @off Hide
 * @desc Show page up/down buttons?
 * If 'Show Buttons' is false, this will be hidden.
 * @default true
 *
 * @param numberShowButton:eval
 * @text Show Number Buttons
 * @parent ShowButtons:eval
 * @type boolean
 * @on Show
 * @off Hide
 * @desc Show number adjustment buttons?
 * If 'Show Buttons' is false, this will be hidden.
 * @default true
 *
 * @param ButtonHeight:num
 * @text Button Area Height
 * @parent UIArea
 * @type number
 * @min 1
 * @desc Sets the height for the button area.
 * Default: 52
 * @default 52
 *
 * @param BottomButtons:eval
 * @text Bottom Buttons
 * @parent UIArea
 * @type boolean
 * @on Bottom
 * @off Top
 * @desc Put the buttons at the bottom of the screen?
 * @default false
 *
 * @param SideButtons:eval
 * @text Side Buttons
 * @parent UIArea
 * @type boolean
 * @on Side
 * @off Normal
 * @desc Push buttons to the side of the UI if there is room.
 * @default true
 *
 * @param MenuObjects
 * @text Menu Objects
 *
 * @param LvExpGauge:eval
 * @text Level -> EXP Gauge
 * @parent MenuObjects
 * @type boolean
 * @on Draw Gauge
 * @off Keep As Is
 * @desc Draw an EXP Gauge under the drawn level.
 * @default true
 *
 * @param ParamArrow:str
 * @text Parameter Arrow
 * @parent MenuObjects
 * @desc The arrow used to show changes in the parameter values.
 * @default →
 *
 * @param TextCodeSupport
 * @text Text Code Support
 *
 * @param TextCodeClassNames:eval
 * @text Class Names
 * @parent TextCodeSupport
 * @type boolean
 * @on Suport Text Codes
 * @off Normal Text
 * @desc Make class names support text codes?
 * @default true
 *
 * @param TextCodeNicknames:eval
 * @text Nicknames
 * @parent TextCodeSupport
 * @type boolean
 * @on Suport Text Codes
 * @off Normal Text
 * @desc Make nicknames support text codes?
 * @default true
 *
 */
/* ----------------------------------------------------------------------------
 * Window Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~Window:
 *
 * @param WindowDefaults
 * @text Defaults
 *
 * @param EnableMasking:eval
 * @text Enable Masking
 * @parent WindowDefaults
 * @type boolean
 * @on Masking On
 * @off Masking Off
 * @desc Enable window masking (windows hide other windows behind 
 * them)? WARNING: Turning it on can obscure data.
 * @default false
 *
 * @param LineHeight:num
 * @text Line Height
 * @parent WindowDefaults
 * @desc Default line height used for standard windows.
 * Default: 36
 * @default 36
 *
 * @param ItemPadding:num
 * @text Item Padding
 * @parent WindowDefaults
 * @desc Default line padding used for standard windows.
 * Default: 8
 * @default 8
 *
 * @param BackOpacity:num
 * @text Back Opacity
 * @parent WindowDefaults
 * @desc Default back opacity used for standard windows.
 * Default: 192
 * @default 192
 *
 * @param TranslucentOpacity:num
 * @text Translucent Opacity
 * @parent WindowDefaults
 * @desc Default translucent opacity used for standard windows.
 * Default: 160
 * @default 160
 *
 * @param OpenSpeed:num
 * @text Window Opening Speed
 * @parent WindowDefaults
 * @desc Default open speed used for standard windows.
 * Default: 32 (Use a number between 0-255)
 * @default 32
 * @default 24
 *
 * @param ColSpacing:num
 * @text Column Spacing
 * @parent WindowDefaults
 * @desc Default column spacing for selectable windows.
 * Default: 8
 * @default 8
 *
 * @param RowSpacing:num
 * @text Row Spacing
 * @parent WindowDefaults
 * @desc Default row spacing for selectable windows.
 * Default: 4
 * @default 4
 * 
 * @param SelectableItems
 * @text Selectable Items
 *
 * @param ShowItemBackground:eval
 * @text Show Background?
 * @parent SelectableItems
 * @type boolean
 * @on Show Backgrounds
 * @off No backgrounds.
 * @desc Selectable menu items have dark boxes behind them. Show them?
 * @default true
 *
 * @param ItemHeight:num
 * @text Item Height Padding
 * @parent SelectableItems
 * @desc Default padding for selectable items.
 * Default: 8
 * @default 8
 *
 * @param DrawItemBackgroundJS:func
 * @text JS: Draw Background
 * @parent SelectableItems
 * @type note
 * @desc Code used to draw the background rectangle behind clickable menu objects
 * @default "const rect = arguments[0];\nconst c1 = ColorManager.itemBackColor1();\nconst c2 = ColorManager.itemBackColor2();\nconst x = rect.x;\nconst y = rect.y;\nconst w = rect.width;\nconst h = rect.height;\nthis.contentsBack.gradientFillRect(x, y, w, h, c1, c2, true);\nthis.contentsBack.strokeRect(x, y, w, h, c1);"
 */
/* ----------------------------------------------------------------------------
 * Screen Resolution Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ScreenResolution:
 *
 * @param Troops
 *
 * @param RepositionActors:eval
 * @text Reposition Actors
 * @parent Troops
 * @type boolean
 * @on Reposition
 * @off Keep As Is
 * @desc Update the position of actors in battle if the screen resolution has changed. Ignore if using Battle Core.
 * @default true
 *
 * @param RepositionEnemies:eval
 * @text Reposition Enemies
 * @parent Troops
 * @type boolean
 * @on Reposition
 * @off Keep As Is
 * @desc Update the position of enemies in battle if the screen resolution has changed.
 * @default true
 *
 * @param RepositionEnemies130:eval
 * @text For MZ 1.3.0+?
 * @parent RepositionEnemies:eval
 * @type boolean
 * @on Reposition
 * @off Keep As Is
 * @desc Both this parameter and its parent parameter need to be on when using RPG Maker MZ 1.3.0+.
 * @default false
 *
 */
/* ----------------------------------------------------------------------------
 * Screen Shake Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ScreenShake:
 *
 * @param DefaultStyle:str
 * @text Default Style
 * @type select
 * @option Original
 * @value original
 * @option Random
 * @value random
 * @option Horizontal
 * @value horizontal
 * @option Vertical
 * @value vertical
 * @desc The default style used for screen shakes.
 * @default random
 *
 * @param originalJS:func
 * @text JS: Original Style
 * @type note
 * @desc This code gives you control over screen shake for this
 * screen shake style.
 * @default "// Calculation\nthis.x += Math.round($gameScreen.shake());"
 *
 * @param randomJS:func
 * @text JS: Random Style
 * @type note
 * @desc This code gives you control over screen shake for this
 * screen shake style.
 * @default "// Calculation\n// Original Formula by Aries of Sheratan\nconst power = $gameScreen._shakePower * 0.75;\nconst speed = $gameScreen._shakeSpeed * 0.60;\nconst duration = $gameScreen._shakeDuration;\nthis.x += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);\nthis.y += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);"
 *
 * @param horzJS:func
 * @text JS: Horizontal Style
 * @type note
 * @desc This code gives you control over screen shake for this
 * screen shake style.
 * @default "// Calculation\n// Original Formula by Aries of Sheratan\nconst power = $gameScreen._shakePower * 0.75;\nconst speed = $gameScreen._shakeSpeed * 0.60;\nconst duration = $gameScreen._shakeDuration;\nthis.x += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);"
 *
 * @param vertJS:func
 * @text JS: Vertical Style
 * @type note
 * @desc This code gives you control over screen shake for this
 * screen shake style.
 * @default "// Calculation\n// Original Formula by Aries of Sheratan\nconst power = $gameScreen._shakePower * 0.75;\nconst speed = $gameScreen._shakeSpeed * 0.60;\nconst duration = $gameScreen._shakeDuration;\nthis.y += Math.round(Math.randomInt(power) - Math.randomInt(speed)) * (Math.min(duration, 30) * 0.5);"
 *
 */
/* ----------------------------------------------------------------------------
 * Custom Parameter Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~CustomParam:
 *
 * @param ParamName:str
 * @text Parameter Name
 * @desc What's the parameter's name?
 * Used for VisuStella MZ menus.
 * @default Untitled
 *
 * @param Abbreviation:str
 * @text Abbreviation
 * @parent ParamName:str
 * @desc What abbreviation do you want to use for the parameter?
 * Do not use special characters. Avoid numbers if possible.
 * @default unt
 *
 * @param Icon:num
 * @text Icon
 * @parent ParamName:str
 * @desc What icon do you want to use to represent this parameter?
 * Used for VisuStella MZ menus.
 * @default 160
 *
 * @param Type:str
 * @text Type
 * @parent ParamName:str
 * @type select
 * @option Integer (Whole Numbers Only)
 * @value integer
 * @option Float (Decimals are Allowed)
 * @value float
 * @desc What kind of number value will be returned with this parameter?
 * @default integer
 *
 * @param ValueJS:json
 * @text JS: Value
 * @type note
 * @desc Run this code when this parameter is to be returned.
 * @default "// Declare Constants\nconst user = this;\n\n// Calculations\nreturn 1;"
 *
 */
/* ----------------------------------------------------------------------------
 * Show Picture Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~ShowPicture:
 * 
 * @param Position
 *
 * @param Origin:num
 * @text Origin
 * @parent Position
 * @type select
 * @option 0 - Upper Left
 * @value 0
 * @option 1 - Center
 * @value 1
 * @desc What is the origin of this picture icon?
 * @default 0
 *
 * @param PositionX:eval
 * @text Position X
 * @parent Position
 * @desc X coordinate of the picture.
 * You may use JavaScript code.
 * @default 0
 *
 * @param PositionY:eval
 * @text Position Y
 * @parent Position
 * @desc Y coordinate of the picture.
 * You may use JavaScript code.
 * @default 0
 * 
 * @param Scale
 *
 * @param ScaleX:eval
 * @text Width %
 * @parent Scale
 * @desc Horizontal scale of the picture.
 * You may use JavaScript code.
 * @default 100
 *
 * @param ScaleY:eval
 * @text Height %
 * @parent Scale
 * @desc Vertical scale of the picture.
 * You may use JavaScript code.
 * @default 100
 * 
 * @param Blend
 *
 * @param Opacity:eval
 * @text Opacity
 * @parent Blend
 * @desc Insert a number to determine opacity level. Use a
 * number between 0 and 255. You may use JavaScript code.
 * @default 255
 *
 * @param BlendMode:num
 * @text Blend Mode
 * @parent Blend
 * @type select
 * @option 0 - Normal
 * @value 0
 * @option 1 - Additive
 * @value 1
 * @option 2 - Multiply
 * @value 2
 * @option 3 - Screen
 * @value 3
 * @desc What kind of blend mode do you wish to apply to the picture?
 * @default 0
 *
 */
/* ----------------------------------------------------------------------------
 * JS Quick Function Settings
 * ----------------------------------------------------------------------------
 */
/*~struct~jsQuickFunc:
 *
 * @param FunctionName:str
 * @text Function Name
 * @desc The function's name in the global namespace.
 * Will not overwrite functions/variables of the same name.
 * @default Untitled
 *
 * @param CodeJS:json
 * @text JS: Code
 * @type note
 * @desc Run this code when using the function.
 * @default "// Insert this as a function anywhere you can input code\n// such as Script Calls or Conditional Branch Scripts.\n\n// Process Code\n"
 *
 */
//=============================================================================

const _0x54167d=_0x4d17;(function(_0x421162,_0x6f84ea){const _0x46360d=_0x4d17,_0x3708cd=_0x421162();while(!![]){try{const _0x3e4012=parseInt(_0x46360d(0x24f))/0x1+-parseInt(_0x46360d(0x37b))/0x2*(-parseInt(_0x46360d(0x390))/0x3)+parseInt(_0x46360d(0x34c))/0x4*(-parseInt(_0x46360d(0x32e))/0x5)+parseInt(_0x46360d(0x2b0))/0x6+-parseInt(_0x46360d(0x219))/0x7*(-parseInt(_0x46360d(0x387))/0x8)+-parseInt(_0x46360d(0x889))/0x9*(parseInt(_0x46360d(0x488))/0xa)+parseInt(_0x46360d(0x80e))/0xb*(parseInt(_0x46360d(0x94c))/0xc);if(_0x3e4012===_0x6f84ea)break;else _0x3708cd['push'](_0x3708cd['shift']());}catch(_0x50f9aa){_0x3708cd['push'](_0x3708cd['shift']());}}}(_0x2505,0x57955));var label='CoreEngine',tier=tier||0x0,dependencies=[],pluginData=$plugins[_0x54167d(0x64f)](function(_0x29b46c){const _0x23b8a5=_0x54167d;return _0x29b46c[_0x23b8a5(0x32f)]&&_0x29b46c['description']['includes']('['+label+']');})[0x0];VisuMZ[label][_0x54167d(0x331)]=VisuMZ[label]['Settings']||{},VisuMZ[_0x54167d(0x683)]=function(_0x4a0aa8,_0x59526a){const _0x543377=_0x54167d;for(const _0x457b39 in _0x59526a){if(_0x543377(0x2a7)!=='UzvEz'){if(_0x457b39['match'](/(.*):(.*)/i)){const _0x39fb6f=String(RegExp['$1']),_0x3d5bef=String(RegExp['$2'])[_0x543377(0x8dd)]()[_0x543377(0x314)]();let _0x56913e,_0x46176a,_0x35a8c8;switch(_0x3d5bef){case _0x543377(0x991):_0x56913e=_0x59526a[_0x457b39]!==''?Number(_0x59526a[_0x457b39]):0x0;break;case _0x543377(0x76e):_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a['map'](_0x515b2d=>Number(_0x515b2d));break;case _0x543377(0x370):_0x56913e=_0x59526a[_0x457b39]!==''?eval(_0x59526a[_0x457b39]):null;break;case _0x543377(0x24a):_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a[_0x543377(0x90c)](_0x99de00=>eval(_0x99de00));break;case'JSON':_0x56913e=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):'';break;case _0x543377(0x5fc):_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a[_0x543377(0x90c)](_0x9a0629=>JSON[_0x543377(0x7c7)](_0x9a0629));break;case _0x543377(0x4af):_0x56913e=_0x59526a[_0x457b39]!==''?new Function(JSON['parse'](_0x59526a[_0x457b39])):new Function(_0x543377(0x3f6));break;case'ARRAYFUNC':_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a[_0x543377(0x90c)](_0x27f03a=>new Function(JSON[_0x543377(0x7c7)](_0x27f03a)));break;case'STR':_0x56913e=_0x59526a[_0x457b39]!==''?String(_0x59526a[_0x457b39]):'';break;case _0x543377(0x651):_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a['map'](_0x26673b=>String(_0x26673b));break;case _0x543377(0x4e1):_0x35a8c8=_0x59526a[_0x457b39]!==''?JSON['parse'](_0x59526a[_0x457b39]):{},_0x4a0aa8[_0x39fb6f]={},VisuMZ[_0x543377(0x683)](_0x4a0aa8[_0x39fb6f],_0x35a8c8);continue;case _0x543377(0x923):_0x46176a=_0x59526a[_0x457b39]!==''?JSON[_0x543377(0x7c7)](_0x59526a[_0x457b39]):[],_0x56913e=_0x46176a['map'](_0x17dd7b=>VisuMZ['ConvertParams']({},JSON[_0x543377(0x7c7)](_0x17dd7b)));break;default:continue;}_0x4a0aa8[_0x39fb6f]=_0x56913e;}}else _0x1f1f35['x']=_0xe98d0[_0x543377(0x3ad)](_0x212d50['x']),_0x381a71['y']=_0x5e6107[_0x543377(0x3ad)](_0x3d6d6e['y']),_0x34f61b[_0x543377(0x281)]=_0x186676[_0x543377(0x3ad)](_0x59d7bc[_0x543377(0x281)]),_0xcf41c7[_0x543377(0x3e1)]=_0x4e2717['round'](_0x216507['height']),this[_0x543377(0x3e9)](),_0x4f5fee['CoreEngine'][_0x543377(0x6b7)][_0x543377(0x204)](this,_0x502c1c),this[_0x543377(0x383)]();}return _0x4a0aa8;},VisuMZ['CoreEngine'][_0x54167d(0x5ef)]=SceneManager[_0x54167d(0x4fc)],SceneManager[_0x54167d(0x4fc)]=function(){const _0x2be842=_0x54167d;VisuMZ[_0x2be842(0x940)]['SceneManager_exit'][_0x2be842(0x204)](this);if(Utils[_0x2be842(0x20a)]>='1.4.4'){if('lkOUn'!==_0x2be842(0x9e1))for(const _0x46f15a of _0x5d72fb[_0x2be842(0x921)]){if(_0x46f15a['ShowJS'][_0x2be842(0x204)](this)){const _0x5dd7dc=_0x46f15a[_0x2be842(0x221)];let _0x4527bc=_0x46f15a[_0x2be842(0x20d)];if(['',_0x2be842(0x916)][_0x2be842(0x9ef)](_0x4527bc))_0x4527bc=_0x46f15a[_0x2be842(0x424)]['call'](this);const _0x487ef5=_0x46f15a[_0x2be842(0x338)][_0x2be842(0x204)](this),_0x56ac74=_0x46f15a[_0x2be842(0x5c8)][_0x2be842(0x204)](this);this[_0x2be842(0x771)](_0x4527bc,_0x5dd7dc,_0x487ef5,_0x56ac74),this[_0x2be842(0x60e)](_0x5dd7dc,_0x46f15a[_0x2be842(0x406)][_0x2be842(0x6ac)](this,_0x56ac74));}}else{if(typeof nw==='object')nw[_0x2be842(0x4c8)]['quit']();}}},(_0x56e6c3=>{const _0x396162=_0x54167d,_0x258d1a=_0x56e6c3[_0x396162(0x614)];for(const _0x3c0811 of dependencies){if('IFQRX'!==_0x396162(0x8c5)){if(!Imported[_0x3c0811]){if(_0x396162(0x26d)===_0x396162(0x26d)){alert(_0x396162(0x654)[_0x396162(0x482)](_0x258d1a,_0x3c0811)),SceneManager[_0x396162(0x4fc)]();break;}else{if(_0x4215da[_0x396162(0x48d)][_0x396162(0x204)](this)){const _0x1bcb02=_0x3005e3[_0x396162(0x221)];let _0x2c9305=_0x3e7be5['TextStr'];if(['','Untitled']['includes'](_0x2c9305))_0x2c9305=_0x3443e2[_0x396162(0x424)][_0x396162(0x204)](this);const _0x36f3c2=_0x4230fc[_0x396162(0x338)][_0x396162(0x204)](this),_0x54bf76=_0x5b1f9a[_0x396162(0x5c8)][_0x396162(0x204)](this);this[_0x396162(0x771)](_0x2c9305,_0x1bcb02,_0x36f3c2,_0x54bf76),this[_0x396162(0x60e)](_0x1bcb02,_0x55538b[_0x396162(0x406)][_0x396162(0x6ac)](this,_0x54bf76));}}}}else _0x5a2bb8['_x']=_0x58f751['_x'],_0x20a4e2['_y']=_0x395aa2['_y'];}const _0x1e8d0b=_0x56e6c3['description'];if(_0x1e8d0b['match'](/\[Version[ ](.*?)\]/i)){const _0x168e35=Number(RegExp['$1']);_0x168e35!==VisuMZ[label][_0x396162(0x553)]&&(_0x396162(0x3a3)==='AkROb'?(alert(_0x396162(0x21e)['format'](_0x258d1a,_0x168e35)),SceneManager[_0x396162(0x4fc)]()):this['_menuButton']['x']=_0x526107[_0x396162(0x497)]+0x4);}if(_0x1e8d0b['match'](/\[Tier[ ](\d+)\]/i)){if(_0x396162(0x375)===_0x396162(0x375)){const _0x31615a=Number(RegExp['$1']);_0x31615a<tier?(alert(_0x396162(0x864)[_0x396162(0x482)](_0x258d1a,_0x31615a,tier)),SceneManager[_0x396162(0x4fc)]()):tier=Math[_0x396162(0x350)](_0x31615a,tier);}else{if(_0x15cd85['ParseAllNotetags'])return;}}VisuMZ[_0x396162(0x683)](VisuMZ[label][_0x396162(0x331)],_0x56e6c3[_0x396162(0x733)]);})(pluginData),((()=>{const _0x28b3d4=_0x54167d;if(VisuMZ['CoreEngine'][_0x28b3d4(0x331)]['QoL'][_0x28b3d4(0x670)]??!![])for(const _0x33f781 in $plugins){if(_0x28b3d4(0x5f5)!=='Mabdk')this['_forcedBattleSys']=0x2;else{const _0x36b4af=$plugins[_0x33f781];_0x36b4af[_0x28b3d4(0x614)][_0x28b3d4(0x59b)](/(.*)\/(.*)/i)&&(_0x36b4af[_0x28b3d4(0x614)]=String(RegExp['$2'][_0x28b3d4(0x314)]()));}}})()),PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],_0x54167d(0x363),_0xffdbb0=>{const _0x549574=_0x54167d;if(!SceneManager['_scene'])return;if(!SceneManager[_0x549574(0x4ce)][_0x549574(0x6ae)])return;VisuMZ['ConvertParams'](_0xffdbb0,_0xffdbb0);const _0x41da03=Math[_0x549574(0x3ad)](_0xffdbb0[_0x549574(0x766)]),_0x5ea3c7=Math[_0x549574(0x3ad)](_0xffdbb0[_0x549574(0x9cf)]);$gameTemp[_0x549574(0x8f9)](_0x41da03,_0x5ea3c7,_0xffdbb0['AnimationID'],_0xffdbb0[_0x549574(0x665)],_0xffdbb0['Mute']);}),PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],_0x54167d(0x3ee),_0x5c5b59=>{const _0x2bb70d=_0x54167d;if(!$gameTemp[_0x2bb70d(0x562)]())return;if(!Utils[_0x2bb70d(0x303)]())return;SceneManager['_scene'][_0x2bb70d(0x2bc)]=![],VisuMZ[_0x2bb70d(0x940)][_0x2bb70d(0x23b)]();}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x51b),_0x4a729b=>{const _0x140d44=_0x54167d;if(!$gameTemp[_0x140d44(0x562)]())return;if(!Utils[_0x140d44(0x303)]())return;SceneManager[_0x140d44(0x4ce)][_0x140d44(0x2bc)]=![],VisuMZ['CoreEngine'][_0x140d44(0x726)]();}),PluginManager['registerCommand'](pluginData['name'],_0x54167d(0x6cd),_0x19a54a=>{const _0x8143a=_0x54167d;if(!$gameTemp['isPlaytest']())return;if(!Utils[_0x8143a(0x303)]())return;if(!$gameMap)return;if($gameMap['mapId']()<=0x0)return;VisuMZ['ConvertParams'](_0x19a54a,_0x19a54a);const _0x445749=_0x8143a(0x2eb)[_0x8143a(0x482)]($gameMap['mapId']()['padZero'](0x3)),_0x104408=VisuMZ['CoreEngine'][_0x8143a(0x6a6)]($gameMap['mapId']());VisuMZ['CoreEngine']['ExportString'](_0x104408,_0x445749,!![]);}),PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],_0x54167d(0x645),_0x5cb7fc=>{const _0x5460d0=_0x54167d;if(!$gameTemp['isPlaytest']())return;if(!Utils[_0x5460d0(0x303)]())return;if(!$gameParty[_0x5460d0(0x540)]())return;VisuMZ[_0x5460d0(0x683)](_0x5cb7fc,_0x5cb7fc);const _0x2b440c=_0x5460d0(0x3d4)[_0x5460d0(0x482)]($gameTroop['_troopId'][_0x5460d0(0x3c7)](0x4)),_0x28adf2=VisuMZ[_0x5460d0(0x940)][_0x5460d0(0x78a)]($gameTroop['_troopId']);VisuMZ[_0x5460d0(0x940)][_0x5460d0(0x207)](_0x28adf2,_0x2b440c,!![]);}),VisuMZ['CoreEngine']['ExportString']=function(_0x87ec69,_0x2809a7,_0x53e616){const _0x3c5f61=_0x54167d,_0x2b29a0=require('fs');let _0x1b29db='Exported_Script_%1.txt'[_0x3c5f61(0x482)](_0x2809a7||'0');_0x2b29a0[_0x3c5f61(0x8d8)](_0x1b29db,_0x87ec69,_0x2cf9f8=>{const _0x1d87dc=_0x3c5f61;if(_0x2cf9f8){if('ZnbGC'===_0x1d87dc(0x75a)){if(_0x417a2c instanceof _0x489df1)this[_0x1d87dc(0x246)](_0x45c8fc);else _0x16f7b0 instanceof _0x2733f3&&_0x24bfc7[0x0]===_0x1d87dc(0x401)?this[_0x1d87dc(0x96e)](_0x13e091):this['catchUnknownError'](_0x1f0f15);this['stop']();}else throw err;}else _0x53e616&&alert('Saved\x20file\x20as\x20%1\x20in\x20project\x20folder.'[_0x1d87dc(0x482)](_0x1b29db));});},VisuMZ[_0x54167d(0x940)][_0x54167d(0x23b)]=function(){const _0x426225=_0x54167d,_0x1c1720=[];for(const _0x11de93 of $dataMapInfos){if(!_0x11de93)continue;_0x1c1720['push'](_0x11de93['id']);}const _0x9d5bff=_0x1c1720[_0x426225(0x95b)]*0x64+Math[_0x426225(0x549)](0x64);alert(_0x426225(0x782)[_0x426225(0x482)](_0x9d5bff)),this[_0x426225(0x5cc)]=[],this['_currentMap']=$dataMap;for(const _0x39e9bf of _0x1c1720){if('QPZsD'!==_0x426225(0x9ae))VisuMZ[_0x426225(0x940)]['loadMapData'](_0x39e9bf);else return _0x1329e1['CoreEngine'][_0x426225(0x331)][_0x426225(0x2e9)][_0x426225(0x413)];}setTimeout(VisuMZ[_0x426225(0x940)][_0x426225(0x93f)]['bind'](this),_0x9d5bff);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x71c)]=function(_0x51d868){const _0x4adbcc=_0x54167d,_0x20775c=_0x4adbcc(0x397)['format'](_0x51d868['padZero'](0x3)),_0x24c3f3=new XMLHttpRequest(),_0x4dcbc2=_0x4adbcc(0x30f)+_0x20775c;_0x24c3f3['open'](_0x4adbcc(0x7c8),_0x4dcbc2),_0x24c3f3['overrideMimeType'](_0x4adbcc(0x26c)),_0x24c3f3[_0x4adbcc(0x2ac)]=()=>this[_0x4adbcc(0x7eb)](_0x24c3f3,_0x51d868,_0x20775c,_0x4dcbc2),_0x24c3f3[_0x4adbcc(0x67f)]=()=>DataManager[_0x4adbcc(0x813)](_0x4adbcc(0x2ed),_0x20775c,_0x4dcbc2),_0x24c3f3[_0x4adbcc(0x7e3)]();},VisuMZ['CoreEngine'][_0x54167d(0x7eb)]=function(_0x22144a,_0x462cc8,_0x55a7a,_0xfc9145){const _0x24fade=_0x54167d;$dataMap=JSON[_0x24fade(0x7c7)](_0x22144a[_0x24fade(0x335)]),DataManager[_0x24fade(0x7a1)]($dataMap),this[_0x24fade(0x5cc)][_0x462cc8]=VisuMZ[_0x24fade(0x940)][_0x24fade(0x6a6)](_0x462cc8),$dataMap=this[_0x24fade(0x6e9)];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x93f)]=function(){const _0x33fb07=_0x54167d,_0x378b9d=_0x33fb07(0x732);this[_0x33fb07(0x5cc)][_0x33fb07(0x233)](undefined)['remove']('')['remove'](null);const _0x114ba1=this[_0x33fb07(0x5cc)][_0x33fb07(0x53d)](_0x33fb07(0x96c))['trim']();VisuMZ['CoreEngine'][_0x33fb07(0x207)](_0x114ba1,_0x378b9d,!![]),SceneManager[_0x33fb07(0x4ce)]['_active']=!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x6a6)]=function(_0x4e1c27){const _0x25b72c=_0x54167d;if(!$dataMap)return'';let _0x52c839='█'[_0x25b72c(0x779)](0x46)+'\x0a\x0a',_0x12d0d8='═'[_0x25b72c(0x779)](0x46)+'\x0a\x0a',_0x3000f5='';this[_0x25b72c(0x582)]=0x0;for(const _0x464212 of $dataMap[_0x25b72c(0x437)]){if(!_0x464212)continue;let _0x381a22=_0x464212['id'],_0x1a9545=_0x464212['name'],_0x7b8c6d=_0x464212[_0x25b72c(0x6e0)];for(const _0x4d321d of _0x7b8c6d){const _0x3996de=_0x7b8c6d[_0x25b72c(0x63e)](_0x4d321d)+0x1;let _0x3fe3ab=_0x12d0d8+_0x25b72c(0x41e),_0x4676ee=VisuMZ[_0x25b72c(0x940)][_0x25b72c(0x8b2)](_0x4d321d[_0x25b72c(0x9d7)]);if(_0x4676ee[_0x25b72c(0x95b)]>0x0){if(_0x25b72c(0x6dd)!==_0x25b72c(0x53f)){if(_0x3000f5[_0x25b72c(0x95b)]>0x0){if(_0x25b72c(0x44c)!=='kJaza')_0x3000f5+=_0x12d0d8+_0x25b72c(0x96c);else{const _0x488a8d=_0x1a4f18['width']-_0x2e539e[_0x25b72c(0x497)]-_0x2cf2af[_0x25b72c(0x940)][_0x25b72c(0x331)]['UI'][_0x25b72c(0x3a0)]*0x2,_0x344ac8=_0xc71823[_0x25b72c(0x4ec)][_0x25b72c(0x468)][_0x25b72c(0x204)](this)*0x4;if(_0x488a8d>=_0x344ac8)_0x40df45[_0x25b72c(0x87d)](!![]);}}else{const _0xafab9=$dataMapInfos[_0x4e1c27][_0x25b72c(0x614)];_0x3000f5+=_0x52c839+_0x25b72c(0x388)['format'](_0x4e1c27,_0xafab9||_0x25b72c(0x678))+_0x52c839;}_0x3000f5+=_0x3fe3ab[_0x25b72c(0x482)](_0x381a22,_0x1a9545,_0x3996de,_0x4676ee);}else return this['isMapScrollLinked']()?this[_0x25b72c(0x36c)]():_0x44e74e[_0x25b72c(0x940)]['Game_Picture_x']['call'](this);}}}if(_0x3000f5[_0x25b72c(0x95b)]>0x0){if('EINQq'===_0x25b72c(0x945))_0x3000f5+=_0x12d0d8;else{_0x816e2f+=_0x1a8f4e;if(_0x3e28b9>=_0x342c9f)_0x643b7a=_0x38b0b5-0x1;this[_0x25b72c(0x63f)](_0x34d29a);}}return _0x3000f5;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x726)]=function(){const _0x170f60=_0x54167d,_0x5dce89=$dataTroops[_0x170f60(0x95b)]*0xa+Math[_0x170f60(0x549)](0xa);alert(_0x170f60(0xa02)[_0x170f60(0x482)](_0x5dce89));const _0x3feaf6=[];for(const _0x2fb694 of $dataTroops){if('Nhenn'===_0x170f60(0x212)){const _0x2c6281=_0x170f60(0x560);this[_0x170f60(0x961)]=this['_colorCache']||{};if(this[_0x170f60(0x961)][_0x2c6281])return this['_colorCache'][_0x2c6281];const _0x3fc813=_0x3b60e9['CoreEngine']['Settings'][_0x170f60(0x530)]['ColorNormal'];return this[_0x170f60(0x731)](_0x2c6281,_0x3fc813);}else{if(!_0x2fb694)continue;const _0x1bb4d2=_0x2fb694['id'];_0x3feaf6[_0x1bb4d2]=VisuMZ['CoreEngine'][_0x170f60(0x78a)](_0x1bb4d2);}}setTimeout(VisuMZ['CoreEngine'][_0x170f60(0x628)][_0x170f60(0x6ac)](this,_0x3feaf6),_0x5dce89);},VisuMZ['CoreEngine']['ExtractStrFromTroop']=function(_0x1317b2){const _0x366aeb=_0x54167d;if(!$dataTroops[_0x1317b2])return'';let _0x4947a5='█'[_0x366aeb(0x779)](0x46)+'\x0a\x0a',_0x29b322='═'[_0x366aeb(0x779)](0x46)+'\x0a\x0a',_0x9525f2='';this[_0x366aeb(0x582)]=0x0;const _0x1ff14a=$dataTroops[_0x1317b2];let _0x4365aa=_0x1ff14a[_0x366aeb(0x6e0)];for(const _0xbb6002 of _0x4365aa){if(_0x366aeb(0x5af)!==_0x366aeb(0x30d)){const _0x1f02e7=_0x4365aa['indexOf'](_0xbb6002)+0x1;let _0x1ec86d=_0x29b322+_0x366aeb(0x7a4),_0x547c93=VisuMZ[_0x366aeb(0x940)]['ExtractStrFromList'](_0xbb6002['list']);if(_0x547c93['length']>0x0){if(_0x9525f2[_0x366aeb(0x95b)]>0x0){if(_0x366aeb(0x444)===_0x366aeb(0x444))_0x9525f2+=_0x29b322+_0x366aeb(0x96c);else{const _0xd8ff57=_0x2bf427[_0x366aeb(0x497)],_0x5ac46f=_0x570f5b[_0x366aeb(0x4ec)][_0x366aeb(0x7c4)](),_0x253557=0x0;let _0x5aaf6f=0x0;return this[_0x366aeb(0x6e7)]()==='top'?_0x5aaf6f=0x0:_0x5aaf6f=_0x452646[_0x366aeb(0x996)]-_0x5ac46f,new _0x410672(_0x253557,_0x5aaf6f,_0xd8ff57,_0x5ac46f);}}else'qZvAk'!=='qZvAk'?this[_0x366aeb(0x308)]():_0x9525f2+=_0x4947a5+_0x366aeb(0x90e)[_0x366aeb(0x482)](_0x1317b2,_0x1ff14a['name']||_0x366aeb(0x678))+_0x4947a5;_0x9525f2+=_0x1ec86d[_0x366aeb(0x482)](_0x1f02e7,_0x547c93);}}else _0x33b1cf[_0x366aeb(0x940)][_0x366aeb(0x775)][_0x366aeb(0x204)](this,_0x3cbeae,_0x30d7f2,_0x51b643,_0x42cad3),this['markCoreEngineModified']();}return _0x9525f2['length']>0x0&&(_0x9525f2+=_0x29b322),_0x9525f2;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x628)]=function(_0x590c61){const _0x154919=_0x54167d,_0x460787=_0x154919(0x983);_0x590c61[_0x154919(0x233)](undefined)['remove']('')['remove'](null);const _0x24232f=_0x590c61['join']('\x0a\x0a\x0a\x0a\x0a')[_0x154919(0x314)]();VisuMZ[_0x154919(0x940)][_0x154919(0x207)](_0x24232f,_0x460787,!![]),SceneManager[_0x154919(0x4ce)][_0x154919(0x2bc)]=!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x8b2)]=function(_0x314db0){const _0x3ea5c6=_0x54167d;let _0x543384='\x0a'+'─'[_0x3ea5c6(0x779)](0x46)+'\x0a',_0x3e5ce6='\x0a'+'┄'['repeat'](0x46)+'\x0a',_0x2a554f='';for(const _0x5584b2 of _0x314db0){if(_0x3ea5c6(0x68f)!==_0x3ea5c6(0x79c)){if(!_0x5584b2)continue;if(_0x5584b2[_0x3ea5c6(0x28c)]===0x65)_0x2a554f+=_0x543384+'\x0a',_0x2a554f+=_0x3ea5c6(0x741),_0x5584b2[_0x3ea5c6(0x733)][0x4]!==''&&_0x5584b2[_0x3ea5c6(0x733)][0x4]!==undefined&&(_0x3ea5c6(0x44b)==='DjrMS'?_0x4b5a3a[_0x3ea5c6(0x940)][_0x3ea5c6(0x347)]['call'](this,_0x14348b):_0x2a554f+=_0x3ea5c6(0x810)['format'](_0x5584b2['parameters'][0x4]));else{if(_0x5584b2[_0x3ea5c6(0x28c)]===0x191){if(_0x3ea5c6(0x443)!==_0x3ea5c6(0x836))_0x2a554f+=_0x3ea5c6(0x5f8)['format'](_0x5584b2['parameters'][0x0]);else{const _0x3091f1=0x90,_0x58c10f=0x60,_0x1593a8=0x18;this[_0x3ea5c6(0x561)]['bitmap']=this[_0x3ea5c6(0x23a)],this[_0x3ea5c6(0x561)]['anchor']['x']=0.5,this[_0x3ea5c6(0x561)]['anchor']['y']=0x1,this[_0x3ea5c6(0x561)][_0x3ea5c6(0x35d)](_0x12dc60[_0x3ea5c6(0x3ad)](this[_0x3ea5c6(0x376)]/0x2),this[_0x3ea5c6(0x79d)]),this[_0x3ea5c6(0x561)][_0x3ea5c6(0x2bf)](_0x3091f1,_0x58c10f,_0x1593a8,_0x1593a8),this[_0x3ea5c6(0x561)]['alpha']=0xff;}}else{if(_0x5584b2[_0x3ea5c6(0x28c)]===0x192)_0x2a554f+=_0x543384,_0x2a554f+=_0x3ea5c6(0x720)[_0x3ea5c6(0x482)](_0x3e5ce6,_0x5584b2['parameters'][0x0]+0x1,_0x5584b2[_0x3ea5c6(0x733)][0x1]);else{if(_0x5584b2[_0x3ea5c6(0x28c)]===0x193)_0x2a554f+=_0x543384,_0x2a554f+=_0x3ea5c6(0x7bb)[_0x3ea5c6(0x482)](_0x3e5ce6);else{if(_0x5584b2['code']===0x194)'ngofv'===_0x3ea5c6(0x88d)?_0x2762bb=_0x3a5c3b[_0x3ea5c6(0x940)]['Scene_MenuBase_mainAreaHeight'][_0x3ea5c6(0x204)](this):(_0x2a554f+=_0x543384,_0x2a554f+=_0x3ea5c6(0x8f2)[_0x3ea5c6(0x482)](_0x3e5ce6));else{if(_0x5584b2['code']===0x69)_0x2a554f+=_0x543384+'\x0a',_0x2a554f+='〘Scrolling\x20Text〙\x0a';else{if(_0x5584b2['code']===0x6c)_0x2a554f+=_0x543384+'\x0a',_0x2a554f+=_0x3ea5c6(0x835)['format'](_0x5584b2[_0x3ea5c6(0x733)][0x0]);else{if(_0x5584b2['code']===0x198)_0x2a554f+=_0x3ea5c6(0x5f8)['format'](_0x5584b2[_0x3ea5c6(0x733)][0x0]);else{if(_0x5584b2[_0x3ea5c6(0x28c)]===0x75){const _0x5b3887=$dataCommonEvents[_0x5584b2['parameters'][0x0]];if(_0x5b3887&&this['_commonEventLayers']<=0xa){if(_0x3ea5c6(0x5a4)!==_0x3ea5c6(0x9bf)){this['_commonEventLayers']++;let _0x2d2148=VisuMZ[_0x3ea5c6(0x940)][_0x3ea5c6(0x8b2)](_0x5b3887['list']);_0x2d2148[_0x3ea5c6(0x95b)]>0x0&&(_0x2a554f+=_0x543384,_0x2a554f+=_0x3e5ce6,_0x2a554f+=_0x3ea5c6(0x6ee)[_0x3ea5c6(0x482)](_0x5b3887['id'],_0x5b3887[_0x3ea5c6(0x614)]),_0x2a554f+=_0x3e5ce6,_0x2a554f+=_0x2d2148,_0x2a554f+=_0x3e5ce6,_0x2a554f+=_0x3ea5c6(0x501)[_0x3ea5c6(0x482)](_0x5b3887['id'],_0x5b3887[_0x3ea5c6(0x614)]),_0x2a554f+=_0x3e5ce6),this['_commonEventLayers']--;}else return _0x59c890?_0x1de704(_0x876d1f[_0x3ea5c6(0x3ad)](_0x24d293*0x64))+'%':_0x643fa9;}}}}}}}}}}}else{const _0x4b0de5=this[_0x3ea5c6(0x50c)]()[_0x3ea5c6(0x9b7)][_0x49d131][0x63],_0x1c2bf3=this[_0x3ea5c6(0x50c)]()[_0x3ea5c6(0x9b7)][_0x2b7daf][0x62];return _0x4b0de5+(_0x4b0de5-_0x1c2bf3)*(this[_0x3ea5c6(0x472)]-0x63);}}return _0x2a554f['length']>0x0&&(_0x2a554f+=_0x543384),_0x2a554f;},PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],'OpenURL',_0x3f2e81=>{const _0x96944a=_0x54167d;VisuMZ[_0x96944a(0x683)](_0x3f2e81,_0x3f2e81);const _0x1b8c58=_0x3f2e81[_0x96944a(0x334)];VisuMZ[_0x96944a(0x24c)](_0x1b8c58);}),PluginManager[_0x54167d(0x8f5)](pluginData['name'],_0x54167d(0x3a2),_0x51e706=>{const _0x307005=_0x54167d;VisuMZ[_0x307005(0x683)](_0x51e706,_0x51e706);const _0x46ec59=_0x51e706[_0x307005(0x570)]||0x0;$gameParty['gainGold'](_0x46ec59);}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],'MapOnceParallel',_0x1d7a93=>{const _0x36f601=_0x54167d;if(!SceneManager[_0x36f601(0x8c0)]())return;VisuMZ[_0x36f601(0x683)](_0x1d7a93,_0x1d7a93);const _0x4bfa20=_0x1d7a93[_0x36f601(0x2d0)];SceneManager[_0x36f601(0x4ce)]['playOnceParallelInterpreter'](_0x4bfa20);}),PluginManager[_0x54167d(0x8f5)](pluginData['name'],'PictureCoordinatesMode',_0x3ab8ae=>{const _0x28ab3b=_0x54167d;if(!$gameTemp[_0x28ab3b(0x562)]())return;if(!Utils[_0x28ab3b(0x303)]())return;VisuMZ['ConvertParams'](_0x3ab8ae,_0x3ab8ae);const _0x23834d=_0x3ab8ae[_0x28ab3b(0x77e)]||0x1;$gameTemp[_0x28ab3b(0x9eb)]=_0x23834d;}),PluginManager[_0x54167d(0x8f5)](pluginData['name'],'PictureEasingType',_0x4e2a77=>{const _0x88463d=_0x54167d;VisuMZ[_0x88463d(0x683)](_0x4e2a77,_0x4e2a77);const _0x16855f=_0x4e2a77[_0x88463d(0x907)]||0x1,_0x5a59bb=_0x4e2a77[_0x88463d(0x7b7)]||_0x88463d(0x33c),_0x58e01e=$gameScreen[_0x88463d(0x217)](_0x16855f);_0x58e01e&&(_0x88463d(0x2fd)!==_0x88463d(0x2fd)?this[_0x88463d(0x698)]=0x0:_0x58e01e[_0x88463d(0xa18)](_0x5a59bb));}),PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],'PictureEraseAll',_0x4dfecf=>{for(let _0x18d6ed=0x1;_0x18d6ed<=0x64;_0x18d6ed++){$gameScreen['erasePicture'](_0x18d6ed);}}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x22c),_0x468197=>{const _0x5d0b4d=_0x54167d;VisuMZ['ConvertParams'](_0x468197,_0x468197);const _0x2c4316=Math['min'](_0x468197['StartID'],_0x468197[_0x5d0b4d(0x241)]),_0x2c4ecc=Math[_0x5d0b4d(0x350)](_0x468197[_0x5d0b4d(0x3d3)],_0x468197[_0x5d0b4d(0x241)]);for(let _0x3b47ab=_0x2c4316;_0x3b47ab<=_0x2c4ecc;_0x3b47ab++){if('IXqRB'!==_0x5d0b4d(0x3e8))$gameScreen['erasePicture'](_0x3b47ab);else return _0x27648f[_0x5d0b4d(0x45a)](_0x4bf15a,'','');}}),PluginManager['registerCommand'](pluginData['name'],_0x54167d(0x6f5),_0x388b49=>{const _0x52cf01=_0x54167d;VisuMZ['ConvertParams'](_0x388b49,_0x388b49);const _0x476d8c=Math[_0x52cf01(0x3ad)](_0x388b49['PictureID'])[_0x52cf01(0x29b)](0x1,0x64),_0x393dfd=_0x388b49['Settings'],_0x12ca25=_0x393dfd[_0x52cf01(0x84a)][_0x52cf01(0x29b)](0x0,0x1),_0x3bd22d=Math['round'](_0x393dfd[_0x52cf01(0x677)]||0x0),_0x1c002a=Math[_0x52cf01(0x3ad)](_0x393dfd[_0x52cf01(0x7f5)]||0x0),_0x557b3e=Math[_0x52cf01(0x3ad)](_0x393dfd['ScaleX']||0x0),_0x3dfc66=Math[_0x52cf01(0x3ad)](_0x393dfd[_0x52cf01(0x9c6)]||0x0),_0x345357=Math['round'](_0x393dfd[_0x52cf01(0x3e3)])[_0x52cf01(0x29b)](0x0,0xff),_0xe156bd=_0x393dfd[_0x52cf01(0x5f0)],_0x2cf069=_0x52cf01(0x993),_0x201411=_0x388b49[_0x52cf01(0x495)]?_0x52cf01(0x495):_0x52cf01(0x992),_0x4b48c4=_0x2cf069[_0x52cf01(0x482)](_0x388b49[_0x52cf01(0x3bf)],_0x201411);$gameScreen['showPicture'](_0x476d8c,_0x4b48c4,_0x12ca25,_0x3bd22d,_0x1c002a,_0x557b3e,_0x3dfc66,_0x345357,_0xe156bd);}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x5c9),_0x571e5b=>{const _0x3b7dd6=_0x54167d;VisuMZ[_0x3b7dd6(0x683)](_0x571e5b,_0x571e5b);const _0x4aa097=_0x571e5b['Type']||_0x3b7dd6(0x206),_0x58717e=_0x571e5b[_0x3b7dd6(0x699)][_0x3b7dd6(0x29b)](0x1,0x9),_0x560b71=_0x571e5b[_0x3b7dd6(0x717)][_0x3b7dd6(0x29b)](0x1,0x9),_0x45b0fd=_0x571e5b['Duration']||0x1,_0x466182=_0x571e5b[_0x3b7dd6(0x7da)];$gameScreen['setCoreEngineScreenShakeStyle'](_0x4aa097),$gameScreen[_0x3b7dd6(0x669)](_0x58717e,_0x560b71,_0x45b0fd);if(_0x466182){const _0x27fda8=$gameTemp['getLastPluginCommandInterpreter']();if(_0x27fda8)_0x27fda8[_0x3b7dd6(0x660)](_0x45b0fd);}}),PluginManager[_0x54167d(0x8f5)](pluginData['name'],_0x54167d(0xa0f),_0x3f5c76=>{const _0x4217aa=_0x54167d;VisuMZ[_0x4217aa(0x683)](_0x3f5c76,_0x3f5c76);const _0x47d80d=_0x3f5c76[_0x4217aa(0x447)]||0x1;$gameSystem[_0x4217aa(0x358)](_0x47d80d);}),PluginManager['registerCommand'](pluginData['name'],_0x54167d(0x900),_0x6e6b38=>{const _0x4b9a3b=_0x54167d;if($gameParty[_0x4b9a3b(0x540)]())return;VisuMZ[_0x4b9a3b(0x683)](_0x6e6b38,_0x6e6b38);const _0x31914b=_0x6e6b38[_0x4b9a3b(0x447)];if(_0x31914b[_0x4b9a3b(0x59b)](/Front/i)){if(_0x4b9a3b(0x374)!==_0x4b9a3b(0x374))return this[_0x4b9a3b(0x8da)]||this;else $gameSystem[_0x4b9a3b(0x8ac)](![]);}else{if(_0x31914b[_0x4b9a3b(0x59b)](/Side/i)){if('jFlQB'!==_0x4b9a3b(0x4c5))$gameSystem[_0x4b9a3b(0x8ac)](!![]);else return _0x477c08['CoreEngine'][_0x4b9a3b(0x331)][_0x4b9a3b(0x530)][_0x4b9a3b(0x972)];}else $gameSystem[_0x4b9a3b(0x8ac)](!$gameSystem[_0x4b9a3b(0x22e)]());}}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x258),_0x2c00f2=>{const _0x31d1ec=_0x54167d;if($gameParty[_0x31d1ec(0x540)]())return;VisuMZ[_0x31d1ec(0x683)](_0x2c00f2,_0x2c00f2);const _0x21230f=[_0x31d1ec(0x9d2),_0x31d1ec(0x91f),'me','se'];for(const _0x396885 of _0x21230f){if('NHZWb'!==_0x31d1ec(0x752))this[_0x31d1ec(0x432)]&&(this['openness']+=this[_0x31d1ec(0x473)](),this[_0x31d1ec(0x88f)]()&&(this[_0x31d1ec(0x432)]=![]));else{const _0x5edb7d=_0x2c00f2[_0x396885],_0x53b980='%1/'[_0x31d1ec(0x482)](_0x396885);for(const _0x487100 of _0x5edb7d){if(_0x31d1ec(0x47e)!==_0x31d1ec(0x38a))AudioManager['createBuffer'](_0x53b980,_0x487100);else{_0x367728=_0x52453e(_0x3f9231||'')[_0x31d1ec(0x8dd)]();const _0x12d377=_0xd4009c[_0x31d1ec(0x940)][_0x31d1ec(0x331)][_0x31d1ec(0x3fa)];if(_0x1b7252===_0x31d1ec(0x578))return _0x3ac472[_0x31d1ec(0x722)]['params'][0x0];if(_0x2f0ca1===_0x31d1ec(0x784))return _0x304668[_0x31d1ec(0x722)][_0x31d1ec(0x9b7)][0x1];if(_0x24df06==='ATK')return _0x32c789[_0x31d1ec(0x722)][_0x31d1ec(0x9b7)][0x2];if(_0x18fcbe===_0x31d1ec(0x3ce))return _0x509931['terms']['params'][0x3];if(_0x3b16d8===_0x31d1ec(0x203))return _0x3ac1de[_0x31d1ec(0x722)][_0x31d1ec(0x9b7)][0x4];if(_0xb06693===_0x31d1ec(0x7e8))return _0x4779ae['terms'][_0x31d1ec(0x9b7)][0x5];if(_0x1adaa6===_0x31d1ec(0x778))return _0x1b1eac['terms'][_0x31d1ec(0x9b7)][0x6];if(_0x30c5a8==='LUK')return _0x45db40[_0x31d1ec(0x722)][_0x31d1ec(0x9b7)][0x7];if(_0x29b986===_0x31d1ec(0x8a9))return _0x12d377[_0x31d1ec(0xa04)];if(_0x67c800==='EVA')return _0x12d377[_0x31d1ec(0x449)];if(_0x17dfe5==='CRI')return _0x12d377['XParamVocab2'];if(_0x428669==='CEV')return _0x12d377[_0x31d1ec(0x3bc)];if(_0x5b2eae==='MEV')return _0x12d377['XParamVocab4'];if(_0x4cd6d2===_0x31d1ec(0x603))return _0x12d377['XParamVocab5'];if(_0x5759c4===_0x31d1ec(0x81e))return _0x12d377['XParamVocab6'];if(_0xe0eb1c==='HRG')return _0x12d377[_0x31d1ec(0x535)];if(_0x3cfe2d===_0x31d1ec(0x9de))return _0x12d377[_0x31d1ec(0x77c)];if(_0x17c08d==='TRG')return _0x12d377[_0x31d1ec(0x461)];if(_0x8d0c97===_0x31d1ec(0x7b3))return _0x12d377[_0x31d1ec(0x7cb)];if(_0x41d368===_0x31d1ec(0xa0d))return _0x12d377[_0x31d1ec(0x417)];if(_0x1afb87==='REC')return _0x12d377[_0x31d1ec(0x6f3)];if(_0x2042c1===_0x31d1ec(0x66d))return _0x12d377['SParamVocab3'];if(_0x2e1676===_0x31d1ec(0x43f))return _0x12d377[_0x31d1ec(0x736)];if(_0x570500===_0x31d1ec(0x5c3))return _0x12d377[_0x31d1ec(0x700)];if(_0x5eff92===_0x31d1ec(0x70a))return _0x12d377[_0x31d1ec(0x396)];if(_0x30b7be==='MDR')return _0x12d377['SParamVocab7'];if(_0x3067b0===_0x31d1ec(0x4b5))return _0x12d377[_0x31d1ec(0x746)];if(_0x57165d==='EXR')return _0x12d377[_0x31d1ec(0x400)];if(_0x53e209[_0x31d1ec(0x940)][_0x31d1ec(0x7d1)][_0x1b2bbb])return _0x9516c3[_0x31d1ec(0x940)][_0x31d1ec(0x7d1)][_0x3fa1d8];return'';}}}}}),PluginManager[_0x54167d(0x8f5)](pluginData['name'],_0x54167d(0x971),_0x2a5b92=>{const _0xe21bbd=_0x54167d;if($gameParty[_0xe21bbd(0x540)]())return;VisuMZ[_0xe21bbd(0x683)](_0x2a5b92,_0x2a5b92);const _0x319751=[_0xe21bbd(0x265),_0xe21bbd(0x2e7),_0xe21bbd(0x514),_0xe21bbd(0xa16),_0xe21bbd(0x515),'faces',_0xe21bbd(0x37c),'pictures',_0xe21bbd(0x564),'sv_enemies',_0xe21bbd(0x32b),_0xe21bbd(0x72a),_0xe21bbd(0x3ac),'titles2'];for(const _0x2f2339 of _0x319751){const _0x34ebc6=_0x2a5b92[_0x2f2339],_0x4886cd='img/%1/'[_0xe21bbd(0x482)](_0x2f2339);for(const _0x542003 of _0x34ebc6){ImageManager[_0xe21bbd(0x4e3)](_0x4886cd,_0x542003);}}}),PluginManager['registerCommand'](pluginData['name'],_0x54167d(0x789),_0x14fc05=>{const _0x186eb4=_0x54167d;if($gameParty['inBattle']())return;VisuMZ['ConvertParams'](_0x14fc05,_0x14fc05);const _0x34b7fe=_0x14fc05['IDs'],_0x408cd4=(_0x14fc05[_0x186eb4(0x526)]||0x0)/0x64;for(const _0x524aba of _0x34b7fe){if(_0x186eb4(0x919)!=='yeDkC')_0x564b1e[_0x186eb4(0x5fe)](_0x5f4674);else{const _0x4eb511=Math['random']()<=_0x408cd4;$gameSwitches[_0x186eb4(0x667)](_0x524aba,_0x4eb511);}}}),PluginManager['registerCommand'](pluginData[_0x54167d(0x614)],_0x54167d(0x91b),_0x376b1c=>{const _0x41da98=_0x54167d;if($gameParty[_0x41da98(0x540)]())return;VisuMZ[_0x41da98(0x683)](_0x376b1c,_0x376b1c);const _0x54d29a=Math['min'](_0x376b1c[_0x41da98(0x3d3)],_0x376b1c[_0x41da98(0x241)]),_0xaedcf4=Math[_0x41da98(0x350)](_0x376b1c[_0x41da98(0x3d3)],_0x376b1c[_0x41da98(0x241)]),_0x43fca2=(_0x376b1c[_0x41da98(0x526)]||0x0)/0x64;for(let _0x43bff7=_0x54d29a;_0x43bff7<=_0xaedcf4;_0x43bff7++){const _0x3bda30=Math[_0x41da98(0x206)]()<=_0x43fca2;$gameSwitches['setValue'](_0x43bff7,_0x3bda30);}}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x25c),_0x1e150b=>{const _0x43bed9=_0x54167d;if($gameParty[_0x43bed9(0x540)]())return;VisuMZ[_0x43bed9(0x683)](_0x1e150b,_0x1e150b);const _0x19e99c=_0x1e150b[_0x43bed9(0x528)];for(const _0x408bd2 of _0x19e99c){if('jllmJ'===_0x43bed9(0x76f))this[_0x43bed9(0x532)]=[];else{const _0x26f9d7=$gameSwitches['value'](_0x408bd2);$gameSwitches[_0x43bed9(0x667)](_0x408bd2,!_0x26f9d7);}}}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],'SwitchToggleRange',_0x24f724=>{const _0x3b8ecf=_0x54167d;if($gameParty['inBattle']())return;VisuMZ[_0x3b8ecf(0x683)](_0x24f724,_0x24f724);const _0x2f44d9=Math[_0x3b8ecf(0x3e0)](_0x24f724[_0x3b8ecf(0x3d3)],_0x24f724[_0x3b8ecf(0x241)]),_0x2b7066=Math[_0x3b8ecf(0x350)](_0x24f724['StartID'],_0x24f724[_0x3b8ecf(0x241)]);for(let _0x2b6b96=_0x2f44d9;_0x2b6b96<=_0x2b7066;_0x2b6b96++){const _0x496175=$gameSwitches[_0x3b8ecf(0x570)](_0x2b6b96);$gameSwitches[_0x3b8ecf(0x667)](_0x2b6b96,!_0x496175);}}),PluginManager[_0x54167d(0x8f5)](pluginData[_0x54167d(0x614)],_0x54167d(0x962),_0x29b53e=>{const _0x3af6ba=_0x54167d;if($gameParty['inBattle']())return;VisuMZ['ConvertParams'](_0x29b53e,_0x29b53e);const _0x271623=_0x29b53e[_0x3af6ba(0x447)][_0x3af6ba(0x8dd)]()[_0x3af6ba(0x314)](),_0x87cde6=VisuMZ[_0x3af6ba(0x940)][_0x3af6ba(0x7bc)](_0x271623);$gameSystem[_0x3af6ba(0x59d)](_0x87cde6);}),VisuMZ[_0x54167d(0x940)][_0x54167d(0x7bc)]=function(_0x9a80aa){const _0x26afeb=_0x54167d;_0x9a80aa=_0x9a80aa||_0x26afeb(0x92b),_0x9a80aa=String(_0x9a80aa)[_0x26afeb(0x8dd)]()[_0x26afeb(0x314)]();switch(_0x9a80aa){case'DTB':return 0x0;case'TPB\x20ACTIVE':Imported[_0x26afeb(0x6ec)]&&(ConfigManager[_0x26afeb(0x9ec)]=!![]);return 0x1;case _0x26afeb(0x5ed):Imported[_0x26afeb(0x6ec)]&&(ConfigManager[_0x26afeb(0x9ec)]=![]);return 0x2;case _0x26afeb(0x9f3):if(Imported[_0x26afeb(0x285)])return _0x26afeb(0x9f3);break;case _0x26afeb(0x470):if(Imported[_0x26afeb(0x448)]){if(_0x26afeb(0x6eb)===_0x26afeb(0x6eb))return'STB';else this[_0x26afeb(0x710)]();}break;case _0x26afeb(0x9aa):if(Imported[_0x26afeb(0x721)])return'BTB';break;case _0x26afeb(0x39a):if(Imported[_0x26afeb(0x4e7)])return _0x26afeb(0x7f1)!==_0x26afeb(0x2ce)?_0x26afeb(0x39a):_0x32e94c['CoreEngine'][_0x26afeb(0x7fb)][_0x26afeb(0x204)](this);break;case _0x26afeb(0x332):if(Imported['VisuMZ_2_BattleSystemOTB']){if(_0x26afeb(0x81b)===_0x26afeb(0x81b))return _0x26afeb(0x332);else this['_backgroundFilter']=new _0x20a7f3[(_0x26afeb(0x6f6))][(_0x26afeb(0x98b))](_0x2b3647=!![]),this['_backgroundSprite']=new _0x4d3b92(),this['_backgroundSprite']['bitmap']=_0x15e024[_0x26afeb(0x67d)](),this[_0x26afeb(0x420)][_0x26afeb(0x6f6)]=[this[_0x26afeb(0x214)]],this[_0x26afeb(0x8fe)][_0x26afeb(0x45f)](this[_0x26afeb(0x420)]);}break;case _0x26afeb(0x965):if(Imported[_0x26afeb(0x80b)])return _0x26afeb(0x965);break;case _0x26afeb(0x92c):if(Imported[_0x26afeb(0x3fd)])return _0x26afeb(0x92c);break;}return $dataSystem[_0x26afeb(0x9e8)];},PluginManager['registerCommand'](pluginData['name'],_0x54167d(0x84e),_0x4399a5=>{const _0x347b3c=_0x54167d;VisuMZ[_0x347b3c(0x683)](_0x4399a5,_0x4399a5);const _0x164fc7=_0x4399a5[_0x347b3c(0x447)]||0x1;$gameSystem['setWindowPadding'](_0x164fc7);}),VisuMZ[_0x54167d(0x940)]['Scene_Boot_onDatabaseLoaded']=Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x34e)],Scene_Boot['prototype'][_0x54167d(0x34e)]=function(){const _0x586b67=_0x54167d;VisuMZ['CoreEngine'][_0x586b67(0x305)][_0x586b67(0x204)](this),this[_0x586b67(0x9e7)](),this[_0x586b67(0x3ba)](),this[_0x586b67(0x44d)](),this[_0x586b67(0x95a)](),this[_0x586b67(0x946)](),VisuMZ['ParseAllNotetags']();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x364)]={},Scene_Boot[_0x54167d(0x4ec)]['process_VisuMZ_CoreEngine_RegExp']=function(){const _0x24509d=_0x54167d,_0x2c63d6=[_0x24509d(0x578),_0x24509d(0x784),_0x24509d(0x6ea),'DEF','MAT','MDF',_0x24509d(0x778),_0x24509d(0x7cf)],_0x207906=[_0x24509d(0x8a9),_0x24509d(0x2d9),'CRI',_0x24509d(0x891),_0x24509d(0x8b1),_0x24509d(0x603),_0x24509d(0x81e),_0x24509d(0x293),_0x24509d(0x9de),_0x24509d(0x627)],_0x44551e=[_0x24509d(0x7b3),_0x24509d(0xa0d),_0x24509d(0x3ab),_0x24509d(0x66d),_0x24509d(0x43f),_0x24509d(0x5c3),_0x24509d(0x70a),_0x24509d(0x90d),_0x24509d(0x4b5),_0x24509d(0x282)],_0x115138=[_0x2c63d6,_0x207906,_0x44551e],_0x5b4349=[_0x24509d(0x8dc),'Plus1',_0x24509d(0x662),_0x24509d(0x82c),_0x24509d(0x9cc),_0x24509d(0x538),'Rate2',_0x24509d(0x68a),_0x24509d(0x42e),_0x24509d(0x963)];for(const _0x47f29c of _0x115138){let _0x128d12='';if(_0x47f29c===_0x2c63d6)_0x128d12=_0x24509d(0x594);if(_0x47f29c===_0x207906)_0x128d12=_0x24509d(0x904);if(_0x47f29c===_0x44551e)_0x128d12=_0x24509d(0x652);for(const _0x576781 of _0x5b4349){let _0x4359b0=_0x24509d(0x25f)[_0x24509d(0x482)](_0x128d12,_0x576781);VisuMZ['CoreEngine'][_0x24509d(0x364)][_0x4359b0]=[],VisuMZ['CoreEngine']['RegExp'][_0x4359b0+'JS']=[];let _0x351bf1=_0x24509d(0x37a);if([_0x24509d(0x8dc),'Flat'][_0x24509d(0x9ef)](_0x576781))_0x351bf1+=_0x24509d(0x659);else{if(['Plus1',_0x24509d(0x42e)][_0x24509d(0x9ef)](_0x576781))_0x351bf1+=_0x24509d(0x366);else{if([_0x24509d(0x662),'Flat2'][_0x24509d(0x9ef)](_0x576781))_0x351bf1+=_0x24509d(0x936);else{if(_0x576781===_0x24509d(0x82c)){if(_0x24509d(0xa00)!=='TyyOD')_0x351bf1+='(\x5cd+)>';else{const _0x4c210c=this['isMVAnimation'](_0x502f89),_0x5df5b8=new(_0x4c210c?_0x1d2890:_0x1e0624)();_0x5df5b8['targetObjects']=_0x2d66ec,_0x5df5b8['setup'](_0x32ed63,_0x4ac1ed,_0x1da65f,_0x2ab424),_0x5df5b8[_0x24509d(0x20f)](_0x1335b4),this[_0x24509d(0x84c)][_0x24509d(0x45f)](_0x5df5b8),this[_0x24509d(0x4dc)][_0x24509d(0x398)](_0x5df5b8);}}else{if(_0x576781===_0x24509d(0x538))_0x351bf1+=_0x24509d(0x61a);else{if(_0x576781===_0x24509d(0x727)){if(_0x24509d(0x2f0)!=='wqdiq'){const _0x4a6183=new _0xa1414b['BaseTexture']();_0x4a6183[_0x24509d(0x328)](0x800,0x800),_0x33c622[_0x24509d(0x940)]['Settings']['QoL'][_0x24509d(0x777)]&&(_0x4a6183['scaleMode']=_0x109a11[_0x24509d(0x767)][_0x24509d(0x72f)]),this[_0x24509d(0x54e)]['push'](_0x4a6183);}else _0x351bf1+=_0x24509d(0x89d);}}}}}}for(const _0x160b17 of _0x47f29c){let _0x4cd3dc=_0x576781['replace'](/[\d+]/g,'')[_0x24509d(0x8dd)]();const _0x41a869=_0x351bf1['format'](_0x160b17,_0x4cd3dc);VisuMZ[_0x24509d(0x940)][_0x24509d(0x364)][_0x4359b0]['push'](new RegExp(_0x41a869,'i'));const _0x501b74=_0x24509d(0x523)[_0x24509d(0x482)](_0x160b17,_0x4cd3dc);VisuMZ[_0x24509d(0x940)][_0x24509d(0x364)][_0x4359b0+'JS']['push'](new RegExp(_0x501b74,'i'));}}}},Scene_Boot['prototype']['process_VisuMZ_CoreEngine_Notetags']=function(){if(VisuMZ['ParseAllNotetags'])return;},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x44d)]=function(){const _0x4151d5=_0x54167d,_0xae914d=VisuMZ['CoreEngine']['Settings'];_0xae914d[_0x4151d5(0x2e9)][_0x4151d5(0x21a)]&&VisuMZ['ShowDevTools'](!![]);_0xae914d[_0x4151d5(0x2e9)][_0x4151d5(0x62f)]&&(Input[_0x4151d5(0x21f)][0x23]='end',Input[_0x4151d5(0x21f)][0x24]=_0x4151d5(0x588));if(_0xae914d['ButtonAssist']){const _0x2c0411=_0xae914d[_0x4151d5(0x464)];_0x2c0411[_0x4151d5(0x504)]=_0x2c0411[_0x4151d5(0x504)]||'\x5c}❪SHIFT❫\x5c{',_0x2c0411[_0x4151d5(0x8fb)]=_0x2c0411[_0x4151d5(0x8fb)]||_0x4151d5(0x657);}if(_0xae914d[_0x4151d5(0x8a6)][_0x4151d5(0x8e6)]){if(_0x4151d5(0x6f9)!==_0x4151d5(0x6f9))return _0x1aaea0[_0x4151d5(0x556)][_0x4151d5(0x7fe)][_0x4151d5(0x204)](this);else Input[_0x4151d5(0x21f)][0x57]='up',Input['keyMapper'][0x41]='left',Input['keyMapper'][0x53]=_0x4151d5(0x83a),Input[_0x4151d5(0x21f)][0x44]=_0x4151d5(0x231),Input[_0x4151d5(0x21f)][0x45]=_0x4151d5(0x316);}_0xae914d[_0x4151d5(0x8a6)]['DashToggleR']&&(Input['keyMapper'][0x52]=_0x4151d5(0x5cd)),_0xae914d['Param'][_0x4151d5(0x70d)]=_0xae914d['Param'][_0x4151d5(0x70d)]['map'](_0x367797=>_0x367797['toUpperCase']()[_0x4151d5(0x314)]()),_0xae914d[_0x4151d5(0x3fa)][_0x4151d5(0x886)]=_0xae914d[_0x4151d5(0x3fa)]['ExtDisplayedParams'][_0x4151d5(0x90c)](_0x306bc8=>_0x306bc8[_0x4151d5(0x8dd)]()[_0x4151d5(0x314)]());},Scene_Boot['prototype'][_0x54167d(0x95a)]=function(){const _0x437a54=_0x54167d;this[_0x437a54(0x744)]();},Scene_Boot[_0x54167d(0x4ec)]['process_VisuMZ_CoreEngine_jsQuickFunctions']=function(){const _0x214f58=_0x54167d,_0x2a1dfb=VisuMZ[_0x214f58(0x940)][_0x214f58(0x331)][_0x214f58(0x873)];for(const _0xee5a84 of _0x2a1dfb){const _0x14dfb6=_0xee5a84[_0x214f58(0x806)][_0x214f58(0x3ed)](/[ ]/g,''),_0x1062a5=_0xee5a84[_0x214f58(0x563)];VisuMZ['CoreEngine'][_0x214f58(0x895)](_0x14dfb6,_0x1062a5);}},VisuMZ[_0x54167d(0x940)]['createJsQuickFunction']=function(_0x132b99,_0x2bd9cf){const _0x597a73=_0x54167d;if(!!window[_0x132b99]){if($gameTemp[_0x597a73(0x562)]())console[_0x597a73(0x262)](_0x597a73(0x6b4)[_0x597a73(0x482)](_0x132b99));}const _0x14e15c=_0x597a73(0x704)[_0x597a73(0x482)](_0x132b99,_0x2bd9cf);window[_0x132b99]=new Function(_0x14e15c);},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x946)]=function(){const _0x146725=_0x54167d,_0x148508=VisuMZ[_0x146725(0x940)]['Settings']['CustomParam'];if(!_0x148508)return;for(const _0x2f1ae9 of _0x148508){if(!_0x2f1ae9)continue;VisuMZ[_0x146725(0x940)]['createCustomParameter'](_0x2f1ae9);}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x7d1)]={},VisuMZ[_0x54167d(0x940)]['CustomParamIcons']={},VisuMZ[_0x54167d(0x940)][_0x54167d(0x6dc)]={},VisuMZ[_0x54167d(0x940)][_0x54167d(0x450)]={},VisuMZ[_0x54167d(0x940)]['createCustomParameter']=function(_0x591c4c){const _0x31855d=_0x54167d,_0x178679=_0x591c4c[_0x31855d(0x3e5)],_0x17b192=_0x591c4c[_0x31855d(0x6fc)],_0x1eb3da=_0x591c4c[_0x31855d(0x685)],_0x3e25da=_0x591c4c[_0x31855d(0x89a)],_0x1a0de6=new Function(_0x591c4c[_0x31855d(0x508)]);VisuMZ[_0x31855d(0x940)][_0x31855d(0x7d1)][_0x178679[_0x31855d(0x8dd)]()['trim']()]=_0x17b192,VisuMZ[_0x31855d(0x940)][_0x31855d(0x377)][_0x178679[_0x31855d(0x8dd)]()[_0x31855d(0x314)]()]=_0x1eb3da,VisuMZ['CoreEngine']['CustomParamType'][_0x178679[_0x31855d(0x8dd)]()[_0x31855d(0x314)]()]=_0x3e25da,VisuMZ[_0x31855d(0x940)][_0x31855d(0x450)][_0x178679[_0x31855d(0x8dd)]()[_0x31855d(0x314)]()]=_0x178679,Object[_0x31855d(0x201)](Game_BattlerBase[_0x31855d(0x4ec)],_0x178679,{'get'(){const _0x1f8ce6=_0x31855d,_0x1a0ba6=_0x1a0de6['call'](this);return _0x3e25da==='integer'?Math[_0x1f8ce6(0x3ad)](_0x1a0ba6):_0x1a0ba6;}});},VisuMZ['ParseAllNotetags']=function(){const _0x4ac35d=_0x54167d;for(const _0x26f832 of $dataActors){if(_0x4ac35d(0x576)==='kVFjY'){if(_0x26f832)VisuMZ[_0x4ac35d(0x276)](_0x26f832);}else this['makeDocumentTitle']();}for(const _0x11c674 of $dataClasses){if(_0x11c674)VisuMZ['ParseClassNotetags'](_0x11c674);}for(const _0x67a16a of $dataSkills){if(_0x4ac35d(0x294)!=='cibUW'){const _0x299d64=_0x52290f[_0x536db8],_0x876d28='%1/'[_0x4ac35d(0x482)](_0x5871e4);for(const _0x2cad94 of _0x299d64){_0x460d28[_0x4ac35d(0x9bb)](_0x876d28,_0x2cad94);}}else{if(_0x67a16a)VisuMZ[_0x4ac35d(0x5b9)](_0x67a16a);}}for(const _0x5e7be6 of $dataItems){if(_0x4ac35d(0x381)!==_0x4ac35d(0x381)){if(_0x54f2c1[_0x4ac35d(0x562)]()){const _0x18a3db=_0x56a624[_0x4ac35d(0x940)][_0x4ac35d(0x331)][_0x4ac35d(0x2e9)][_0x4ac35d(0x54a)];if(_0x18a3db>0x0)_0x3817c8[_0x4ac35d(0x42d)](_0x18a3db);}}else{if(_0x5e7be6)VisuMZ[_0x4ac35d(0x321)](_0x5e7be6);}}for(const _0x4eaa45 of $dataWeapons){if(_0x4ac35d(0x62b)!=='MdAwc'){if(_0x4eaa45)VisuMZ[_0x4ac35d(0x67b)](_0x4eaa45);}else return-0.5*(_0x4e1985[_0x4ac35d(0x9ba)](0x2,0xa*_0x34323c)*_0x4ea4c4[_0x4ac35d(0x98c)]((_0x48df82-_0xd3b4b)*(0x2*_0x1180ea['PI'])/_0x79b950));}for(const _0x2f7a82 of $dataArmors){if(_0x4ac35d(0x770)!==_0x4ac35d(0x770))this['_helpWindow'][_0x4ac35d(0x6d0)](_0x246984[_0x4ac35d(0x556)][_0x4ac35d(0x536)]);else{if(_0x2f7a82)VisuMZ[_0x4ac35d(0x7b5)](_0x2f7a82);}}for(const _0x5ec43d of $dataEnemies){if(_0x5ec43d)VisuMZ[_0x4ac35d(0x7ca)](_0x5ec43d);}for(const _0x7fbea7 of $dataStates){if(_0x7fbea7)VisuMZ['ParseStateNotetags'](_0x7fbea7);}for(const _0x4a3188 of $dataTilesets){if('rzcdk'!==_0x4ac35d(0x941)){if(_0x4a3188)VisuMZ[_0x4ac35d(0x653)](_0x4a3188);}else this['_x']=this['_targetX'],this['_y']=this[_0x4ac35d(0x537)],this[_0x4ac35d(0x8c2)]=this[_0x4ac35d(0x816)],this['_scaleY']=this[_0x4ac35d(0x242)],this[_0x4ac35d(0x2d4)]=this[_0x4ac35d(0x360)],this[_0x4ac35d(0x6d2)]&&(this[_0x4ac35d(0x6d2)]['x']=this[_0x4ac35d(0x53e)]['x'],this[_0x4ac35d(0x6d2)]['y']=this[_0x4ac35d(0x53e)]['y']);}},VisuMZ['ParseActorNotetags']=function(_0x105c8c){},VisuMZ['ParseClassNotetags']=function(_0x357bc6){},VisuMZ['ParseSkillNotetags']=function(_0x4d65e8){},VisuMZ[_0x54167d(0x321)]=function(_0x25f66e){},VisuMZ[_0x54167d(0x67b)]=function(_0x32d574){},VisuMZ[_0x54167d(0x7b5)]=function(_0x167092){},VisuMZ[_0x54167d(0x7ca)]=function(_0x39ee7f){},VisuMZ[_0x54167d(0x820)]=function(_0x17fed5){},VisuMZ[_0x54167d(0x653)]=function(_0x1ce90e){},VisuMZ[_0x54167d(0x940)][_0x54167d(0x276)]=VisuMZ[_0x54167d(0x276)],VisuMZ[_0x54167d(0x276)]=function(_0x3a87ba){const _0x45c3eb=_0x54167d;VisuMZ['CoreEngine'][_0x45c3eb(0x276)][_0x45c3eb(0x204)](this,_0x3a87ba);const _0x4453b6=_0x3a87ba[_0x45c3eb(0x31a)];if(_0x4453b6[_0x45c3eb(0x59b)](/<MAX LEVEL:[ ](\d+)>/i)){if('qHtAX'!==_0x45c3eb(0x253)){this['contents']['clear']();for(let _0x5e2989=0x1;_0x5e2989<=0x5;_0x5e2989++){this[_0x45c3eb(0x558)](_0x5e2989);}}else{_0x3a87ba[_0x45c3eb(0x902)]=Number(RegExp['$1']);if(_0x3a87ba['maxLevel']===0x0)_0x3a87ba[_0x45c3eb(0x902)]=Number[_0x45c3eb(0x4a8)];}}_0x4453b6[_0x45c3eb(0x59b)](/<INITIAL LEVEL:[ ](\d+)>/i)&&(_0x3a87ba[_0x45c3eb(0x351)]=Math[_0x45c3eb(0x3e0)](Number(RegExp['$1']),_0x3a87ba['maxLevel']));},VisuMZ['CoreEngine']['ParseClassNotetags']=VisuMZ[_0x54167d(0x61c)],VisuMZ['ParseClassNotetags']=function(_0x223a7f){const _0x54c9bd=_0x54167d;VisuMZ['CoreEngine'][_0x54c9bd(0x61c)]['call'](this,_0x223a7f);if(_0x223a7f[_0x54c9bd(0x908)])for(const _0x1b0374 of _0x223a7f['learnings']){'KGEUq'===_0x54c9bd(0x4bf)?_0x1b0374['note'][_0x54c9bd(0x59b)](/<LEARN AT LEVEL:[ ](\d+)>/i)&&(_0x1b0374[_0x54c9bd(0x472)]=Math[_0x54c9bd(0x350)](Number(RegExp['$1']),0x1)):this[_0x54c9bd(0x69c)](_0x2dbc17);}},VisuMZ['CoreEngine'][_0x54167d(0x7ca)]=VisuMZ[_0x54167d(0x7ca)],VisuMZ['ParseEnemyNotetags']=function(_0x5362b6){const _0x444e0f=_0x54167d;VisuMZ['CoreEngine'][_0x444e0f(0x7ca)]['call'](this,_0x5362b6),_0x5362b6[_0x444e0f(0x472)]=0x1;const _0x518ab7=_0x5362b6[_0x444e0f(0x31a)];if(_0x518ab7[_0x444e0f(0x59b)](/<LEVEL:[ ](\d+)>/i))_0x5362b6['level']=Number(RegExp['$1']);if(_0x518ab7['match'](/<MAXHP:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x0]=Number(RegExp['$1']);if(_0x518ab7[_0x444e0f(0x59b)](/<MAXMP:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x1]=Number(RegExp['$1']);if(_0x518ab7[_0x444e0f(0x59b)](/<ATK:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x2]=Number(RegExp['$1']);if(_0x518ab7[_0x444e0f(0x59b)](/<DEF:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x3]=Number(RegExp['$1']);if(_0x518ab7['match'](/<MAT:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x4]=Number(RegExp['$1']);if(_0x518ab7['match'](/<MDF:[ ](\d+)>/i))_0x5362b6['params'][0x5]=Number(RegExp['$1']);if(_0x518ab7['match'](/<AGI:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x6]=Number(RegExp['$1']);if(_0x518ab7[_0x444e0f(0x59b)](/<LUK:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9b7)][0x7]=Number(RegExp['$1']);if(_0x518ab7['match'](/<EXP:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x9ea)]=Number(RegExp['$1']);if(_0x518ab7[_0x444e0f(0x59b)](/<GOLD:[ ](\d+)>/i))_0x5362b6[_0x444e0f(0x8b4)]=Number(RegExp['$1']);},VisuMZ['CoreEngine'][_0x54167d(0x8c7)]=Graphics[_0x54167d(0x44e)],Graphics['_defaultStretchMode']=function(){const _0x5838db=_0x54167d;switch(VisuMZ[_0x5838db(0x940)]['Settings'][_0x5838db(0x2e9)][_0x5838db(0x709)]){case'stretch':return!![];case _0x5838db(0x8a5):return![];default:return VisuMZ[_0x5838db(0x940)]['Graphics_defaultStretchMode']['call'](this);}},VisuMZ['CoreEngine'][_0x54167d(0x517)]=Graphics['printError'],Graphics[_0x54167d(0x93c)]=function(_0x3032eb,_0x3c3feb,_0x5c76b8=null){const _0x7394c6=_0x54167d;VisuMZ[_0x7394c6(0x940)][_0x7394c6(0x517)][_0x7394c6(0x204)](this,_0x3032eb,_0x3c3feb,_0x5c76b8),VisuMZ[_0x7394c6(0x4c7)](![]);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x280)]=Graphics[_0x54167d(0x763)],Graphics['_centerElement']=function(_0x57e9b7){const _0x1e44b3=_0x54167d;VisuMZ['CoreEngine'][_0x1e44b3(0x280)]['call'](this,_0x57e9b7),this[_0x1e44b3(0x66a)](_0x57e9b7);},Graphics[_0x54167d(0x66a)]=function(_0x1da430){const _0x53cd7d=_0x54167d;if(VisuMZ[_0x53cd7d(0x940)]['Settings'][_0x53cd7d(0x2e9)][_0x53cd7d(0x9c5)]){if(_0x53cd7d(0x394)===_0x53cd7d(0x9ab)){const _0x3ebd6b=_0x413e63[_0x53cd7d(0x940)][_0x53cd7d(0x331)][_0x53cd7d(0x5c9)];this[_0x53cd7d(0x21d)]=_0x3ebd6b?.[_0x53cd7d(0x4fe)]||'random';}else _0x1da430[_0x53cd7d(0x460)]['font-smooth']=_0x53cd7d(0x3a4);}VisuMZ[_0x53cd7d(0x940)][_0x53cd7d(0x331)][_0x53cd7d(0x2e9)][_0x53cd7d(0x777)]&&(_0x1da430[_0x53cd7d(0x460)][_0x53cd7d(0x36a)]='pixelated');const _0x29895a=Math[_0x53cd7d(0x350)](0x0,Math[_0x53cd7d(0x42f)](_0x1da430[_0x53cd7d(0x281)]*this[_0x53cd7d(0x3f0)])),_0x4a9992=Math['max'](0x0,Math[_0x53cd7d(0x42f)](_0x1da430[_0x53cd7d(0x3e1)]*this[_0x53cd7d(0x3f0)]));_0x1da430[_0x53cd7d(0x460)][_0x53cd7d(0x281)]=_0x29895a+'px',_0x1da430[_0x53cd7d(0x460)][_0x53cd7d(0x3e1)]=_0x4a9992+'px';},VisuMZ['CoreEngine'][_0x54167d(0x76d)]=Bitmap[_0x54167d(0x4ec)]['initialize'],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x8d7)]=function(_0xc17414,_0x51dccf){const _0x472386=_0x54167d;VisuMZ[_0x472386(0x940)][_0x472386(0x76d)][_0x472386(0x204)](this,_0xc17414,_0x51dccf),this[_0x472386(0x8e8)]=!(VisuMZ[_0x472386(0x940)][_0x472386(0x331)][_0x472386(0x2e9)]['PixelateImageRendering']??!![]);},Bitmap[_0x54167d(0x4ec)]['markCoreEngineModified']=function(){this['_customModified']=!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x4b0)]=Sprite[_0x54167d(0x4ec)][_0x54167d(0x954)],Sprite[_0x54167d(0x4ec)]['destroy']=function(){const _0x156752=_0x54167d;VisuMZ[_0x156752(0x940)][_0x156752(0x4b0)][_0x156752(0x204)](this),this[_0x156752(0x8d0)]();},Sprite[_0x54167d(0x4ec)]['destroyCoreEngineMarkedBitmaps']=function(){const _0x5b11fc=_0x54167d;if(!this[_0x5b11fc(0x228)])return;if(!this[_0x5b11fc(0x228)][_0x5b11fc(0x380)])return;this[_0x5b11fc(0x228)][_0x5b11fc(0x3d2)]&&!this[_0x5b11fc(0x554)][_0x5b11fc(0x3d2)]['destroyed']&&(_0x5b11fc(0x27d)==='PlhGt'?_0x154d4c[_0x5b11fc(0x940)]['Game_Interpreter_command355'][_0x5b11fc(0x204)](this):this[_0x5b11fc(0x228)][_0x5b11fc(0x954)]());},VisuMZ['CoreEngine'][_0x54167d(0x833)]=Bitmap[_0x54167d(0x4ec)]['resize'],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x776)]=function(_0x304469,_0x206b55){const _0x6b96a3=_0x54167d;VisuMZ['CoreEngine'][_0x6b96a3(0x833)][_0x6b96a3(0x204)](this,_0x304469,_0x206b55),this[_0x6b96a3(0x7f7)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5ac)]=Bitmap['prototype']['blt'],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x46f)]=function(_0x1e7289,_0x2f35ea,_0x5f0044,_0x3fff6e,_0x17e1cd,_0x2ca952,_0x50ae3f,_0x385fde,_0x639a7f){const _0x30e8bf=_0x54167d;_0x2f35ea=Math[_0x30e8bf(0x3ad)](_0x2f35ea),_0x5f0044=Math['round'](_0x5f0044),_0x3fff6e=Math[_0x30e8bf(0x3ad)](_0x3fff6e),_0x17e1cd=Math['round'](_0x17e1cd),_0x2ca952=Math[_0x30e8bf(0x3ad)](_0x2ca952),_0x50ae3f=Math[_0x30e8bf(0x3ad)](_0x50ae3f),VisuMZ[_0x30e8bf(0x940)][_0x30e8bf(0x5ac)][_0x30e8bf(0x204)](this,_0x1e7289,_0x2f35ea,_0x5f0044,_0x3fff6e,_0x17e1cd,_0x2ca952,_0x50ae3f,_0x385fde,_0x639a7f),this[_0x30e8bf(0x7f7)]();},VisuMZ['CoreEngine'][_0x54167d(0x775)]=Bitmap['prototype'][_0x54167d(0x915)],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x915)]=function(_0x3e105b,_0x32d8ac,_0x388bbc,_0x44e605){const _0xfc6d41=_0x54167d;VisuMZ[_0xfc6d41(0x940)][_0xfc6d41(0x775)][_0xfc6d41(0x204)](this,_0x3e105b,_0x32d8ac,_0x388bbc,_0x44e605),this[_0xfc6d41(0x7f7)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x85f)]=Bitmap[_0x54167d(0x4ec)][_0x54167d(0x434)],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x434)]=function(_0x3de557,_0x21f6a5,_0x37f1a5,_0x541578,_0x52eeda){const _0x4f90f3=_0x54167d;VisuMZ[_0x4f90f3(0x940)][_0x4f90f3(0x85f)]['call'](this,_0x3de557,_0x21f6a5,_0x37f1a5,_0x541578,_0x52eeda),this['markCoreEngineModified']();},VisuMZ['CoreEngine'][_0x54167d(0x5e0)]=Bitmap[_0x54167d(0x4ec)][_0x54167d(0x3cf)],Bitmap['prototype']['strokeRect']=function(_0x1ed27f,_0x5ce87,_0x158379,_0x21e804,_0x375fc4){const _0x55bd24=_0x54167d;VisuMZ[_0x55bd24(0x940)][_0x55bd24(0x5e0)][_0x55bd24(0x204)](this,_0x1ed27f,_0x5ce87,_0x158379,_0x21e804,_0x375fc4),this[_0x55bd24(0x7f7)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x3da)]=Bitmap[_0x54167d(0x4ec)]['gradientFillRect'],Bitmap[_0x54167d(0x4ec)]['gradientFillRect']=function(_0x4ab1c4,_0x52b079,_0x5b27fe,_0xf243ab,_0x146bf9,_0x36266b,_0x20e300){const _0x49a3da=_0x54167d;VisuMZ[_0x49a3da(0x940)][_0x49a3da(0x3da)][_0x49a3da(0x204)](this,_0x4ab1c4,_0x52b079,_0x5b27fe,_0xf243ab,_0x146bf9,_0x36266b,_0x20e300),this['markCoreEngineModified']();},VisuMZ[_0x54167d(0x940)]['Bitmap_drawCircle']=Bitmap[_0x54167d(0x4ec)][_0x54167d(0x566)],Bitmap['prototype'][_0x54167d(0x566)]=function(_0x2c3dbb,_0xcd4c1a,_0x5f397c,_0x3e712f){const _0x631f9e=_0x54167d;_0x2c3dbb=Math['round'](_0x2c3dbb),_0xcd4c1a=Math['round'](_0xcd4c1a),_0x5f397c=Math[_0x631f9e(0x3ad)](_0x5f397c),VisuMZ[_0x631f9e(0x940)][_0x631f9e(0x298)][_0x631f9e(0x204)](this,_0x2c3dbb,_0xcd4c1a,_0x5f397c,_0x3e712f),this[_0x631f9e(0x7f7)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x28e)]=Bitmap['prototype'][_0x54167d(0x330)],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x330)]=function(_0xaa5b48){const _0x46a5c2=_0x54167d;return Math['ceil'](VisuMZ[_0x46a5c2(0x940)][_0x46a5c2(0x28e)][_0x46a5c2(0x204)](this,_0xaa5b48));},VisuMZ[_0x54167d(0x940)]['Bitmap_drawText']=Bitmap['prototype'][_0x54167d(0x2cc)],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x2cc)]=function(_0x4400d0,_0x14a905,_0x3828d3,_0x4bf612,_0x38e5ee,_0x1ab238){const _0xfe13=_0x54167d;_0x14a905=Math[_0xfe13(0x3ad)](_0x14a905),_0x3828d3=Math[_0xfe13(0x3ad)](_0x3828d3),_0x4bf612=Math['round'](_0x4bf612),_0x38e5ee=Math[_0xfe13(0x3ad)](_0x38e5ee),VisuMZ[_0xfe13(0x940)][_0xfe13(0x2e4)][_0xfe13(0x204)](this,_0x4400d0,_0x14a905,_0x3828d3,_0x4bf612,_0x38e5ee,_0x1ab238),this['markCoreEngineModified']();},VisuMZ['CoreEngine']['Bitmap_drawTextOutline']=Bitmap['prototype'][_0x54167d(0x4b4)],Bitmap[_0x54167d(0x4ec)][_0x54167d(0x4b4)]=function(_0x44446d,_0x547e14,_0x51c0b0,_0xf7e9c7){const _0x21fdb4=_0x54167d;VisuMZ[_0x21fdb4(0x940)][_0x21fdb4(0x331)][_0x21fdb4(0x2e9)][_0x21fdb4(0x9e0)]?_0x21fdb4(0x73f)===_0x21fdb4(0x73f)?this['_drawTextShadow'](_0x44446d,_0x547e14,_0x51c0b0,_0xf7e9c7):_0x393dd6['CoreEngine'][_0x21fdb4(0x9d8)]['call'](this):VisuMZ['CoreEngine'][_0x21fdb4(0x4ff)][_0x21fdb4(0x204)](this,_0x44446d,_0x547e14,_0x51c0b0,_0xf7e9c7);},Bitmap[_0x54167d(0x4ec)]['_drawTextShadow']=function(_0x2f1561,_0x201bef,_0x5b31d,_0x2d29bd){const _0x31eb52=_0x54167d,_0x38fc6a=this['context'];_0x38fc6a['fillStyle']=this[_0x31eb52(0x431)],_0x38fc6a[_0x31eb52(0x70c)](_0x2f1561,_0x201bef+0x2,_0x5b31d+0x2,_0x2d29bd);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x638)]=Input[_0x54167d(0x531)],Input['clear']=function(){const _0x24b2a1=_0x54167d;VisuMZ[_0x24b2a1(0x940)]['Input_clear'][_0x24b2a1(0x204)](this),this['_inputString']=undefined,this[_0x24b2a1(0x912)]=undefined,this[_0x24b2a1(0x88b)]=Input['keyRepeatWait'];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x91e)]=Input[_0x54167d(0x3b5)],Input[_0x54167d(0x3b5)]=function(){const _0x5ce9f5=_0x54167d;VisuMZ[_0x5ce9f5(0x940)][_0x5ce9f5(0x91e)][_0x5ce9f5(0x204)](this);if(this[_0x5ce9f5(0x88b)])this[_0x5ce9f5(0x88b)]--;},VisuMZ['CoreEngine'][_0x54167d(0x4d1)]=Input[_0x54167d(0x898)],Input['_pollGamepads']=function(){const _0x4a6325=_0x54167d;if(this['_gamepadWait'])return;VisuMZ[_0x4a6325(0x940)][_0x4a6325(0x4d1)][_0x4a6325(0x204)](this);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x8f0)]=Input[_0x54167d(0x454)],Input[_0x54167d(0x454)]=function(){const _0x47253e=_0x54167d;VisuMZ['CoreEngine'][_0x47253e(0x8f0)][_0x47253e(0x204)](this),document['addEventListener'](_0x47253e(0x51a),this[_0x47253e(0x95d)][_0x47253e(0x6ac)](this));},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5ec)]=Input['_onKeyDown'],Input['_onKeyDown']=function(_0x588a46){const _0x1c13c3=_0x54167d;this[_0x1c13c3(0x912)]=_0x588a46[_0x1c13c3(0x6e5)],VisuMZ['CoreEngine'][_0x1c13c3(0x5ec)][_0x1c13c3(0x204)](this,_0x588a46);},Input[_0x54167d(0x95d)]=function(_0x11d26d){const _0x43130e=_0x54167d;this[_0x43130e(0x93a)](_0x11d26d);},Input[_0x54167d(0x93a)]=function(_0x5ad27f){const _0x12b736=_0x54167d;this['_inputSpecialKeyCode']=_0x5ad27f[_0x12b736(0x6e5)];let _0x4053ef=String['fromCharCode'](_0x5ad27f[_0x12b736(0x5a6)]);this[_0x12b736(0x2f6)]===undefined?this[_0x12b736(0x2f6)]=_0x4053ef:this[_0x12b736(0x2f6)]+=_0x4053ef;},VisuMZ[_0x54167d(0x940)]['Input_shouldPreventDefault']=Input[_0x54167d(0x58c)],Input[_0x54167d(0x58c)]=function(_0x355a09){const _0x369b09=_0x54167d;if(_0x355a09===0x8)return![];return VisuMZ[_0x369b09(0x940)][_0x369b09(0x6e6)][_0x369b09(0x204)](this,_0x355a09);},Input[_0x54167d(0x623)]=function(_0x15c187){const _0x279d76=_0x54167d;if(_0x15c187[_0x279d76(0x59b)](/backspace/i))return this[_0x279d76(0x912)]===0x8;if(_0x15c187[_0x279d76(0x59b)](/enter/i))return this[_0x279d76(0x912)]===0xd;if(_0x15c187['match'](/escape/i))return this[_0x279d76(0x912)]===0x1b;},Input[_0x54167d(0x8e3)]=function(){return[0x30,0x31,0x32,0x33,0x34,0x35,0x36,0x37,0x38,0x39]['contains'](this['_inputSpecialKeyCode']);},Input['isArrowPressed']=function(){const _0x4b77ef=_0x54167d;return[0x25,0x26,0x27,0x28]['contains'](this[_0x4b77ef(0x912)]);},Input[_0x54167d(0x599)]=function(){const _0x1f76dd=_0x54167d;if(navigator[_0x1f76dd(0x42b)]){const _0x2ea322=navigator[_0x1f76dd(0x42b)]();if(_0x2ea322)for(const _0x535733 of _0x2ea322){if(_0x535733&&_0x535733[_0x1f76dd(0x74a)])return!![];}}return![];},Input[_0x54167d(0x40e)]=function(){const _0x1e779a=_0x54167d;if(navigator['getGamepads']){const _0x1b6973=navigator[_0x1e779a(0x42b)]();if(_0x1b6973){if(_0x1e779a(0x65c)!==_0x1e779a(0x2c8))for(const _0x496517 of _0x1b6973){if(_0x496517&&_0x496517[_0x1e779a(0x74a)]){if(this['isGamepadButtonPressed'](_0x496517))return!![];}}else _0x1d4741('%1\x27s\x20version\x20does\x20not\x20match\x20plugin\x27s.\x20Please\x20update\x20it\x20in\x20the\x20Plugin\x20Manager.'['format'](_0x4d5494,_0x258c5a)),_0x2e608e[_0x1e779a(0x4fc)]();}}return![];},Input[_0x54167d(0x649)]=function(_0x196d83){const _0x5db403=_0x54167d,_0x48adce=_0x196d83[_0x5db403(0x277)];for(let _0x64b41e=0x0;_0x64b41e<_0x48adce[_0x5db403(0x95b)];_0x64b41e++){if(_0x48adce[_0x64b41e]['pressed'])return!![];}return![];},VisuMZ[_0x54167d(0x940)]['Tilemap_addShadow']=Tilemap['prototype'][_0x54167d(0x37e)],Tilemap[_0x54167d(0x4ec)][_0x54167d(0x37e)]=function(_0x3befb6,_0x27ff5a,_0x7725f5,_0x4e72e4){const _0x4b0e6c=_0x54167d;if($gameMap&&$gameMap['areTileShadowsHidden']())return;VisuMZ['CoreEngine'][_0x4b0e6c(0x5a9)]['call'](this,_0x3befb6,_0x27ff5a,_0x7725f5,_0x4e72e4);},Tilemap['Renderer'][_0x54167d(0x4ec)][_0x54167d(0x581)]=function(){const _0x3f81ea=_0x54167d;this['_destroyInternalTextures']();for(let _0xc7435f=0x0;_0xc7435f<Tilemap[_0x3f81ea(0x824)]['MAX_GL_TEXTURES'];_0xc7435f++){const _0x531663=new PIXI[(_0x3f81ea(0x7e2))]();_0x531663[_0x3f81ea(0x328)](0x800,0x800);if(VisuMZ[_0x3f81ea(0x940)][_0x3f81ea(0x331)][_0x3f81ea(0x2e9)]['PixelateImageRendering']){if('LoEcc'===_0x3f81ea(0x6ad))_0x531663[_0x3f81ea(0x768)]=PIXI[_0x3f81ea(0x767)][_0x3f81ea(0x72f)];else return _0x5a6d18['layoutSettings'][_0x3f81ea(0x68d)][_0x3f81ea(0x204)](this);}this[_0x3f81ea(0x54e)]['push'](_0x531663);}},WindowLayer[_0x54167d(0x4ec)][_0x54167d(0x53b)]=function(){const _0x44d3ac=_0x54167d;if(SceneManager&&SceneManager['_scene']){if('fbdwC'!=='fbdwC')_0x59b0ee[_0x44d3ac(0x940)][_0x44d3ac(0x9d1)][_0x44d3ac(0x204)](this);else return SceneManager['_scene'][_0x44d3ac(0x507)]();}else return!![];},VisuMZ[_0x54167d(0x940)]['WindowLayer_render']=WindowLayer[_0x54167d(0x4ec)][_0x54167d(0x47b)],WindowLayer['prototype'][_0x54167d(0x47b)]=function render(_0x574591){const _0x5455c6=_0x54167d;if(this['isMaskingEnabled']())_0x5455c6(0x6be)!==_0x5455c6(0x2e3)?VisuMZ[_0x5455c6(0x940)]['WindowLayer_render'][_0x5455c6(0x204)](this,_0x574591):this['_commandWindow'][_0x5455c6(0x6d0)](_0x4dd2f5[_0x5455c6(0x556)][_0x5455c6(0x626)]);else{if('mHJtB'===_0x5455c6(0x589))this[_0x5455c6(0x951)](_0x574591);else return _0x11a0b8[_0x5455c6(0x556)][_0x5455c6(0x8af)][_0x5455c6(0x204)](this);}},WindowLayer['prototype'][_0x54167d(0x951)]=function render(_0x41abe6){const _0x49881d=_0x54167d;if(!this['visible'])return;const _0xf976b6=new PIXI[(_0x49881d(0x842))](),_0x5c46c7=_0x41abe6['gl'],_0x9c32a0=this[_0x49881d(0xa1b)]['clone']();_0x41abe6[_0x49881d(0x999)][_0x49881d(0x33e)](),_0xf976b6['transform']=this[_0x49881d(0x4ac)],_0x41abe6[_0x49881d(0x266)][_0x49881d(0x49a)](),_0x5c46c7[_0x49881d(0x1f3)](_0x5c46c7[_0x49881d(0x867)]);while(_0x9c32a0[_0x49881d(0x95b)]>0x0){const _0x415599=_0x9c32a0[_0x49881d(0x843)]();_0x415599[_0x49881d(0x803)]&&_0x415599[_0x49881d(0x572)]&&_0x415599[_0x49881d(0x51c)]>0x0&&(_0x5c46c7[_0x49881d(0x7f4)](_0x5c46c7[_0x49881d(0x2f3)],0x0,~0x0),_0x5c46c7[_0x49881d(0x2ef)](_0x5c46c7[_0x49881d(0x760)],_0x5c46c7[_0x49881d(0x760)],_0x5c46c7[_0x49881d(0x760)]),_0x415599[_0x49881d(0x47b)](_0x41abe6),_0x41abe6[_0x49881d(0x266)]['flush'](),_0xf976b6['clear'](),_0x5c46c7['stencilFunc'](_0x5c46c7[_0x49881d(0x9d3)],0x1,~0x0),_0x5c46c7[_0x49881d(0x2ef)](_0x5c46c7[_0x49881d(0x319)],_0x5c46c7[_0x49881d(0x319)],_0x5c46c7[_0x49881d(0x319)]),_0x5c46c7['blendFunc'](_0x5c46c7[_0x49881d(0xa14)],_0x5c46c7[_0x49881d(0x6bb)]),_0xf976b6[_0x49881d(0x47b)](_0x41abe6),_0x41abe6['batch'][_0x49881d(0x49a)](),_0x5c46c7[_0x49881d(0x7e7)](_0x5c46c7['ONE'],_0x5c46c7[_0x49881d(0x899)]));}_0x5c46c7['disable'](_0x5c46c7[_0x49881d(0x867)]),_0x5c46c7[_0x49881d(0x531)](_0x5c46c7['STENCIL_BUFFER_BIT']),_0x5c46c7[_0x49881d(0x855)](0x0),_0x41abe6[_0x49881d(0x266)]['flush']();for(const _0x51e979 of this[_0x49881d(0xa1b)]){!_0x51e979[_0x49881d(0x803)]&&_0x51e979[_0x49881d(0x572)]&&_0x51e979[_0x49881d(0x47b)](_0x41abe6);}_0x41abe6[_0x49881d(0x266)]['flush']();},DataManager[_0x54167d(0x98f)]=function(_0x315239){const _0x319d33=_0x54167d;return this[_0x319d33(0x7c1)](_0x315239)&&_0x315239[_0x319d33(0x50d)]===0x2;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x6f2)]=DataManager[_0x54167d(0x952)],DataManager[_0x54167d(0x952)]=function(){const _0x5f09e8=_0x54167d;VisuMZ[_0x5f09e8(0x940)][_0x5f09e8(0x6f2)][_0x5f09e8(0x204)](this),this[_0x5f09e8(0x422)](),this[_0x5f09e8(0x586)]();},DataManager['reservePlayTestNewGameCommonEvent']=function(){const _0x43d25c=_0x54167d;if($gameTemp[_0x43d25c(0x562)]()){const _0x396d18=VisuMZ[_0x43d25c(0x940)]['Settings'][_0x43d25c(0x2e9)]['NewGameCommonEvent'];if(_0x396d18>0x0)$gameTemp['reserveCommonEvent'](_0x396d18);}},DataManager[_0x54167d(0x586)]=function(){const _0x319fce=_0x54167d,_0x1ece8a=VisuMZ[_0x319fce(0x940)][_0x319fce(0x331)]['QoL']['NewGameCommonEventAll']||0x0;if(_0x1ece8a>0x0)$gameTemp['reserveCommonEvent'](_0x1ece8a);},DataManager[_0x54167d(0x910)]=function(_0x462a2f){const _0x2d112c=_0x54167d,_0x427c53=$dataTroops[_0x462a2f];if(!_0x427c53)return'';let _0x382d6d='';_0x382d6d+=_0x427c53[_0x2d112c(0x614)];for(const _0x317d42 of _0x427c53[_0x2d112c(0x6e0)]){if(_0x2d112c(0x2c6)!=='LMxRv')_0x453812[_0x2d112c(0x940)]['Scene_Boot_updateDocumentTitle'][_0x2d112c(0x204)](this);else for(const _0x3bee75 of _0x317d42[_0x2d112c(0x9d7)]){[0x6c,0x198][_0x2d112c(0x9ef)](_0x3bee75['code'])&&(_0x382d6d+='\x0a',_0x382d6d+=_0x3bee75[_0x2d112c(0x733)][0x0]);}}return _0x382d6d;};function _0x2505(){const _0x1c99ff=['xparam','VcUnz','BACK_SLASH','pictureId','learnings','_stored_powerDownColor','Spriteset_Battle_createEnemies','Game_Action_setAttack','map','MDR','〖〖〖\x20Troop\x20%1:\x20%2\x20Script\x20〗〗〗\x0a\x0a','Scene_Status_create','createTroopNote','_moveEasingType','_inputSpecialKeyCode','split','drawGameTitle','clearRect','Untitled','INBACK','ListRect','yeDkC','Window_StatusBase_drawActorSimpleStatus','SwitchRandomizeRange','OPEN_CURLY_BRACKET','Window_Base_drawIcon','Input_update','bgs','Scene_Map_update','_commandList','displayY','ARRAYSTRUCT','focus','currencyUnit','button','Window_NameInput_initialize','Game_Screen_initialize','GoldFontSize','CLEAR','DATABASE','PTB','NUMPAD6','command105','VQUrP','key%1','test','Scene_Map_updateMain','BottomHelp','buttonAssistText5','active','([\x5c+\x5c-]\x5cd+\x5c.?\x5cd+)>','FanvW','NUMPAD8','setClickHandler','_registerKeyInput','successRate','printError','VNUAB','Game_Event_isCollidedWithEvents','exportAllMapStrings','CoreEngine','Hqrsg','NeYuL','updateWaitMode','paramMaxJS','EINQq','process_VisuMZ_CoreEngine_CustomParameters','Scene_Skill_create','paramWidth','TRAIT_PARAM','playCancel','OptionsRect','5052KpFimA','isSceneBattle','switchModes','result','_pageupButton','renderNoMask','setupNewGame','xparamPlus','destroy','oHUKx','createDimmerSprite','DIVIDE','translucentOpacity','_stored_tpGaugeColor1','process_VisuMZ_CoreEngine_Functions','length','znoYG','_onKeyPress','Game_Interpreter_command355','mpGaugeColor1','startNormalGame','_colorCache','SystemSetBattleSystem','Flat2','paramFlatJS','ETB','isArrowPressed','movePageButtonSideButtonLayout','LILnL','bNstv','ColorMPCost','WIN_ICO_00','\x0a\x0a\x0a\x0a\x0a','mpGaugeColor2','catchLoadError','_screenY','levelUpRecovery','SystemLoadImages','DimColor1','rQcQb','WIN_OEM_WSCTRL','itemHit','processCursorHomeEndTrigger','sparamFlat2','GoldRect','_battlerName','GetParamIcon','wGMqN','CazGT','itemHeight','WIN_OEM_JUMP','keyboard','LoadMenu','F17','buttonAssistKey2','AllTroops','DECIMAL','XParamVocab6','removeOnceParallelInterpreter','aaesO','buttonAssistKey4','_rate','COLON','BlurFilter','sin','_helpWindow','AnimationMirrorOffset','isKeyItem','Window_Base_drawFace','NUM','Pixelated','VisuMZ\x20CoreEngine\x20PictureIcon\x20%1\x20%2','IdERg','IconSParam1','boxHeight','_targetOffsetY','Center','framebuffer','Scene_Map_updateMainMultiply','XUxtd','uKvOu','kcSXf','Window_Gold_refresh','Game_System_initialize','cksYN','paramMax','Scene_Map_createSpritesetFix','contents','ESttR','adjustBoxSize','Upper\x20Left','cancel','_movementDuration','IconXParam1','BTB','CcAnY','hefLs','VBKJm','wtQRC','iJLvH','anchor','HbWYa','vertJS','onNameOk','XNJNb','bitmapHeight','NumberBgType','params','NUMPAD0','checkSubstitute','pow','createBuffer','getBattleSystem','ListBgType','isPointAnimationPlaying','MGhEp','pictureButtons','YhnOD','drawFace','NffsF','cursorUp','FontSmoothing','ScaleY','targetX','YJtZd','NONCONVERT','Scene_Title_drawGameTitle','contentsBack','Rate','_mainSprite','MODECHANGE','pointY','defaultInputMode','Window_NumberInput_processDigitChange','bgm','ALWAYS','showFauxAnimations','ApplyEasing','VdGuQ','list','Scene_Name_onInputOk','iDxdd','QUOTE','vXufJ','KPXUP','_clientArea','MRG','originalJS','FontShadows','lkOUn','encounterStep','Conditional\x20Branch\x20Script\x20Error','Window_Selectable_cursorUp','MCTtb','isRepeated','process_VisuMZ_CoreEngine_RegExp','battleSystem','seVolume','exp','_pictureCoordinatesMode','atbActive','VzeeA','addLoadListener','includes','Scene_GameEnd_createBackground','_hovered','isBottomButtonMode','CTB','guardSkillId','cursorPageup','runCombinedScrollingTextAsCode','OPEN_PAREN','VOLUME_DOWN','calcCoreEasing','bgsVolume','isTpb','commandWindowRect','getInputButtonString','isInstanceOfSceneMap','WIN_OEM_PA3','ahPKK','Enemy','Export\x20Troop\x20Text\x20operation\x20will\x20finish\x20in\x20%1\x20ms(s)','_downArrowSprite','XParamVocab0','TjMIh','_buttonAssistWindow','TimeProgress','_pressed','_encounterCount','statusParamsWindowRect','_stored_expGaugeColor2','volume','GRD','cursorLeft','SystemSetFontSize','ceil','targetOpacity','repositionEnemiesByResolution','setAction','ZERO','animationNextDelay','characters','position','setEasingType','_shakeDuration','setTargetAnchor','children','GYNsf','ForceNoPlayTest','enable','loadGameImagesCoreEngine','_refreshArrows','useFontWidthFix','_origin','advanced','RowSpacing','updateBackOpacity','isSmartEventCollisionOn','CONTEXT_MENU','BTestAddedQuantity','title','_hideButtons','StatusEquipBgType','defineProperty','initBasic','MAT','call','ENTER','random','ExportString','KdjKP','DrawIcons','RPGMAKER_VERSION','BuyBgType','PAUSE','TextStr','faceWidth','setMute','EXCLAMATION','updatePositionCoreEngine','dherO','cXtST','_backgroundFilter','pxkHA','tpCostColor','picture','SceneManager_onKeyDown','218743SPhJfQ','OpenConsole','processKeyboardBackspace','processHandling','_coreEngineShakeStyle','%1\x27s\x20version\x20does\x20not\x20match\x20plugin\x27s.\x20Please\x20update\x20it\x20in\x20the\x20Plugin\x20Manager.','keyMapper','updatePlayTestF7','Symbol','YWMJw','NUMPAD4','F22','targetObjects','determineSideButtonLayoutValid','smallParamFontSize','bitmap','updateMove','scaleSprite','LevelUpFullHp','PictureEraseRange','buttonAssistText%1','isSideView','anchorCoreEasing','Sprite_Animation_processSoundTimings','right','drawTextTopAligned','remove','isBottomHelpMode','isMapScrollLinked','paramRateJS','JeQGi','exec','createChildSprite','_windowskin','ExportStrFromAllMaps','hideButtonFromView','MSsCh','_dummyWindow','updateTransform','INQUINT','EndingID','_targetScaleY','SHIFT','Scene_Unlisted','setupBattleTestItems','catchNormalError','paramName','Game_Map_setup','outlineColorGauge','ARRAYEVAL','isEnemy','openURL','IconParam5','contentsOpacity','139250anJBYC','ecJKR','IconXParam6','WIN_OEM_AUTO','qHtAX','makeDocumentTitle','createCommandWindow','_storedStack','EnableNameInput','SystemLoadAudio','_mirror','TaUlC','\x20Origin:\x20%1','SwitchToggleOne','platform','concat','%1%2','isUseModernControls','optSideView','log','INCUBIC','mMnXL','animations','batch','WIqrq','_cacheScaleX','processPointAnimationRequests','HELP','VyoMZ','application/json','ORKWv','updateShadow','ActorMPColor','MclQH','EREOF','initialBattleSystem','Scene_Battle_createSpriteset','buttonAssistOffset1','NumberRect','ParseActorNotetags','buttons','Sprite_Battler_startMove','IQOVo','Script\x20Call\x20Error','gainSilentTp','END','OLrsT','SnAxz','mMMOB','Graphics_centerElement','width','EXR','ButtonHeight','titleCommandWindow','VisuMZ_2_BattleSystemCTB','MIN_SAFE_INTEGER','inputWindowRect','isFullDocumentTitle','forceOutOfPlaytest','ShowButtons','iconWidth','code','buttonY','Bitmap_measureTextWidth','GREATER_THAN','rgba(0,\x200,\x200,\x200.7)','listWindowRect','pixelated','HRG','cibUW','kHvwD','VisuMZ_2_BattleSystemOTB','nah','Bitmap_drawCircle','IconXParam7','removeAllFauxAnimations','clamp','doesNameContainBannedWords','_stored_pendingColor','_itemWindow','updatePositionCoreEngineShakeHorz','IconXParam2','ALTGR','addWindow','XParamVocab4','nw.gui','drawGauge','F6key','PLgWm','FVLri','iQhkM','createButtonAssistWindow','hpGaugeColor2','onload','origin','NewGameBoot','0.00','1884450GzkPUW','ItemRect','zwVSL','playTestCtrlT','loadPicture','HRhOz','Sprite_Gauge_gaugeRate','get','Window_Base_drawCharacter','BannedWords','setupCustomRateCoreEngine','drawActorLevel','_active','buttonAssistWindowButtonRect','Window_NameInput_refresh','setFrame','PIPE','AntiZoomPictures','yHcsT','darwin','xparamPlus1','Scene_Battle_update','LMxRv','BhqSY','DFHIS','Window_NameInput_processTouch','getLastPluginCommandInterpreter','stringKeyMap','drawText','drawGameVersion','TQQmY','DummyRect','CommonEventID','\x5c}❪SHIFT❫\x5c{','veKze','ppNpG','_opacity','INOUTQUART','processTimingData','INOUTCIRC','enableDigitGrouping','EVA','PRESERVCONVERSION(%1)','damageColor','loadIconBitmap','updatePictureCoordinates','textHeight','updateCoreEasing','Sprite_AnimationMV_processTimingData','Scene_Base_create','ActorRect','NKauJ','Bitmap_drawText','drawActorClass','setCommonEvent','battlebacks1','Window_Base_createTextState','QoL','paramFlatBonus','Map%1','helpAreaHeight','$dataMap','mirror','stencilOp','wqdiq','meVolume','dimColor1','EQUAL','_skillTypeWindow','isGameActive','_inputString','OutlineColor','zTbhL','_list','drawGameSubtitle','targetScaleX','shake','DXkTu','bgmVolume','moveRelativeToResolutionChange','save','xparamFlatJS','INOUTQUINT','isNwjs','jYqsH','Scene_Boot_onDatabaseLoaded','F11','mhp','moveMenuButtonSideButtonLayout','_targets','ColorExpGauge1','ColorMaxLvGauge1','LevelUpFullMp','HaUlW','createTitleButtons','data/','CancelText','iIvPx','TitleCommandList','tpColor','trim','_tempActor','pagedown','CLOSE_BRACKET','isCursorMovable','REPLACE','note','isAnimationOffsetXMirrored','tFYlL','targetScaleY','IconParam3','playEscape','ParamArrow','ParseItemNotetags','buttonAssistText1','paramRate2','_battleField','mJmpI','aDOHF','HbfeQ','setSize','loadSystemImages','_stored_tpGaugeColor2','system','resetTextColor','BasicParameterFormula','13435FdhcJe','status','measureTextWidth','Settings','OTB','pop','URL','responseText','LEFT','type','EnableJS','Scene_Menu_create','BTestWeapons','GoldMax','Linear','WIN_OEM_FJ_TOUROKU','forceStencil','JUNJA','SkillTypeRect','createCustomBackgroundImages','StatusBgType','paramFlat','animationShouldMirror','BzwDu','pxhrr','Game_Character_processMoveCommand','aEubW','setActorHome','_playtestF7Looping','Window_EquipItem_isEnabled','740qjculp','Lspfg','onDatabaseLoaded','OutlineColorGauge','max','initialLevel','wXAVc','QsZcI','SwitchActorText','nBSks','qpMXe','sv_enemies','setMainFontSize','WIN_OEM_BACKTAB','HANJA','EditBgType','setupCoreEngine','move','#%1','SELECT','_targetOpacity','CONVERT','gaugeLineHeight','AnimationPoint','RegExp','setMoveEasingType','([\x5c+\x5c-]\x5cd+)([%％])>','WIN_OEM_FJ_JISHO','Window_NameInput_cursorLeft','Hkzcg','image-rendering','WIN_OEM_FINISH','xScrollLinkedOffset','itemHitImprovedAccuracy','_timerSprite','HYhSx','EVAL','showPointAnimations','xIvve','Spriteset_Base_isAnimationPlaying','DqPdA','jvIXM','_width','CustomParamIcons','changeTextColor','ColorGaugeBack','<%1\x20%2:[\x20]','8mcmAIs','parallaxes','itemLineRect','_addShadow','_sellWindow','_customModified','bAvnW','toFixed','initCoreEasing','yScrollLinkedOffset','_cacheScaleY','xparamFlat1','32nxsRAX','〖〖〖\x20Map\x20%1:\x20%2\x20Script\x20〗〗〗\x0a\x0a','OWbCB','jhcPl','WRqgj','updateOpacity','EvUkg','onButtonImageLoad','sparamPlus2','62253IVRcEH','Game_Troop_setup','ColorTPGauge1','usableSkills','vepFG','_stored_mpCostColor','SParamVocab6','Map%1.json','push','hit','FTB','goldWindowRect','LESS_THAN','GameEnd','IconXParam5','drawValue','BoxMargin','oLfiQ','GoldChange','AkROb','none','makeCommandList','Nlgtu','Title','_slotWindow','PRINT','dummyWindowRect','REC','titles1','round','BottomButtons','xpZTL','_clickHandler','Game_Picture_y','IconParam0','INBOUNCE','areButtonsOutsideMainUI','update','Window','ctrlKey','drawParamText','INOUTSINE','process_VisuMZ_CoreEngine_Notetags','buttonAssistKey%1','XParamVocab3','JYgfI','FNVpm','IconIndex','rMSqt','child_process','WIN_OEM_FJ_LOYA','rgba(0,\x200,\x200,\x201.0)','ColorDeath','_stored_powerUpColor','command357','padZero','_stored_maxLvGaugeColor1','escape','subjectHitRate','EaLiN','statusEquipWindowRect','SPACE','DEF','strokeRect','_editWindow','Sprite_Picture_loadBitmap','_baseTexture','StartID','Troop%1','mute','clearForcedGameTroopSettingsCoreEngine','Game_Actor_changeClass','Window_NameInput_cursorDown','number','Bitmap_gradientFillRect','yrvBl','helpAreaBottom','IconSParam8','alwaysDash','catchException','min','height','_goldWindow','Opacity','MultiKeyFmt','Abbreviation','INOUTBOUNCE','_mapNameWindow','OQZjM','initDigitGrouping','equips','Window_StatusBase_drawActorLevel','jVEiE','replace','ExportAllMapText','repositionCancelButtonSideButtonLayout','_realScale','performEscape','setCoreEngineScreenShakeStyle','paramBaseAboveLevel99','_subject','Window_NumberInput_start','return\x200','updateData','yKrOQ','Scene_Base_terminate','Param','nextLevelExp','showDevTools','VisuMZ_2_BattleSystemPTB','Scene_Boot_startNormalGame','ColorTPGauge2','SParamVocab9','LoadError','_movementWholeDuration','outlineColorDmg','drawIconBySize','pEEZl','CallHandlerJS','INQUAD','buttonAssistText4','IconSet','PLAY','YgPsp','Total','Scene_MenuBase_helpAreaTop','isGamepadTriggered','BattleManager_checkSubstitute','EAprN','SkillMenu','_maxDigits','SmartEventCollisionPriority','ctGaugeColor1','iTMFT','font','SParamVocab1','ACCEPT','makeDeepCopy','CommandRect','HOME','thZly','mmp','《《《\x20Event\x20%1:\x20%2,\x20Page\x20%3\x20》》》\x0a%4\x0a','getCoreEngineScreenShakeStyle','_backgroundSprite','mainAreaHeight','reservePlayTestNewGameCommonEvent','textColor','TextJS','WIN_OEM_ENLW','currentLevelExp','PRINTSCREEN','profileWindowRect','Keyboard','_lastOrigin','getGamepads','mIuJC','reserveCommonEvent','Flat1','floor','processCursorMove','outlineColor','_opening','select','fillRect','HASH','_backSprite1','events','evaded','qoDDp','isItemStyle','currentExp','WlEeG','OUTEXPO','Scene_Map_createSpriteset_detach','MCR','Scene_Base_createWindowLayer','mbFww','EQUALS','PPTsc','DvgCp','xparamFlat2','initCoreEngineScreenShake','option','VisuMZ_2_BattleSystemSTB','XParamVocab1','hHwHv','rPHnx','lfRva','process_VisuMZ_CoreEngine_Settings','_defaultStretchMode','retrieveFauxAnimation','CustomParamAbb','members','UAOWf','playTestF7','_setupEventHandlers','paramRate','DamageColor','INOUTELASTIC','YeJYm','numberWindowRect','PreserveNumbers','tkwau','_listWindow','ColorCTGauge1','BGKPD','addChild','style','XParamVocab9','getBackgroundOpacity','Scene_Map_updateScene','ButtonAssist','cursorRight','playBuzzer','Spriteset_Base_updatePosition','blockWidth','sparamRate1','itemPadding','retrievePointAnimation','setAttack','CIRCUMFLEX','missed','blt','STB','isClosed','level','openingSpeed','IconSParam5','_digitGroupingEx','clearZoom','DigitGroupingLocale','_pictureCoordinatesWindow','oniEs','ayhwP','render','menu','refreshDimmerBitmap','iLmyQ','OUTSINE','skillTypeWindowRect','ROYtK','format','gTLiZ','_stored_hpGaugeColor2','_stored_systemColor','isCollidedWithEvents','textAlign','1030ZYnuhN','uiAreaWidth','createFauxAnimationSprite','ShortcutScripts','applyCoreEasing','ShowJS','ProfileBgType','itemBackColor2','startAnimation','expGaugeColor1','addChildToBack','pvyvx','CsZcv','Smooth','cnIDD','boxWidth','loadSystem','innerWidth','flush','makeFontSmaller','ItemHeight','command111','buttonAssistOffset%1','canUse','Game_Party_consumeItem','menuShowButton','updatePosition','NkUHk','DigitGroupingGaugeSprites','QJITM','initMembers','BgType','MAX_SAFE_INTEGER','constructor','onInputBannedWords','rowSpacing','transform','setGuard','lTpVN','FUNC','Sprite_destroy','VrfJe','X:\x20%1','backspace','_drawTextOutline','FDR','CvggE','isEnabled','alphabetic','consumeItem','uSREI','vertical','getCustomBackgroundSettings','Game_Picture_updateMove','EXEyA','KGEUq','_sideButtonLayout','jnQMW','EXECUTE','buttonAssistText2','removeChild','sTsSG','INSINE','ShowDevTools','App','updateOrigin','nAkmR','sparamFlat1','NUM_LOCK','This\x20scene\x20cannot\x20utilize\x20a\x20Once\x20Parallel!','_scene','restore','smooth','Input_pollGamepads','OUTQUART','_backSprite','ctGaugeColor2','measureTextWidthNoRounding','F21','checkCacheKey','hpColor','sSOKm','ShowItemBackground','Window_Base_update','_pointAnimationSprites','end','subject','NUMPAD7','ImprovedAccuracySystem','STRUCT','alpha','loadBitmap','paramValueByName','WkDdu','SParameterFormula','VisuMZ_2_BattleSystemFTB','buttonAssistKey1','onInputOk','_hideTileShadows','BgFilename2','prototype','oeJCm','_duration','_data','_buttonType','calcEasing','SPsWC','_hp','_updateFilterArea','Basic','isActor','WlMER','_muteSound','INSERT','hide','VReHx','exit','KCScy','DefaultStyle','Bitmap_drawTextOutline','egwaO','〘Common\x20Event\x20%1:\x20%2〙\x20End','offsetX','getPointAnimationLayer','KeySHIFT','deselect','ActorTPColor','isWindowMaskingEnabled','ValueJS','vZzWb','ColorHPGauge2','_stored_gaugeBackColor','currentClass','itypeId','_actorWindow','setViewportCoreEngineFix','string','updatePadding','gaugeRate','setupValueFont','battlebacks2','enemies','createMenuButton','Graphics_printError','OPEN_BRACKET','getCombinedScrollingText','keypress','ExportAllTroopText','openness','sparamPlusJS','_mode','Window_Selectable_processTouch','expGaugeColor2','_actor','yXCGh','<JS\x20%1\x20%2:[\x20](.*)>','KWupN','yPVqh','Chance','Scene_Battle_createSpritesetFix','IDs','MenuLayout','MhzLQ','VLUXl','mainCommandWidth','_number','updateEffekseer','Scene_MenuBase_mainAreaHeight','Color','clear','_fauxAnimationQueue','Game_Picture_calcEasing','EVdVa','XParamVocab7','HelpBgType','_targetY','Rate1','_changingClass','itemBackColor1','isMaskingEnabled','helpAreaTopSideButtonLayout','join','_targetAnchor','xmlmN','inBattle','toLocaleString','_playTestFastMode','awNnV','AccuracyBoost','drawTextEx','WIN_OEM_RESET','Sprite_AnimationMV_updatePosition','SLASH','randomInt','NewGameCommonEvent','isTriggered','Subtitle','Location','_internalTextures','_pagedownButton','qolaj','DETACH_PICTURE_CONTAINER','expRate','version','_bitmap','_repositioned','layoutSettings','WSvSv','drawSegment','TranslucentOpacity','EtJuT','initCoreEngine','itemEva','createWindowLayer','_pictureName','COMMA','_stored_normalColor','_pauseSignSprite','isPlaytest','CodeJS','sv_actors','_targetOffsetX','drawCircle','_stored_deathColor','GoldOverlap','_animationQueue','RIGHT','pjQME','DPTKq','clearOnceParallelInterpreters','Game_Actor_levelUp','makeActionList','value','Sprite_Button_initialize','visible','itemWindowRect','ImgLoad','RepositionEnemies','kVFjY','cTTgu','MAXHP','GoldBgType','_pictureContainer','mJyxh','onClick','changeClass','YDdZg','updatePositionCoreEngineShakeOriginal','Game_Action_itemEva','_createInternalTextures','_commonEventLayers','qJMOH','canAttack','ItemBgType','reserveNewGameCommonEvent','cxXfe','home','mHJtB','parseForcedGameTroopSettingsCoreEngine','CTnYP','_shouldPreventDefault','initVisuMZCoreEngine','isMVAnimation','KUBBm','adjustSprite','Scene_Equip_create','open','TDfmI','param','DetachBattlePictureContainer','Sprite_Actor_setActorHome','PGDN','IconSParam9','isGamepadConnected','MULTIPLY','match','SceneManager_initialize','setBattleSystem','dimColor2','WpXzw','createBackground','pictures','drawRightArrow','show','VkJEn','BTestItems','charCode','helpWindowRect','lpPEz','Tilemap_addShadow','OLrKf','CategoryRect','Bitmap_blt','_offsetX','pageup','CLFCN','isMagical','_stored_maxLvGaugeColor2','updateDocumentTitle','nEdzo','NUMPAD5','ltBSm','EnableNumberInput','_coreEasing','eva','ParseSkillNotetags','ftJrJ','SceneManager_isGameActive','coxRC','sparamFlatJS','hpGaugeColor1','Game_Interpreter_PluginCommand','ETtpT','processTouchModernControls','targetY','TCR','Game_Interpreter_command105','ckNuz','BattleSystem','VoiUx','ExtJS','ScreenShake','_stored_expGaugeColor1','bitmapWidth','_storedMapText','dashToggle','categoryWindowRect','gPJsb','buttonAssistOffset2','FTmma','eventsXyNt','vlGvU','CLOSE_CURLY_BRACKET','powerUpColor','targetBackOpacity','ItemBackColor1','setHome','playOk','GroupDigits','Scene_Battle_createCancelButton','maxCols','command355','isMaxLevel','Game_Interpreter_updateWaitMode','Bitmap_strokeRect','UNDERSCORE','maxLvGaugeColor2','Scene_Battle_createSpriteset_detach','F24','command122','ColorPowerUp','redraw','Scene_Options_create','add','displayX','createPointAnimationQueue','Input_onKeyDown','TPB\x20WAIT','isInputting','SceneManager_exit','BlendMode','sellWindowRect','clearCachedKeys','BattleManager_processEscape','BDYok','Mabdk','Game_Interpreter_command122','upXDl','%1\x0a','_isPlaytest','SaveMenu','UEyVL','ARRAYJSON','JPwIl','playOnceParallelInterpreter','IconSParam7','buttonAssistSwitch','useDigitGroupingEx','YPeTN','MRF','subtitle','stypeId','processKeyboardHandling','charAt','buttonAssistKey5','isPlaying','_makeFontNameText','InputBgType','skills','SParamVocab7','setHandler','CategoryBgType','xdg-open','sparamFlatBonus','PERIOD','WIN_ICO_HELP','name','drawAllParams','createPointAnimation','RevertPreserveNumbers','DELETE','isEventRunning','(\x5cd+)([%％])>','playLoad','ParseClassNotetags','context','Scene_Map_createSpriteset','Game_Action_updateLastTarget','RightMenus','processBack','wYTgW','isSpecialCode','updateKeyText','buyWindowRect','CommandBgType','TRG','exportAllTroopStrings','_onceParallelInterpreters','WIN_OEM_PA1','BQvji','_blank','EscapeAlways','ESC','ModernControls','EXSEL','updateFauxAnimations','BattleManager_update','processKeyboardEnd','NUMPAD3','_closing','systemColor','OUTELASTIC','Input_clear','ytfFF','IconParam2','ZOOM','_dimmerSprite','PZuLI','indexOf','smoothSelect','ParamMax','nickname','VTwPB','updateMain','buttonAssistCancel','ExportCurTroopText','default','Spriteset_Base_destroy','QiKmO','isGamepadButtonPressed','updateClose','createPointAnimationSprite','requestFauxAnimation','ColorManager_loadWindowskin','createPageButtons','filter','DwHzu','ARRAYSTR','sparam','ParseTilesetNotetags','%1\x20is\x20missing\x20a\x20required\x20plugin.\x0aPlease\x20install\x20%2\x20into\x20the\x20Plugin\x20Manager.','VOLUME_MUTE','getColor','\x5c}❪TAB❫\x5c{','IconXParam3','([\x5c+\x5c-]\x5cd+)>','setupCoreEasing','isHandled','WuyyS','SLKOv','fadeSpeed','targets','wait','paramchangeTextColor','Plus2','cursorDown','processFauxAnimationRequests','Mirror','OnLoadJS','setValue','gaugeHeight','startShake','_centerElementCoreEngine','create','SnapshotOpacity','PHA','_isButtonHidden','tiUzD','SubfolderParse','QFWwE','xhYiI','buttonAssistKey3','maxBattleMembers','rpasX','TextFmt','PositionX','Unnamed','Game_Action_itemHit','IfNOR','ParseWeaponNotetags','Gold','backgroundBitmap','OUTQUAD','onerror','kGqAB','editWindowRect','KANA','ConvertParams','mToyr','Icon','getInputMultiButtonStrings','RepositionActors','processSoundTimings','F19','Flat','center','isBusy','HelpRect','ColorMaxLvGauge2','etURi','buttonAssistWindowSideRect','Sprite_Gauge_currentValue','StatusParamsRect','FoaZJ','buttonAreaHeight','Game_Picture_show','Scene_MenuBase_createPageButtons','CRSEL','_forcedBattleSys','Power','commandWindowRows','isOptionValid','setSkill','index','processCursorMoveModernControls','sqrt','uyaXN','cancelShowButton','Manual','updateCurrentEvent','_lastY','DigitGroupingExText','ExtractStrFromMap','maxLvGaugeColor1','nAjzA','RadJA','toLowerCase','makeTargetSprites','bind','LoEcc','_spriteset','_CoreEngineSettings','oEGnS','Window_Selectable_cursorDown','apply','_lastX','WARNING:\x20%1\x20has\x20already\x20been\x20declared\x0aand\x20cannot\x20be\x20used\x20as\x20a\x20Quick\x20JS\x20Function','CANCEL','Scene_MenuBase_createCancelButton','Window_Base_initialize','ItemPadding','kcXXm','tpGaugeColor2','ONE','DigitGroupingStandardText','ButtonFadeSpeed','eNsph','INOUTCUBIC','IconParam4','attackSkillId','slice','QUESTION_MARK','colSpacing','processEscape','numRepeats','_windowLayer','Saved\x20file\x20as\x20%1\x20in\x20project\x20folder.','popScene','IconSParam3','EditRect','YhXVI','ExportCurMapText','Window_NameInput_cursorUp','MenuBg','setBackgroundType','_targetX','_anchor','PnbQz','horzJS','playTestF6','actor','SellBgType','BTestArmors','isExpGaugeDrawn','F16','_margin','CustomParamType','XUYHP','Actor','_stored_hpGaugeColor1','pages','_animation','isCancelled','LINEAR','outbounce','keyCode','Input_shouldPreventDefault','getButtonAssistLocation','CRI','_currentMap','ATK','SsaBu','VisuMZ_1_OptionsCore','paramBase','〘Common\x20Event\x20%1:\x20%2〙\x20Start','initMembersCoreEngine','ItemMenu','ColSpacing','DataManager_setupNewGame','SParamVocab2','GoldIcon','PictureShowIcon','filters','mfqZs','_buyWindow','BppAz','cos','inbounce','ParamName','PkKAm','setupRate','bYjxR','SParamVocab5','DummyBgType','Window_Base_drawText','Window_NameInput_cursorRight','\x0a\x20\x20\x20\x20\x20\x20\x20\x20try\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20%2\x0a\x20\x20\x20\x20\x20\x20\x20\x20}\x20catch\x20(e)\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20if\x20($gameTemp.isPlaytest())\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20console.log(\x27JS\x20Quick\x20Function\x20\x22%1\x22\x20Error!\x27);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20console.log(e);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20return\x200;\x0a\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20','textWidth','isActiveTpb','YPBJM','Game_BattlerBase_initMembers','AutoStretch','PDR','drawCharacter','fillText','DisplayedParams','KmbOp','onKeyDownKeysF6F7','startAutoNewGame','playCursor','isNextScene','Game_Actor_paramBase','_stored_mpGaugeColor1','YjNvh','mapId','Speed','YGlxF','updateLastTarget','rPvYp','up2','loadMapData','Sprite_Button_updateOpacity','altKey','WIN_ICO_CLEAR','%1〘Choice\x20%2〙\x20%3%1','VisuMZ_2_BattleSystemBTB','terms','resetFontSettings','paramPlus','startMove','ExportStrFromAllTroops','Rate2','asin','animationId','tilesets','Duration','IconXParam9','_coreEasingType','makeAutoBattleActions','NEAREST','xparamPlus2','getColorDataFromPluginParameters','AllMaps','parameters','_lastPluginCommandInterpreter','OpenSpeed','SParamVocab4','actorWindowRect','PERCENT','drawGoldItemStyle','BiHrF','deWjN','htxph','PictureFilename','buttonAssistOffset4','sZGwA','TextCodeNicknames','〘Show\x20Text〙\x0a','updatePositionCoreEngineShakeRand','TAB','process_VisuMZ_CoreEngine_jsQuickFunctions','Xyyzv','SParamVocab8','Scene_Base_terminateAnimationClearBugFix','setAnchor','tpGaugeColor1','connected','HYPHEN_MINUS','_cache','skipBranch','Window_Selectable_processCursorMove','integer','left','blRJM','NHZWb','levelUp','VOLUME_UP','_fauxAnimationSprites','drawActorNickname','vJdEC','UTWnc','RQVlp','queqh','getLevel','sparamPlus1','KeyItemProtect','Window_NameInput_cursorPageup','skillId','KEEP','FhhGa','SideButtons','_centerElement','isPhysical','loadTitle1','pointX','SCALE_MODES','scaleMode','processDigitChange','_context','applyForcedGameTroopSettingsCoreEngine','allowShiftScrolling','Bitmap_initialize','ARRAYNUM','gxBih','GjTrD','addCommand','processKeyboardDigitChange','start','ConvertNumberToString','Bitmap_clearRect','resize','PixelateImageRendering','AGI','repeat','paramX','powerDownColor','XParamVocab8','enableDigitGroupingEx','PictureID','_backSprite2','img/%1/','numberShowButton','Export\x20Map\x20Text\x20operation\x20will\x20finish\x20in\x20%1\x20ms(s)','XParamVocab2','MAXMP','createPointAnimationTargets','updatePictureAntiZoom','item','WSXhW','SwitchRandomizeOne','ExtractStrFromTroop','ColorPowerDown','mainAreaTopSideButtonLayout','makeInputButtonString','Scene_Shop_create','vRoTx','ADD','isDying','uiAreaHeight','drawItem','_digitGrouping','loadTitle2','useDigitGrouping','TJeBC','BACKSPACE','INEXPO','globalAlpha','ActorBgType','MaxUx','_height','traitObjects','fontSize','EGndI','onLoad','setActionState','bXtFV','《《《\x20Page\x20%1\x20》》》\x0a%2\x0a','_balloonQueue','F20','_statusParamsWindow','rightArrowWidth','cursorPagedown','skillTypes','INCIRC','endAnimation','top','_index','YqSxn','makeCoreEngineCommandList','drawActorSimpleStatus','TextManager_param','TGR','maxItems','ParseArmorNotetags','Spriteset_Base_update','easingType','_forcedTroopView','BACK_QUOTE','evade','%1〘Choice\x20Cancel〙%1','CreateBattleSystemID','backOpacity','TextCodeClassNames','pnczI','BgFilename1','isItem','CommandWidth','filterArea','lineHeight','alignBottom','F7key','parse','GET','Control\x20Variables\x20Script\x20Error','ParseEnemyNotetags','SParamVocab0','windowRect','NoTileShadows','ByawF','LUK','checkSmartEventCollision','CustomParamNames','isPressed','StatusMenu','ONoNM','UXGGo','_offsetY','hXIzH','setBackgroundOpacity','updateMainMultiply','Wait','OUTBACK','optionsWindowRect','refresh','opacity','ColorTPCost','original','_screenX','BaseTexture','send','Y:\x20%1','updatePointAnimations','Scene_Name_create','blendFunc','MDF','LmylF','LATIN1','storeMapData','waiting','adjustPictureAntiZoom','padding','Game_Picture_move','createSpriteset','tLkBm','XuYWs','buttonAssistText3','stencilFunc','PositionY','DetachMapPictureContainer','markCoreEngineModified','imageSmoothingEnabled','duration','OutlineColorDmg','Game_Picture_x','CrisisRate','Game_Temp_initialize','StatusRect','DimColor2','sceneTerminationClearEffects','_refreshBack','updateScene','_isWindow','textBaseline','GHfXQ','FunctionName','fXkce','SEMICOLON','canEquip','FontWidthFix','VisuMZ_2_BattleSystemETB','ASTERISK','applyEasing','5093SJLFSQ','XZacm','【%1】\x0a','EGODr','WIN_OEM_CUSEL','onXhrError','iconHeight','_target','_targetScaleX','yYuli','INELASTIC','ItemStyle','scale','hzcAF','setViewport','reduce','CNT','wtwVH','ParseStateNotetags','updateMotion','down2','setLastPluginCommandInterpreter','Layer','en-US','StatusParamsBgType','statusWindowRect','processAlwaysEscape','EncounterRateMinimum','xparamRate1','F23','Max','setup','IconParam1','pQojK','drawActorExpGauge','UpdatePictureCoordinates','setupFont','Bitmap_resize','setupButtonImage','》Comment《\x0a%1\x0a','BnWXX','%1:\x20Exit\x20','InputRect','Fxdtc','down','FotoT','background','measureText','createCancelButton','zDJoK','windowOpacity','createEnemies','Graphics','shift','_cancelButton','tVttM','tab','ColorMPGauge2','IconSParam6','isAnimationForEach','Origin','WOZqw','_effectsContainer','drawIcon','SystemSetWindowPadding','isAlive','_categoryWindow','isForFriend','setColorTone','Window_ShopSell_isEnabled','NUMPAD2','clearStencil','onEscapeSuccess','VaxtH','currentValue','processMoveCommand','OUTQUINT','LQJXY','_stored_crisisColor','WIN_OEM_FJ_MASSHOU','randomJS','Bitmap_fillRect','_stored_ctGaugeColor1','SideView','targetEvaRate','FINAL','%1\x20is\x20incorrectly\x20placed\x20on\x20the\x20plugin\x20list.\x0aIt\x20is\x20a\x20Tier\x20%2\x20plugin\x20placed\x20over\x20other\x20Tier\x20%3\x20plugins.\x0aPlease\x20reorder\x20the\x20plugin\x20list\x20from\x20smallest\x20to\x20largest\x20tier\x20numbers.','ZHHCK','_optionsWindow','STENCIL_TEST','gsnnN','innerHeight','horizontal','blMOV','faceHeight','ColorHPGauge1','XjoCG','helpAreaTop','DefaultMode','WIN_OEM_FJ_ROYA','FontSize','jsQuickFunc','removePointAnimation','deathColor','XUCVl','IconSParam2','OS_KEY','_shakeSpeed','_refreshPauseSign','mainAreaHeightSideButtonLayout','Scene_Boot_updateDocumentTitle','setSideButtonLayout','dFtmQ','yDQYW','ETuiq','FadeSpeed','removeFauxAnimation','StatusEquipRect','maxTp','updateAnchor','ExtDisplayedParams','NUMPAD1','mainAreaTop','36pmbBHu','F13','_gamepadWait','EquipMenu','UUAHm','YetZM','isOpen','_scaleY','CEV','DOUBLE_QUOTE','requestMotion','_viewportSize','createJsQuickFunction','EnableMasking','_commandWindow','_pollGamepads','ONE_MINUS_SRC_ALPHA','Type','Show\x20Scrolling\x20Text\x20Script\x20Error','mainFontSize','(\x5cd+\x5c.?\x5cd+)>','_pointAnimationQueue','makeFontBigger','dnFpJ','updatePositionCoreEngineShakeVert','terminate','Game_Interpreter_command111','areButtonsHidden','normal','KeyboardInput','encounterStepsMinimum','_statusEquipWindow','HIT','resetBattleSystem','_shakePower','setSideView','itemRect','pZTrZ','SlotRect','drawNewParam','MEV','ExtractStrFromList','MvAnimationRate','gold','_statusWindow','ZWpbJ','paramRate1','buttonAssistOk','ukTmz','otfqx','yZsMT','isFauxAnimationPlaying','faces','gainItem','abs','isSceneMap','WIN_OEM_COPY','_scaleX','initButtonHidden','valueOutlineColor','zrDQy','dIrBB','Graphics_defaultStretchMode','zaHFT','IconParam6','Game_Picture_initBasic','XParameterFormula','RepositionEnemies130','stop','fpVxp','retreat','destroyCoreEngineMarkedBitmaps','_inputWindow','ShopMenu','onKeyDown','Scene_Map_createMenuButton','DocumentTitleFmt','DBwVI','initialize','writeFile','setCoreEngineUpdateWindowBg','_tilemap','_drawTextBody','Plus','toUpperCase','updateOnceParallelInterpreters','isMenuButtonAssistEnabled','_upArrowSprite','isTouchedInsideFrame','ScreenResolution','isNumpadPressed','offsetY','isAnimationPlaying','WASD','win32','_smooth','addOnceParallelInterpreter','sparamRate','animationBaseDelay','Cxddq','needsUpdate','maxGold','isSideButtonLayout','Input_setupEventHandlers','_menuButton','%1〘End\x20Choice\x20Selection〙%1','Scene_Boot_loadSystemImages','moveCancelButtonSideButtonLayout','registerCommand','EISU','EmqSv','updateDashToggle','requestPointAnimation','processTouch','KeyTAB','processKeyboardDelete','PorrG','_baseSprite','_profileWindow','SystemSetSideView','SInIe','maxLevel','removeAllPointAnimations'];_0x2505=function(){return _0x1c99ff;};return _0x2505();}(VisuMZ['CoreEngine'][_0x54167d(0x331)][_0x54167d(0x2e9)][_0x54167d(0x48b)]??!![])&&($scene=null,VisuMZ[_0x54167d(0x940)][_0x54167d(0x2e1)]=Scene_Base['prototype'][_0x54167d(0x66b)],Scene_Base['prototype'][_0x54167d(0x66b)]=function(){const _0x46767d=_0x54167d;VisuMZ[_0x46767d(0x940)][_0x46767d(0x2e1)][_0x46767d(0x204)](this),$scene=this;},$spriteset=null,VisuMZ['CoreEngine']['Scene_Map_createSpriteset']=Scene_Map[_0x54167d(0x4ec)]['createSpriteset'],Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x7f0)]=function(){const _0x256097=_0x54167d;VisuMZ[_0x256097(0x940)][_0x256097(0x61e)][_0x256097(0x204)](this),$spriteset=this[_0x256097(0x6ae)];},VisuMZ['CoreEngine'][_0x54167d(0x273)]=Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x7f0)],Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x7f0)]=function(){const _0x1e6052=_0x54167d;VisuMZ[_0x1e6052(0x940)][_0x1e6052(0x273)]['call'](this),$spriteset=this[_0x1e6052(0x6ae)];},VisuMZ['CoreEngine']['Scene_Base_terminate']=Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x8a2)],Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x8a2)]=function(){const _0x168762=_0x54167d;VisuMZ[_0x168762(0x940)][_0x168762(0x3f9)][_0x168762(0x204)](this),$spriteset=null,$subject=null,$targets=null,$target=null;},$subject=null,$targets=null,$target=null,VisuMZ[_0x54167d(0x940)][_0x54167d(0x632)]=BattleManager['update'],BattleManager[_0x54167d(0x3b5)]=function(_0x13d3c7){const _0x22229f=_0x54167d;VisuMZ[_0x22229f(0x940)][_0x22229f(0x632)][_0x22229f(0x204)](this,_0x13d3c7),$subject=this[_0x22229f(0x3f4)],$targets=this[_0x22229f(0x309)],$target=this[_0x22229f(0x815)]||this[_0x22229f(0x309)][0x0];},$event=null,VisuMZ[_0x54167d(0x940)]['Game_Event_start']=Game_Event[_0x54167d(0x4ec)][_0x54167d(0x773)],Game_Event[_0x54167d(0x4ec)][_0x54167d(0x773)]=function(){const _0x26b545=_0x54167d;VisuMZ[_0x26b545(0x940)]['Game_Event_start'][_0x26b545(0x204)](this),$event=this;},VisuMZ['CoreEngine'][_0x54167d(0x920)]=Scene_Map[_0x54167d(0x4ec)]['update'],Scene_Map[_0x54167d(0x4ec)]['update']=function(){const _0x2d4dcc=_0x54167d;VisuMZ[_0x2d4dcc(0x940)][_0x2d4dcc(0x920)][_0x2d4dcc(0x204)](this),$gameMap[_0x2d4dcc(0x6a3)]();},Game_Map[_0x54167d(0x4ec)][_0x54167d(0x6a3)]=function(){const _0x4ac0c4=_0x54167d;!this[_0x4ac0c4(0x619)]()&&$event!==null&&($event=null);},$commonEvent=function(_0x3c70b9){if($gameTemp)$gameTemp['reserveCommonEvent'](_0x3c70b9);},$onceParallel=function(_0x1ae8c5){const _0x4056b8=_0x54167d;if(SceneManager['isSceneMap']())$scene['playOnceParallelInterpreter'](_0x1ae8c5);else{if(SceneManager[_0x4056b8(0x94d)]()){if(Imported['VisuMZ_1_BattleCore'])$scene[_0x4056b8(0x5fe)](_0x1ae8c5);else $gameTemp&&$gameTemp[_0x4056b8(0x562)]()&&alert('Once\x20Parallel\x20for\x20Battle\x20requires\x20VisuMZ_1_BattleCore!');}else $gameTemp&&$gameTemp[_0x4056b8(0x562)]()&&('nQGZX'!==_0x4056b8(0x295)?alert(_0x4056b8(0x4cd)):_0x55a261[_0x4056b8(0x9bb)](_0xa4773c,_0x250f7b));}});function _0x4d17(_0xa4214b,_0x18f1db){const _0x250546=_0x2505();return _0x4d17=function(_0x4d17b5,_0x4dfc44){_0x4d17b5=_0x4d17b5-0x1f1;let _0x4dc7cb=_0x250546[_0x4d17b5];return _0x4dc7cb;},_0x4d17(_0xa4214b,_0x18f1db);};StorageManager['jsonToZip']=function(_0x1c906d){return new Promise((_0x19a961,_0x26ea84)=>{const _0x216770=_0x4d17;if('qdfZo'!==_0x216770(0x4f2))try{if(_0x216770(0x3be)===_0x216770(0x788)){_0x22544a&&_0x141811&&_0x579c31['note']&&this['parseForcedGameTroopSettingsCoreEngine'](_0x306a49[_0x216770(0x31a)]);const _0x5a2421=_0x12211d[_0x43c123];if(_0x5a2421){let _0x273272=_0x4f01e9['createTroopNote'](_0x5a2421['id']);this[_0x216770(0x58a)](_0x273272);}}else{const _0x41fdd1=pako['deflate'](_0x1c906d,{'to':_0x216770(0x510),'level':0x1});if(_0x41fdd1[_0x216770(0x95b)]>=0xc350){}_0x19a961(_0x41fdd1);}}catch(_0x3fb0c8){_0x26ea84(_0x3fb0c8);}else return this['enemy']()['level'];});},TextManager['stringKeyMap']=['','','',_0x54167d(0x6b5),'','',_0x54167d(0x26a),'',_0x54167d(0x798),_0x54167d(0x743),'','',_0x54167d(0x92a),_0x54167d(0x205),'ENTER_SPECIAL','',_0x54167d(0x243),'CTRL','ALT',_0x54167d(0x20c),'CAPSLOCK',_0x54167d(0x682),_0x54167d(0x8f6),_0x54167d(0x33f),_0x54167d(0x863),_0x54167d(0x35a),'',_0x54167d(0x62e),_0x54167d(0x361),_0x54167d(0x9c9),_0x54167d(0x418),_0x54167d(0x9ce),_0x54167d(0x3cd),'PGUP',_0x54167d(0x597),_0x54167d(0x27c),_0x54167d(0x41b),_0x54167d(0x336),'UP',_0x54167d(0x56a),'DOWN',_0x54167d(0x35f),_0x54167d(0x3a9),_0x54167d(0x4c2),_0x54167d(0x427),_0x54167d(0x4f9),_0x54167d(0x618),'','0','1','2','3','4','5','6','7','8','9',_0x54167d(0x98a),_0x54167d(0x808),_0x54167d(0x39c),_0x54167d(0x442),_0x54167d(0x28f),_0x54167d(0x6c3),'AT','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z',_0x54167d(0x878),'',_0x54167d(0x1fc),'','SLEEP',_0x54167d(0x9b8),_0x54167d(0x887),_0x54167d(0x854),_0x54167d(0x634),_0x54167d(0x223),_0x54167d(0x5b4),_0x54167d(0x92d),_0x54167d(0x4df),_0x54167d(0x938),'NUMPAD9',_0x54167d(0x59a),_0x54167d(0x790),'SEPARATOR','SUBTRACT',_0x54167d(0x984),_0x54167d(0x957),'F1','F2','F3','F4','F5','F6','F7','F8','F9','F10',_0x54167d(0x306),'F12',_0x54167d(0x88a),'F14','F15',_0x54167d(0x6da),_0x54167d(0x981),'F18',_0x54167d(0x689),_0x54167d(0x7a6),_0x54167d(0x4d6),_0x54167d(0x224),_0x54167d(0x82b),_0x54167d(0x5e4),'','','','','','','','',_0x54167d(0x4cc),'SCROLL_LOCK',_0x54167d(0x367),_0x54167d(0x85d),_0x54167d(0x33d),_0x54167d(0x3c2),_0x54167d(0x871),'','','','','','','','','',_0x54167d(0x46d),_0x54167d(0x210),_0x54167d(0x892),_0x54167d(0x435),'DOLLAR',_0x54167d(0x738),'AMPERSAND',_0x54167d(0x5e1),_0x54167d(0x9f7),'CLOSE_PAREN',_0x54167d(0x80c),'PLUS',_0x54167d(0x2c0),_0x54167d(0x74b),_0x54167d(0x91c),_0x54167d(0x5d4),'TILDE','','','','',_0x54167d(0x655),_0x54167d(0x9f8),_0x54167d(0x754),'','',_0x54167d(0x808),'EQUALS',_0x54167d(0x55f),'MINUS',_0x54167d(0x612),_0x54167d(0x548),_0x54167d(0x7b9),'','','','','','','','','','','','','','','','','','','','','','','','','','',_0x54167d(0x518),_0x54167d(0x906),_0x54167d(0x317),_0x54167d(0x9da),'','META',_0x54167d(0x2a1),'',_0x54167d(0x613),_0x54167d(0x96b),'',_0x54167d(0x71f),'','',_0x54167d(0x546),_0x54167d(0x97e),_0x54167d(0x62a),'WIN_OEM_PA2',_0x54167d(0x9ff),_0x54167d(0x974),_0x54167d(0x812),'WIN_OEM_ATTN',_0x54167d(0x36b),_0x54167d(0x8c1),_0x54167d(0x252),_0x54167d(0x425),_0x54167d(0x359),'ATTN',_0x54167d(0x697),_0x54167d(0x630),_0x54167d(0x271),_0x54167d(0x40a),_0x54167d(0x63b),'','PA1','WIN_OEM_CLEAR',''],TextManager[_0x54167d(0x8b8)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)]['ButtonAssist']['OkText'],TextManager[_0x54167d(0x644)]=VisuMZ['CoreEngine'][_0x54167d(0x331)]['ButtonAssist'][_0x54167d(0x310)],TextManager['buttonAssistSwitch']=VisuMZ['CoreEngine'][_0x54167d(0x331)][_0x54167d(0x464)][_0x54167d(0x354)],VisuMZ[_0x54167d(0x940)][_0x54167d(0x7b2)]=TextManager[_0x54167d(0x594)],TextManager[_0x54167d(0x594)]=function(_0x45d392){const _0x52f380=_0x54167d;return typeof _0x45d392===_0x52f380(0x3d9)?VisuMZ[_0x52f380(0x940)]['TextManager_param'][_0x52f380(0x204)](this,_0x45d392):_0x52f380(0x9dc)!=='KPXUP'?_0x2207df[_0x52f380(0x556)][_0x52f380(0x692)][_0x52f380(0x204)](this):this[_0x52f380(0x247)](_0x45d392);},TextManager[_0x54167d(0x247)]=function(_0x499f1e){const _0x91bfc0=_0x54167d;_0x499f1e=String(_0x499f1e||'')[_0x91bfc0(0x8dd)]();const _0x175930=VisuMZ['CoreEngine'][_0x91bfc0(0x331)][_0x91bfc0(0x3fa)];if(_0x499f1e===_0x91bfc0(0x578))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x0];if(_0x499f1e===_0x91bfc0(0x784))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x1];if(_0x499f1e===_0x91bfc0(0x6ea))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x2];if(_0x499f1e===_0x91bfc0(0x3ce))return $dataSystem['terms']['params'][0x3];if(_0x499f1e==='MAT')return $dataSystem[_0x91bfc0(0x722)]['params'][0x4];if(_0x499f1e===_0x91bfc0(0x7e8))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x5];if(_0x499f1e===_0x91bfc0(0x778))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x6];if(_0x499f1e===_0x91bfc0(0x7cf))return $dataSystem[_0x91bfc0(0x722)][_0x91bfc0(0x9b7)][0x7];if(_0x499f1e==='HIT')return _0x175930[_0x91bfc0(0xa04)];if(_0x499f1e===_0x91bfc0(0x2d9))return _0x175930[_0x91bfc0(0x449)];if(_0x499f1e===_0x91bfc0(0x6e8))return _0x175930[_0x91bfc0(0x783)];if(_0x499f1e==='CEV')return _0x175930[_0x91bfc0(0x3bc)];if(_0x499f1e===_0x91bfc0(0x8b1))return _0x175930[_0x91bfc0(0x2a3)];if(_0x499f1e==='MRF')return _0x175930['XParamVocab5'];if(_0x499f1e===_0x91bfc0(0x81e))return _0x175930[_0x91bfc0(0x985)];if(_0x499f1e==='HRG')return _0x175930[_0x91bfc0(0x535)];if(_0x499f1e===_0x91bfc0(0x9de))return _0x175930[_0x91bfc0(0x77c)];if(_0x499f1e===_0x91bfc0(0x627))return _0x175930[_0x91bfc0(0x461)];if(_0x499f1e===_0x91bfc0(0x7b3))return _0x175930[_0x91bfc0(0x7cb)];if(_0x499f1e===_0x91bfc0(0xa0d))return _0x175930[_0x91bfc0(0x417)];if(_0x499f1e===_0x91bfc0(0x3ab))return _0x175930['SParamVocab2'];if(_0x499f1e===_0x91bfc0(0x66d))return _0x175930['SParamVocab3'];if(_0x499f1e===_0x91bfc0(0x43f))return _0x175930['SParamVocab4'];if(_0x499f1e===_0x91bfc0(0x5c3))return _0x175930[_0x91bfc0(0x700)];if(_0x499f1e===_0x91bfc0(0x70a))return _0x175930['SParamVocab6'];if(_0x499f1e===_0x91bfc0(0x90d))return _0x175930[_0x91bfc0(0x60d)];if(_0x499f1e==='FDR')return _0x175930[_0x91bfc0(0x746)];if(_0x499f1e===_0x91bfc0(0x282))return _0x175930[_0x91bfc0(0x400)];if(VisuMZ[_0x91bfc0(0x940)][_0x91bfc0(0x7d1)][_0x499f1e])return VisuMZ[_0x91bfc0(0x940)][_0x91bfc0(0x7d1)][_0x499f1e];return'';},TextManager[_0x54167d(0x9fd)]=function(_0xd21d99){const _0x2348f7=_0x54167d;if(_0xd21d99===_0x2348f7(0x9a7))_0xd21d99='escape';let _0x231809=[];for(let _0x4489da in Input['keyMapper']){_0x4489da=Number(_0x4489da);if(_0x4489da>=0x60&&_0x4489da<=0x69)continue;if([0x12,0x20][_0x2348f7(0x9ef)](_0x4489da))continue;_0xd21d99===Input[_0x2348f7(0x21f)][_0x4489da]&&_0x231809['push'](_0x4489da);}for(let _0x256b0e=0x0;_0x256b0e<_0x231809['length'];_0x256b0e++){if(_0x2348f7(0x9c8)!==_0x2348f7(0x9c8)){if(!_0x38fed2['isPlaytest']())return;if(!_0x54053d[_0x2348f7(0x303)]())return;_0x14831f['_scene'][_0x2348f7(0x2bc)]=![],_0x59ea0e[_0x2348f7(0x940)]['ExportStrFromAllMaps']();}else _0x231809[_0x256b0e]=TextManager[_0x2348f7(0x2cb)][_0x231809[_0x256b0e]];}return this[_0x2348f7(0x78d)](_0x231809);},TextManager[_0x54167d(0x78d)]=function(_0x309647){const _0xb7b5f5=_0x54167d,_0x12418f=VisuMZ[_0xb7b5f5(0x940)][_0xb7b5f5(0x331)][_0xb7b5f5(0x464)],_0x3c9e9a=_0x12418f['KeyUnlisted'],_0x48fabd=_0x309647[_0xb7b5f5(0x333)](),_0x5c66e5='Key%1'['format'](_0x48fabd);return _0x12418f[_0x5c66e5]?_0x12418f[_0x5c66e5]:_0x3c9e9a[_0xb7b5f5(0x482)](_0x48fabd);},TextManager[_0x54167d(0x686)]=function(_0x2d9795,_0x1d9596){const _0x3e264e=_0x54167d,_0x3c401e=VisuMZ[_0x3e264e(0x940)][_0x3e264e(0x331)][_0x3e264e(0x464)],_0x275c2a=_0x3c401e[_0x3e264e(0x3e4)],_0x1a1bc9=this[_0x3e264e(0x9fd)](_0x2d9795),_0x5c881e=this[_0x3e264e(0x9fd)](_0x1d9596);return _0x275c2a[_0x3e264e(0x482)](_0x1a1bc9,_0x5c881e);},VisuMZ['CoreEngine'][_0x54167d(0x64d)]=ColorManager['loadWindowskin'],ColorManager['loadWindowskin']=function(){const _0xe8b6c9=_0x54167d;VisuMZ[_0xe8b6c9(0x940)][_0xe8b6c9(0x64d)][_0xe8b6c9(0x204)](this),this[_0xe8b6c9(0x961)]=this[_0xe8b6c9(0x961)]||{};},ColorManager[_0x54167d(0x731)]=function(_0x5ce7b9,_0x47ef59){const _0x448e4e=_0x54167d;return _0x47ef59=String(_0x47ef59),this[_0x448e4e(0x961)]=this['_colorCache']||{},_0x47ef59['match'](/#(.*)/i)?this[_0x448e4e(0x961)][_0x5ce7b9]='#%1'[_0x448e4e(0x482)](String(RegExp['$1'])):_0x448e4e(0x27f)===_0x448e4e(0x27f)?this[_0x448e4e(0x961)][_0x5ce7b9]=this['textColor'](Number(_0x47ef59)):_0x5e81aa('This\x20scene\x20cannot\x20utilize\x20a\x20Once\x20Parallel!'),this[_0x448e4e(0x961)][_0x5ce7b9];},ColorManager[_0x54167d(0x656)]=function(_0x3efaef){const _0x15fc4a=_0x54167d;return _0x3efaef=String(_0x3efaef),_0x3efaef[_0x15fc4a(0x59b)](/#(.*)/i)?_0x15fc4a(0x35e)[_0x15fc4a(0x482)](String(RegExp['$1'])):this[_0x15fc4a(0x423)](Number(_0x3efaef));},ColorManager[_0x54167d(0x5f2)]=function(){this['_colorCache']={};},ColorManager['normalColor']=function(){const _0x1c3702=_0x54167d,_0x2fd0ed=_0x1c3702(0x560);this[_0x1c3702(0x961)]=this[_0x1c3702(0x961)]||{};if(this[_0x1c3702(0x961)][_0x2fd0ed])return this[_0x1c3702(0x961)][_0x2fd0ed];const _0x2e6564=VisuMZ[_0x1c3702(0x940)][_0x1c3702(0x331)][_0x1c3702(0x530)]['ColorNormal'];return this[_0x1c3702(0x731)](_0x2fd0ed,_0x2e6564);},ColorManager['systemColor']=function(){const _0x5aec6a=_0x54167d,_0x46ec8a=_0x5aec6a(0x485);this[_0x5aec6a(0x961)]=this[_0x5aec6a(0x961)]||{};if(this[_0x5aec6a(0x961)][_0x46ec8a])return this[_0x5aec6a(0x961)][_0x46ec8a];const _0x5152f8=VisuMZ[_0x5aec6a(0x940)][_0x5aec6a(0x331)]['Color']['ColorSystem'];return this[_0x5aec6a(0x731)](_0x46ec8a,_0x5152f8);},ColorManager['crisisColor']=function(){const _0x5114bc=_0x54167d,_0x42265f=_0x5114bc(0x85c);this[_0x5114bc(0x961)]=this[_0x5114bc(0x961)]||{};if(this[_0x5114bc(0x961)][_0x42265f])return this[_0x5114bc(0x961)][_0x42265f];const _0x292fdc=VisuMZ['CoreEngine'][_0x5114bc(0x331)][_0x5114bc(0x530)]['ColorCrisis'];return this[_0x5114bc(0x731)](_0x42265f,_0x292fdc);},ColorManager[_0x54167d(0x875)]=function(){const _0x213e62=_0x54167d,_0x2fbdfa=_0x213e62(0x567);this[_0x213e62(0x961)]=this[_0x213e62(0x961)]||{};if(this[_0x213e62(0x961)][_0x2fbdfa])return this[_0x213e62(0x961)][_0x2fbdfa];const _0x557539=VisuMZ[_0x213e62(0x940)][_0x213e62(0x331)]['Color'][_0x213e62(0x3c4)];return this[_0x213e62(0x731)](_0x2fbdfa,_0x557539);},ColorManager['gaugeBackColor']=function(){const _0x5612ff=_0x54167d,_0x13549e=_0x5612ff(0x50b);this['_colorCache']=this[_0x5612ff(0x961)]||{};if(this[_0x5612ff(0x961)][_0x13549e])return this[_0x5612ff(0x961)][_0x13549e];const _0xa15e93=VisuMZ[_0x5612ff(0x940)][_0x5612ff(0x331)][_0x5612ff(0x530)][_0x5612ff(0x379)];return this['getColorDataFromPluginParameters'](_0x13549e,_0xa15e93);},ColorManager[_0x54167d(0x5be)]=function(){const _0x19b7e5=_0x54167d,_0x325a3b=_0x19b7e5(0x6df);this['_colorCache']=this[_0x19b7e5(0x961)]||{};if(this['_colorCache'][_0x325a3b])return this[_0x19b7e5(0x961)][_0x325a3b];const _0x28e009=VisuMZ['CoreEngine']['Settings'][_0x19b7e5(0x530)][_0x19b7e5(0x86d)];return this[_0x19b7e5(0x731)](_0x325a3b,_0x28e009);},ColorManager[_0x54167d(0x2ab)]=function(){const _0x231442=_0x54167d,_0x4f7d05=_0x231442(0x484);this['_colorCache']=this[_0x231442(0x961)]||{};if(this[_0x231442(0x961)][_0x4f7d05])return this[_0x231442(0x961)][_0x4f7d05];const _0xd9e62f=VisuMZ[_0x231442(0x940)][_0x231442(0x331)][_0x231442(0x530)][_0x231442(0x50a)];return this['getColorDataFromPluginParameters'](_0x4f7d05,_0xd9e62f);},ColorManager[_0x54167d(0x95f)]=function(){const _0x272f29=_0x54167d,_0x148373=_0x272f29(0x714);this[_0x272f29(0x961)]=this[_0x272f29(0x961)]||{};if(this[_0x272f29(0x961)][_0x148373])return this['_colorCache'][_0x148373];const _0x40aef7=VisuMZ[_0x272f29(0x940)][_0x272f29(0x331)][_0x272f29(0x530)]['ColorMPGauge1'];return this[_0x272f29(0x731)](_0x148373,_0x40aef7);},ColorManager[_0x54167d(0x96d)]=function(){const _0x99260a=_0x54167d,_0x51157f='_stored_mpGaugeColor2';this[_0x99260a(0x961)]=this[_0x99260a(0x961)]||{};if(this['_colorCache'][_0x51157f])return this['_colorCache'][_0x51157f];const _0x2b67b0=VisuMZ['CoreEngine']['Settings']['Color'][_0x99260a(0x847)];return this['getColorDataFromPluginParameters'](_0x51157f,_0x2b67b0);},ColorManager['mpCostColor']=function(){const _0xacc995=_0x54167d,_0x16d27a=_0xacc995(0x395);this['_colorCache']=this['_colorCache']||{};if(this[_0xacc995(0x961)][_0x16d27a])return this[_0xacc995(0x961)][_0x16d27a];const _0x211ae9=VisuMZ[_0xacc995(0x940)]['Settings'][_0xacc995(0x530)][_0xacc995(0x96a)];return this[_0xacc995(0x731)](_0x16d27a,_0x211ae9);},ColorManager[_0x54167d(0x5d5)]=function(){const _0x4d61b3=_0x54167d,_0x52ff54=_0x4d61b3(0x3c5);this['_colorCache']=this[_0x4d61b3(0x961)]||{};if(this['_colorCache'][_0x52ff54])return this[_0x4d61b3(0x961)][_0x52ff54];const _0x4de8a3=VisuMZ['CoreEngine']['Settings'][_0x4d61b3(0x530)][_0x4d61b3(0x5e6)];return this['getColorDataFromPluginParameters'](_0x52ff54,_0x4de8a3);},ColorManager[_0x54167d(0x77b)]=function(){const _0x54be6e=_0x54167d,_0x370178=_0x54be6e(0x909);this['_colorCache']=this['_colorCache']||{};if(this['_colorCache'][_0x370178])return this[_0x54be6e(0x961)][_0x370178];const _0x2a7db3=VisuMZ['CoreEngine'][_0x54be6e(0x331)]['Color'][_0x54be6e(0x78b)];return this[_0x54be6e(0x731)](_0x370178,_0x2a7db3);},ColorManager[_0x54167d(0x414)]=function(){const _0x1bca77=_0x54167d,_0xf1498d=_0x1bca77(0x860);this[_0x1bca77(0x961)]=this[_0x1bca77(0x961)]||{};if(this['_colorCache'][_0xf1498d])return this[_0x1bca77(0x961)][_0xf1498d];const _0x1b4bb5=VisuMZ['CoreEngine'][_0x1bca77(0x331)][_0x1bca77(0x530)][_0x1bca77(0x45d)];return this['getColorDataFromPluginParameters'](_0xf1498d,_0x1b4bb5);},ColorManager[_0x54167d(0x4d4)]=function(){const _0x19419f=_0x54167d,_0x4609c4='_stored_ctGaugeColor2';this[_0x19419f(0x961)]=this[_0x19419f(0x961)]||{};if(this[_0x19419f(0x961)][_0x4609c4])return this[_0x19419f(0x961)][_0x4609c4];const _0x325d0d=VisuMZ[_0x19419f(0x940)][_0x19419f(0x331)][_0x19419f(0x530)]['ColorCTGauge2'];return this['getColorDataFromPluginParameters'](_0x4609c4,_0x325d0d);},ColorManager[_0x54167d(0x749)]=function(){const _0x1575b7=_0x54167d,_0x59e5fb=_0x1575b7(0x959);this['_colorCache']=this[_0x1575b7(0x961)]||{};if(this[_0x1575b7(0x961)][_0x59e5fb])return this[_0x1575b7(0x961)][_0x59e5fb];const _0x4390c1=VisuMZ[_0x1575b7(0x940)][_0x1575b7(0x331)][_0x1575b7(0x530)][_0x1575b7(0x392)];return this[_0x1575b7(0x731)](_0x59e5fb,_0x4390c1);},ColorManager[_0x54167d(0x6ba)]=function(){const _0x3624fb=_0x54167d,_0x1cec54=_0x3624fb(0x32a);this[_0x3624fb(0x961)]=this['_colorCache']||{};if(this[_0x3624fb(0x961)][_0x1cec54])return this[_0x3624fb(0x961)][_0x1cec54];const _0x5aa55d=VisuMZ[_0x3624fb(0x940)][_0x3624fb(0x331)][_0x3624fb(0x530)][_0x3624fb(0x3ff)];return this['getColorDataFromPluginParameters'](_0x1cec54,_0x5aa55d);},ColorManager[_0x54167d(0x216)]=function(){const _0x459ce8=_0x54167d,_0x4cf1eb='_stored_tpCostColor';this[_0x459ce8(0x961)]=this['_colorCache']||{};if(this[_0x459ce8(0x961)][_0x4cf1eb])return this[_0x459ce8(0x961)][_0x4cf1eb];const _0x18383b=VisuMZ['CoreEngine'][_0x459ce8(0x331)][_0x459ce8(0x530)][_0x459ce8(0x7df)];return this['getColorDataFromPluginParameters'](_0x4cf1eb,_0x18383b);},ColorManager['pendingColor']=function(){const _0x432ddf=_0x54167d,_0x13257c=_0x432ddf(0x29d);this[_0x432ddf(0x961)]=this[_0x432ddf(0x961)]||{};if(this[_0x432ddf(0x961)][_0x13257c])return this[_0x432ddf(0x961)][_0x13257c];const _0x32068b=VisuMZ[_0x432ddf(0x940)][_0x432ddf(0x331)][_0x432ddf(0x530)][_0x432ddf(0x7df)];return this[_0x432ddf(0x731)](_0x13257c,_0x32068b);},ColorManager[_0x54167d(0x491)]=function(){const _0x27e254=_0x54167d,_0x9f8f73=_0x27e254(0x5ca);this[_0x27e254(0x961)]=this[_0x27e254(0x961)]||{};if(this[_0x27e254(0x961)][_0x9f8f73])return this[_0x27e254(0x961)][_0x9f8f73];const _0x16973b=VisuMZ[_0x27e254(0x940)][_0x27e254(0x331)][_0x27e254(0x530)][_0x27e254(0x30a)];return this[_0x27e254(0x731)](_0x9f8f73,_0x16973b);},ColorManager[_0x54167d(0x520)]=function(){const _0x480eb6=_0x54167d,_0x4b5d00=_0x480eb6(0xa0b);this[_0x480eb6(0x961)]=this[_0x480eb6(0x961)]||{};if(this[_0x480eb6(0x961)][_0x4b5d00])return this[_0x480eb6(0x961)][_0x4b5d00];const _0x586a5a=VisuMZ['CoreEngine'][_0x480eb6(0x331)]['Color']['ColorExpGauge2'];return this[_0x480eb6(0x731)](_0x4b5d00,_0x586a5a);},ColorManager[_0x54167d(0x6a7)]=function(){const _0x3f84e2=_0x54167d,_0x11f0e0=_0x3f84e2(0x3c8);this['_colorCache']=this[_0x3f84e2(0x961)]||{};if(this['_colorCache'][_0x11f0e0])return this[_0x3f84e2(0x961)][_0x11f0e0];const _0x2edc64=VisuMZ[_0x3f84e2(0x940)][_0x3f84e2(0x331)][_0x3f84e2(0x530)][_0x3f84e2(0x30b)];return this[_0x3f84e2(0x731)](_0x11f0e0,_0x2edc64);},ColorManager['maxLvGaugeColor2']=function(){const _0x1c6433=_0x54167d,_0xe07ec8=_0x1c6433(0x5b1);this[_0x1c6433(0x961)]=this['_colorCache']||{};if(this[_0x1c6433(0x961)][_0xe07ec8])return this['_colorCache'][_0xe07ec8];const _0x2d94c5=VisuMZ['CoreEngine'][_0x1c6433(0x331)][_0x1c6433(0x530)]['ColorMaxLvGauge2'];return this[_0x1c6433(0x731)](_0xe07ec8,_0x2d94c5);},ColorManager[_0x54167d(0x4d8)]=function(_0x5e1009){const _0x4c0120=_0x54167d;return VisuMZ[_0x4c0120(0x940)]['Settings'][_0x4c0120(0x530)]['ActorHPColor'][_0x4c0120(0x204)](this,_0x5e1009);},ColorManager['mpColor']=function(_0x4322fc){const _0x21d1f0=_0x54167d;return VisuMZ[_0x21d1f0(0x940)][_0x21d1f0(0x331)]['Color'][_0x21d1f0(0x26f)][_0x21d1f0(0x204)](this,_0x4322fc);},ColorManager[_0x54167d(0x313)]=function(_0x11499c){const _0x5c84a1=_0x54167d;return VisuMZ[_0x5c84a1(0x940)]['Settings'][_0x5c84a1(0x530)][_0x5c84a1(0x506)][_0x5c84a1(0x204)](this,_0x11499c);},ColorManager[_0x54167d(0x661)]=function(_0x2840e3){const _0x115504=_0x54167d;return VisuMZ[_0x115504(0x940)]['Settings']['Color']['ParamChange'][_0x115504(0x204)](this,_0x2840e3);},ColorManager[_0x54167d(0x2db)]=function(_0x5b5019){const _0x399b12=_0x54167d;return VisuMZ[_0x399b12(0x940)][_0x399b12(0x331)][_0x399b12(0x530)]['DamageColor'][_0x399b12(0x204)](this,_0x5b5019);},ColorManager[_0x54167d(0x431)]=function(){const _0x57a778=_0x54167d;return VisuMZ['CoreEngine'][_0x57a778(0x331)][_0x57a778(0x530)][_0x57a778(0x2f7)];},ColorManager[_0x54167d(0x403)]=function(){const _0x3959c1=_0x54167d;return VisuMZ['CoreEngine'][_0x3959c1(0x331)]['Color']['OutlineColorDmg']||_0x3959c1(0x290);},ColorManager[_0x54167d(0x249)]=function(){const _0x45ad87=_0x54167d;return VisuMZ['CoreEngine'][_0x45ad87(0x331)][_0x45ad87(0x530)][_0x45ad87(0x34f)]||_0x45ad87(0x3c3);},ColorManager[_0x54167d(0x2f2)]=function(){const _0xb8b4c6=_0x54167d;return VisuMZ[_0xb8b4c6(0x940)][_0xb8b4c6(0x331)]['Color'][_0xb8b4c6(0x972)];},ColorManager['dimColor2']=function(){const _0x183a2d=_0x54167d;return VisuMZ[_0x183a2d(0x940)][_0x183a2d(0x331)][_0x183a2d(0x530)][_0x183a2d(0x7ff)];},ColorManager['itemBackColor1']=function(){const _0x1ef015=_0x54167d;return VisuMZ['CoreEngine']['Settings']['Color'][_0x1ef015(0x5d7)];},ColorManager[_0x54167d(0x48f)]=function(){const _0x4dbdbf=_0x54167d;return VisuMZ['CoreEngine'][_0x4dbdbf(0x331)][_0x4dbdbf(0x530)]['ItemBackColor2'];},SceneManager[_0x54167d(0x256)]=[],SceneManager[_0x54167d(0x94d)]=function(){const _0x3d15fb=_0x54167d;return this[_0x3d15fb(0x4ce)]&&this[_0x3d15fb(0x4ce)][_0x3d15fb(0x4a9)]===Scene_Battle;},SceneManager[_0x54167d(0x8c0)]=function(){const _0x8051bd=_0x54167d;return this[_0x8051bd(0x4ce)]&&this[_0x8051bd(0x4ce)][_0x8051bd(0x4a9)]===Scene_Map;},SceneManager[_0x54167d(0x9fe)]=function(){const _0xe0b53f=_0x54167d;return this[_0xe0b53f(0x4ce)]&&this[_0xe0b53f(0x4ce)]instanceof Scene_Map;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x59c)]=SceneManager[_0x54167d(0x8d7)],SceneManager[_0x54167d(0x8d7)]=function(){const _0xbda408=_0x54167d;VisuMZ[_0xbda408(0x940)][_0xbda408(0x59c)][_0xbda408(0x204)](this),this[_0xbda408(0x58d)]();},VisuMZ['CoreEngine'][_0x54167d(0x218)]=SceneManager['onKeyDown'],SceneManager[_0x54167d(0x8d3)]=function(_0x53d026){const _0x28b1b0=_0x54167d;if($gameTemp)this[_0x28b1b0(0x70f)](_0x53d026);VisuMZ[_0x28b1b0(0x940)]['SceneManager_onKeyDown']['call'](this,_0x53d026);},SceneManager[_0x54167d(0x70f)]=function(_0x51d92b){const _0x2d2a0b=_0x54167d;if(!_0x51d92b[_0x2d2a0b(0x3b7)]&&!_0x51d92b[_0x2d2a0b(0x71e)])switch(_0x51d92b[_0x2d2a0b(0x6e5)]){case 0x54:this['playTestCtrlT']();break;case 0x75:this[_0x2d2a0b(0x6d5)]();break;case 0x76:if(Input[_0x2d2a0b(0x7d2)](_0x2d2a0b(0x843))||Input[_0x2d2a0b(0x7d2)]('ctrl'))return;this['playTestF7']();break;}},SceneManager[_0x54167d(0x6d5)]=function(){const _0x59be71=_0x54167d;if($gameTemp[_0x59be71(0x562)]()&&VisuMZ[_0x59be71(0x940)][_0x59be71(0x331)][_0x59be71(0x2e9)][_0x59be71(0x2a6)]){ConfigManager[_0x59be71(0x9e9)]!==0x0?(ConfigManager[_0x59be71(0x2fe)]=0x0,ConfigManager[_0x59be71(0x9fa)]=0x0,ConfigManager['meVolume']=0x0,ConfigManager['seVolume']=0x0):(ConfigManager['bgmVolume']=0x64,ConfigManager[_0x59be71(0x9fa)]=0x64,ConfigManager[_0x59be71(0x2f1)]=0x64,ConfigManager['seVolume']=0x64);ConfigManager[_0x59be71(0x300)]();if(this[_0x59be71(0x4ce)][_0x59be71(0x4a9)]===Scene_Options){if(_0x59be71(0x5b5)==='nMUpV'){if(_0x3bf4e8)_0x26b8ca['ParseWeaponNotetags'](_0x3d55af);}else{if(this[_0x59be71(0x4ce)][_0x59be71(0x866)])this[_0x59be71(0x4ce)]['_optionsWindow'][_0x59be71(0x7dd)]();if(this[_0x59be71(0x4ce)][_0x59be71(0x45c)])this['_scene'][_0x59be71(0x45c)]['refresh']();}}}},SceneManager[_0x54167d(0x453)]=function(){const _0x1d19d7=_0x54167d;$gameTemp['isPlaytest']()&&VisuMZ[_0x1d19d7(0x940)][_0x1d19d7(0x331)][_0x1d19d7(0x2e9)][_0x1d19d7(0x7c6)]&&($gameTemp['_playTestFastMode']=!$gameTemp[_0x1d19d7(0x542)]);},SceneManager[_0x54167d(0x2b3)]=function(){const _0x4d1bce=_0x54167d;if(!$gameTemp[_0x4d1bce(0x562)]())return;if(!SceneManager[_0x4d1bce(0x94d)]())return;for(const _0x13ff7b of $gameParty[_0x4d1bce(0x451)]()){if(!_0x13ff7b)continue;_0x13ff7b[_0x4d1bce(0x27b)](_0x13ff7b[_0x4d1bce(0x884)]());}},SceneManager[_0x54167d(0x58d)]=function(){const _0x304201=_0x54167d;this[_0x304201(0x4c0)]=![],this[_0x304201(0x1ff)]=!VisuMZ[_0x304201(0x940)]['Settings']['UI'][_0x304201(0x28a)];},SceneManager[_0x54167d(0x87d)]=function(_0x399041){const _0x159f5b=_0x54167d;VisuMZ[_0x159f5b(0x940)][_0x159f5b(0x331)]['UI']['SideButtons']&&(this[_0x159f5b(0x4c0)]=_0x399041);},SceneManager[_0x54167d(0x8ef)]=function(){const _0x51dc95=_0x54167d;return this[_0x51dc95(0x4c0)];},SceneManager[_0x54167d(0x8a4)]=function(){const _0x5ad746=_0x54167d;return this[_0x5ad746(0x1ff)];},SceneManager[_0x54167d(0x3b4)]=function(){const _0x42a46b=_0x54167d;return this['areButtonsHidden']()||this[_0x42a46b(0x8ef)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5bb)]=SceneManager[_0x54167d(0x2f5)],SceneManager[_0x54167d(0x2f5)]=function(){const _0x8e48c7=_0x54167d;return VisuMZ[_0x8e48c7(0x940)][_0x8e48c7(0x331)]['QoL']['RequireFocus']?VisuMZ[_0x8e48c7(0x940)][_0x8e48c7(0x5bb)][_0x8e48c7(0x204)](this):'uHlLE'==='uHlLE'?!![]:0x1;},SceneManager[_0x54167d(0x3df)]=function(_0xc1e5ca){const _0x42b864=_0x54167d;if(_0xc1e5ca instanceof Error)_0x42b864(0x9ac)!==_0x42b864(0x550)?this['catchNormalError'](_0xc1e5ca):this[_0x42b864(0x433)](0x0);else{if(_0xc1e5ca instanceof Array&&_0xc1e5ca[0x0]==='LoadError'){if(_0x42b864(0x6fd)!==_0x42b864(0x6fd))return _0x234717[_0x42b864(0x940)]['CustomParamNames'][_0x1be010];else this[_0x42b864(0x96e)](_0xc1e5ca);}else this['catchUnknownError'](_0xc1e5ca);}this[_0x42b864(0x8cd)]();},VisuMZ['CoreEngine'][_0x54167d(0x5f3)]=BattleManager[_0x54167d(0x6c5)],BattleManager[_0x54167d(0x6c5)]=function(){const _0x1446a2=_0x54167d;if(VisuMZ[_0x1446a2(0x940)][_0x1446a2(0x331)][_0x1446a2(0x2e9)][_0x1446a2(0x62d)]){if(_0x1446a2(0x817)===_0x1446a2(0x817))this[_0x1446a2(0x828)]();else return 0x0;}else return VisuMZ[_0x1446a2(0x940)][_0x1446a2(0x5f3)]['call'](this);},BattleManager[_0x54167d(0x828)]=function(){const _0x5c5564=_0x54167d;return $gameParty[_0x5c5564(0x3f1)](),SoundManager[_0x5c5564(0x31f)](),this[_0x5c5564(0x856)](),!![];},BattleManager[_0x54167d(0x9fb)]=function(){const _0x390f61=_0x54167d;return $gameSystem[_0x390f61(0x9bc)]()>=0x1;},BattleManager[_0x54167d(0x706)]=function(){const _0x2c53d9=_0x54167d;return $gameSystem[_0x2c53d9(0x9bc)]()===0x1;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x7fd)]=Game_Temp['prototype'][_0x54167d(0x8d7)],Game_Temp['prototype']['initialize']=function(){const _0x191997=_0x54167d;VisuMZ[_0x191997(0x940)][_0x191997(0x7fd)]['call'](this),this[_0x191997(0x289)](),this['createFauxAnimationQueue'](),this[_0x191997(0x5eb)]();},Game_Temp['prototype'][_0x54167d(0x289)]=function(){const _0x592682=_0x54167d;VisuMZ[_0x592682(0x940)][_0x592682(0x331)]['QoL'][_0x592682(0x1f2)]&&(this[_0x592682(0x5f9)]=![]);},Game_Temp[_0x54167d(0x4ec)]['setLastPluginCommandInterpreter']=function(_0x20da50){const _0xb5507b=_0x54167d;this[_0xb5507b(0x734)]=_0x20da50;},Game_Temp['prototype'][_0x54167d(0x2ca)]=function(){const _0xc78194=_0x54167d;return this[_0xc78194(0x734)];},Game_Temp['prototype'][_0x54167d(0x3d6)]=function(){const _0x3981b5=_0x54167d;this[_0x3981b5(0x7b8)]=undefined,this['_forcedBattleSys']=undefined;},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x76b)]=function(_0x2a6e5a){const _0x3a2c2f=_0x54167d;$gameMap&&$dataMap&&$dataMap[_0x3a2c2f(0x31a)]&&this['parseForcedGameTroopSettingsCoreEngine']($dataMap[_0x3a2c2f(0x31a)]);const _0xf89f82=$dataTroops[_0x2a6e5a];if(_0xf89f82){if(_0x3a2c2f(0x78f)!==_0x3a2c2f(0x880)){let _0x545207=DataManager[_0x3a2c2f(0x910)](_0xf89f82['id']);this[_0x3a2c2f(0x58a)](_0x545207);}else{const _0x15e896=_0x53dcec[_0x19e6bd];_0x15e896[_0x3a2c2f(0x614)][_0x3a2c2f(0x59b)](/(.*)\/(.*)/i)&&(_0x15e896[_0x3a2c2f(0x614)]=_0x4ac54c(_0x479f7a['$2']['trim']()));}}},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x58a)]=function(_0x458665){const _0x3e2a4e=_0x54167d;if(!_0x458665)return;if(_0x458665[_0x3e2a4e(0x59b)](/<(?:FRONTVIEW|FRONT VIEW|FV)>/i))this['_forcedTroopView']='FV';else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:SIDEVIEW|SIDE VIEW|SV)>/i))this[_0x3e2a4e(0x7b8)]='SV';else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:BATTLEVIEW|BATTLE VIEW):[ ](.*)>/i)){const _0x2ebde=String(RegExp['$1']);if(_0x2ebde[_0x3e2a4e(0x59b)](/(?:FRONTVIEW|FRONT VIEW|FV)/i))_0x3e2a4e(0x758)!==_0x3e2a4e(0x4a3)?this[_0x3e2a4e(0x7b8)]='FV':_0x33cf44['prototype'][_0x3e2a4e(0x430)][_0x3e2a4e(0x204)](this);else{if(_0x2ebde[_0x3e2a4e(0x59b)](/(?:SIDEVIEW|SIDE VIEW|SV)/i)){if('pMPKH'===_0x3e2a4e(0x52a))return _0x56cbe5['layoutSettings']['StatusRect'][_0x3e2a4e(0x204)](this);else this[_0x3e2a4e(0x7b8)]='SV';}}}}}if(_0x458665[_0x3e2a4e(0x59b)](/<(?:DTB)>/i))this[_0x3e2a4e(0x698)]=0x0;else{if(_0x458665['match'](/<(?:TPB|ATB)[ ]ACTIVE>/i))this[_0x3e2a4e(0x698)]=0x1;else{if(_0x458665['match'](/<(?:TPB|ATB)[ ]WAIT>/i))this[_0x3e2a4e(0x698)]=0x2;else{if(_0x458665['match'](/<(?:CTB)>/i))'jVEiE'===_0x3e2a4e(0x3ec)?Imported[_0x3e2a4e(0x285)]&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x9f3)):this['setViewportCoreEngineFix'](_0xae1a42);else{if(_0x458665['match'](/<(?:STB)>/i))Imported[_0x3e2a4e(0x448)]&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x470));else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:BTB)>/i)){if(_0x3e2a4e(0x7d4)!==_0x3e2a4e(0x7d4))return _0x53bfc7['CoreEngine'][_0x3e2a4e(0x331)][_0x3e2a4e(0x529)][_0x3e2a4e(0x3a7)][_0x3e2a4e(0x41a)][_0x3e2a4e(0x204)](this);else Imported[_0x3e2a4e(0x721)]&&(_0x3e2a4e(0x99b)!==_0x3e2a4e(0x99b)?(_0x2aa038['CoreEngine'][_0x3e2a4e(0x90f)][_0x3e2a4e(0x204)](this),this[_0x3e2a4e(0x8d9)]()):this['_forcedBattleSys']=_0x3e2a4e(0x9aa));}else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:FTB)>/i)){if(_0x3e2a4e(0x639)===_0x3e2a4e(0x639))Imported[_0x3e2a4e(0x4e7)]&&(this['_forcedBattleSys']=_0x3e2a4e(0x39a));else return _0x2a5746[_0x3e2a4e(0x556)][_0x3e2a4e(0x68d)][_0x3e2a4e(0x204)](this);}else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:OTB)>/i))Imported[_0x3e2a4e(0x296)]&&(this['_forcedBattleSys']='OTB');else{if(_0x458665[_0x3e2a4e(0x59b)](/<(?:ETB)>/i)){if(Imported['VisuMZ_2_BattleSystemETB']){if(_0x3e2a4e(0x57e)!==_0x3e2a4e(0x45e))this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x965);else{const _0x5da744=_0x3e2a4e(0x5b1);this['_colorCache']=this[_0x3e2a4e(0x961)]||{};if(this[_0x3e2a4e(0x961)][_0x5da744])return this['_colorCache'][_0x5da744];const _0x2c2599=_0x3483de['CoreEngine']['Settings'][_0x3e2a4e(0x530)][_0x3e2a4e(0x68e)];return this[_0x3e2a4e(0x731)](_0x5da744,_0x2c2599);}}}else{if(_0x458665['match'](/<(?:PTB)>/i))'lCdja'===_0x3e2a4e(0x994)?_0x9f357e[_0x3e2a4e(0x4e7)]&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x39a)):Imported[_0x3e2a4e(0x3fd)]&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x92c));else{if(_0x458665['match'](/<(?:BATTLEVIEW|BATTLE VIEW):[ ](.*)>/i)){const _0x3ceaba=String(RegExp['$1']);if(_0x3ceaba['match'](/DTB/i))_0x3e2a4e(0x56c)==='evrfa'?this['playCursorSound']():this['_forcedBattleSys']=0x0;else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/(?:TPB|ATB)[ ]ACTIVE/i))this[_0x3e2a4e(0x698)]=0x1;else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/(?:TPB|ATB)[ ]WAIT/i))this[_0x3e2a4e(0x698)]=0x2;else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/CTB/i)){if(_0x3e2a4e(0x4fb)!==_0x3e2a4e(0x4fb)){if(_0x259513[_0x3e2a4e(0x698)]!==_0x30a919)return _0x598391[_0x3e2a4e(0x698)];if(this[_0x3e2a4e(0x6af)]===_0x40d426)this['initCoreEngine']();if(this['_CoreEngineSettings']['BattleSystem']===_0x4479d6)this['resetBattleSystem']();return this['_CoreEngineSettings']['BattleSystem'];}else Imported['VisuMZ_2_BattleSystemCTB']&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x9f3));}else{if(_0x3ceaba['match'](/STB/i)){if(Imported[_0x3e2a4e(0x448)]){if(_0x3e2a4e(0x6d3)!==_0x3e2a4e(0x87f))this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x470);else{if(this[_0x3e2a4e(0x4ea)]===_0x5a40d0)this['setupCoreEngine']();return this[_0x3e2a4e(0x4ea)];}}}else{if(_0x3ceaba['match'](/BTB/i))Imported[_0x3e2a4e(0x721)]&&(this['_forcedBattleSys']=_0x3e2a4e(0x9aa));else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/FTB/i))Imported[_0x3e2a4e(0x4e7)]&&(_0x3e2a4e(0x97b)!==_0x3e2a4e(0x97b)?_0x43a88a['isPlaytest']()&&(_0x184eb9[_0x3e2a4e(0x262)](_0x3e2a4e(0x27a)),_0x6c664[_0x3e2a4e(0x262)](_0x19c64d)):this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x39a));else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/OTB/i))_0x3e2a4e(0x86e)!==_0x3e2a4e(0x86e)?(this['_pageupButton']['x']=-0x1*(this[_0x3e2a4e(0x950)][_0x3e2a4e(0x281)]+this[_0x3e2a4e(0x54f)]['width']+0x8),this[_0x3e2a4e(0x54f)]['x']=-0x1*(this['_pagedownButton'][_0x3e2a4e(0x281)]+0x4)):Imported[_0x3e2a4e(0x296)]&&(this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x332));else{if(_0x3ceaba[_0x3e2a4e(0x59b)](/ETB/i))_0x3e2a4e(0x7af)!==_0x3e2a4e(0x602)?Imported[_0x3e2a4e(0x80b)]&&(_0x3e2a4e(0x355)!==_0x3e2a4e(0x355)?this['switchModes'](_0x3e2a4e(0x646)):this[_0x3e2a4e(0x698)]=_0x3e2a4e(0x965)):this[_0x3e2a4e(0x433)](-0x1);else _0x3ceaba[_0x3e2a4e(0x59b)](/PTB/i)&&(Imported[_0x3e2a4e(0x3fd)]&&('tZQkA'!=='tZQkA'?this['_listWindow'][_0x3e2a4e(0x6d0)](_0x281222[_0x3e2a4e(0x556)][_0x3e2a4e(0x9bd)]):this[_0x3e2a4e(0x698)]='PTB'));}}}}}}}}}}}}}}}}}}}},Game_Temp[_0x54167d(0x4ec)]['createFauxAnimationQueue']=function(){const _0xdbe9d1=_0x54167d;this[_0xdbe9d1(0x532)]=[];},Game_Temp['prototype'][_0x54167d(0x64c)]=function(_0x13222c,_0x1ee8a3,_0x5aa329,_0x40556d){const _0x175236=_0x54167d;if(!this['showFauxAnimations']())return;_0x5aa329=_0x5aa329||![],_0x40556d=_0x40556d||![];if($dataAnimations[_0x1ee8a3]){const _0x5c4ccb={'targets':_0x13222c,'animationId':_0x1ee8a3,'mirror':_0x5aa329,'mute':_0x40556d};this['_fauxAnimationQueue']['push'](_0x5c4ccb);for(const _0x2901df of _0x13222c){_0x2901df[_0x175236(0x490)]&&_0x2901df[_0x175236(0x490)]();}}},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x9d4)]=function(){return!![];},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x44f)]=function(){const _0x111705=_0x54167d;return this[_0x111705(0x532)]['shift']();},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x5eb)]=function(){const _0xe2dd3=_0x54167d;this[_0xe2dd3(0x89e)]=[];},Game_Temp[_0x54167d(0x4ec)]['requestPointAnimation']=function(_0x29f923,_0x498cd4,_0x27e29c,_0xe48697,_0x34f2a7){const _0x4ff748=_0x54167d;if(!this[_0x4ff748(0x371)]())return;_0xe48697=_0xe48697||![],_0x34f2a7=_0x34f2a7||![];if($dataAnimations[_0x27e29c]){const _0x1510f4={'x':_0x29f923,'y':_0x498cd4,'animationId':_0x27e29c,'mirror':_0xe48697,'mute':_0x34f2a7};this[_0x4ff748(0x89e)]['push'](_0x1510f4);}},Game_Temp[_0x54167d(0x4ec)]['showPointAnimations']=function(){return!![];},Game_Temp[_0x54167d(0x4ec)]['retrievePointAnimation']=function(){const _0x57672d=_0x54167d;return this['_pointAnimationQueue'][_0x57672d(0x843)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x99f)]=Game_System['prototype'][_0x54167d(0x8d7)],Game_System[_0x54167d(0x4ec)][_0x54167d(0x8d7)]=function(){const _0x1ca701=_0x54167d;VisuMZ[_0x1ca701(0x940)][_0x1ca701(0x99f)][_0x1ca701(0x204)](this),this[_0x1ca701(0x55b)]();},Game_System['prototype']['initCoreEngine']=function(){const _0x50fee6=_0x54167d;this['_CoreEngineSettings']={'SideView':$dataSystem[_0x50fee6(0x261)],'BattleSystem':this[_0x50fee6(0x272)](),'FontSize':$dataSystem['advanced'][_0x50fee6(0x79f)],'Padding':0xc};},Game_System[_0x54167d(0x4ec)]['isSideView']=function(){const _0x5d2b0e=_0x54167d;if($gameTemp[_0x5d2b0e(0x7b8)]==='SV'){if(_0x5d2b0e(0x311)==='iIvPx')return!![];else{var _0x1b570d=_0x21144a(_0x11c713['$1']);_0x44118e+=_0x1b570d;}}else{if($gameTemp['_forcedTroopView']==='FV')return![];}if(this[_0x5d2b0e(0x6af)]===undefined)this[_0x5d2b0e(0x55b)]();if(this['_CoreEngineSettings'][_0x5d2b0e(0x861)]===undefined)this[_0x5d2b0e(0x55b)]();return this[_0x5d2b0e(0x6af)]['SideView'];},Game_System[_0x54167d(0x4ec)][_0x54167d(0x8ac)]=function(_0x5c7647){const _0x20b9a6=_0x54167d;if(this[_0x20b9a6(0x6af)]===undefined)this[_0x20b9a6(0x55b)]();if(this[_0x20b9a6(0x6af)][_0x20b9a6(0x861)]===undefined)this[_0x20b9a6(0x55b)]();this['_CoreEngineSettings'][_0x20b9a6(0x861)]=_0x5c7647;},Game_System[_0x54167d(0x4ec)][_0x54167d(0x8aa)]=function(){const _0x46668f=_0x54167d;if(this[_0x46668f(0x6af)]===undefined)this['initCoreEngine']();this['_CoreEngineSettings'][_0x46668f(0x5c6)]=this['initialBattleSystem']();},Game_System[_0x54167d(0x4ec)][_0x54167d(0x272)]=function(){const _0x37e36f=_0x54167d,_0x14a5ca=(VisuMZ[_0x37e36f(0x940)]['Settings'][_0x37e36f(0x5c6)]||'DATABASE')['toUpperCase']()[_0x37e36f(0x314)]();return VisuMZ['CoreEngine']['CreateBattleSystemID'](_0x14a5ca);},Game_System['prototype'][_0x54167d(0x9bc)]=function(){const _0x1f81a7=_0x54167d;if($gameTemp['_forcedBattleSys']!==undefined)return $gameTemp[_0x1f81a7(0x698)];if(this[_0x1f81a7(0x6af)]===undefined)this[_0x1f81a7(0x55b)]();if(this['_CoreEngineSettings'][_0x1f81a7(0x5c6)]===undefined)this[_0x1f81a7(0x8aa)]();return this['_CoreEngineSettings']['BattleSystem'];},Game_System['prototype'][_0x54167d(0x59d)]=function(_0x54d5f6){const _0x1bd928=_0x54167d;if(this[_0x1bd928(0x6af)]===undefined)this[_0x1bd928(0x55b)]();if(this[_0x1bd928(0x6af)][_0x1bd928(0x5c6)]===undefined)this[_0x1bd928(0x8aa)]();this['_CoreEngineSettings'][_0x1bd928(0x5c6)]=_0x54d5f6;},Game_System[_0x54167d(0x4ec)][_0x54167d(0x89c)]=function(){const _0x431f0c=_0x54167d;if(this[_0x431f0c(0x6af)]===undefined)this['initCoreEngine']();if(this['_CoreEngineSettings']['FontSize']===undefined)this[_0x431f0c(0x55b)]();return this[_0x431f0c(0x6af)]['FontSize'];},Game_System[_0x54167d(0x4ec)]['setMainFontSize']=function(_0x3b56b2){const _0x29e8de=_0x54167d;if(this[_0x29e8de(0x6af)]===undefined)this[_0x29e8de(0x55b)]();if(this[_0x29e8de(0x6af)]['TimeProgress']===undefined)this[_0x29e8de(0x55b)]();this[_0x29e8de(0x6af)][_0x29e8de(0x872)]=_0x3b56b2;},Game_System[_0x54167d(0x4ec)]['windowPadding']=function(){const _0x3035bb=_0x54167d;if(this['_CoreEngineSettings']===undefined)this[_0x3035bb(0x55b)]();if(this['_CoreEngineSettings']['Padding']===undefined)this[_0x3035bb(0x55b)]();return this['_CoreEngineSettings']['Padding'];},Game_System[_0x54167d(0x4ec)]['setWindowPadding']=function(_0x369332){const _0x4e9210=_0x54167d;if(this[_0x4e9210(0x6af)]===undefined)this['initCoreEngine']();if(this[_0x4e9210(0x6af)][_0x4e9210(0xa07)]===undefined)this[_0x4e9210(0x55b)]();this['_CoreEngineSettings']['Padding']=_0x369332;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x928)]=Game_Screen[_0x54167d(0x4ec)][_0x54167d(0x8d7)],Game_Screen['prototype'][_0x54167d(0x8d7)]=function(){VisuMZ['CoreEngine']['Game_Screen_initialize']['call'](this),this['initCoreEngineScreenShake']();},Game_Screen[_0x54167d(0x4ec)][_0x54167d(0x446)]=function(){const _0x4c9da4=_0x54167d,_0x268459=VisuMZ[_0x4c9da4(0x940)]['Settings'][_0x4c9da4(0x5c9)];this['_coreEngineShakeStyle']=_0x268459?.[_0x4c9da4(0x4fe)]||_0x4c9da4(0x206);},Game_Screen[_0x54167d(0x4ec)][_0x54167d(0x41f)]=function(){const _0xab4790=_0x54167d;if(this[_0xab4790(0x21d)]===undefined)this[_0xab4790(0x446)]();return this['_coreEngineShakeStyle'];},Game_Screen['prototype']['setCoreEngineScreenShakeStyle']=function(_0x438b51){const _0x1833de=_0x54167d;if(this[_0x1833de(0x21d)]===undefined)this[_0x1833de(0x446)]();this[_0x1833de(0x21d)]=_0x438b51[_0x1833de(0x6aa)]()['trim']();},Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x235)]=function(){const _0x45031e=_0x54167d;if($gameParty[_0x45031e(0x540)]())return![];return this[_0x45031e(0x614)]()&&this[_0x45031e(0x614)]()[_0x45031e(0x607)](0x0)==='!';},VisuMZ[_0x54167d(0x940)]['Game_Picture_x']=Game_Picture[_0x54167d(0x4ec)]['x'],Game_Picture[_0x54167d(0x4ec)]['x']=function(){const _0x218370=_0x54167d;if(this[_0x218370(0x235)]())return this['xScrollLinkedOffset']();else{if('KCScy'===_0x218370(0x4fd))return VisuMZ[_0x218370(0x940)][_0x218370(0x7fb)][_0x218370(0x204)](this);else this['coreEngineRepositionEnemies']()&&this[_0x218370(0xa12)](),_0x3f1629[_0x218370(0x940)]['Spriteset_Battle_createEnemies'][_0x218370(0x204)](this);}},Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x36c)]=function(){const _0x47bee0=_0x54167d,_0x22d38a=$gameMap[_0x47bee0(0x5ea)]()*$gameMap['tileWidth']();return this['_x']-_0x22d38a;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x3b1)]=Game_Picture[_0x54167d(0x4ec)]['y'],Game_Picture[_0x54167d(0x4ec)]['y']=function(){const _0x2fcf0b=_0x54167d;if(this[_0x2fcf0b(0x235)]()){if(_0x2fcf0b(0x500)!==_0x2fcf0b(0x500))this[_0x2fcf0b(0x46c)]();else return this[_0x2fcf0b(0x384)]();}else{if('CsZcv'===_0x2fcf0b(0x494))return VisuMZ[_0x2fcf0b(0x940)][_0x2fcf0b(0x3b1)][_0x2fcf0b(0x204)](this);else _0x4673d8[_0x2fcf0b(0x940)][_0x2fcf0b(0x920)][_0x2fcf0b(0x204)](this),_0x5b3e5d[_0x2fcf0b(0x6a3)]();}},Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x384)]=function(){const _0x23bb8f=_0x54167d,_0x19a837=$gameMap[_0x23bb8f(0x922)]()*$gameMap['tileHeight']();return this['_y']-_0x19a837;},Game_Picture[_0x54167d(0x4ec)][_0x54167d(0xa18)]=function(_0x40bf05){this['_coreEasingType']=_0x40bf05;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x533)]=Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x4f1)],Game_Picture[_0x54167d(0x4ec)]['calcEasing']=function(_0x45d58e){const _0x3285c4=_0x54167d;return this[_0x3285c4(0x72d)]=this[_0x3285c4(0x72d)]||0x0,[0x0,0x1,0x2,0x3][_0x3285c4(0x9ef)](this['_coreEasingType'])?VisuMZ[_0x3285c4(0x940)][_0x3285c4(0x533)][_0x3285c4(0x204)](this,_0x45d58e):VisuMZ[_0x3285c4(0x9d5)](_0x45d58e,this[_0x3285c4(0x72d)]);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x679)]=Game_Action['prototype'][_0x54167d(0x975)],Game_Action[_0x54167d(0x4ec)]['itemHit']=function(_0xdf2e61){const _0x5a5dcd=_0x54167d;if(VisuMZ['CoreEngine'][_0x5a5dcd(0x331)]['QoL'][_0x5a5dcd(0x4e0)]){if('kuzyw'==='kuzyw')return this[_0x5a5dcd(0x36d)](_0xdf2e61);else this[_0x5a5dcd(0x2cc)](_0x2fc154,_0x45bde7,_0x1c0a8d,_0x3e5b00,'right');}else return VisuMZ['CoreEngine'][_0x5a5dcd(0x679)][_0x5a5dcd(0x204)](this,_0xdf2e61);},Game_Action[_0x54167d(0x4ec)][_0x54167d(0x36d)]=function(_0x27eb38){const _0x1d863a=this['itemSuccessRate'](_0x27eb38),_0x46e3cf=this['subjectHitRate'](_0x27eb38),_0xf45621=this['targetEvaRate'](_0x27eb38);return _0x1d863a*(_0x46e3cf-_0xf45621);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x580)]=Game_Action[_0x54167d(0x4ec)]['itemEva'],Game_Action[_0x54167d(0x4ec)]['itemEva']=function(_0x5b59de){const _0x327579=_0x54167d;if(VisuMZ[_0x327579(0x940)][_0x327579(0x331)][_0x327579(0x2e9)][_0x327579(0x4e0)])return 0x0;else{if(_0x327579(0x34d)==='TKxDU')_0x33259b[_0x327579(0x940)][_0x327579(0x833)][_0x327579(0x204)](this,_0x39f495,_0x34c54c),this[_0x327579(0x7f7)]();else return VisuMZ['CoreEngine'][_0x327579(0x580)]['call'](this,_0x5b59de);}},Game_Action['prototype']['itemSuccessRate']=function(_0x5ea2dd){const _0x4a05e9=_0x54167d;return this[_0x4a05e9(0x787)]()[_0x4a05e9(0x93b)]*0.01;},Game_Action[_0x54167d(0x4ec)][_0x54167d(0x3ca)]=function(_0x52d6f6){const _0x1ebfaa=_0x54167d;if(VisuMZ['CoreEngine'][_0x1ebfaa(0x331)][_0x1ebfaa(0x2e9)]['AccuracyBoost']&&this[_0x1ebfaa(0x7c1)]())return 0x1;if(this[_0x1ebfaa(0x764)]()){if(_0x1ebfaa(0x8f7)==='EmqSv'){if(VisuMZ[_0x1ebfaa(0x940)][_0x1ebfaa(0x331)][_0x1ebfaa(0x2e9)][_0x1ebfaa(0x544)]&&this['subject']()[_0x1ebfaa(0x4f6)]()){if(_0x1ebfaa(0x9c3)!==_0x1ebfaa(0x9c3)){if(!_0x98387c[_0x1ebfaa(0x562)]())return;if(!_0x56abc0['isNwjs']())return;if(!_0x167035)return;if(_0x416eab[_0x1ebfaa(0x716)]()<=0x0)return;_0x11bd8d['ConvertParams'](_0x2c4a9a,_0x32ad95);const _0x57630c='Map%1'['format'](_0x46f2f9['mapId']()['padZero'](0x3)),_0x11ab0e=_0x4fa0a3[_0x1ebfaa(0x940)][_0x1ebfaa(0x6a6)](_0x4b6b0f[_0x1ebfaa(0x716)]());_0x46ed9c[_0x1ebfaa(0x940)][_0x1ebfaa(0x207)](_0x11ab0e,_0x57630c,!![]);}else return this[_0x1ebfaa(0x4de)]()[_0x1ebfaa(0x399)]+0.05;}else return this['subject']()[_0x1ebfaa(0x399)];}else return _0xdeb781['CoreEngine']['Game_Action_numRepeats'][_0x1ebfaa(0x204)](this);}else return 0x1;},Game_Action[_0x54167d(0x4ec)][_0x54167d(0x862)]=function(_0xa88e05){const _0x3bd4d1=_0x54167d;if(this[_0x3bd4d1(0x4de)]()['isActor']()===_0xa88e05[_0x3bd4d1(0x4f6)]())return 0x0;if(this[_0x3bd4d1(0x764)]()){if(_0x3bd4d1(0x6a9)===_0x3bd4d1(0x6a9))return VisuMZ[_0x3bd4d1(0x940)][_0x3bd4d1(0x331)][_0x3bd4d1(0x2e9)][_0x3bd4d1(0x544)]&&_0xa88e05[_0x3bd4d1(0x24b)]()?_0xa88e05[_0x3bd4d1(0x5b8)]-0.05:_0xa88e05[_0x3bd4d1(0x5b8)];else _0x345e5e=_0x37a29c['concat'](_0x59904e);}else return this[_0x3bd4d1(0x5b0)]()?_0xa88e05['mev']:0x0;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x61f)]=Game_Action['prototype'][_0x54167d(0x719)],Game_Action[_0x54167d(0x4ec)]['updateLastTarget']=function(_0x56e2e6){const _0x18b97f=_0x54167d;VisuMZ[_0x18b97f(0x940)][_0x18b97f(0x61f)]['call'](this,_0x56e2e6);if(VisuMZ[_0x18b97f(0x940)][_0x18b97f(0x331)][_0x18b97f(0x2e9)]['ImprovedAccuracySystem'])return;const _0x3df33d=_0x56e2e6[_0x18b97f(0x94f)]();if(_0x3df33d[_0x18b97f(0x46e)]){if(_0x18b97f(0x6ff)!==_0x18b97f(0x6ff))return _0x213948[_0x18b97f(0x556)][_0x18b97f(0x918)][_0x18b97f(0x204)](this);else 0x1-this[_0x18b97f(0x55c)](_0x56e2e6)>this[_0x18b97f(0x975)](_0x56e2e6)&&(_0x3df33d[_0x18b97f(0x46e)]=![],_0x3df33d[_0x18b97f(0x438)]=!![]);}},VisuMZ['CoreEngine'][_0x54167d(0x708)]=Game_BattlerBase['prototype']['initMembers'],Game_BattlerBase['prototype'][_0x54167d(0x4a6)]=function(){const _0x4dc3d3=_0x54167d;this[_0x4dc3d3(0x74c)]={},VisuMZ['CoreEngine'][_0x4dc3d3(0x708)]['call'](this);},VisuMZ[_0x54167d(0x940)]['Game_BattlerBase_refresh']=Game_BattlerBase['prototype'][_0x54167d(0x7dd)],Game_BattlerBase[_0x54167d(0x4ec)]['refresh']=function(){const _0x53a5b6=_0x54167d;this[_0x53a5b6(0x74c)]={},VisuMZ[_0x53a5b6(0x940)]['Game_BattlerBase_refresh']['call'](this);},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x4d7)]=function(_0x6a265c){const _0x1bf3ed=_0x54167d;return this['_cache']=this[_0x1bf3ed(0x74c)]||{},this['_cache'][_0x6a265c]!==undefined;},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x724)]=function(_0x394846){const _0x234f75=_0x54167d,_0x1610a8=(_0x4b5c1a,_0x56d503)=>{const _0x139d6d=_0x4d17;if(!_0x56d503)return _0x4b5c1a;if(_0x56d503[_0x139d6d(0x31a)][_0x139d6d(0x59b)](VisuMZ[_0x139d6d(0x940)][_0x139d6d(0x364)][_0x139d6d(0x724)][_0x394846])){var _0x20e616=Number(RegExp['$1']);_0x4b5c1a+=_0x20e616;}if(_0x56d503['note']['match'](VisuMZ[_0x139d6d(0x940)][_0x139d6d(0x364)]['paramPlusJS'][_0x394846])){if(_0x139d6d(0x2c2)!==_0x139d6d(0x2c2))return 0x0;else{var _0x346381=String(RegExp['$1']);try{'TjMIh'!==_0x139d6d(0xa05)?(_0x194714[_0x139d6d(0x4ec)][_0x139d6d(0x8a2)][_0x139d6d(0x204)](this),!_0x31bf1e['isNextScene'](_0x34edda)&&(this['_spriteset']['update'](),this['_mapNameWindow'][_0x139d6d(0x4fa)](),this[_0x139d6d(0x6c7)]['visible']=![],_0x209a8f['snapForBackground']()),_0x1caaee['clearZoom'](),this[_0x139d6d(0x56d)]()):_0x4b5c1a+=eval(_0x346381);}catch(_0x5f1088){if($gameTemp[_0x139d6d(0x562)]())console[_0x139d6d(0x262)](_0x5f1088);}}}return _0x4b5c1a;};return this[_0x234f75(0x79e)]()[_0x234f75(0x81d)](_0x1610a8,this['_paramPlus'][_0x394846]);},Game_BattlerBase['prototype']['paramMax']=function(_0x47ccdf){const _0x48eacc=_0x54167d;var _0x34368e=_0x48eacc(0x4f5)+(this[_0x48eacc(0x4f6)]()?_0x48eacc(0x6de):_0x48eacc(0xa01))+_0x48eacc(0x640)+_0x47ccdf;if(this[_0x48eacc(0x4d7)](_0x34368e))return this[_0x48eacc(0x74c)][_0x34368e];this[_0x48eacc(0x74c)][_0x34368e]=eval(VisuMZ[_0x48eacc(0x940)]['Settings'][_0x48eacc(0x3fa)][_0x34368e]);const _0xeda5b3=(_0x5405f6,_0x2e21d2)=>{const _0x4572ab=_0x48eacc;if(!_0x2e21d2)return _0x5405f6;if(_0x2e21d2['note'][_0x4572ab(0x59b)](VisuMZ[_0x4572ab(0x940)][_0x4572ab(0x364)][_0x4572ab(0x9a1)][_0x47ccdf])){var _0x310aff=Number(RegExp['$1']);if(_0x310aff===0x0)_0x310aff=Number[_0x4572ab(0x4a8)];_0x5405f6=Math[_0x4572ab(0x350)](_0x5405f6,_0x310aff);}if(_0x2e21d2[_0x4572ab(0x31a)][_0x4572ab(0x59b)](VisuMZ[_0x4572ab(0x940)][_0x4572ab(0x364)][_0x4572ab(0x944)][_0x47ccdf])){var _0xfbdd41=String(RegExp['$1']);try{if('ScAFD'===_0x4572ab(0x41c)){return _0x4972e3[_0x4572ab(0x4ec)][_0x4572ab(0x97d)][_0x4572ab(0x204)](this)+_0x1b4282[_0x4572ab(0x940)][_0x4572ab(0x331)][_0x4572ab(0x3b6)][_0x4572ab(0x49c)];;}else _0x5405f6=Math[_0x4572ab(0x350)](_0x5405f6,Number(eval(_0xfbdd41)));}catch(_0x5bfc85){if($gameTemp[_0x4572ab(0x562)]())console[_0x4572ab(0x262)](_0x5bfc85);}}return _0x5405f6;};if(this[_0x48eacc(0x74c)][_0x34368e]===0x0)this[_0x48eacc(0x74c)][_0x34368e]=Number['MAX_SAFE_INTEGER'];return this[_0x48eacc(0x74c)][_0x34368e]=this['traitObjects']()['reduce'](_0xeda5b3,this[_0x48eacc(0x74c)][_0x34368e]),this[_0x48eacc(0x74c)][_0x34368e];},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x455)]=function(_0x1ecc4c){const _0x2e2d79=_0x54167d,_0x3f79f1=this['traitsPi'](Game_BattlerBase[_0x2e2d79(0x949)],_0x1ecc4c),_0x172752=(_0x973df,_0x45aef1)=>{const _0x148448=_0x2e2d79;if(!_0x45aef1)return _0x973df;if(_0x45aef1[_0x148448(0x31a)][_0x148448(0x59b)](VisuMZ[_0x148448(0x940)][_0x148448(0x364)][_0x148448(0x8b7)][_0x1ecc4c])){if(_0x148448(0x3f8)===_0x148448(0x3f8)){var _0x34fc23=Number(RegExp['$1'])/0x64;_0x973df*=_0x34fc23;}else this[_0x148448(0x5c1)]();}if(_0x45aef1[_0x148448(0x31a)][_0x148448(0x59b)](VisuMZ[_0x148448(0x940)][_0x148448(0x364)][_0x148448(0x323)][_0x1ecc4c])){if(_0x148448(0x92f)!==_0x148448(0x92f))return this['helpAreaBottom']();else{var _0x34fc23=Number(RegExp['$1']);_0x973df*=_0x34fc23;}}if(_0x45aef1[_0x148448(0x31a)]['match'](VisuMZ[_0x148448(0x940)][_0x148448(0x364)][_0x148448(0x236)][_0x1ecc4c])){if(_0x148448(0x58f)!==_0x148448(0x8bb)){var _0x917a08=String(RegExp['$1']);try{_0x973df*=eval(_0x917a08);}catch(_0x17e7e0){if($gameTemp[_0x148448(0x562)]())console[_0x148448(0x262)](_0x17e7e0);}}else return _0x21c1a8[_0x148448(0x429)]||'Keyboard';}return _0x973df;};return this[_0x2e2d79(0x79e)]()[_0x2e2d79(0x81d)](_0x172752,_0x3f79f1);},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x2ea)]=function(_0x37ab30){const _0x56baff=_0x54167d,_0x5a3a11=(_0x331488,_0x3287a2)=>{const _0x47f907=_0x4d17;if(!_0x3287a2)return _0x331488;if(_0x3287a2[_0x47f907(0x31a)][_0x47f907(0x59b)](VisuMZ['CoreEngine'][_0x47f907(0x364)][_0x47f907(0x343)][_0x37ab30])){if(_0x47f907(0x67a)!==_0x47f907(0x67a)){if(_0x5c5d41['match'](/backspace/i))return this[_0x47f907(0x912)]===0x8;if(_0x1d7755[_0x47f907(0x59b)](/enter/i))return this[_0x47f907(0x912)]===0xd;if(_0x5c031d[_0x47f907(0x59b)](/escape/i))return this[_0x47f907(0x912)]===0x1b;}else{var _0x27f07a=Number(RegExp['$1']);_0x331488+=_0x27f07a;}}if(_0x3287a2[_0x47f907(0x31a)][_0x47f907(0x59b)](VisuMZ[_0x47f907(0x940)][_0x47f907(0x364)][_0x47f907(0x964)][_0x37ab30])){if(_0x47f907(0x73c)===_0x47f907(0x1f1))return this[_0x47f907(0x9f6)](_0x6ab79f);else{var _0x441998=String(RegExp['$1']);try{if(_0x47f907(0x279)===_0x47f907(0x279))_0x331488+=eval(_0x441998);else{_0x37e8ab[_0x47f907(0x683)](_0x14550c,_0x3f9c3a);const _0x1e4e2c=_0xf93876[_0x47f907(0x89a)]||_0x47f907(0x206),_0xbd2094=_0xfc5126[_0x47f907(0x699)]['clamp'](0x1,0x9),_0x2598bf=_0x194ff9[_0x47f907(0x717)][_0x47f907(0x29b)](0x1,0x9),_0x48f203=_0x5b53df[_0x47f907(0x72b)]||0x1,_0x2aa7c1=_0x1e7aaf['Wait'];_0x21228e[_0x47f907(0x3f2)](_0x1e4e2c),_0x1e73c8[_0x47f907(0x669)](_0xbd2094,_0x2598bf,_0x48f203);if(_0x2aa7c1){const _0xa6545d=_0x396dcb[_0x47f907(0x2ca)]();if(_0xa6545d)_0xa6545d[_0x47f907(0x660)](_0x48f203);}}}catch(_0x3f55ad){if($gameTemp[_0x47f907(0x562)]())console['log'](_0x3f55ad);}}}return _0x331488;};return this[_0x56baff(0x79e)]()[_0x56baff(0x81d)](_0x5a3a11,0x0);},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x594)]=function(_0x37c076){const _0x1d65b0=_0x54167d;let _0x486b3a=_0x1d65b0(0x594)+_0x37c076+_0x1d65b0(0x40c);if(this[_0x1d65b0(0x4d7)](_0x486b3a))return this['_cache'][_0x486b3a];return this['_cache'][_0x486b3a]=Math['round'](VisuMZ[_0x1d65b0(0x940)][_0x1d65b0(0x331)][_0x1d65b0(0x3fa)][_0x1d65b0(0x32d)][_0x1d65b0(0x204)](this,_0x37c076)),this[_0x1d65b0(0x74c)][_0x486b3a];},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x953)]=function(_0x37e3d2){const _0xd460ce=_0x54167d,_0x1343d8=(_0x324af0,_0x543177)=>{const _0x149c7f=_0x4d17;if(!_0x543177)return _0x324af0;if(_0x543177[_0x149c7f(0x31a)]['match'](VisuMZ[_0x149c7f(0x940)]['RegExp'][_0x149c7f(0x2c4)][_0x37e3d2])){if(_0x149c7f(0x83b)!=='ydDGG'){var _0x22e3d3=Number(RegExp['$1'])/0x64;_0x324af0+=_0x22e3d3;}else this['_forcedBattleSys']=_0x149c7f(0x39a);}if(_0x543177[_0x149c7f(0x31a)][_0x149c7f(0x59b)](VisuMZ['CoreEngine'][_0x149c7f(0x364)][_0x149c7f(0x730)][_0x37e3d2])){if(_0x149c7f(0x483)!==_0x149c7f(0x9c1)){var _0x22e3d3=Number(RegExp['$1']);_0x324af0+=_0x22e3d3;}else this[_0x149c7f(0x4ef)]={},_0x14a35a[_0x149c7f(0x4ec)][_0x149c7f(0x8d7)][_0x149c7f(0x204)](this,_0x4ce2a3),this[_0x149c7f(0x6d0)](_0x146d06[_0x149c7f(0x940)]['Settings'][_0x149c7f(0x464)][_0x149c7f(0x4a7)]||0x0),this[_0x149c7f(0x7dd)]();}if(_0x543177['note'][_0x149c7f(0x59b)](VisuMZ[_0x149c7f(0x940)][_0x149c7f(0x364)]['xparamPlusJS'][_0x37e3d2])){var _0x2aaee5=String(RegExp['$1']);try{_0x149c7f(0x745)!==_0x149c7f(0x745)?(this['_playtestF7Looping']=!![],this['update'](),_0xdddc69[_0x149c7f(0x52e)](),this[_0x149c7f(0x34a)]=![]):_0x324af0+=eval(_0x2aaee5);}catch(_0x287751){if(_0x149c7f(0x56b)!==_0x149c7f(0x56b))this['drawIcon'](_0x39d19e,_0x1831be+0x2,_0x4224ef+0x2),_0x14049a-=_0x23b1e4[_0x149c7f(0x28b)]+0x4,_0x1f140c+=_0xd9ea8[_0x149c7f(0x28b)]+0x4;else{if($gameTemp[_0x149c7f(0x562)]())console[_0x149c7f(0x262)](_0x287751);}}}return _0x324af0;};return this[_0xd460ce(0x79e)]()[_0xd460ce(0x81d)](_0x1343d8,0x0);},Game_BattlerBase[_0x54167d(0x4ec)]['xparamRate']=function(_0x16e32e){const _0x2e6f65=_0x54167d,_0x50a715=(_0x31bc74,_0x5ac27d)=>{const _0x1d5b78=_0x4d17;if(!_0x5ac27d)return _0x31bc74;if(_0x5ac27d[_0x1d5b78(0x31a)]['match'](VisuMZ['CoreEngine'][_0x1d5b78(0x364)][_0x1d5b78(0x82a)][_0x16e32e])){if('hQnPa'!=='xJKPK'){var _0x14d01e=Number(RegExp['$1'])/0x64;_0x31bc74*=_0x14d01e;}else _0x4ed3ff[_0x1d5b78(0x3fd)]&&(this[_0x1d5b78(0x698)]=_0x1d5b78(0x92c));}if(_0x5ac27d['note'][_0x1d5b78(0x59b)](VisuMZ[_0x1d5b78(0x940)][_0x1d5b78(0x364)]['xparamRate2'][_0x16e32e])){if(_0x1d5b78(0x81f)===_0x1d5b78(0x81f)){var _0x14d01e=Number(RegExp['$1']);_0x31bc74*=_0x14d01e;}else{if(this[_0x1d5b78(0x21d)]===_0x5d556a)this[_0x1d5b78(0x446)]();return this[_0x1d5b78(0x21d)];}}if(_0x5ac27d[_0x1d5b78(0x31a)][_0x1d5b78(0x59b)](VisuMZ[_0x1d5b78(0x940)][_0x1d5b78(0x364)]['xparamRateJS'][_0x16e32e])){var _0x4b7530=String(RegExp['$1']);try{'Rijkj'!==_0x1d5b78(0x345)?_0x31bc74*=eval(_0x4b7530):(_0xee4aa4[_0x1d5b78(0x940)][_0x1d5b78(0x8d4)][_0x1d5b78(0x204)](this),_0x740c1e['isSideButtonLayout']()&&this['moveMenuButtonSideButtonLayout']());}catch(_0x42ac54){if($gameTemp[_0x1d5b78(0x562)]())console[_0x1d5b78(0x262)](_0x42ac54);}}return _0x31bc74;};return this[_0x2e6f65(0x79e)]()[_0x2e6f65(0x81d)](_0x50a715,0x1);},Game_BattlerBase[_0x54167d(0x4ec)]['xparamFlatBonus']=function(_0x5db099){const _0x48676a=_0x54167d,_0x7cc6fc=(_0x160570,_0x3afa65)=>{const _0x3d73e2=_0x4d17;if(!_0x3afa65)return _0x160570;if(_0x3afa65[_0x3d73e2(0x31a)]['match'](VisuMZ[_0x3d73e2(0x940)][_0x3d73e2(0x364)][_0x3d73e2(0x386)][_0x5db099])){if('ecqxA'===_0x3d73e2(0x3a1))_0x235175=_0x3c0041[_0x3d73e2(0x350)](_0x20e770,_0x3830c4);else{var _0x22e91b=Number(RegExp['$1'])/0x64;_0x160570+=_0x22e91b;}}if(_0x3afa65[_0x3d73e2(0x31a)][_0x3d73e2(0x59b)](VisuMZ[_0x3d73e2(0x940)][_0x3d73e2(0x364)][_0x3d73e2(0x445)][_0x5db099])){var _0x22e91b=Number(RegExp['$1']);_0x160570+=_0x22e91b;}if(_0x3afa65[_0x3d73e2(0x31a)][_0x3d73e2(0x59b)](VisuMZ[_0x3d73e2(0x940)]['RegExp'][_0x3d73e2(0x301)][_0x5db099])){var _0x29b5ef=String(RegExp['$1']);try{'szsnA'!=='szsnA'?this[_0x3d73e2(0x98d)][_0x3d73e2(0x6d0)](_0x41156a[_0x3d73e2(0x556)][_0x3d73e2(0x536)]):_0x160570+=eval(_0x29b5ef);}catch(_0x3b397b){if(_0x3d73e2(0x4ae)!==_0x3d73e2(0x4ae))this['_digitGrouping']=_0x13a608[_0x3d73e2(0x940)][_0x3d73e2(0x331)]['QoL']['DigitGroupingStandardText'],this[_0x3d73e2(0x475)]=_0x12b50d[_0x3d73e2(0x940)][_0x3d73e2(0x331)][_0x3d73e2(0x2e9)]['DigitGroupingExText'];else{if($gameTemp[_0x3d73e2(0x562)]())console[_0x3d73e2(0x262)](_0x3b397b);}}}return _0x160570;};return this['traitObjects']()[_0x48676a(0x81d)](_0x7cc6fc,0x0);},Game_BattlerBase[_0x54167d(0x4ec)]['xparam']=function(_0x25d9b0){const _0x3cb614=_0x54167d;let _0x482a0d=_0x3cb614(0x904)+_0x25d9b0+_0x3cb614(0x40c);if(this['checkCacheKey'](_0x482a0d))return this[_0x3cb614(0x74c)][_0x482a0d];return this[_0x3cb614(0x74c)][_0x482a0d]=VisuMZ[_0x3cb614(0x940)][_0x3cb614(0x331)][_0x3cb614(0x3fa)][_0x3cb614(0x8cb)]['call'](this,_0x25d9b0),this[_0x3cb614(0x74c)][_0x482a0d];},Game_BattlerBase[_0x54167d(0x4ec)]['sparamPlus']=function(_0x5b9a72){const _0x5e5bef=_0x54167d,_0x546889=(_0x5affda,_0x2339c4)=>{const _0x52934a=_0x4d17;if(_0x52934a(0x2a9)!==_0x52934a(0x2a9))return this[_0x52934a(0x7dd)]();else{if(!_0x2339c4)return _0x5affda;if(_0x2339c4['note'][_0x52934a(0x59b)](VisuMZ['CoreEngine'][_0x52934a(0x364)][_0x52934a(0x75c)][_0x5b9a72])){var _0x5ce011=Number(RegExp['$1'])/0x64;_0x5affda+=_0x5ce011;}if(_0x2339c4[_0x52934a(0x31a)]['match'](VisuMZ[_0x52934a(0x940)][_0x52934a(0x364)][_0x52934a(0x38f)][_0x5b9a72])){var _0x5ce011=Number(RegExp['$1']);_0x5affda+=_0x5ce011;}if(_0x2339c4[_0x52934a(0x31a)]['match'](VisuMZ['CoreEngine'][_0x52934a(0x364)][_0x52934a(0x51d)][_0x5b9a72])){var _0xbad130=String(RegExp['$1']);try{_0x5affda+=eval(_0xbad130);}catch(_0x5b0425){if(_0x52934a(0x42c)!=='MVbuW'){if($gameTemp['isPlaytest']())console[_0x52934a(0x262)](_0x5b0425);}else this[_0x52934a(0x89e)]=[];}}return _0x5affda;}};return this[_0x5e5bef(0x79e)]()[_0x5e5bef(0x81d)](_0x546889,0x0);},Game_BattlerBase['prototype'][_0x54167d(0x8ea)]=function(_0xa6aa7f){const _0x1bcda4=_0x54167d,_0x4e2a2c=(_0x5275a4,_0xa5eeae)=>{const _0x210288=_0x4d17;if(!_0xa5eeae)return _0x5275a4;if(_0xa5eeae['note'][_0x210288(0x59b)](VisuMZ['CoreEngine'][_0x210288(0x364)][_0x210288(0x469)][_0xa6aa7f])){var _0x1f0945=Number(RegExp['$1'])/0x64;_0x5275a4*=_0x1f0945;}if(_0xa5eeae[_0x210288(0x31a)][_0x210288(0x59b)](VisuMZ[_0x210288(0x940)][_0x210288(0x364)]['sparamRate2'][_0xa6aa7f])){var _0x1f0945=Number(RegExp['$1']);_0x5275a4*=_0x1f0945;}if(_0xa5eeae['note'][_0x210288(0x59b)](VisuMZ[_0x210288(0x940)][_0x210288(0x364)]['sparamRateJS'][_0xa6aa7f])){var _0x42918d=String(RegExp['$1']);try{_0x5275a4*=eval(_0x42918d);}catch(_0x56cf6f){if(_0x210288(0x2a8)!==_0x210288(0x2a8))return _0x27ca1f[_0x210288(0x940)][_0x210288(0x331)][_0x210288(0x2e9)]['EncounterRateMinimum'];else{if($gameTemp[_0x210288(0x562)]())console['log'](_0x56cf6f);}}}return _0x5275a4;};return this['traitObjects']()[_0x1bcda4(0x81d)](_0x4e2a2c,0x1);},Game_BattlerBase['prototype'][_0x54167d(0x611)]=function(_0x2d599d){const _0x20c467=_0x54167d,_0x22beef=(_0x343888,_0x5e046a)=>{const _0x58658e=_0x4d17;if(!_0x5e046a)return _0x343888;if(_0x5e046a[_0x58658e(0x31a)]['match'](VisuMZ[_0x58658e(0x940)][_0x58658e(0x364)][_0x58658e(0x4cb)][_0x2d599d])){if('qqSBC'===_0x58658e(0x327)){if(_0x1039f2)_0xcb0d9d[_0x58658e(0x5b9)](_0x272009);}else{var _0x328da2=Number(RegExp['$1'])/0x64;_0x343888+=_0x328da2;}}if(_0x5e046a[_0x58658e(0x31a)]['match'](VisuMZ['CoreEngine'][_0x58658e(0x364)][_0x58658e(0x977)][_0x2d599d])){var _0x328da2=Number(RegExp['$1']);_0x343888+=_0x328da2;}if(_0x5e046a[_0x58658e(0x31a)][_0x58658e(0x59b)](VisuMZ[_0x58658e(0x940)][_0x58658e(0x364)][_0x58658e(0x5bd)][_0x2d599d])){var _0x10e289=String(RegExp['$1']);try{'SnAxz'!==_0x58658e(0x27e)?(_0x5a43f3+=_0x44eccf+'\x0a',_0x906c5+=_0x58658e(0x741),_0x39e96e[_0x58658e(0x733)][0x4]!==''&&_0x5b7b7a[_0x58658e(0x733)][0x4]!==_0x4c512c&&(_0x4bdbe1+=_0x58658e(0x810)['format'](_0xfc2a9a[_0x58658e(0x733)][0x4]))):_0x343888+=eval(_0x10e289);}catch(_0x1d61d3){if(_0x58658e(0x8ce)===_0x58658e(0x8ce)){if($gameTemp[_0x58658e(0x562)]())console[_0x58658e(0x262)](_0x1d61d3);}else this[_0x58658e(0x43a)]()?this[_0x58658e(0x739)]():_0x5a4b1c['CoreEngine']['Window_Gold_refresh'][_0x58658e(0x204)](this);}}return _0x343888;};return this[_0x20c467(0x79e)]()[_0x20c467(0x81d)](_0x22beef,0x0);},Game_BattlerBase[_0x54167d(0x4ec)][_0x54167d(0x652)]=function(_0x49070b){const _0x56e436=_0x54167d;let _0x2247a1=_0x56e436(0x652)+_0x49070b+_0x56e436(0x40c);if(this[_0x56e436(0x4d7)](_0x2247a1))return this[_0x56e436(0x74c)][_0x2247a1];return this[_0x56e436(0x74c)][_0x2247a1]=VisuMZ[_0x56e436(0x940)][_0x56e436(0x331)][_0x56e436(0x3fa)][_0x56e436(0x4e6)]['call'](this,_0x49070b),this[_0x56e436(0x74c)][_0x2247a1];},Game_BattlerBase['prototype'][_0x54167d(0x4e4)]=function(_0x4a38f7,_0x3efc84){const _0x1b339a=_0x54167d;if(typeof paramId===_0x1b339a(0x3d9))return this[_0x1b339a(0x594)](_0x4a38f7);_0x4a38f7=String(_0x4a38f7||'')['toUpperCase']();if(_0x4a38f7===_0x1b339a(0x578))return this[_0x1b339a(0x594)](0x0);if(_0x4a38f7===_0x1b339a(0x784))return this['param'](0x1);if(_0x4a38f7===_0x1b339a(0x6ea))return this[_0x1b339a(0x594)](0x2);if(_0x4a38f7===_0x1b339a(0x3ce))return this[_0x1b339a(0x594)](0x3);if(_0x4a38f7===_0x1b339a(0x203))return this[_0x1b339a(0x594)](0x4);if(_0x4a38f7===_0x1b339a(0x7e8))return this[_0x1b339a(0x594)](0x5);if(_0x4a38f7===_0x1b339a(0x778))return this[_0x1b339a(0x594)](0x6);if(_0x4a38f7==='LUK')return this[_0x1b339a(0x594)](0x7);if(_0x4a38f7===_0x1b339a(0x8a9))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this['xparam'](0x0)*0x64))+'%':this[_0x1b339a(0x904)](0x0);if(_0x4a38f7===_0x1b339a(0x2d9))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this['xparam'](0x1)*0x64))+'%':this[_0x1b339a(0x904)](0x1);if(_0x4a38f7===_0x1b339a(0x6e8))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x904)](0x2)*0x64))+'%':this[_0x1b339a(0x904)](0x2);if(_0x4a38f7==='CEV')return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x904)](0x3)*0x64))+'%':this[_0x1b339a(0x904)](0x3);if(_0x4a38f7==='MEV')return _0x3efc84?String(Math['round'](this[_0x1b339a(0x904)](0x4)*0x64))+'%':this[_0x1b339a(0x904)](0x4);if(_0x4a38f7===_0x1b339a(0x603))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x904)](0x5)*0x64))+'%':this['xparam'](0x5);if(_0x4a38f7===_0x1b339a(0x81e))return _0x3efc84?String(Math['round'](this[_0x1b339a(0x904)](0x6)*0x64))+'%':this['xparam'](0x6);if(_0x4a38f7==='HRG')return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this['xparam'](0x7)*0x64))+'%':this[_0x1b339a(0x904)](0x7);if(_0x4a38f7===_0x1b339a(0x9de))return _0x3efc84?String(Math['round'](this[_0x1b339a(0x904)](0x8)*0x64))+'%':this[_0x1b339a(0x904)](0x8);if(_0x4a38f7==='TRG')return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x904)](0x9)*0x64))+'%':this[_0x1b339a(0x904)](0x9);if(_0x4a38f7===_0x1b339a(0x7b3))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x652)](0x0)*0x64))+'%':this[_0x1b339a(0x652)](0x0);if(_0x4a38f7===_0x1b339a(0xa0d))return _0x3efc84?String(Math['round'](this[_0x1b339a(0x652)](0x1)*0x64))+'%':this[_0x1b339a(0x652)](0x1);if(_0x4a38f7===_0x1b339a(0x3ab))return _0x3efc84?String(Math['round'](this[_0x1b339a(0x652)](0x2)*0x64))+'%':this[_0x1b339a(0x652)](0x2);if(_0x4a38f7===_0x1b339a(0x66d))return _0x3efc84?String(Math['round'](this['sparam'](0x3)*0x64))+'%':this[_0x1b339a(0x652)](0x3);if(_0x4a38f7===_0x1b339a(0x43f))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x652)](0x4)*0x64))+'%':this[_0x1b339a(0x652)](0x4);if(_0x4a38f7==='TCR')return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x652)](0x5)*0x64))+'%':this[_0x1b339a(0x652)](0x5);if(_0x4a38f7===_0x1b339a(0x70a))return _0x3efc84?String(Math['round'](this['sparam'](0x6)*0x64))+'%':this['sparam'](0x6);if(_0x4a38f7===_0x1b339a(0x90d))return _0x3efc84?String(Math['round'](this[_0x1b339a(0x652)](0x7)*0x64))+'%':this[_0x1b339a(0x652)](0x7);if(_0x4a38f7===_0x1b339a(0x4b5))return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x652)](0x8)*0x64))+'%':this[_0x1b339a(0x652)](0x8);if(_0x4a38f7==='EXR')return _0x3efc84?String(Math[_0x1b339a(0x3ad)](this[_0x1b339a(0x652)](0x9)*0x64))+'%':this[_0x1b339a(0x652)](0x9);if(VisuMZ[_0x1b339a(0x940)]['CustomParamAbb'][_0x4a38f7]){if(_0x1b339a(0x901)===_0x1b339a(0x680)){if(!this[_0x1b339a(0x5b7)])return _0x187850;return _0x20b485['ApplyEasing'](_0x11739a,this[_0x1b339a(0x5b7)][_0x1b339a(0x337)]||_0x1b339a(0x6e3));}else{const _0x53dc40=VisuMZ[_0x1b339a(0x940)][_0x1b339a(0x450)][_0x4a38f7],_0x3736a7=this[_0x53dc40];return VisuMZ[_0x1b339a(0x940)][_0x1b339a(0x6dc)][_0x4a38f7]==='integer'?_0x3736a7:_0x3efc84?String(Math[_0x1b339a(0x3ad)](_0x3736a7*0x64))+'%':_0x3736a7;}}return'';},Game_BattlerBase['prototype'][_0x54167d(0x791)]=function(){const _0xebe91a=_0x54167d;return this[_0xebe91a(0x84f)]()&&this[_0xebe91a(0x4f3)]<this[_0xebe91a(0x307)]*VisuMZ[_0xebe91a(0x940)]['Settings']['Param'][_0xebe91a(0x7fc)];},Game_Battler[_0x54167d(0x4ec)]['performMiss']=function(){const _0x3ae010=_0x54167d;SoundManager['playMiss'](),this[_0x3ae010(0x893)](_0x3ae010(0x7ba));},VisuMZ[_0x54167d(0x940)][_0x54167d(0x713)]=Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x6ed)],Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x6ed)]=function(_0x1f3c91){const _0x29bc75=_0x54167d;if(this[_0x29bc75(0x472)]>0x63)return this[_0x29bc75(0x3f3)](_0x1f3c91);return VisuMZ['CoreEngine']['Game_Actor_paramBase'][_0x29bc75(0x204)](this,_0x1f3c91);},Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x3f3)]=function(_0x40a89d){const _0x48f8f9=_0x54167d,_0x1bd693=this[_0x48f8f9(0x50c)]()[_0x48f8f9(0x9b7)][_0x40a89d][0x63],_0x2e9eb5=this['currentClass']()[_0x48f8f9(0x9b7)][_0x40a89d][0x62];return _0x1bd693+(_0x1bd693-_0x2e9eb5)*(this['level']-0x63);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x3d7)]=Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x57d)],Game_Actor['prototype'][_0x54167d(0x57d)]=function(_0x29337b,_0x3c4c9c){const _0x582263=_0x54167d;$gameTemp['_changingClass']=!![],VisuMZ['CoreEngine'][_0x582263(0x3d7)][_0x582263(0x204)](this,_0x29337b,_0x3c4c9c),$gameTemp[_0x582263(0x539)]=undefined;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x56e)]=Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x753)],Game_Actor[_0x54167d(0x4ec)]['levelUp']=function(){const _0x125478=_0x54167d;VisuMZ[_0x125478(0x940)][_0x125478(0x56e)][_0x125478(0x204)](this);if(!$gameTemp[_0x125478(0x539)])this[_0x125478(0x970)]();},Game_Actor['prototype']['levelUpRecovery']=function(){const _0x3ab816=_0x54167d;this['_cache']={};if(VisuMZ[_0x3ab816(0x940)]['Settings'][_0x3ab816(0x2e9)][_0x3ab816(0x22b)])this[_0x3ab816(0x4f3)]=this['mhp'];if(VisuMZ['CoreEngine'][_0x3ab816(0x331)][_0x3ab816(0x2e9)][_0x3ab816(0x30c)])this['_mp']=this[_0x3ab816(0x41d)];},Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x552)]=function(){const _0x19a62e=_0x54167d;if(this[_0x19a62e(0x5de)]())return 0x1;const _0x4474e2=this[_0x19a62e(0x3fb)]()-this['currentLevelExp'](),_0x25dac0=this[_0x19a62e(0x43b)]()-this[_0x19a62e(0x426)]();return(_0x25dac0/_0x4474e2)[_0x19a62e(0x29b)](0x0,0x1);},Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x79e)]=function(){const _0x5b9848=_0x54167d,_0x2e8d54=Game_Battler[_0x5b9848(0x4ec)]['traitObjects']['call'](this);for(const _0xd61abd of this[_0x5b9848(0x3ea)]()){_0xd61abd&&_0x2e8d54[_0x5b9848(0x398)](_0xd61abd);}return _0x2e8d54[_0x5b9848(0x398)](this[_0x5b9848(0x50c)](),this['actor']()),_0x2e8d54;},Object[_0x54167d(0x201)](Game_Enemy[_0x54167d(0x4ec)],_0x54167d(0x472),{'get':function(){const _0x1e6fab=_0x54167d;return this[_0x1e6fab(0x75b)]();},'configurable':!![]}),Game_Enemy[_0x54167d(0x4ec)][_0x54167d(0x75b)]=function(){return this['enemy']()['level'];},Game_Enemy['prototype'][_0x54167d(0x2ff)]=function(){const _0xeecf88=_0x54167d;if(!this[_0xeecf88(0x555)]){if(_0xeecf88(0x5cf)!==_0xeecf88(0x5cf)){if(_0x6ba19c)_0x57b2e4['ParseActorNotetags'](_0x17469d);}else this[_0xeecf88(0x96f)]+=Math[_0xeecf88(0x3ad)]((Graphics[_0xeecf88(0x3e1)]-0x270)/0x2),this[_0xeecf88(0x96f)]-=Math[_0xeecf88(0x42f)]((Graphics[_0xeecf88(0x3e1)]-Graphics[_0xeecf88(0x996)])/0x2),$gameSystem[_0xeecf88(0x22e)]()?this['_screenX']-=Math[_0xeecf88(0x42f)]((Graphics['width']-Graphics['boxWidth'])/0x2):this[_0xeecf88(0x7e1)]+=Math[_0xeecf88(0x3ad)]((Graphics['boxWidth']-0x330)/0x2);}this[_0xeecf88(0x555)]=!![];},Game_Party[_0x54167d(0x4ec)][_0x54167d(0x8ee)]=function(){const _0x2ea6b7=_0x54167d;return VisuMZ[_0x2ea6b7(0x940)]['Settings'][_0x2ea6b7(0x67c)][_0x2ea6b7(0x33b)];},VisuMZ['CoreEngine'][_0x54167d(0x4a0)]=Game_Party[_0x54167d(0x4ec)]['consumeItem'],Game_Party[_0x54167d(0x4ec)][_0x54167d(0x4b9)]=function(_0x148c9d){const _0x192d09=_0x54167d;if(VisuMZ['CoreEngine'][_0x192d09(0x331)]['QoL'][_0x192d09(0x75d)]&&DataManager[_0x192d09(0x98f)](_0x148c9d))return;VisuMZ['CoreEngine'][_0x192d09(0x4a0)]['call'](this,_0x148c9d);},Game_Party[_0x54167d(0x4ec)][_0x54167d(0x245)]=function(){const _0x390a8b=_0x54167d,_0x26af98=VisuMZ['CoreEngine'][_0x390a8b(0x331)]['QoL'],_0x482b0a=_0x26af98[_0x390a8b(0x1fd)]??0x63;let _0x2aa8bc=[];(_0x26af98[_0x390a8b(0x5a5)]??!![])&&(_0x2aa8bc=_0x2aa8bc['concat']($dataItems));(_0x26af98[_0x390a8b(0x33a)]??!![])&&(_0x2aa8bc=_0x2aa8bc[_0x390a8b(0x25e)]($dataWeapons));(_0x26af98[_0x390a8b(0x6d8)]??!![])&&(_0x390a8b(0x6b9)!==_0x390a8b(0x876)?_0x2aa8bc=_0x2aa8bc[_0x390a8b(0x25e)]($dataArmors):(_0x519024['CoreEngine']['Scene_Options_create'][_0x390a8b(0x204)](this),this[_0x390a8b(0x8d9)]()));for(const _0x2e8bff of _0x2aa8bc){if(!_0x2e8bff)continue;if(_0x2e8bff['name'][_0x390a8b(0x314)]()<=0x0)continue;if(_0x2e8bff['name'][_0x390a8b(0x59b)](/-----/i))continue;this[_0x390a8b(0x8be)](_0x2e8bff,_0x482b0a);}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x391)]=Game_Troop['prototype'][_0x54167d(0x82d)],Game_Troop[_0x54167d(0x4ec)]['setup']=function(_0x3ee125){const _0x48878d=_0x54167d;$gameTemp[_0x48878d(0x3d6)](),$gameTemp[_0x48878d(0x76b)](_0x3ee125),VisuMZ[_0x48878d(0x940)][_0x48878d(0x391)][_0x48878d(0x204)](this,_0x3ee125);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x248)]=Game_Map[_0x54167d(0x4ec)][_0x54167d(0x82d)],Game_Map[_0x54167d(0x4ec)]['setup']=function(_0x1abe24){const _0x25a83f=_0x54167d;VisuMZ[_0x25a83f(0x940)][_0x25a83f(0x248)]['call'](this,_0x1abe24),this[_0x25a83f(0x35c)](_0x1abe24);},Game_Map['prototype'][_0x54167d(0x35c)]=function(){const _0x874a6b=_0x54167d;this[_0x874a6b(0x4ea)]=VisuMZ[_0x874a6b(0x940)][_0x874a6b(0x331)][_0x874a6b(0x2e9)][_0x874a6b(0x7cd)]||![];if($dataMap&&$dataMap[_0x874a6b(0x31a)]){if(_0x874a6b(0x525)===_0x874a6b(0x63d)){if(this[_0x874a6b(0x51e)]===_0x874a6b(0x97f)&&!_0x53bd5d[_0x874a6b(0x966)]())return;if(_0x498654[_0x874a6b(0x8e3)]())return;_0x3e6a4c['CoreEngine'][_0x874a6b(0x3d8)][_0x874a6b(0x204)](this,_0x204531),this[_0x874a6b(0x94e)]('default');}else{if($dataMap['note']['match'](/<SHOW TILE SHADOWS>/i))this[_0x874a6b(0x4ea)]=![];if($dataMap[_0x874a6b(0x31a)][_0x874a6b(0x59b)](/<HIDE TILE SHADOWS>/i))this[_0x874a6b(0x4ea)]=!![];}}},Game_Map['prototype']['areTileShadowsHidden']=function(){const _0x29c613=_0x54167d;if(this['_hideTileShadows']===undefined)this['setupCoreEngine']();return this[_0x29c613(0x4ea)];},VisuMZ['CoreEngine'][_0x54167d(0x347)]=Game_Character[_0x54167d(0x4ec)][_0x54167d(0x859)],Game_Character[_0x54167d(0x4ec)]['processMoveCommand']=function(_0x3d0efe){const _0x2e401f=_0x54167d;try{VisuMZ[_0x2e401f(0x940)][_0x2e401f(0x347)][_0x2e401f(0x204)](this,_0x3d0efe);}catch(_0x5146c4){if($gameTemp[_0x2e401f(0x562)]())console['log'](_0x5146c4);}},Game_Player['prototype']['makeEncounterCount']=function(){const _0x3887ce=_0x54167d,_0x5bfe64=$gameMap[_0x3887ce(0x9e2)]();this[_0x3887ce(0xa09)]=Math[_0x3887ce(0x549)](_0x5bfe64)+Math[_0x3887ce(0x549)](_0x5bfe64)+this['encounterStepsMinimum']();},Game_Player[_0x54167d(0x4ec)][_0x54167d(0x8a7)]=function(){const _0x398c18=_0x54167d;return $dataMap&&$dataMap['note']&&$dataMap[_0x398c18(0x31a)][_0x398c18(0x59b)](/<MINIMUM ENCOUNTER STEPS:[ ](\d+)>/i)?Number(RegExp['$1']):VisuMZ['CoreEngine'][_0x398c18(0x331)][_0x398c18(0x2e9)][_0x398c18(0x829)];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x93e)]=Game_Event[_0x54167d(0x4ec)][_0x54167d(0x486)],Game_Event[_0x54167d(0x4ec)]['isCollidedWithEvents']=function(_0x2fea72,_0x54cac4){const _0x1ca064=_0x54167d;if(this[_0x1ca064(0x1fb)]()){if(_0x1ca064(0x237)!=='hOFRa')return this[_0x1ca064(0x7d0)](_0x2fea72,_0x54cac4);else this['moveCancelButtonSideButtonLayout']();}else return VisuMZ[_0x1ca064(0x940)][_0x1ca064(0x93e)][_0x1ca064(0x204)](this,_0x2fea72,_0x54cac4);},Game_Event[_0x54167d(0x4ec)][_0x54167d(0x1fb)]=function(){const _0x36fb87=_0x54167d;return VisuMZ[_0x36fb87(0x940)][_0x36fb87(0x331)][_0x36fb87(0x2e9)]['SmartEventCollisionPriority'];},Game_Event['prototype'][_0x54167d(0x7d0)]=function(_0x4de39e,_0xf091e3){const _0x155978=_0x54167d;if(!this['isNormalPriority']())return![];else{const _0x5f2ffa=$gameMap[_0x155978(0x5d2)](_0x4de39e,_0xf091e3)[_0x155978(0x64f)](_0x21e691=>_0x21e691['isNormalPriority']());return _0x5f2ffa[_0x155978(0x95b)]>0x0;}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5c4)]=Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x92e)],Game_Interpreter[_0x54167d(0x4ec)]['command105']=function(_0x5d6c34){const _0x343973=_0x54167d,_0x36f732=this[_0x343973(0x519)]();if(_0x36f732[_0x343973(0x59b)](/\/\/[ ]SCRIPT[ ]CALL/i)){if(_0x343973(0x8b9)===_0x343973(0x8b9))return this[_0x343973(0x9f6)](_0x36f732);else _0x7419ee[_0x343973(0x472)]=_0x580f17[_0x343973(0x350)](_0x3c16ea(_0x20491a['$1']),0x1);}else return VisuMZ['CoreEngine']['Game_Interpreter_command105'][_0x343973(0x204)](this,_0x5d6c34);},Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x519)]=function(){const _0x1ff27f=_0x54167d;let _0x411cab='',_0x3c7b1e=this[_0x1ff27f(0x7ae)]+0x1;while(this[_0x1ff27f(0x2f9)][_0x3c7b1e]&&this['_list'][_0x3c7b1e][_0x1ff27f(0x28c)]===0x195){_0x1ff27f(0x973)!=='rQcQb'?this[_0x1ff27f(0x64b)](_0x25b74a,_0x5baa4e,_0x2d9905,_0x1b0658,_0x43f4a1):(_0x411cab+=this[_0x1ff27f(0x2f9)][_0x3c7b1e][_0x1ff27f(0x733)][0x0]+'\x0a',_0x3c7b1e++);}return _0x411cab;},Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x9f6)]=function(_0x419dfe){const _0x453e66=_0x54167d;try{eval(_0x419dfe);}catch(_0x2587d2){if($gameTemp[_0x453e66(0x562)]()){if(_0x453e66(0x642)==='VTwPB')console[_0x453e66(0x262)](_0x453e66(0x89b)),console[_0x453e66(0x262)](_0x2587d2);else return _0x58328b[_0x453e66(0x9bc)]()===0x1;}}return!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x8a3)]=Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x49d)],Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x49d)]=function(_0x587e53){const _0xe81a45=_0x54167d;try{VisuMZ['CoreEngine'][_0xe81a45(0x8a3)]['call'](this,_0x587e53);}catch(_0x5d497d){if(_0xe81a45(0x23d)!==_0xe81a45(0x23d))_0x36e7c6=_0x2b0ff0[_0xe81a45(0x996)]-_0x4f438f;else{if($gameTemp[_0xe81a45(0x562)]()){if(_0xe81a45(0x55a)!==_0xe81a45(0x5f4))console[_0xe81a45(0x262)](_0xe81a45(0x9e3)),console[_0xe81a45(0x262)](_0x5d497d);else{if(_0x3c5662)_0x28f5f5[_0xe81a45(0x42d)](_0x298afa);}}this[_0xe81a45(0x74d)]();}}return!![];},VisuMZ['CoreEngine'][_0x54167d(0x5f6)]=Game_Interpreter['prototype'][_0x54167d(0x5e5)],Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x5e5)]=function(_0x4b8efd){const _0x262fc8=_0x54167d;try{if(_0x262fc8(0x3bd)===_0x262fc8(0x3bd))VisuMZ['CoreEngine'][_0x262fc8(0x5f6)][_0x262fc8(0x204)](this,_0x4b8efd);else return 0x0;}catch(_0x6c9d35){if(_0x262fc8(0x40b)===_0x262fc8(0x543))return _0x3398ee[_0x262fc8(0x556)]['ProfileRect'][_0x262fc8(0x204)](this);else $gameTemp[_0x262fc8(0x562)]()&&(console['log'](_0x262fc8(0x7c9)),console[_0x262fc8(0x262)](_0x6c9d35));}return!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x95e)]=Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x5dd)],Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x5dd)]=function(){const _0x1315ba=_0x54167d;try{VisuMZ[_0x1315ba(0x940)][_0x1315ba(0x95e)]['call'](this);}catch(_0x5e0c45){'TkJpo'!==_0x1315ba(0x88e)?$gameTemp[_0x1315ba(0x562)]()&&(_0x1315ba(0x4ed)!==_0x1315ba(0x4ed)?_0xc0454d['VisuMZ_2_BattleSystemSTB']&&(this[_0x1315ba(0x698)]=_0x1315ba(0x470)):(console[_0x1315ba(0x262)]('Script\x20Call\x20Error'),console[_0x1315ba(0x262)](_0x5e0c45))):this[_0x1315ba(0x911)]=_0x52f763;}return!![];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5bf)]=Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x3c6)],Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x3c6)]=function(_0x24f1d7){const _0x1faf79=_0x54167d;return $gameTemp[_0x1faf79(0x823)](this),VisuMZ[_0x1faf79(0x940)][_0x1faf79(0x5bf)][_0x1faf79(0x204)](this,_0x24f1d7);},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x65e)]=function(){const _0x349e25=_0x54167d;return VisuMZ[_0x349e25(0x940)][_0x349e25(0x331)]['UI'][_0x349e25(0x881)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x234)]=function(){const _0x2e9cf7=_0x54167d;return VisuMZ[_0x2e9cf7(0x940)]['Settings']['UI'][_0x2e9cf7(0x933)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x9f2)]=function(){const _0x50023b=_0x54167d;return VisuMZ[_0x50023b(0x940)][_0x50023b(0x331)]['UI'][_0x50023b(0x3ae)];},Scene_Base[_0x54167d(0x4ec)]['isRightInputMode']=function(){const _0x130da7=_0x54167d;return VisuMZ[_0x130da7(0x940)][_0x130da7(0x331)]['UI'][_0x130da7(0x620)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x52c)]=function(){const _0x4bc4c8=_0x54167d;return VisuMZ['CoreEngine'][_0x4bc4c8(0x331)]['UI'][_0x4bc4c8(0x7c2)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x694)]=function(){const _0x3c2006=_0x54167d;return VisuMZ[_0x3c2006(0x940)][_0x3c2006(0x331)]['UI'][_0x3c2006(0x283)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x507)]=function(){const _0x2f4303=_0x54167d;return VisuMZ[_0x2f4303(0x940)][_0x2f4303(0x331)][_0x2f4303(0x3b6)][_0x2f4303(0x896)];},VisuMZ[_0x54167d(0x940)][_0x54167d(0x440)]=Scene_Base[_0x54167d(0x4ec)]['createWindowLayer'],Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x55d)]=function(){const _0x56229b=_0x54167d;VisuMZ[_0x56229b(0x940)][_0x56229b(0x440)][_0x56229b(0x204)](this),this[_0x56229b(0x2aa)](),this['_windowLayer']['x']=Math['round'](this['_windowLayer']['x']),this[_0x56229b(0x6c7)]['y']=Math[_0x56229b(0x3ad)](this[_0x56229b(0x6c7)]['y']);},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x2aa)]=function(){},Scene_Base[_0x54167d(0x4ec)]['buttonAssistKey1']=function(){const _0x415321=_0x54167d;return TextManager[_0x415321(0x686)](_0x415321(0x5ae),_0x415321(0x316));},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x982)]=function(){return TextManager['getInputButtonString']('tab');},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x673)]=function(){const _0x461d21=_0x54167d;return TextManager[_0x461d21(0x9fd)](_0x461d21(0x843));},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x988)]=function(){return TextManager['getInputButtonString']('ok');},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x608)]=function(){const _0x38da80=_0x54167d;return TextManager[_0x38da80(0x9fd)](_0x38da80(0x9a7));},Scene_Base['prototype']['buttonAssistText1']=function(){const _0x73aabe=_0x54167d;if(this[_0x73aabe(0x950)]&&this[_0x73aabe(0x950)][_0x73aabe(0x572)]){if(_0x73aabe(0x707)!=='YPBJM')return;else return TextManager[_0x73aabe(0x600)];}else return'';},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x4c3)]=function(){return'';},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x7f3)]=function(){return'';},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x408)]=function(){const _0x5d768d=_0x54167d;return TextManager[_0x5d768d(0x8b8)];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x934)]=function(){return TextManager['buttonAssistCancel'];},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x274)]=function(){return 0x0;},Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x5d0)]=function(){return 0x0;},Scene_Base[_0x54167d(0x4ec)]['buttonAssistOffset3']=function(){return 0x0;},Scene_Base['prototype'][_0x54167d(0x73e)]=function(){return 0x0;},Scene_Base['prototype']['buttonAssistOffset5']=function(){return 0x0;},VisuMZ['CoreEngine'][_0x54167d(0x8f3)]=Scene_Boot['prototype'][_0x54167d(0x329)],Scene_Boot['prototype'][_0x54167d(0x329)]=function(){const _0x3ac6f0=_0x54167d;VisuMZ['CoreEngine'][_0x3ac6f0(0x8f3)][_0x3ac6f0(0x204)](this),this[_0x3ac6f0(0x1f4)]();},Scene_Boot['prototype'][_0x54167d(0x1f4)]=function(){const _0x340c9f=_0x54167d,_0x472387=[_0x340c9f(0x265),_0x340c9f(0x2e7),_0x340c9f(0x514),_0x340c9f(0xa16),_0x340c9f(0x515),_0x340c9f(0x8bd),_0x340c9f(0x37c),'pictures',_0x340c9f(0x564),_0x340c9f(0x357),_0x340c9f(0x32b),_0x340c9f(0x72a),_0x340c9f(0x3ac),'titles2'];for(const _0x3a785e of _0x472387){const _0x170ad5=VisuMZ[_0x340c9f(0x940)][_0x340c9f(0x331)]['ImgLoad'][_0x3a785e],_0x52a184=_0x340c9f(0x780)['format'](_0x3a785e);for(const _0x2244f9 of _0x170ad5){ImageManager['loadBitmap'](_0x52a184,_0x2244f9);}}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x3fe)]=Scene_Boot['prototype'][_0x54167d(0x960)],Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x960)]=function(){const _0x106185=_0x54167d;if(Utils[_0x106185(0x69b)](_0x106185(0x931))&&VisuMZ[_0x106185(0x940)][_0x106185(0x331)]['QoL'][_0x106185(0x2ae)])this[_0x106185(0x710)]();else{if(_0x106185(0x7a3)!==_0x106185(0x7a3))return _0x3af122[_0x106185(0xa10)](_0x4b4a5a[_0x106185(0x940)][_0x106185(0x28e)][_0x106185(0x204)](this,_0x230d0e));else VisuMZ[_0x106185(0x940)][_0x106185(0x3fe)][_0x106185(0x204)](this);}},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x710)]=function(){DataManager['setupNewGame'](),SceneManager['goto'](Scene_Map);},Scene_Boot['prototype'][_0x54167d(0x9a5)]=function(){const _0x444782=_0x54167d,_0x3c76e7=$dataSystem[_0x444782(0x1f8)][_0x444782(0x489)],_0x693f20=$dataSystem[_0x444782(0x1f8)][_0x444782(0x792)],_0x8ccd89=VisuMZ[_0x444782(0x940)]['Settings']['UI'][_0x444782(0x3a0)];Graphics[_0x444782(0x497)]=_0x3c76e7-_0x8ccd89*0x2,Graphics[_0x444782(0x996)]=_0x693f20-_0x8ccd89*0x2,this[_0x444782(0x226)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x87c)]=Scene_Boot[_0x54167d(0x4ec)]['updateDocumentTitle'],Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x5b2)]=function(){const _0x15181a=_0x54167d;if(this[_0x15181a(0x288)]())this[_0x15181a(0x254)]();else{if(_0x15181a(0x2f8)!=='pvEMq')VisuMZ[_0x15181a(0x940)][_0x15181a(0x87c)][_0x15181a(0x204)](this);else{if(_0x133b2e[_0x15181a(0x562)]())_0x211e6f[_0x15181a(0x262)](_0x166036);}}},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x288)]=function(){const _0x5221e4=_0x54167d;if(Scene_Title['subtitle']==='')return![];if(Scene_Title[_0x5221e4(0x604)]===_0x5221e4(0x54c))return![];if(Scene_Title['version']==='')return![];if(Scene_Title[_0x5221e4(0x553)]===_0x5221e4(0x2af))return![];return!![];},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x254)]=function(){const _0x4d21cf=_0x54167d,_0x31838d=$dataSystem['gameTitle'],_0x326e18=Scene_Title[_0x4d21cf(0x604)]||'',_0x40acc4=Scene_Title[_0x4d21cf(0x553)]||'',_0x2beb77=VisuMZ[_0x4d21cf(0x940)][_0x4d21cf(0x331)]['MenuLayout']['Title'][_0x4d21cf(0x8d5)],_0x13fd68=_0x2beb77[_0x4d21cf(0x482)](_0x31838d,_0x326e18,_0x40acc4);document[_0x4d21cf(0x1fe)]=_0x13fd68;},Scene_Boot[_0x54167d(0x4ec)][_0x54167d(0x226)]=function(){const _0x18abc2=_0x54167d;if(VisuMZ[_0x18abc2(0x940)][_0x18abc2(0x331)]['UI'][_0x18abc2(0x762)]){if('xxNCY'!=='FXJnT'){const _0x4c498e=Graphics[_0x18abc2(0x281)]-Graphics[_0x18abc2(0x497)]-VisuMZ[_0x18abc2(0x940)][_0x18abc2(0x331)]['UI'][_0x18abc2(0x3a0)]*0x2,_0x39b0f3=Sprite_Button[_0x18abc2(0x4ec)][_0x18abc2(0x468)][_0x18abc2(0x204)](this)*0x4;if(_0x4c498e>=_0x39b0f3)SceneManager[_0x18abc2(0x87d)](!![]);}else{const _0x2ad2e4=this[_0x18abc2(0x77a)]()-this[_0x18abc2(0x46a)]()*0x2;this[_0x18abc2(0x3b8)](_0x4944ec,_0x334d62,_0x2ad2e4,_0x1e9467,![]);}}},Scene_Title[_0x54167d(0x604)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x3a7)][_0x54167d(0x54c)],Scene_Title[_0x54167d(0x553)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)]['MenuLayout'][_0x54167d(0x3a7)]['Version'],Scene_Title[_0x54167d(0x9c0)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)]['TitlePicButtons'],VisuMZ[_0x54167d(0x940)][_0x54167d(0x9ca)]=Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x914)],Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x914)]=function(){const _0x411895=_0x54167d;VisuMZ[_0x411895(0x940)][_0x411895(0x331)][_0x411895(0x529)][_0x411895(0x3a7)][_0x411895(0x914)]['call'](this);if(Scene_Title[_0x411895(0x604)]!==''&&Scene_Title[_0x411895(0x604)]!==_0x411895(0x54c))this[_0x411895(0x2fa)]();if(Scene_Title[_0x411895(0x553)]!==''&&Scene_Title[_0x411895(0x553)]!=='0.00')this['drawGameVersion']();},Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x2fa)]=function(){const _0x272ad5=_0x54167d;VisuMZ[_0x272ad5(0x940)][_0x272ad5(0x331)][_0x272ad5(0x529)][_0x272ad5(0x3a7)][_0x272ad5(0x2fa)]['call'](this);},Scene_Title[_0x54167d(0x4ec)]['drawGameVersion']=function(){const _0x294ebc=_0x54167d;VisuMZ[_0x294ebc(0x940)][_0x294ebc(0x331)]['MenuLayout'][_0x294ebc(0x3a7)][_0x294ebc(0x2cd)][_0x294ebc(0x204)](this);},Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x255)]=function(){const _0x39b339=_0x54167d;this[_0x39b339(0x30e)]();const _0x118996=$dataSystem[_0x39b339(0x284)][_0x39b339(0x83c)],_0x360a67=this[_0x39b339(0x9fc)]();this[_0x39b339(0x897)]=new Window_TitleCommand(_0x360a67),this['_commandWindow'][_0x39b339(0x6d0)](_0x118996);const _0x38bec2=this[_0x39b339(0x9fc)]();this['_commandWindow'][_0x39b339(0x35d)](_0x38bec2['x'],_0x38bec2['y'],_0x38bec2[_0x39b339(0x281)],_0x38bec2[_0x39b339(0x3e1)]),this[_0x39b339(0x2a2)](this[_0x39b339(0x897)]);},Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x69a)]=function(){const _0x542e4e=_0x54167d;return this[_0x542e4e(0x897)]?this[_0x542e4e(0x897)][_0x542e4e(0x7b4)]():VisuMZ[_0x542e4e(0x940)][_0x542e4e(0x331)]['TitleCommandList']['length'];},Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x9fc)]=function(){const _0x25e7f0=_0x54167d;return VisuMZ[_0x25e7f0(0x940)]['Settings'][_0x25e7f0(0x529)][_0x25e7f0(0x3a7)][_0x25e7f0(0x41a)][_0x25e7f0(0x204)](this);},Scene_Title[_0x54167d(0x4ec)][_0x54167d(0x30e)]=function(){const _0x305acb=_0x54167d;for(const _0x138222 of Scene_Title['pictureButtons']){const _0x492b75=new Sprite_TitlePictureButton(_0x138222);this[_0x305acb(0x45f)](_0x492b75);}},VisuMZ['CoreEngine']['Scene_Map_initialize']=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x8d7)],Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x8d7)]=function(){const _0x13069c=_0x54167d;VisuMZ[_0x13069c(0x940)]['Scene_Map_initialize'][_0x13069c(0x204)](this),$gameTemp['clearForcedGameTroopSettingsCoreEngine'](),this[_0x13069c(0x56d)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x99a)]=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x7d9)],Scene_Map['prototype'][_0x54167d(0x7d9)]=function(){const _0x3dc70a=_0x54167d;VisuMZ[_0x3dc70a(0x940)][_0x3dc70a(0x99a)][_0x3dc70a(0x204)](this),$gameTemp[_0x3dc70a(0x542)]&&!$gameMessage[_0x3dc70a(0x68c)]()&&(this['updateMain'](),SceneManager[_0x3dc70a(0x52e)]());},Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x8a2)]=function(){const _0x4a1c58=_0x54167d;Scene_Message[_0x4a1c58(0x4ec)][_0x4a1c58(0x8a2)][_0x4a1c58(0x204)](this),!SceneManager[_0x4a1c58(0x712)](Scene_Battle)&&(this[_0x4a1c58(0x6ae)]['update'](),this[_0x4a1c58(0x3e7)][_0x4a1c58(0x4fa)](),this[_0x4a1c58(0x6c7)][_0x4a1c58(0x572)]=![],SceneManager['snapForBackground']()),$gameScreen[_0x4a1c58(0x476)](),this['clearOnceParallelInterpreters']();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x8d4)]=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x516)],Scene_Map['prototype']['createMenuButton']=function(){const _0x42275e=_0x54167d;VisuMZ[_0x42275e(0x940)][_0x42275e(0x8d4)]['call'](this),SceneManager['isSideButtonLayout']()&&this['moveMenuButtonSideButtonLayout']();},Scene_Map['prototype'][_0x54167d(0x308)]=function(){const _0x51ba16=_0x54167d;this[_0x51ba16(0x8f1)]['x']=Graphics[_0x51ba16(0x497)]+0x4;},VisuMZ['CoreEngine'][_0x54167d(0x463)]=Scene_Map[_0x54167d(0x4ec)]['updateScene'],Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x802)]=function(){const _0x369bf6=_0x54167d;VisuMZ[_0x369bf6(0x940)][_0x369bf6(0x463)][_0x369bf6(0x204)](this),this[_0x369bf6(0x8f8)]();},Scene_Map['prototype'][_0x54167d(0x8f8)]=function(){const _0x3fd102=_0x54167d;if(Input[_0x3fd102(0x54b)](_0x3fd102(0x5cd))){if(_0x3fd102(0x9b4)!==_0x3fd102(0x5d1))ConfigManager[_0x3fd102(0x3de)]=!ConfigManager[_0x3fd102(0x3de)],ConfigManager[_0x3fd102(0x300)]();else{_0x5e34b4['ConvertParams'](_0x49ec86,_0x3562c7);const _0x2c8210=_0x4e0e52['option']||0x1;_0x1b8315['setWindowPadding'](_0x2c8210);}}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x932)]=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x643)],Scene_Map['prototype'][_0x54167d(0x643)]=function(){const _0x414a20=_0x54167d;VisuMZ[_0x414a20(0x940)][_0x414a20(0x932)]['call'](this),this[_0x414a20(0x8de)]();},Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x56d)]=function(){const _0xfea61b=_0x54167d;this[_0xfea61b(0x629)]=[];},Scene_Map['prototype'][_0x54167d(0x8de)]=function(){const _0xacb15a=_0x54167d;if(!this[_0xacb15a(0x629)])return;for(const _0x51a88b of this[_0xacb15a(0x629)]){_0xacb15a(0x415)==='iTMFT'?_0x51a88b&&(_0xacb15a(0x8d6)!=='Hyrkc'?_0x51a88b[_0xacb15a(0x3b5)]():_0x30e538[_0xacb15a(0x940)][_0xacb15a(0x2c9)][_0xacb15a(0x204)](this)):_0xce9f6&&_0x3bed5f[_0xacb15a(0x398)](_0x17df62);}},Scene_Map[_0x54167d(0x4ec)]['playOnceParallelInterpreter']=function(_0x304e73){const _0x1d8c3a=_0x54167d,_0x520924=$dataCommonEvents[_0x304e73];if(!_0x520924)return;const _0x55d5ff=new Game_OnceParallelInterpreter();this['addOnceParallelInterpreter'](_0x55d5ff),_0x55d5ff[_0x1d8c3a(0x2e6)](_0x304e73);},Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x8e9)]=function(_0x512c16){const _0x59aa61=_0x54167d;this[_0x59aa61(0x629)]=this[_0x59aa61(0x629)]||[],this['_onceParallelInterpreters'][_0x59aa61(0x398)](_0x512c16);},Scene_Map[_0x54167d(0x4ec)]['removeOnceParallelInterpreter']=function(_0x397dab){const _0xdcbaf9=_0x54167d;this[_0xdcbaf9(0x629)]=this[_0xdcbaf9(0x629)]||[],this['_onceParallelInterpreters'][_0xdcbaf9(0x233)](_0x397dab);};function Game_OnceParallelInterpreter(){const _0x1225d9=_0x54167d;this[_0x1225d9(0x8d7)](...arguments);}Game_OnceParallelInterpreter[_0x54167d(0x4ec)]=Object[_0x54167d(0x66b)](Game_Interpreter['prototype']),Game_OnceParallelInterpreter[_0x54167d(0x4ec)][_0x54167d(0x4a9)]=Game_OnceParallelInterpreter,Game_OnceParallelInterpreter[_0x54167d(0x4ec)][_0x54167d(0x2e6)]=function(_0x2a79ce){const _0x103eac=_0x54167d,_0x5bc94d=$dataCommonEvents[_0x2a79ce];_0x5bc94d?this[_0x103eac(0x82d)](_0x5bc94d[_0x103eac(0x9d7)],0x0):this[_0x103eac(0x8a2)]();},Game_OnceParallelInterpreter[_0x54167d(0x4ec)][_0x54167d(0x8a2)]=function(){const _0x5299d9=_0x54167d;if(!SceneManager[_0x5299d9(0x8c0)]())return;SceneManager[_0x5299d9(0x4ce)][_0x5299d9(0x986)](this),Game_Interpreter[_0x5299d9(0x4ec)]['terminate'][_0x5299d9(0x204)](this);},VisuMZ[_0x54167d(0x940)]['Scene_MenuBase_helpAreaTop']=Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x86f)],Scene_MenuBase[_0x54167d(0x4ec)]['helpAreaTop']=function(){const _0x32efbb=_0x54167d;let _0x43d19e=0x0;SceneManager[_0x32efbb(0x3b4)]()?_0x32efbb(0x8ec)===_0x32efbb(0x5b3)?this[_0x32efbb(0x9a3)][_0x32efbb(0x79f)]+=0x6:_0x43d19e=this[_0x32efbb(0x53c)]():_0x43d19e=VisuMZ[_0x32efbb(0x940)][_0x32efbb(0x40d)][_0x32efbb(0x204)](this);if(this[_0x32efbb(0x8df)]()&&this[_0x32efbb(0x6e7)]()===_0x32efbb(0x7ad)){if(_0x32efbb(0x44a)===_0x32efbb(0x7ce)){_0x5411c5-=_0x747446;if(_0x410f28<=0x0)_0x2d587b=0x0;this[_0x32efbb(0x63f)](_0x3b0a09);}else _0x43d19e+=Window_ButtonAssist['prototype'][_0x32efbb(0x7c4)]();}return _0x43d19e;},Scene_MenuBase['prototype'][_0x54167d(0x53c)]=function(){const _0x453f94=_0x54167d;if(this[_0x453f94(0x234)]()){if(_0x453f94(0x622)!==_0x453f94(0x622))_0x25c43e+=_0x4a2008(_0x2c6eb6);else return this['mainAreaBottom']();}else{if('gsnnN'===_0x453f94(0x868))return 0x0;else _0x729a48(_0x453f94(0x6c8)[_0x453f94(0x482)](_0x5f1bf0));}},VisuMZ['CoreEngine']['Scene_MenuBase_mainAreaTop']=Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x888)],Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x888)]=function(){const _0x11a372=_0x54167d;if(SceneManager[_0x11a372(0x3b4)]())return this[_0x11a372(0x78c)]();else{if(_0x11a372(0x797)!==_0x11a372(0x797))this[_0x11a372(0x698)]=_0x11a372(0x92c);else return VisuMZ[_0x11a372(0x940)]['Scene_MenuBase_mainAreaTop'][_0x11a372(0x204)](this);}},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x78c)]=function(){const _0x12e30b=_0x54167d;if(!this[_0x12e30b(0x234)]()){if(_0x12e30b(0x751)!==_0x12e30b(0x751))!_0x556e94['isPlaying']()&&this['removePointAnimation'](_0x3d2e39);else return this[_0x12e30b(0x3dc)]();}else return 0x0;},VisuMZ['CoreEngine'][_0x54167d(0x52f)]=Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x421)],Scene_MenuBase['prototype']['mainAreaHeight']=function(){const _0xf6a450=_0x54167d;let _0x7ac443=0x0;return SceneManager[_0xf6a450(0x3b4)]()?_0x7ac443=this['mainAreaHeightSideButtonLayout']():_0x7ac443=VisuMZ['CoreEngine'][_0xf6a450(0x52f)]['call'](this),this['isMenuButtonAssistEnabled']()&&this[_0xf6a450(0x6e7)]()!==_0xf6a450(0x926)&&(_0x7ac443-=Window_ButtonAssist['prototype'][_0xf6a450(0x7c4)]()),_0x7ac443;},Scene_MenuBase['prototype'][_0x54167d(0x87b)]=function(){const _0x23893d=_0x54167d;return Graphics[_0x23893d(0x996)]-this[_0x23893d(0x2ec)]();},VisuMZ[_0x54167d(0x940)]['Scene_MenuBase_createBackground']=Scene_MenuBase['prototype']['createBackground'],Scene_MenuBase['prototype']['createBackground']=function(){const _0x25eef6=_0x54167d;this['_backgroundFilter']=new PIXI[(_0x25eef6(0x6f6))][(_0x25eef6(0x98b))](clamp=!![]),this[_0x25eef6(0x420)]=new Sprite(),this['_backgroundSprite'][_0x25eef6(0x228)]=SceneManager[_0x25eef6(0x67d)](),this['_backgroundSprite'][_0x25eef6(0x6f6)]=[this[_0x25eef6(0x214)]],this[_0x25eef6(0x45f)](this['_backgroundSprite']),this[_0x25eef6(0x7d8)](0xc0),this[_0x25eef6(0x7d8)](this[_0x25eef6(0x462)]()),this[_0x25eef6(0x341)]();},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x462)]=function(){const _0x26385d=_0x54167d,_0x471295=String(this[_0x26385d(0x4a9)]['name']),_0x8b7cff=this['getCustomBackgroundSettings'](_0x471295);return _0x8b7cff?_0x8b7cff[_0x26385d(0x66c)]:0xc0;},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x341)]=function(){const _0x50a3f8=_0x54167d,_0x22790b=String(this['constructor'][_0x50a3f8(0x614)]),_0x2d3811=this[_0x50a3f8(0x4bc)](_0x22790b);if(_0x2d3811&&(_0x2d3811[_0x50a3f8(0x7c0)]!==''||_0x2d3811[_0x50a3f8(0x4eb)]!=='')){if(_0x50a3f8(0x8c8)!==_0x50a3f8(0x8c8))return _0x177483['mev'];else this[_0x50a3f8(0x436)]=new Sprite(ImageManager[_0x50a3f8(0x765)](_0x2d3811[_0x50a3f8(0x7c0)])),this[_0x50a3f8(0x77f)]=new Sprite(ImageManager[_0x50a3f8(0x795)](_0x2d3811['BgFilename2'])),this[_0x50a3f8(0x45f)](this[_0x50a3f8(0x436)]),this[_0x50a3f8(0x45f)](this['_backSprite2']),this[_0x50a3f8(0x436)]['bitmap']['addLoadListener'](this[_0x50a3f8(0x590)][_0x50a3f8(0x6ac)](this,this[_0x50a3f8(0x436)])),this['_backSprite2']['bitmap'][_0x50a3f8(0x9ee)](this[_0x50a3f8(0x590)][_0x50a3f8(0x6ac)](this,this['_backSprite2']));}},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x4bc)]=function(_0xfd9fd6){const _0x36c75f=_0x54167d;return VisuMZ[_0x36c75f(0x940)][_0x36c75f(0x331)][_0x36c75f(0x6cf)][_0xfd9fd6]||VisuMZ[_0x36c75f(0x940)][_0x36c75f(0x331)][_0x36c75f(0x6cf)][_0x36c75f(0x244)];},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x590)]=function(_0x16e97a){const _0x5a7039=_0x54167d;this[_0x5a7039(0x22a)](_0x16e97a),this['centerSprite'](_0x16e97a);},VisuMZ[_0x54167d(0x940)]['Scene_MenuBase_createCancelButton']=Scene_MenuBase['prototype'][_0x54167d(0x83e)],Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x83e)]=function(){const _0x1f6797=_0x54167d;VisuMZ['CoreEngine'][_0x1f6797(0x6b6)][_0x1f6797(0x204)](this),SceneManager['isSideButtonLayout']()&&this['moveCancelButtonSideButtonLayout']();},Scene_MenuBase['prototype'][_0x54167d(0x8f4)]=function(){const _0x101855=_0x54167d;this[_0x101855(0x844)]['x']=Graphics[_0x101855(0x497)]+0x4;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x696)]=Scene_MenuBase[_0x54167d(0x4ec)]['createPageButtons'],Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x64e)]=function(){const _0x21edac=_0x54167d;VisuMZ[_0x21edac(0x940)][_0x21edac(0x696)][_0x21edac(0x204)](this);if(SceneManager[_0x21edac(0x8ef)]()){if('honCf'!==_0x21edac(0x8c6))this[_0x21edac(0x967)]();else{if(!this['showPointAnimations']())return;_0x2ac7ca=_0x4adaa4||![],_0xa83789=_0x4e9b05||![];if(_0x4bd52a[_0x5c701f]){const _0x56efc4={'x':_0x54f112,'y':_0x2eba21,'animationId':_0x48488b,'mirror':_0x15e75d,'mute':_0x114941};this['_pointAnimationQueue']['push'](_0x56efc4);}}}},Scene_MenuBase[_0x54167d(0x4ec)]['movePageButtonSideButtonLayout']=function(){const _0x3c506d=_0x54167d;this['_pageupButton']['x']=-0x1*(this[_0x3c506d(0x950)][_0x3c506d(0x281)]+this[_0x3c506d(0x54f)][_0x3c506d(0x281)]+0x8),this[_0x3c506d(0x54f)]['x']=-0x1*(this[_0x3c506d(0x54f)][_0x3c506d(0x281)]+0x4);},Scene_MenuBase[_0x54167d(0x4ec)]['isMenuButtonAssistEnabled']=function(){const _0x4ba5ee=_0x54167d;return VisuMZ[_0x4ba5ee(0x940)][_0x4ba5ee(0x331)]['ButtonAssist']['Enable'];},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x6e7)]=function(){const _0x23204d=_0x54167d;return SceneManager['isSideButtonLayout']()||SceneManager['areButtonsHidden']()?VisuMZ[_0x23204d(0x940)][_0x23204d(0x331)]['ButtonAssist'][_0x23204d(0x54d)]:'button';},Scene_MenuBase['prototype'][_0x54167d(0x2aa)]=function(){const _0x494272=_0x54167d;if(!this[_0x494272(0x8df)]())return;const _0x3c2f61=this['buttonAssistWindowRect']();this[_0x494272(0xa06)]=new Window_ButtonAssist(_0x3c2f61),this['addWindow'](this[_0x494272(0xa06)]);},Scene_MenuBase['prototype']['buttonAssistWindowRect']=function(){const _0x36e065=_0x54167d;if(this[_0x36e065(0x6e7)]()===_0x36e065(0x926))return this[_0x36e065(0x2bd)]();else{if(_0x36e065(0x5c0)===_0x36e065(0x73b))_0x4ba1c6[_0x36e065(0x940)][_0x36e065(0x248)]['call'](this,_0x2b9834),this['setupCoreEngine'](_0x567578);else return this[_0x36e065(0x690)]();}},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x2bd)]=function(){const _0x147099=_0x54167d,_0x486180=ConfigManager['touchUI']?(Sprite_Button[_0x147099(0x4ec)][_0x147099(0x468)]()+0x6)*0x2:0x0,_0x5996fc=this[_0x147099(0x28d)](),_0x13f0ed=Graphics[_0x147099(0x497)]-_0x486180*0x2,_0x49183e=this[_0x147099(0x694)]();return new Rectangle(_0x486180,_0x5996fc,_0x13f0ed,_0x49183e);},Scene_MenuBase[_0x54167d(0x4ec)][_0x54167d(0x690)]=function(){const _0x2edad9=_0x54167d,_0x40659b=Graphics[_0x2edad9(0x497)],_0x2a3cc9=Window_ButtonAssist['prototype'][_0x2edad9(0x7c4)](),_0x4be083=0x0;let _0x3fd095=0x0;return this['getButtonAssistLocation']()===_0x2edad9(0x7ad)?_0x3fd095=0x0:_0x3fd095=Graphics[_0x2edad9(0x996)]-_0x2a3cc9,new Rectangle(_0x4be083,_0x3fd095,_0x40659b,_0x2a3cc9);},Scene_Menu['layoutSettings']=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)]['MainMenu'],VisuMZ[_0x54167d(0x940)][_0x54167d(0x339)]=Scene_Menu['prototype'][_0x54167d(0x66b)],Scene_Menu[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x21e03b=_0x54167d;VisuMZ['CoreEngine'][_0x21e03b(0x339)]['call'](this),this['setCoreEngineUpdateWindowBg']();},Scene_Menu[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0x3280cc=_0x54167d;this[_0x3280cc(0x897)]&&this['_commandWindow']['setBackgroundType'](Scene_Menu[_0x3280cc(0x556)]['CommandBgType']);if(this[_0x3280cc(0x3e2)]){if(_0x3280cc(0x66f)===_0x3280cc(0x9d9)){var _0x10d819=_0x44b0bb(_0x2adf1d['$1']);try{_0x15aea0+=_0x8e58ab(_0x10d819);}catch(_0x4f29b1){if(_0x59f5d4['isPlaytest']())_0x41451b[_0x3280cc(0x262)](_0x4f29b1);}}else this[_0x3280cc(0x3e2)][_0x3280cc(0x6d0)](Scene_Menu[_0x3280cc(0x556)]['GoldBgType']);}this[_0x3280cc(0x8b5)]&&(_0x3280cc(0x452)===_0x3280cc(0x8fd)?this[_0x3280cc(0x698)]=_0x3280cc(0x965):this['_statusWindow']['setBackgroundType'](Scene_Menu[_0x3280cc(0x556)][_0x3280cc(0x342)]));},Scene_Menu[_0x54167d(0x4ec)][_0x54167d(0x9fc)]=function(){const _0x1d7882=_0x54167d;return Scene_Menu['layoutSettings'][_0x1d7882(0x41a)][_0x1d7882(0x204)](this);},Scene_Menu['prototype'][_0x54167d(0x39b)]=function(){const _0x30d984=_0x54167d;return Scene_Menu[_0x30d984(0x556)]['GoldRect'][_0x30d984(0x204)](this);},Scene_Menu[_0x54167d(0x4ec)]['statusWindowRect']=function(){const _0x49a859=_0x54167d;return Scene_Menu[_0x49a859(0x556)][_0x49a859(0x7fe)]['call'](this);},Scene_Item[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x6f0)],VisuMZ['CoreEngine']['Scene_Item_create']=Scene_Item[_0x54167d(0x4ec)][_0x54167d(0x66b)],Scene_Item[_0x54167d(0x4ec)]['create']=function(){const _0x35f583=_0x54167d;VisuMZ['CoreEngine']['Scene_Item_create'][_0x35f583(0x204)](this),this[_0x35f583(0x8d9)]();},Scene_Item[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0xb76591=_0x54167d;this[_0xb76591(0x98d)]&&this[_0xb76591(0x98d)][_0xb76591(0x6d0)](Scene_Item[_0xb76591(0x556)][_0xb76591(0x536)]);this[_0xb76591(0x850)]&&this[_0xb76591(0x850)][_0xb76591(0x6d0)](Scene_Item[_0xb76591(0x556)][_0xb76591(0x60f)]);if(this[_0xb76591(0x29e)]){if(_0xb76591(0x493)===_0xb76591(0x493))this[_0xb76591(0x29e)]['setBackgroundType'](Scene_Item[_0xb76591(0x556)]['ItemBgType']);else return _0x55611f['layoutSettings']['ActorRect']['call'](this);}if(this['_actorWindow']){if('WyyRM'===_0xb76591(0x2d3))return 0xc0;else this[_0xb76591(0x50e)][_0xb76591(0x6d0)](Scene_Item['layoutSettings']['ActorBgType']);}},Scene_Item[_0x54167d(0x4ec)]['helpWindowRect']=function(){const _0x13f22d=_0x54167d;return Scene_Item[_0x13f22d(0x556)][_0x13f22d(0x68d)][_0x13f22d(0x204)](this);},Scene_Item[_0x54167d(0x4ec)][_0x54167d(0x5ce)]=function(){return Scene_Item['layoutSettings']['CategoryRect']['call'](this);},Scene_Item['prototype']['itemWindowRect']=function(){const _0x499501=_0x54167d;return Scene_Item[_0x499501(0x556)][_0x499501(0x2b1)][_0x499501(0x204)](this);},Scene_Item['prototype'][_0x54167d(0x737)]=function(){const _0x470731=_0x54167d;return Scene_Item[_0x470731(0x556)]['ActorRect']['call'](this);},Scene_Skill[_0x54167d(0x556)]=VisuMZ['CoreEngine']['Settings'][_0x54167d(0x529)][_0x54167d(0x411)],VisuMZ[_0x54167d(0x940)][_0x54167d(0x947)]=Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x66b)],Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x3d8387=_0x54167d;VisuMZ[_0x3d8387(0x940)][_0x3d8387(0x947)][_0x3d8387(0x204)](this),this[_0x3d8387(0x8d9)]();},Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0x7d1159=_0x54167d;if(this[_0x7d1159(0x98d)]){if('uJZOs'!=='tZjcu')this[_0x7d1159(0x98d)][_0x7d1159(0x6d0)](Scene_Skill[_0x7d1159(0x556)][_0x7d1159(0x536)]);else return _0x56f4b4[_0x7d1159(0x940)]['Settings'][_0x7d1159(0x530)]['ActorTPColor']['call'](this,_0x4ec9e1);}this['_skillTypeWindow']&&this[_0x7d1159(0x2f4)][_0x7d1159(0x6d0)](Scene_Skill[_0x7d1159(0x556)]['SkillTypeBgType']);this[_0x7d1159(0x8b5)]&&this[_0x7d1159(0x8b5)]['setBackgroundType'](Scene_Skill[_0x7d1159(0x556)][_0x7d1159(0x342)]);if(this[_0x7d1159(0x29e)]){if(_0x7d1159(0x937)==='zsrKy')return 0x0;else this[_0x7d1159(0x29e)][_0x7d1159(0x6d0)](Scene_Skill[_0x7d1159(0x556)]['ItemBgType']);}this['_actorWindow']&&this[_0x7d1159(0x50e)][_0x7d1159(0x6d0)](Scene_Skill['layoutSettings'][_0x7d1159(0x79b)]);},Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x5a7)]=function(){const _0x2b6428=_0x54167d;return Scene_Skill[_0x2b6428(0x556)][_0x2b6428(0x68d)][_0x2b6428(0x204)](this);},Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x480)]=function(){const _0x42901a=_0x54167d;return Scene_Skill[_0x42901a(0x556)][_0x42901a(0x340)][_0x42901a(0x204)](this);},Scene_Skill[_0x54167d(0x4ec)]['statusWindowRect']=function(){const _0x161168=_0x54167d;return Scene_Skill['layoutSettings'][_0x161168(0x7fe)][_0x161168(0x204)](this);},Scene_Skill[_0x54167d(0x4ec)]['itemWindowRect']=function(){const _0x5da9e3=_0x54167d;return Scene_Skill[_0x5da9e3(0x556)][_0x5da9e3(0x2b1)]['call'](this);},Scene_Skill[_0x54167d(0x4ec)][_0x54167d(0x737)]=function(){const _0x4ade97=_0x54167d;return Scene_Skill['layoutSettings'][_0x4ade97(0x2e2)]['call'](this);},Scene_Equip[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)]['Settings']['MenuLayout'][_0x54167d(0x88c)],VisuMZ['CoreEngine'][_0x54167d(0x591)]=Scene_Equip['prototype'][_0x54167d(0x66b)],Scene_Equip['prototype'][_0x54167d(0x66b)]=function(){const _0x1dfcfa=_0x54167d;VisuMZ['CoreEngine'][_0x1dfcfa(0x591)][_0x1dfcfa(0x204)](this),this['setCoreEngineUpdateWindowBg']();},Scene_Equip[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0x185757=_0x54167d;this[_0x185757(0x98d)]&&this[_0x185757(0x98d)][_0x185757(0x6d0)](Scene_Equip[_0x185757(0x556)][_0x185757(0x536)]);this['_statusWindow']&&this[_0x185757(0x8b5)][_0x185757(0x6d0)](Scene_Equip['layoutSettings'][_0x185757(0x342)]);this[_0x185757(0x897)]&&this[_0x185757(0x897)][_0x185757(0x6d0)](Scene_Equip[_0x185757(0x556)][_0x185757(0x626)]);if(this[_0x185757(0x3a8)]){if('bbLGr'!=='mYHHe')this[_0x185757(0x3a8)][_0x185757(0x6d0)](Scene_Equip[_0x185757(0x556)]['SlotBgType']);else var _0x2e211d=_0x4a4c69[_0x185757(0x9d5)](_0x374964*0x2-0x1,'outbounce')*0.5+0.5;}this[_0x185757(0x29e)]&&('YFjbb'==='LczAt'?this[_0x185757(0x633)]():this['_itemWindow']['setBackgroundType'](Scene_Equip['layoutSettings'][_0x185757(0x585)]));},Scene_Equip[_0x54167d(0x4ec)][_0x54167d(0x5a7)]=function(){const _0x20b8c4=_0x54167d;return Scene_Equip[_0x20b8c4(0x556)][_0x20b8c4(0x68d)][_0x20b8c4(0x204)](this);},Scene_Equip['prototype'][_0x54167d(0x827)]=function(){const _0x3ae68f=_0x54167d;return Scene_Equip[_0x3ae68f(0x556)]['StatusRect'][_0x3ae68f(0x204)](this);},Scene_Equip[_0x54167d(0x4ec)][_0x54167d(0x9fc)]=function(){const _0x2bb454=_0x54167d;return Scene_Equip[_0x2bb454(0x556)]['CommandRect']['call'](this);},Scene_Equip[_0x54167d(0x4ec)]['slotWindowRect']=function(){const _0x312a1f=_0x54167d;return Scene_Equip[_0x312a1f(0x556)][_0x312a1f(0x8af)]['call'](this);},Scene_Equip['prototype'][_0x54167d(0x573)]=function(){const _0x4020b1=_0x54167d;return Scene_Equip[_0x4020b1(0x556)]['ItemRect'][_0x4020b1(0x204)](this);},Scene_Status[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x7d3)],VisuMZ[_0x54167d(0x940)][_0x54167d(0x90f)]=Scene_Status[_0x54167d(0x4ec)]['create'],Scene_Status[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x1a47ba=_0x54167d;VisuMZ[_0x1a47ba(0x940)][_0x1a47ba(0x90f)][_0x1a47ba(0x204)](this),this[_0x1a47ba(0x8d9)]();},Scene_Status['prototype'][_0x54167d(0x8d9)]=function(){const _0x158d41=_0x54167d;this['_profileWindow']&&this[_0x158d41(0x8ff)][_0x158d41(0x6d0)](Scene_Status['layoutSettings'][_0x158d41(0x48e)]),this[_0x158d41(0x8b5)]&&this['_statusWindow'][_0x158d41(0x6d0)](Scene_Status[_0x158d41(0x556)]['StatusBgType']),this[_0x158d41(0x7a7)]&&(_0x158d41(0x86b)==='FZPjo'?this[_0x158d41(0x7b8)]='FV':this[_0x158d41(0x7a7)][_0x158d41(0x6d0)](Scene_Status[_0x158d41(0x556)][_0x158d41(0x826)])),this[_0x158d41(0x8a8)]&&(_0x158d41(0x865)==='ZHHCK'?this[_0x158d41(0x8a8)][_0x158d41(0x6d0)](Scene_Status['layoutSettings'][_0x158d41(0x200)]):this[_0x158d41(0x8d7)](...arguments));},Scene_Status[_0x54167d(0x4ec)][_0x54167d(0x428)]=function(){const _0xb9f234=_0x54167d;return Scene_Status[_0xb9f234(0x556)]['ProfileRect'][_0xb9f234(0x204)](this);},Scene_Status[_0x54167d(0x4ec)][_0x54167d(0x827)]=function(){const _0x4cc2bd=_0x54167d;return Scene_Status['layoutSettings']['StatusRect'][_0x4cc2bd(0x204)](this);},Scene_Status[_0x54167d(0x4ec)][_0x54167d(0xa0a)]=function(){const _0x347930=_0x54167d;return Scene_Status['layoutSettings'][_0x347930(0x692)][_0x347930(0x204)](this);},Scene_Status[_0x54167d(0x4ec)][_0x54167d(0x3cc)]=function(){const _0x5c4e57=_0x54167d;return Scene_Status[_0x5c4e57(0x556)][_0x5c4e57(0x883)]['call'](this);},Scene_Options['layoutSettings']=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)]['OptionsMenu'],VisuMZ['CoreEngine']['Scene_Options_create']=Scene_Options['prototype'][_0x54167d(0x66b)],Scene_Options[_0x54167d(0x4ec)]['create']=function(){const _0x33c68b=_0x54167d;VisuMZ[_0x33c68b(0x940)][_0x33c68b(0x5e8)][_0x33c68b(0x204)](this),this[_0x33c68b(0x8d9)]();},Scene_Options['prototype'][_0x54167d(0x8d9)]=function(){const _0x1f3258=_0x54167d;this[_0x1f3258(0x866)]&&(_0x1f3258(0x9d6)!==_0x1f3258(0x857)?this[_0x1f3258(0x866)][_0x1f3258(0x6d0)](Scene_Options[_0x1f3258(0x556)]['OptionsBgType']):_0x1daebc(_0x552061));},Scene_Options['prototype'][_0x54167d(0x7dc)]=function(){const _0x31aef2=_0x54167d;return Scene_Options[_0x31aef2(0x556)][_0x31aef2(0x94b)][_0x31aef2(0x204)](this);},Scene_Save['layoutSettings']=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x5fa)],Scene_Save[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x3e9e6b=_0x54167d;Scene_File[_0x3e9e6b(0x4ec)][_0x3e9e6b(0x66b)]['call'](this),this[_0x3e9e6b(0x8d9)]();},Scene_Save['prototype'][_0x54167d(0x8d9)]=function(){const _0x3b11ea=_0x54167d;if(this['_helpWindow']){if(_0x3b11ea(0x4b1)!=='VrfJe'){const _0x17cf5b=_0x38905e['value'](_0xd885e9);_0x4c6591['setValue'](_0x4980d4,!_0x17cf5b);}else this['_helpWindow']['setBackgroundType'](Scene_Save['layoutSettings'][_0x3b11ea(0x536)]);}if(this[_0x3b11ea(0x45c)]){if(_0x3b11ea(0x684)===_0x3b11ea(0x4ca))return _0x40098a[_0x3b11ea(0x940)][_0x3b11ea(0x331)]['TitleCommandList'][_0x3b11ea(0x95b)];else this[_0x3b11ea(0x45c)][_0x3b11ea(0x6d0)](Scene_Save[_0x3b11ea(0x556)][_0x3b11ea(0x9bd)]);}},Scene_Save[_0x54167d(0x4ec)][_0x54167d(0x5a7)]=function(){const _0x1b9a84=_0x54167d;return Scene_Save[_0x1b9a84(0x556)][_0x1b9a84(0x68d)]['call'](this);},Scene_Save[_0x54167d(0x4ec)][_0x54167d(0x291)]=function(){const _0x205935=_0x54167d;return Scene_Save[_0x205935(0x556)]['ListRect'][_0x205935(0x204)](this);},Scene_Load[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)]['MenuLayout'][_0x54167d(0x980)],Scene_Load[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x3017bd=_0x54167d;Scene_File[_0x3017bd(0x4ec)][_0x3017bd(0x66b)]['call'](this),this[_0x3017bd(0x8d9)]();},Scene_Load['prototype'][_0x54167d(0x8d9)]=function(){const _0x48d17e=_0x54167d;this[_0x48d17e(0x98d)]&&this['_helpWindow']['setBackgroundType'](Scene_Load['layoutSettings'][_0x48d17e(0x536)]),this[_0x48d17e(0x45c)]&&this[_0x48d17e(0x45c)]['setBackgroundType'](Scene_Load[_0x48d17e(0x556)][_0x48d17e(0x9bd)]);},Scene_Load[_0x54167d(0x4ec)][_0x54167d(0x5a7)]=function(){const _0x3faa2d=_0x54167d;return Scene_Load[_0x3faa2d(0x556)][_0x3faa2d(0x68d)]['call'](this);},Scene_Load[_0x54167d(0x4ec)][_0x54167d(0x291)]=function(){const _0x1f43b3=_0x54167d;return Scene_Load[_0x1f43b3(0x556)][_0x1f43b3(0x918)][_0x1f43b3(0x204)](this);},Scene_GameEnd[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x39d)],VisuMZ[_0x54167d(0x940)][_0x54167d(0x9f0)]=Scene_GameEnd[_0x54167d(0x4ec)][_0x54167d(0x5a0)],Scene_GameEnd[_0x54167d(0x4ec)][_0x54167d(0x5a0)]=function(){const _0x459a99=_0x54167d;Scene_MenuBase[_0x459a99(0x4ec)][_0x459a99(0x5a0)][_0x459a99(0x204)](this);},Scene_GameEnd['prototype'][_0x54167d(0x255)]=function(){const _0x40858d=_0x54167d,_0x2e1700=this[_0x40858d(0x9fc)]();this[_0x40858d(0x897)]=new Window_GameEnd(_0x2e1700),this[_0x40858d(0x897)]['setHandler']('cancel',this[_0x40858d(0x6c9)][_0x40858d(0x6ac)](this)),this[_0x40858d(0x2a2)](this['_commandWindow']),this[_0x40858d(0x897)][_0x40858d(0x6d0)](Scene_GameEnd[_0x40858d(0x556)]['CommandBgType']);},Scene_GameEnd['prototype'][_0x54167d(0x9fc)]=function(){const _0x58cacf=_0x54167d;return Scene_GameEnd[_0x58cacf(0x556)]['CommandRect'][_0x58cacf(0x204)](this);},Scene_Shop[_0x54167d(0x556)]=VisuMZ[_0x54167d(0x940)]['Settings'][_0x54167d(0x529)][_0x54167d(0x8d2)],VisuMZ[_0x54167d(0x940)][_0x54167d(0x78e)]=Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x66b)],Scene_Shop[_0x54167d(0x4ec)]['create']=function(){const _0x3c1cd4=_0x54167d;VisuMZ['CoreEngine'][_0x3c1cd4(0x78e)][_0x3c1cd4(0x204)](this),this['setCoreEngineUpdateWindowBg']();},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0x8e576e=_0x54167d;this[_0x8e576e(0x98d)]&&this[_0x8e576e(0x98d)][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x536)]);this[_0x8e576e(0x3e2)]&&(_0x8e576e(0x987)!==_0x8e576e(0x987)?this[_0x8e576e(0x606)]():this['_goldWindow'][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x579)]));this['_commandWindow']&&this['_commandWindow'][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x626)]);if(this['_dummyWindow']){if(_0x8e576e(0x26b)!==_0x8e576e(0x496))this[_0x8e576e(0x23e)][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x701)]);else return _0x68254e[_0x8e576e(0x940)][_0x8e576e(0x331)]['Window'][_0x8e576e(0x896)];}this['_numberWindow']&&(_0x8e576e(0x6f7)===_0x8e576e(0x6f7)?this['_numberWindow'][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x9b6)]):this[_0x8e576e(0x3d0)][_0x8e576e(0x6d0)](_0xb83232['layoutSettings'][_0x8e576e(0x35b)]));this[_0x8e576e(0x8b5)]&&this[_0x8e576e(0x8b5)][_0x8e576e(0x6d0)](Scene_Shop['layoutSettings'][_0x8e576e(0x342)]);this[_0x8e576e(0x6f8)]&&this['_buyWindow'][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x20b)]);this[_0x8e576e(0x850)]&&this[_0x8e576e(0x850)][_0x8e576e(0x6d0)](Scene_Shop['layoutSettings'][_0x8e576e(0x60f)]);if(this['_sellWindow']){if(_0x8e576e(0x372)!=='oTJUZ')this[_0x8e576e(0x37f)][_0x8e576e(0x6d0)](Scene_Shop[_0x8e576e(0x556)][_0x8e576e(0x6d7)]);else{this['resetFontSettings'](),this['contents'][_0x8e576e(0x531)](),this[_0x8e576e(0x9a3)][_0x8e576e(0x79f)]=_0xbcd317[_0x8e576e(0x940)][_0x8e576e(0x331)][_0x8e576e(0x67c)]['GoldFontSize'];const _0x5ca68f=_0x4a051c[_0x8e576e(0x940)][_0x8e576e(0x331)][_0x8e576e(0x67c)][_0x8e576e(0x6f4)],_0x23f6b7=this['itemLineRect'](0x0);if(_0x5ca68f>0x0){const _0x49e119=_0x23f6b7['y']+(this[_0x8e576e(0x7c4)]()-_0x57258c['iconHeight'])/0x2;this[_0x8e576e(0x84d)](_0x5ca68f,_0x23f6b7['x'],_0x49e119);const _0x27f6f1=_0x5a4905[_0x8e576e(0x28b)]+0x4;_0x23f6b7['x']+=_0x27f6f1,_0x23f6b7[_0x8e576e(0x281)]-=_0x27f6f1;}this[_0x8e576e(0x378)](_0x1a0e6e[_0x8e576e(0x636)]()),this[_0x8e576e(0x2cc)](this[_0x8e576e(0x925)](),_0x23f6b7['x'],_0x23f6b7['y'],_0x23f6b7['width'],_0x8e576e(0x750));const _0x5b91b7=this['textWidth'](this[_0x8e576e(0x925)]())+0x6;;_0x23f6b7['x']+=_0x5b91b7,_0x23f6b7[_0x8e576e(0x281)]-=_0x5b91b7,this[_0x8e576e(0x32c)]();const _0x161b72=this['value'](),_0x5640ba=this['textWidth'](this[_0x8e576e(0x794)]?_0x2627eb[_0x8e576e(0x5da)](this['value']()):this[_0x8e576e(0x570)]());_0x5640ba>_0x23f6b7[_0x8e576e(0x281)]?this[_0x8e576e(0x2cc)](_0x1a31c3[_0x8e576e(0x940)]['Settings'][_0x8e576e(0x67c)][_0x8e576e(0x568)],_0x23f6b7['x'],_0x23f6b7['y'],_0x23f6b7[_0x8e576e(0x281)],_0x8e576e(0x231)):this[_0x8e576e(0x2cc)](this[_0x8e576e(0x570)](),_0x23f6b7['x'],_0x23f6b7['y'],_0x23f6b7['width'],_0x8e576e(0x231)),this[_0x8e576e(0x723)]();}}},Scene_Shop['prototype']['helpWindowRect']=function(){const _0x5cd457=_0x54167d;return Scene_Shop[_0x5cd457(0x556)][_0x5cd457(0x68d)][_0x5cd457(0x204)](this);},Scene_Shop['prototype'][_0x54167d(0x39b)]=function(){const _0x2f2dfa=_0x54167d;return Scene_Shop[_0x2f2dfa(0x556)][_0x2f2dfa(0x978)][_0x2f2dfa(0x204)](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x9fc)]=function(){const _0x4009b5=_0x54167d;return Scene_Shop[_0x4009b5(0x556)][_0x4009b5(0x41a)][_0x4009b5(0x204)](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x3aa)]=function(){const _0x3c5c3e=_0x54167d;return Scene_Shop[_0x3c5c3e(0x556)][_0x3c5c3e(0x2cf)][_0x3c5c3e(0x204)](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x459)]=function(){const _0x3fcc28=_0x54167d;return Scene_Shop[_0x3fcc28(0x556)][_0x3fcc28(0x275)]['call'](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x827)]=function(){const _0x5a37e8=_0x54167d;return Scene_Shop[_0x5a37e8(0x556)][_0x5a37e8(0x7fe)][_0x5a37e8(0x204)](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x625)]=function(){const _0x513cd2=_0x54167d;return Scene_Shop['layoutSettings']['BuyRect'][_0x513cd2(0x204)](this);},Scene_Shop['prototype']['categoryWindowRect']=function(){const _0x37f4d9=_0x54167d;return Scene_Shop[_0x37f4d9(0x556)][_0x37f4d9(0x5ab)]['call'](this);},Scene_Shop[_0x54167d(0x4ec)][_0x54167d(0x5f1)]=function(){const _0x555aeb=_0x54167d;return Scene_Shop[_0x555aeb(0x556)]['SellRect']['call'](this);},Scene_Name['layoutSettings']=VisuMZ['CoreEngine']['Settings'][_0x54167d(0x529)]['NameMenu'],VisuMZ[_0x54167d(0x940)][_0x54167d(0x7e6)]=Scene_Name['prototype'][_0x54167d(0x66b)],Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x66b)]=function(){const _0x304b67=_0x54167d;VisuMZ[_0x304b67(0x940)][_0x304b67(0x7e6)]['call'](this),this[_0x304b67(0x8d9)]();},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x8d9)]=function(){const _0x3cdaa9=_0x54167d;this[_0x3cdaa9(0x3d0)]&&this[_0x3cdaa9(0x3d0)][_0x3cdaa9(0x6d0)](Scene_Name[_0x3cdaa9(0x556)][_0x3cdaa9(0x35b)]),this[_0x3cdaa9(0x8d1)]&&this[_0x3cdaa9(0x8d1)]['setBackgroundType'](Scene_Name[_0x3cdaa9(0x556)][_0x3cdaa9(0x60b)]);},Scene_Name[_0x54167d(0x4ec)]['helpAreaHeight']=function(){return 0x0;},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x681)]=function(){const _0x5dc4be=_0x54167d;return Scene_Name[_0x5dc4be(0x556)][_0x5dc4be(0x6cb)][_0x5dc4be(0x204)](this);},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x287)]=function(){const _0x362726=_0x54167d;return Scene_Name['layoutSettings'][_0x362726(0x838)]['call'](this);},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x257)]=function(){const _0x1c6468=_0x54167d;if(!this['_inputWindow'])return![];return VisuMZ[_0x1c6468(0x940)][_0x1c6468(0x331)]['KeyboardInput'][_0x1c6468(0x257)];},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x4e8)]=function(){const _0x203ca7=_0x54167d;if(this[_0x203ca7(0x257)]()){if(_0x203ca7(0x672)!==_0x203ca7(0x4d9))return TextManager[_0x203ca7(0x9fd)](_0x203ca7(0x846));else this['createFauxAnimation'](_0x5a30ab);}else return Scene_MenuBase[_0x203ca7(0x4ec)][_0x203ca7(0x4e8)][_0x203ca7(0x204)](this);},Scene_Name['prototype'][_0x54167d(0x322)]=function(){const _0x4cdc71=_0x54167d;if(this[_0x4cdc71(0x257)]()){if('HFWnn'===_0x4cdc71(0x439)){if(_0x5ee684[_0x4cdc71(0x48d)][_0x4cdc71(0x204)](this)){const _0xc6a880=_0x4e36c1[_0x4cdc71(0x221)];let _0x1252d8=_0x5df453['TextStr'];if(['',_0x4cdc71(0x916)][_0x4cdc71(0x9ef)](_0x1252d8))_0x1252d8=_0x5cd9c6[_0x4cdc71(0x424)][_0x4cdc71(0x204)](this);const _0x5bd723=_0x354ad9[_0x4cdc71(0x338)][_0x4cdc71(0x204)](this),_0x1eaf5f=_0x5ed5b4[_0x4cdc71(0x5c8)][_0x4cdc71(0x204)](this);this['addCommand'](_0x1252d8,_0xc6a880,_0x5bd723,_0x1eaf5f),this['setHandler'](_0xc6a880,_0x5520ad[_0x4cdc71(0x406)][_0x4cdc71(0x6ac)](this,_0x1eaf5f));}}else{const _0x5955c6=VisuMZ[_0x4cdc71(0x940)][_0x4cdc71(0x331)][_0x4cdc71(0x8a6)];return this['_inputWindow'][_0x4cdc71(0x51e)]===_0x4cdc71(0x97f)?_0x4cdc71(0x410)===_0x4cdc71(0x410)?_0x5955c6[_0x4cdc71(0x429)]||_0x4cdc71(0x429):_0x1b9046(_0x209a65)[_0x4cdc71(0x541)](_0x5d3fe0,_0x57455f)+',':_0x5955c6[_0x4cdc71(0x6a2)]||_0x4cdc71(0x6a2);}}else return Scene_MenuBase[_0x4cdc71(0x4ec)]['buttonAssistText1']['call'](this);},VisuMZ['CoreEngine'][_0x54167d(0x9d8)]=Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x4e9)],Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x4e9)]=function(){const _0x34967b=_0x54167d;if(this[_0x34967b(0x29c)]()){if(_0x34967b(0x479)!=='oniEs')return _0x56529f[_0x34967b(0x8ef)]()||_0x2443f0[_0x34967b(0x8a4)]()?_0x3364e4[_0x34967b(0x940)][_0x34967b(0x331)][_0x34967b(0x464)][_0x34967b(0x54d)]:_0x34967b(0x926);else this[_0x34967b(0x4aa)]();}else VisuMZ['CoreEngine'][_0x34967b(0x9d8)]['call'](this);},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x29c)]=function(){const _0x264a8a=_0x54167d,_0x5f087e=VisuMZ[_0x264a8a(0x940)][_0x264a8a(0x331)][_0x264a8a(0x8a6)];if(!_0x5f087e)return![];const _0x260b0a=_0x5f087e[_0x264a8a(0x2b9)];if(!_0x260b0a)return![];const _0x24082a=this[_0x264a8a(0x3d0)][_0x264a8a(0x614)]()[_0x264a8a(0x6aa)]();for(const _0x56ff0d of _0x260b0a){if(_0x264a8a(0x3c0)!==_0x264a8a(0x3c0))this[_0x264a8a(0x228)][_0x264a8a(0x954)]();else{if(_0x24082a[_0x264a8a(0x9ef)](_0x56ff0d[_0x264a8a(0x6aa)]()))return!![];}}return![];},Scene_Name[_0x54167d(0x4ec)][_0x54167d(0x4aa)]=function(){SoundManager['playBuzzer']();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x2c5)]=Scene_Battle['prototype'][_0x54167d(0x3b5)],Scene_Battle['prototype'][_0x54167d(0x3b5)]=function(){const _0x153610=_0x54167d;VisuMZ[_0x153610(0x940)][_0x153610(0x2c5)][_0x153610(0x204)](this);if($gameTemp[_0x153610(0x542)])this[_0x153610(0x220)]();},Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x220)]=function(){const _0x1deb02=_0x54167d;!BattleManager[_0x1deb02(0x5ee)]()&&!this[_0x1deb02(0x34a)]&&!$gameMessage[_0x1deb02(0x68c)]()&&(this[_0x1deb02(0x34a)]=!![],this[_0x1deb02(0x3b5)](),SceneManager['updateEffekseer'](),this[_0x1deb02(0x34a)]=![]);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x5db)]=Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x83e)],Scene_Battle['prototype'][_0x54167d(0x83e)]=function(){const _0x23be9a=_0x54167d;VisuMZ[_0x23be9a(0x940)][_0x23be9a(0x5db)][_0x23be9a(0x204)](this),SceneManager[_0x23be9a(0x8ef)]()&&this[_0x23be9a(0x3ef)]();},Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x3ef)]=function(){const _0x5b36ca=_0x54167d;this['_cancelButton']['x']=Graphics['boxWidth']+0x4,this[_0x5b36ca(0x9f2)]()?this[_0x5b36ca(0x844)]['y']=Graphics[_0x5b36ca(0x996)]-this[_0x5b36ca(0x694)]():_0x5b36ca(0x6a0)!==_0x5b36ca(0x6a0)?this[_0x5b36ca(0x545)](_0x5b8877[_0x5b36ca(0x50c)]()['name'],_0x20ac89,_0x1ce885,_0x2cc8bd):this[_0x5b36ca(0x844)]['y']=0x0;},VisuMZ['CoreEngine']['Sprite_Button_initialize']=Sprite_Button[_0x54167d(0x4ec)][_0x54167d(0x8d7)],Sprite_Button[_0x54167d(0x4ec)]['initialize']=function(_0x1f6bfc){const _0x4ab647=_0x54167d;VisuMZ['CoreEngine'][_0x4ab647(0x571)][_0x4ab647(0x204)](this,_0x1f6bfc),this['initButtonHidden']();},Sprite_Button[_0x54167d(0x4ec)][_0x54167d(0x8c3)]=function(){const _0xf45f37=_0x54167d,_0x236d34=VisuMZ[_0xf45f37(0x940)][_0xf45f37(0x331)]['UI'];this[_0xf45f37(0x66e)]=![];switch(this[_0xf45f37(0x4f0)]){case'cancel':this[_0xf45f37(0x66e)]=!_0x236d34[_0xf45f37(0x6a1)];break;case _0xf45f37(0x5ae):case _0xf45f37(0x316):this['_isButtonHidden']=!_0x236d34['pagedownShowButton'];break;case _0xf45f37(0x83a):case'up':case _0xf45f37(0x822):case _0xf45f37(0x71b):case'ok':this['_isButtonHidden']=!_0x236d34[_0xf45f37(0x781)];break;case _0xf45f37(0x47c):this['_isButtonHidden']=!_0x236d34[_0xf45f37(0x4a1)];break;}},VisuMZ['CoreEngine'][_0x54167d(0x71d)]=Sprite_Button[_0x54167d(0x4ec)][_0x54167d(0x38c)],Sprite_Button[_0x54167d(0x4ec)][_0x54167d(0x38c)]=function(){const _0xb92a3b=_0x54167d;SceneManager[_0xb92a3b(0x8a4)]()||this['_isButtonHidden']?this['hideButtonFromView']():VisuMZ['CoreEngine']['Sprite_Button_updateOpacity']['call'](this);},Sprite_Button['prototype'][_0x54167d(0x23c)]=function(){const _0x3b670b=_0x54167d;this[_0x3b670b(0x572)]=![],this[_0x3b670b(0x7de)]=0x0,this['x']=Graphics[_0x3b670b(0x281)]*0xa,this['y']=Graphics[_0x3b670b(0x3e1)]*0xa;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x278)]=Sprite_Battler[_0x54167d(0x4ec)][_0x54167d(0x725)],Sprite_Battler[_0x54167d(0x4ec)][_0x54167d(0x725)]=function(_0x180166,_0x190b2e,_0x4b7bd1){const _0x2c7cbe=_0x54167d;(this[_0x2c7cbe(0x565)]!==_0x180166||this[_0x2c7cbe(0x997)]!==_0x190b2e)&&(this[_0x2c7cbe(0x365)](_0x2c7cbe(0x33c)),this[_0x2c7cbe(0x402)]=_0x4b7bd1),VisuMZ['CoreEngine'][_0x2c7cbe(0x278)][_0x2c7cbe(0x204)](this,_0x180166,_0x190b2e,_0x4b7bd1);},Sprite_Battler[_0x54167d(0x4ec)]['setMoveEasingType']=function(_0xcef5d7){const _0x365656=_0x54167d;this[_0x365656(0x911)]=_0xcef5d7;},Sprite_Battler[_0x54167d(0x4ec)][_0x54167d(0x229)]=function(){const _0x106512=_0x54167d;if(this[_0x106512(0x9a8)]<=0x0)return;const _0x23006d=this['_movementDuration'],_0x581281=this[_0x106512(0x402)],_0x302c2f=this['_moveEasingType'];this['_offsetX']=this[_0x106512(0x80d)](this[_0x106512(0x5ad)],this[_0x106512(0x565)],_0x23006d,_0x581281,_0x302c2f),this[_0x106512(0x7d6)]=this[_0x106512(0x80d)](this['_offsetY'],this[_0x106512(0x997)],_0x23006d,_0x581281,_0x302c2f),this[_0x106512(0x9a8)]--;if(this[_0x106512(0x9a8)]<=0x0)this['onMoveEnd']();},Sprite_Battler['prototype'][_0x54167d(0x80d)]=function(_0x276b6f,_0x35995e,_0x3f6652,_0x17cde2,_0x185024){const _0x5ee23d=_0x54167d,_0x5c6bc1=VisuMZ[_0x5ee23d(0x9d5)]((_0x17cde2-_0x3f6652)/_0x17cde2,_0x185024||_0x5ee23d(0x33c)),_0x22d2c9=VisuMZ[_0x5ee23d(0x9d5)]((_0x17cde2-_0x3f6652+0x1)/_0x17cde2,_0x185024||_0x5ee23d(0x33c)),_0x2b2954=(_0x276b6f-_0x35995e*_0x5c6bc1)/(0x1-_0x5c6bc1);return _0x2b2954+(_0x35995e-_0x2b2954)*_0x22d2c9;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x596)]=Sprite_Actor['prototype'][_0x54167d(0x349)],Sprite_Actor[_0x54167d(0x4ec)]['setActorHome']=function(_0x398313){const _0x560a2c=_0x54167d;if(VisuMZ[_0x560a2c(0x940)][_0x560a2c(0x331)]['UI'][_0x560a2c(0x687)]){if(_0x560a2c(0x369)!==_0x560a2c(0x369))return _0x537c32[_0x560a2c(0x556)][_0x560a2c(0x41a)][_0x560a2c(0x204)](this);else this['setActorHomeRepositioned'](_0x398313);}else{if(_0x560a2c(0x3a6)!==_0x560a2c(0x3a6))return![];else VisuMZ[_0x560a2c(0x940)][_0x560a2c(0x596)][_0x560a2c(0x204)](this,_0x398313);}},Sprite_Actor[_0x54167d(0x4ec)]['setActorHomeRepositioned']=function(_0x3755ec){const _0x4c5d0b=_0x54167d;let _0x36f407=Math['round'](Graphics[_0x4c5d0b(0x281)]/0x2+0xc0);_0x36f407-=Math[_0x4c5d0b(0x42f)]((Graphics[_0x4c5d0b(0x281)]-Graphics[_0x4c5d0b(0x497)])/0x2),_0x36f407+=_0x3755ec*0x20;let _0x2f9a39=Graphics[_0x4c5d0b(0x3e1)]-0xc8-$gameParty[_0x4c5d0b(0x674)]()*0x30;_0x2f9a39-=Math[_0x4c5d0b(0x42f)]((Graphics['height']-Graphics['boxHeight'])/0x2),_0x2f9a39+=_0x3755ec*0x30,this[_0x4c5d0b(0x5d8)](_0x36f407,_0x2f9a39);},Sprite_Actor[_0x54167d(0x4ec)][_0x54167d(0x8cf)]=function(){const _0x6aabf3=_0x54167d;this[_0x6aabf3(0x725)](0x4b0,0x0,0x78);},Sprite_Animation[_0x54167d(0x4ec)][_0x54167d(0x20f)]=function(_0x5b5758){const _0x3c3bfb=_0x54167d;this[_0x3c3bfb(0x4f8)]=_0x5b5758;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x230)]=Sprite_Animation[_0x54167d(0x4ec)]['processSoundTimings'],Sprite_Animation['prototype'][_0x54167d(0x688)]=function(){const _0x163ab9=_0x54167d;if(this[_0x163ab9(0x4f8)])return;VisuMZ[_0x163ab9(0x940)][_0x163ab9(0x230)][_0x163ab9(0x204)](this);},VisuMZ[_0x54167d(0x940)]['Sprite_Animation_setViewport']=Sprite_Animation[_0x54167d(0x4ec)][_0x54167d(0x81c)],Sprite_Animation[_0x54167d(0x4ec)]['setViewport']=function(_0x3ca743){const _0x594736=_0x54167d;this[_0x594736(0x31b)]()?_0x594736(0x52b)!==_0x594736(0x8b6)?this['setViewportCoreEngineFix'](_0x3ca743):this[_0x594736(0x4ad)]():VisuMZ[_0x594736(0x940)]['Sprite_Animation_setViewport'][_0x594736(0x204)](this,_0x3ca743);},Sprite_Animation['prototype'][_0x54167d(0x31b)]=function(){const _0x99650a=_0x54167d;if(!this[_0x99650a(0x6e1)])return![];const _0x485d31=this[_0x99650a(0x6e1)][_0x99650a(0x614)]||'';if(_0x485d31[_0x99650a(0x59b)](/<MIRROR OFFSET X>/i))return!![];if(_0x485d31[_0x99650a(0x59b)](/<NO MIRROR OFFSET X>/i))return![];return VisuMZ[_0x99650a(0x940)][_0x99650a(0x331)][_0x99650a(0x2e9)][_0x99650a(0x98e)];},Sprite_Animation[_0x54167d(0x4ec)][_0x54167d(0x50f)]=function(_0x42962a){const _0x3a1726=_0x54167d,_0x2a7395=this['_viewportSize'],_0x13f24f=this[_0x3a1726(0x894)],_0x233117=this[_0x3a1726(0x6e1)][_0x3a1726(0x502)]*(this[_0x3a1726(0x259)]?-0x1:0x1)-_0x2a7395/0x2,_0x4154cf=this['_animation'][_0x3a1726(0x8e4)]-_0x13f24f/0x2,_0x2a6d59=this['targetPosition'](_0x42962a);_0x42962a['gl']['viewport'](_0x233117+_0x2a6d59['x'],_0x4154cf+_0x2a6d59['y'],_0x2a7395,_0x13f24f);},Sprite_Animation['prototype']['targetSpritePosition']=function(_0x4f58c0){const _0x1c21e3=_0x54167d;if(_0x4f58c0[_0x1c21e3(0x9cd)]){}const _0x1b0ae5=this[_0x1c21e3(0x6e1)]['name'];let _0x4712d4=_0x4f58c0[_0x1c21e3(0x3e1)]*_0x4f58c0[_0x1c21e3(0x81a)]['y'],_0xbe422a=0x0,_0xd6df38=-_0x4712d4/0x2;if(_0x1b0ae5[_0x1c21e3(0x59b)](/<(?:HEAD|HEADER|TOP)>/i))_0xd6df38=-_0x4712d4;if(_0x1b0ae5['match'](/<(?:FOOT|FOOTER|BOTTOM)>/i))_0xd6df38=0x0;if(this[_0x1c21e3(0x6e1)][_0x1c21e3(0x7c5)])_0xd6df38=0x0;if(_0x1b0ae5[_0x1c21e3(0x59b)](/<(?:LEFT)>/i))_0xbe422a=-_0x4f58c0[_0x1c21e3(0x281)]/0x2;if(_0x1b0ae5[_0x1c21e3(0x59b)](/<(?:RIGHT)>/i))_0xbe422a=_0x4f58c0[_0x1c21e3(0x281)]/0x2;if(_0x1b0ae5[_0x1c21e3(0x59b)](/<ANCHOR X:[ ](\d+\.?\d*)>/i)){if('WSvSv'!==_0x1c21e3(0x557)){if(!this[_0x1c21e3(0x8ed)]())return;this['refresh']();}else _0xbe422a=Number(RegExp['$1'])*_0x4f58c0[_0x1c21e3(0x281)];}_0x1b0ae5[_0x1c21e3(0x59b)](/<ANCHOR Y:[ ](\d+\.?\d*)>/i)&&(_0xd6df38=(0x1-Number(RegExp['$1']))*-_0x4712d4);_0x1b0ae5[_0x1c21e3(0x59b)](/<ANCHOR:[ ](\d+\.?\d*),[ ](\d+\.?\d*)>/i)&&(_0xbe422a=Number(RegExp['$1'])*_0x4f58c0[_0x1c21e3(0x281)],_0xd6df38=(0x1-Number(RegExp['$2']))*-_0x4712d4);if(_0x1b0ae5['match'](/<OFFSET X:[ ]([\+\-]\d+)>/i))_0xbe422a+=Number(RegExp['$1']);if(_0x1b0ae5[_0x1c21e3(0x59b)](/<OFFSET Y:[ ]([\+\-]\d+)>/i))_0xd6df38+=Number(RegExp['$1']);_0x1b0ae5['match'](/<OFFSET:[ ]([\+\-]\d+),[ ]([\+\-]\d+)>/i)&&(_0xbe422a+=Number(RegExp['$1']),_0xd6df38+=Number(RegExp['$2']));const _0x28de73=new Point(_0xbe422a,_0xd6df38);return _0x4f58c0[_0x1c21e3(0x23f)](),_0x4f58c0['worldTransform'][_0x1c21e3(0x6b2)](_0x28de73);},Sprite_AnimationMV[_0x54167d(0x4ec)][_0x54167d(0x6fe)]=function(){const _0x13e78a=_0x54167d;this[_0x13e78a(0x989)]=VisuMZ[_0x13e78a(0x940)][_0x13e78a(0x331)]['QoL'][_0x13e78a(0x8b3)]??0x4,this[_0x13e78a(0x2ba)](),this[_0x13e78a(0x989)]=this[_0x13e78a(0x989)]['clamp'](0x1,0xa);},Sprite_AnimationMV['prototype'][_0x54167d(0x2ba)]=function(){const _0x22ad83=_0x54167d;if(!this[_0x22ad83(0x6e1)]);const _0x36e555=this[_0x22ad83(0x6e1)][_0x22ad83(0x614)]||'';if(_0x36e555[_0x22ad83(0x59b)](/<RATE:[ ](\d+)>/i)){if('AYaIy'!==_0x22ad83(0x352))this[_0x22ad83(0x989)]=(Number(RegExp['$1'])||0x1)[_0x22ad83(0x29b)](0x1,0xa);else{const _0x20aac9=_0x503ae9(_0x28dfe9['$1']);_0x20aac9!==_0x235117[_0x30e110][_0x22ad83(0x553)]&&(_0x3d5784(_0x22ad83(0x21e)[_0x22ad83(0x482)](_0x5b2d40,_0x20aac9)),_0x2ffcd9[_0x22ad83(0x4fc)]());}}},Sprite_AnimationMV['prototype'][_0x54167d(0x20f)]=function(_0x5333b8){const _0x14710a=_0x54167d;this[_0x14710a(0x4f8)]=_0x5333b8;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x2e0)]=Sprite_AnimationMV[_0x54167d(0x4ec)]['processTimingData'],Sprite_AnimationMV['prototype'][_0x54167d(0x2d6)]=function(_0xc28449){const _0x2f0f1c=_0x54167d;this[_0x2f0f1c(0x4f8)]&&(_0xc28449=JsonEx[_0x2f0f1c(0x419)](_0xc28449),_0xc28449['se']&&(_0xc28449['se'][_0x2f0f1c(0xa0c)]=0x0)),VisuMZ['CoreEngine'][_0x2f0f1c(0x2e0)][_0x2f0f1c(0x204)](this,_0xc28449);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x547)]=Sprite_AnimationMV['prototype'][_0x54167d(0x4a2)],Sprite_AnimationMV[_0x54167d(0x4ec)][_0x54167d(0x4a2)]=function(){const _0x27aa4a=_0x54167d;VisuMZ['CoreEngine'][_0x27aa4a(0x547)]['call'](this);if(this[_0x27aa4a(0x6e1)][_0x27aa4a(0xa17)]===0x3){if(this['x']===0x0)this['x']=Math[_0x27aa4a(0x3ad)](Graphics[_0x27aa4a(0x281)]/0x2);if(this['y']===0x0)this['y']=Math[_0x27aa4a(0x3ad)](Graphics[_0x27aa4a(0x3e1)]/0x2);}},Sprite_Damage[_0x54167d(0x4ec)]['createDigits']=function(_0x3f2f8c){const _0x50f151=_0x54167d;let _0x30f155=Math[_0x50f151(0x8bf)](_0x3f2f8c)['toString']();if(this[_0x50f151(0x796)]()){if(_0x50f151(0x325)==='mJmpI')_0x30f155=VisuMZ[_0x50f151(0x5da)](_0x30f155);else return _0x111c65&&_0x5aa654['note']&&_0x1432b1[_0x50f151(0x31a)][_0x50f151(0x59b)](/<MINIMUM ENCOUNTER STEPS:[ ](\d+)>/i)?_0x2fc2c5(_0x5788dd['$1']):_0x47f588['CoreEngine'][_0x50f151(0x331)][_0x50f151(0x2e9)][_0x50f151(0x829)];}const _0x2fc73b=this[_0x50f151(0x79f)](),_0x60479f=Math[_0x50f151(0x42f)](_0x2fc73b*0.75);for(let _0x4f2daf=0x0;_0x4f2daf<_0x30f155[_0x50f151(0x95b)];_0x4f2daf++){const _0x524f93=this[_0x50f151(0x239)](_0x60479f,_0x2fc73b);_0x524f93['bitmap'][_0x50f151(0x2cc)](_0x30f155[_0x4f2daf],0x0,0x0,_0x60479f,_0x2fc73b,_0x50f151(0x68b)),_0x524f93['x']=(_0x4f2daf-(_0x30f155[_0x50f151(0x95b)]-0x1)/0x2)*_0x60479f,_0x524f93['dy']=-_0x4f2daf;}},Sprite_Damage[_0x54167d(0x4ec)][_0x54167d(0x796)]=function(){const _0x2a2a6e=_0x54167d;return VisuMZ[_0x2a2a6e(0x940)][_0x2a2a6e(0x331)]['QoL']['DigitGroupingDamageSprites'];},Sprite_Damage[_0x54167d(0x4ec)][_0x54167d(0x8c4)]=function(){const _0x229793=_0x54167d;return ColorManager[_0x229793(0x403)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x2b6)]=Sprite_Gauge['prototype'][_0x54167d(0x512)],Sprite_Gauge['prototype'][_0x54167d(0x512)]=function(){const _0x11f3a2=_0x54167d;return VisuMZ[_0x11f3a2(0x940)][_0x11f3a2(0x2b6)][_0x11f3a2(0x204)](this)['clamp'](0x0,0x1);},VisuMZ['CoreEngine'][_0x54167d(0x691)]=Sprite_Gauge['prototype'][_0x54167d(0x858)],Sprite_Gauge[_0x54167d(0x4ec)][_0x54167d(0x858)]=function(){const _0x4a00b1=_0x54167d;let _0x30eb6b=VisuMZ[_0x4a00b1(0x940)][_0x4a00b1(0x691)][_0x4a00b1(0x204)](this);return _0x30eb6b;},Sprite_Gauge[_0x54167d(0x4ec)][_0x54167d(0x39f)]=function(){const _0x49d03d=_0x54167d;let _0x553a19=this[_0x49d03d(0x858)]();if(this[_0x49d03d(0x796)]()){if(_0x49d03d(0x73a)===_0x49d03d(0x5ba))return!![];else _0x553a19=VisuMZ['GroupDigits'](_0x553a19);}const _0x126ed1=this[_0x49d03d(0x5cb)]()-0x1,_0x244163=this[_0x49d03d(0x2de)]?this[_0x49d03d(0x2de)]():this[_0x49d03d(0x9b5)]();this[_0x49d03d(0x513)](),this['bitmap']['drawText'](_0x553a19,0x0,0x0,_0x126ed1,_0x244163,_0x49d03d(0x231));},Sprite_Gauge['prototype']['valueOutlineWidth']=function(){return 0x3;},Sprite_Gauge[_0x54167d(0x4ec)][_0x54167d(0x796)]=function(){const _0xbb499=_0x54167d;return VisuMZ[_0xbb499(0x940)][_0xbb499(0x331)]['QoL'][_0xbb499(0x4a4)];},Sprite_Gauge['prototype'][_0x54167d(0x8c4)]=function(){const _0x5baa79=_0x54167d;return ColorManager[_0x5baa79(0x249)]();},VisuMZ[_0x54167d(0x940)]['Sprite_Picture_loadBitmap']=Sprite_Picture['prototype'][_0x54167d(0x4e3)],Sprite_Picture[_0x54167d(0x4ec)][_0x54167d(0x4e3)]=function(){const _0x595072=_0x54167d;if(this[_0x595072(0x55e)]['match'](/VisuMZ CoreEngine PictureIcon (\d+)/i)){if(_0x595072(0x83f)===_0x595072(0x7f2))return _0x2b770e[_0x595072(0x940)]['Settings'][_0x595072(0x2e9)][_0x595072(0x80a)]??!![];else this['loadIconBitmap'](Number(RegExp['$1']));}else VisuMZ[_0x595072(0x940)][_0x595072(0x3d1)][_0x595072(0x204)](this);},Sprite_Picture['prototype'][_0x54167d(0x2dc)]=function(_0x4c2ddd){const _0x42fbd8=_0x54167d,_0x23e40e=ImageManager[_0x42fbd8(0x28b)],_0x4d7011=ImageManager['iconHeight'],_0x28c7fb=this[_0x42fbd8(0x55e)][_0x42fbd8(0x59b)](/SMOOTH/i);this[_0x42fbd8(0x228)]=new Bitmap(_0x23e40e,_0x4d7011);const _0xb8f7b1=ImageManager['loadSystem'](_0x42fbd8(0x409)),_0x35a147=_0x4c2ddd%0x10*_0x23e40e,_0x4c5229=Math[_0x42fbd8(0x42f)](_0x4c2ddd/0x10)*_0x4d7011;this['bitmap'][_0x42fbd8(0x4d0)]=_0x28c7fb,this['bitmap'][_0x42fbd8(0x46f)](_0xb8f7b1,_0x35a147,_0x4c5229,_0x23e40e,_0x4d7011,0x0,0x0,_0x23e40e,_0x4d7011);};function Sprite_TitlePictureButton(){const _0x482244=_0x54167d;this[_0x482244(0x8d7)](...arguments);}Sprite_TitlePictureButton[_0x54167d(0x4ec)]=Object['create'](Sprite_Clickable[_0x54167d(0x4ec)]),Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x4a9)]=Sprite_TitlePictureButton,Sprite_TitlePictureButton['prototype'][_0x54167d(0x8d7)]=function(_0x476001){const _0x12313e=_0x54167d;Sprite_Clickable['prototype'][_0x12313e(0x8d7)]['call'](this),this['_data']=_0x476001,this[_0x12313e(0x3b0)]=null,this['setup']();},Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x82d)]=function(){const _0x5f2806=_0x54167d;this['x']=Graphics['width'],this['y']=Graphics[_0x5f2806(0x3e1)],this[_0x5f2806(0x572)]=![],this[_0x5f2806(0x834)]();},Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x834)]=function(){const _0x461d4c=_0x54167d;this[_0x461d4c(0x228)]=ImageManager[_0x461d4c(0x2b4)](this[_0x461d4c(0x4ef)][_0x461d4c(0x73d)]),this['bitmap']['addLoadListener'](this[_0x461d4c(0x38e)][_0x461d4c(0x6ac)](this));},Sprite_TitlePictureButton['prototype'][_0x54167d(0x38e)]=function(){const _0x3d5a26=_0x54167d;this['_data'][_0x3d5a26(0x666)][_0x3d5a26(0x204)](this),this[_0x3d5a26(0x4ef)]['PositionJS'][_0x3d5a26(0x204)](this),this[_0x3d5a26(0x939)](this['_data']['CallHandlerJS'][_0x3d5a26(0x6ac)](this));},Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x3b5)]=function(){const _0x3c804a=_0x54167d;Sprite_Clickable[_0x3c804a(0x4ec)][_0x3c804a(0x3b5)][_0x3c804a(0x204)](this),this[_0x3c804a(0x38c)](),this['processTouch']();},Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x65e)]=function(){const _0x57f1ad=_0x54167d;return VisuMZ[_0x57f1ad(0x940)]['Settings'][_0x57f1ad(0x529)][_0x57f1ad(0x3a7)][_0x57f1ad(0x6bd)];},Sprite_TitlePictureButton[_0x54167d(0x4ec)]['updateOpacity']=function(){const _0x36baa1=_0x54167d;if(this[_0x36baa1(0xa08)]||this[_0x36baa1(0x9f1)]){if(_0x36baa1(0x577)!==_0x36baa1(0x3db))this['opacity']=0xff;else try{const _0x1a2102=_0x290cee['deflate'](_0x2b3ab6,{'to':_0x36baa1(0x510),'level':0x1});if(_0x1a2102[_0x36baa1(0x95b)]>=0xc350){}_0x5a85b5(_0x1a2102);}catch(_0x275ed2){_0x5eb0e0(_0x275ed2);}}else _0x36baa1(0x59f)!=='WpXzw'?(_0x1c8dfa[_0x36baa1(0x531)](),this[_0x36baa1(0x9b3)]()):(this[_0x36baa1(0x7de)]+=this[_0x36baa1(0x572)]?this[_0x36baa1(0x65e)]():-0x1*this['fadeSpeed'](),this[_0x36baa1(0x7de)]=Math[_0x36baa1(0x3e0)](0xc0,this[_0x36baa1(0x7de)]));},Sprite_TitlePictureButton['prototype'][_0x54167d(0x939)]=function(_0x56deb3){this['_clickHandler']=_0x56deb3;},Sprite_TitlePictureButton[_0x54167d(0x4ec)][_0x54167d(0x57c)]=function(){const _0xea2cda=_0x54167d;this[_0xea2cda(0x3b0)]&&(_0xea2cda(0x969)===_0xea2cda(0x969)?this[_0xea2cda(0x3b0)]():(_0x4ea8d9['CoreEngine']['Game_Temp_initialize'][_0xea2cda(0x204)](this),this[_0xea2cda(0x289)](),this['createFauxAnimationQueue'](),this[_0xea2cda(0x5eb)]()));},VisuMZ['CoreEngine']['Spriteset_Base_initialize']=Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x8d7)],Spriteset_Base['prototype'][_0x54167d(0x8d7)]=function(){const _0x1f2358=_0x54167d;VisuMZ[_0x1f2358(0x940)]['Spriteset_Base_initialize'][_0x1f2358(0x204)](this),this[_0x1f2358(0x6ef)]();},Spriteset_Base[_0x54167d(0x4ec)]['initMembersCoreEngine']=function(){const _0x1e7a70=_0x54167d;this['_fauxAnimationSprites']=[],this['_pointAnimationSprites']=[],this[_0x1e7a70(0x268)]=this['scale']['x'],this[_0x1e7a70(0x385)]=this[_0x1e7a70(0x81a)]['y'];},VisuMZ[_0x54167d(0x940)]['Spriteset_Base_destroy']=Spriteset_Base['prototype'][_0x54167d(0x954)],Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x954)]=function(_0x130d7d){const _0x227d25=_0x54167d;this[_0x227d25(0x29a)](),this[_0x227d25(0x903)](),VisuMZ[_0x227d25(0x940)][_0x227d25(0x647)][_0x227d25(0x204)](this,_0x130d7d);},VisuMZ['CoreEngine'][_0x54167d(0x7b6)]=Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x3b5)],Spriteset_Base['prototype'][_0x54167d(0x3b5)]=function(){const _0x58f14a=_0x54167d;VisuMZ[_0x58f14a(0x940)][_0x58f14a(0x7b6)]['call'](this),this[_0x58f14a(0x786)](),this[_0x58f14a(0x631)](),this[_0x58f14a(0x7e5)]();},Spriteset_Base['prototype'][_0x54167d(0x786)]=function(){const _0x204119=_0x54167d;if(!VisuMZ[_0x204119(0x940)][_0x204119(0x331)][_0x204119(0x2e9)][_0x204119(0x2c1)])return;if(this[_0x204119(0x268)]===this['scale']['x']&&this[_0x204119(0x385)]===this['scale']['y'])return;this[_0x204119(0x7ed)](),this[_0x204119(0x268)]=this['scale']['x'],this['_cacheScaleY']=this['scale']['y'];},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x7ed)]=function(){const _0x900d0d=_0x54167d;if(SceneManager['isSceneMap']()&&Spriteset_Map[_0x900d0d(0x551)]){if(_0x900d0d(0x9ad)==='VBKJm')return;else try{_0x1dfe24['CoreEngine']['Game_Character_processMoveCommand'][_0x900d0d(0x204)](this,_0x3507fd);}catch(_0x576fb8){if(_0x28d192['isPlaytest']())_0x158caf[_0x900d0d(0x262)](_0x576fb8);}}else{if(SceneManager[_0x900d0d(0x94d)]()&&Spriteset_Battle[_0x900d0d(0x551)])return;}this[_0x900d0d(0x81a)]['x']!==0x0&&(this[_0x900d0d(0x57a)][_0x900d0d(0x81a)]['x']=0x1/this[_0x900d0d(0x81a)]['x'],this[_0x900d0d(0x57a)]['x']=-(this['x']/this[_0x900d0d(0x81a)]['x'])),this[_0x900d0d(0x81a)]['y']!==0x0&&(this[_0x900d0d(0x57a)][_0x900d0d(0x81a)]['y']=0x1/this['scale']['y'],this[_0x900d0d(0x57a)]['y']=-(this['y']/this[_0x900d0d(0x81a)]['y']));},VisuMZ[_0x54167d(0x940)]['Spriteset_Base_updatePosition']=Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x4a2)],Spriteset_Base[_0x54167d(0x4ec)]['updatePosition']=function(){const _0x17f292=_0x54167d;VisuMZ[_0x17f292(0x940)][_0x17f292(0x467)][_0x17f292(0x204)](this),this[_0x17f292(0x211)]();},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x211)]=function(){const _0x3470db=_0x54167d;if(!$gameScreen)return;if($gameScreen[_0x3470db(0xa19)]<=0x0)return;this['x']-=Math['round']($gameScreen[_0x3470db(0x2fc)]());const _0xf5d5ee=$gameScreen['getCoreEngineScreenShakeStyle']();switch($gameScreen['getCoreEngineScreenShakeStyle']()){case _0x3470db(0x7e0):this[_0x3470db(0x57f)]();break;case _0x3470db(0x86a):this['updatePositionCoreEngineShakeHorz']();break;case _0x3470db(0x4bb):this[_0x3470db(0x8a1)]();break;default:this[_0x3470db(0x742)]();break;}},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x57f)]=function(){const _0x4f2388=_0x54167d,_0x1641ad=VisuMZ['CoreEngine'][_0x4f2388(0x331)][_0x4f2388(0x5c9)];if(_0x1641ad&&_0x1641ad[_0x4f2388(0x9df)]){if(_0x4f2388(0x522)===_0x4f2388(0x5d3))this[_0x4f2388(0x531)]();else return _0x1641ad[_0x4f2388(0x9df)]['call'](this);}this['x']+=Math[_0x4f2388(0x3ad)]($gameScreen[_0x4f2388(0x2fc)]());},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x742)]=function(){const _0x2d7753=_0x54167d,_0x3fc98b=VisuMZ[_0x2d7753(0x940)][_0x2d7753(0x331)][_0x2d7753(0x5c9)];if(_0x3fc98b&&_0x3fc98b[_0x2d7753(0x85e)])return _0x3fc98b[_0x2d7753(0x85e)]['call'](this);const _0x9f71fc=$gameScreen[_0x2d7753(0x8ab)]*0.75,_0xfbf286=$gameScreen[_0x2d7753(0x879)]*0.6,_0x5dbc50=$gameScreen['_shakeDuration'];this['x']+=Math['round'](Math[_0x2d7753(0x549)](_0x9f71fc)-Math[_0x2d7753(0x549)](_0xfbf286))*(Math[_0x2d7753(0x3e0)](_0x5dbc50,0x1e)*0.5),this['y']+=Math[_0x2d7753(0x3ad)](Math['randomInt'](_0x9f71fc)-Math[_0x2d7753(0x549)](_0xfbf286))*(Math['min'](_0x5dbc50,0x1e)*0.5);},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x29f)]=function(){const _0x442f15=_0x54167d,_0x3ba011=VisuMZ[_0x442f15(0x940)]['Settings'][_0x442f15(0x5c9)];if(_0x3ba011&&_0x3ba011[_0x442f15(0x6d4)]){if(_0x442f15(0x65d)===_0x442f15(0x65d))return _0x3ba011[_0x442f15(0x6d4)][_0x442f15(0x204)](this);else{this[_0x442f15(0x582)]++;let _0x587293=_0x2bb984[_0x442f15(0x940)][_0x442f15(0x8b2)](_0x436793[_0x442f15(0x9d7)]);_0x587293[_0x442f15(0x95b)]>0x0&&(_0xcdcdbf+=_0x3740a2,_0x48370b+=_0x4f2ec2,_0x41c5e9+=_0x442f15(0x6ee)[_0x442f15(0x482)](_0x38dba7['id'],_0x326f9f[_0x442f15(0x614)]),_0x4e9bb6+=_0x444424,_0x1c771a+=_0x587293,_0x2fe6f8+=_0x17bb6d,_0xc52852+=_0x442f15(0x501)[_0x442f15(0x482)](_0x3e5402['id'],_0x17153c[_0x442f15(0x614)]),_0x5e8177+=_0x3a980b),this[_0x442f15(0x582)]--;}}const _0x1ea47c=$gameScreen[_0x442f15(0x8ab)]*0.75,_0x29b938=$gameScreen[_0x442f15(0x879)]*0.6,_0x3a98a2=$gameScreen[_0x442f15(0xa19)];this['x']+=Math[_0x442f15(0x3ad)](Math[_0x442f15(0x549)](_0x1ea47c)-Math['randomInt'](_0x29b938))*(Math['min'](_0x3a98a2,0x1e)*0.5);},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x8a1)]=function(){const _0x3486c8=_0x54167d,_0x4ec1b3=VisuMZ[_0x3486c8(0x940)]['Settings'][_0x3486c8(0x5c9)];if(_0x4ec1b3&&_0x4ec1b3['vertJS'])return _0x4ec1b3[_0x3486c8(0x9b2)][_0x3486c8(0x204)](this);const _0x3d06f7=$gameScreen['_shakePower']*0.75,_0x58f3fc=$gameScreen[_0x3486c8(0x879)]*0.6,_0x5871ca=$gameScreen[_0x3486c8(0xa19)];this['y']+=Math[_0x3486c8(0x3ad)](Math[_0x3486c8(0x549)](_0x3d06f7)-Math[_0x3486c8(0x549)](_0x58f3fc))*(Math['min'](_0x5871ca,0x1e)*0.5);},Spriteset_Base[_0x54167d(0x4ec)]['updateFauxAnimations']=function(){const _0x1336f5=_0x54167d;for(const _0x46c7cf of this[_0x1336f5(0x755)]){if('cksYN'===_0x1336f5(0x9a0)){if(!_0x46c7cf[_0x1336f5(0x609)]()){if(_0x1336f5(0x7e9)==='LmylF')this[_0x1336f5(0x882)](_0x46c7cf);else{const _0x591978=_0x1de636[_0x44719a][_0x1336f5(0x614)];_0x326800+=_0x3c6f14+'〖〖〖\x20Map\x20%1:\x20%2\x20Script\x20〗〗〗\x0a\x0a'['format'](_0x58cd47,_0x591978||_0x1336f5(0x678))+_0x455787;}}}else{const _0xd5d963=[_0x1336f5(0x265),_0x1336f5(0x2e7),_0x1336f5(0x514),_0x1336f5(0xa16),'enemies',_0x1336f5(0x8bd),_0x1336f5(0x37c),_0x1336f5(0x5a1),'sv_actors','sv_enemies',_0x1336f5(0x32b),_0x1336f5(0x72a),'titles1','titles2'];for(const _0x3392a6 of _0xd5d963){const _0xc2aea0=_0x4c0977[_0x1336f5(0x940)]['Settings'][_0x1336f5(0x574)][_0x3392a6],_0x7d45d7=_0x1336f5(0x780)['format'](_0x3392a6);for(const _0x46797e of _0xc2aea0){_0x122ddf[_0x1336f5(0x4e3)](_0x7d45d7,_0x46797e);}}}}this[_0x1336f5(0x664)]();},Spriteset_Base[_0x54167d(0x4ec)]['processFauxAnimationRequests']=function(){const _0x84173e=_0x54167d;for(;;){if(_0x84173e(0x57b)===_0x84173e(0x9b1))!_0x5dd769[_0x84173e(0x5ee)]()&&!this[_0x84173e(0x34a)]&&!_0x300562['isBusy']()&&(this[_0x84173e(0x34a)]=!![],this['update'](),_0x125d1e[_0x84173e(0x52e)](),this['_playtestF7Looping']=![]);else{const _0xf31f56=$gameTemp[_0x84173e(0x44f)]();if(_0xf31f56)this['createFauxAnimation'](_0xf31f56);else{if(_0x84173e(0x6b0)===_0x84173e(0x905))this[_0x84173e(0x828)]();else break;}}}},Spriteset_Base[_0x54167d(0x4ec)]['createFauxAnimation']=function(_0x23777d){const _0x1f0c9e=_0x54167d,_0x1b3746=$dataAnimations[_0x23777d['animationId']],_0x2d26c5=_0x23777d[_0x1f0c9e(0x65f)],_0x24e672=_0x23777d[_0x1f0c9e(0x2ee)],_0x252e10=_0x23777d[_0x1f0c9e(0x3d5)];let _0x3e3bda=this[_0x1f0c9e(0x8eb)]();const _0x377a34=this[_0x1f0c9e(0xa15)]();if(this[_0x1f0c9e(0x849)](_0x1b3746)){if(_0x1f0c9e(0x2b2)===_0x1f0c9e(0x58b))return this['isAlive']()&&this[_0x1f0c9e(0x4f3)]<this[_0x1f0c9e(0x307)]*_0x538df8[_0x1f0c9e(0x940)][_0x1f0c9e(0x331)]['Param'][_0x1f0c9e(0x7fc)];else for(const _0x356a50 of _0x2d26c5){this[_0x1f0c9e(0x48a)]([_0x356a50],_0x1b3746,_0x24e672,_0x3e3bda,_0x252e10),_0x3e3bda+=_0x377a34;}}else this[_0x1f0c9e(0x48a)](_0x2d26c5,_0x1b3746,_0x24e672,_0x3e3bda,_0x252e10);},Spriteset_Base[_0x54167d(0x4ec)]['createFauxAnimationSprite']=function(_0x89d80a,_0x110af4,_0x8e404e,_0x4e409f,_0x21e247){const _0x1c7f5c=_0x54167d,_0x1ef785=this['isMVAnimation'](_0x110af4),_0x58284c=new(_0x1ef785?Sprite_AnimationMV:Sprite_Animation)(),_0x39c32d=this[_0x1c7f5c(0x6ab)](_0x89d80a);if(this[_0x1c7f5c(0x344)](_0x89d80a[0x0])){if(_0x1c7f5c(0x99c)===_0x1c7f5c(0x99c))_0x8e404e=!_0x8e404e;else{if(_0x56d390[_0x1c7f5c(0x940)]['Settings'][_0x1c7f5c(0x2e9)][_0x1c7f5c(0x670)]??!![])for(const _0x2f70de in _0x5bd537){const _0x1e9d04=_0x5061b1[_0x2f70de];_0x1e9d04[_0x1c7f5c(0x614)][_0x1c7f5c(0x59b)](/(.*)\/(.*)/i)&&(_0x1e9d04['name']=_0x42620e(_0x2db08e['$2']['trim']()));}}}_0x58284c[_0x1c7f5c(0x225)]=_0x89d80a,_0x58284c[_0x1c7f5c(0x82d)](_0x39c32d,_0x110af4,_0x8e404e,_0x4e409f),_0x58284c[_0x1c7f5c(0x20f)](_0x21e247),this[_0x1c7f5c(0x84c)][_0x1c7f5c(0x45f)](_0x58284c),this[_0x1c7f5c(0x755)][_0x1c7f5c(0x398)](_0x58284c);},Spriteset_Base[_0x54167d(0x4ec)]['removeFauxAnimation']=function(_0x42195a){const _0x73da2c=_0x54167d;this['_fauxAnimationSprites'][_0x73da2c(0x233)](_0x42195a),this[_0x73da2c(0x84c)][_0x73da2c(0x4c4)](_0x42195a);for(const _0x42bd1d of _0x42195a[_0x73da2c(0x225)]){_0x42bd1d[_0x73da2c(0x7ac)]&&_0x42bd1d[_0x73da2c(0x7ac)]();}_0x42195a['destroy']();},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x29a)]=function(){const _0x3b2767=_0x54167d;for(const _0x4dfad7 of this[_0x3b2767(0x755)]){_0x3b2767(0x5c7)===_0x3b2767(0x5c7)?this[_0x3b2767(0x882)](_0x4dfad7):_0x115b00[_0x3b2767(0x9ec)]=![];}},Spriteset_Base['prototype'][_0x54167d(0x8bc)]=function(){const _0x25a5eb=_0x54167d;return this[_0x25a5eb(0x755)][_0x25a5eb(0x95b)]>0x0;},Spriteset_Base['prototype'][_0x54167d(0x7e5)]=function(){const _0x55aec6=_0x54167d;for(const _0x487556 of this['_pointAnimationSprites']){'PUiOo'===_0x55aec6(0x587)?this[_0x55aec6(0x629)]=[]:!_0x487556[_0x55aec6(0x609)]()&&this[_0x55aec6(0x874)](_0x487556);}this[_0x55aec6(0x269)]();},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x269)]=function(){const _0x38e011=_0x54167d;for(;;){const _0x57d252=$gameTemp[_0x38e011(0x46b)]();if(_0x57d252)this['createPointAnimation'](_0x57d252);else break;}},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x616)]=function(_0x239102){const _0x453bbe=_0x54167d,_0x450715=$dataAnimations[_0x239102[_0x453bbe(0x729)]],_0x489514=this[_0x453bbe(0x785)](_0x239102),_0x4b3a59=_0x239102[_0x453bbe(0x2ee)],_0x36ac2c=_0x239102[_0x453bbe(0x3d5)];let _0x2cff47=this[_0x453bbe(0x8eb)]();const _0x41ce2d=this['animationNextDelay']();if(this[_0x453bbe(0x849)](_0x450715))for(const _0x3c0c2b of _0x489514){this[_0x453bbe(0x64b)]([_0x3c0c2b],_0x450715,_0x4b3a59,_0x2cff47,_0x36ac2c),_0x2cff47+=_0x41ce2d;}else this['createPointAnimationSprite'](_0x489514,_0x450715,_0x4b3a59,_0x2cff47,_0x36ac2c);},Spriteset_Base['prototype']['createPointAnimationTargets']=function(_0x2f537b){const _0x71a5a3=_0x54167d,_0x3241ae=new Sprite_Clickable();_0x3241ae['x']=_0x2f537b['x'],_0x3241ae['y']=_0x2f537b['y'],_0x3241ae['z']=0x64;const _0x15c685=this[_0x71a5a3(0x503)]();return _0x15c685[_0x71a5a3(0x45f)](_0x3241ae),[_0x3241ae];},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x503)]=function(){return this;},Spriteset_Map[_0x54167d(0x4ec)][_0x54167d(0x503)]=function(){const _0xaa06f1=_0x54167d;return this[_0xaa06f1(0x8da)]||this;},Spriteset_Battle[_0x54167d(0x4ec)][_0x54167d(0x503)]=function(){const _0x5a2eb9=_0x54167d;return this[_0x5a2eb9(0x324)]||this;},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x64b)]=function(_0x459c36,_0x24a481,_0x96327f,_0x4085a1,_0x494f53){const _0x23c915=_0x54167d,_0x8b1102=this['isMVAnimation'](_0x24a481),_0x4f9545=new(_0x8b1102?Sprite_AnimationMV:Sprite_Animation)();_0x4f9545[_0x23c915(0x225)]=_0x459c36,_0x4f9545['setup'](_0x459c36,_0x24a481,_0x96327f,_0x4085a1),_0x4f9545[_0x23c915(0x20f)](_0x494f53),this[_0x23c915(0x84c)][_0x23c915(0x45f)](_0x4f9545),this[_0x23c915(0x4dc)][_0x23c915(0x398)](_0x4f9545);},Spriteset_Base['prototype'][_0x54167d(0x874)]=function(_0x156df6){const _0x3eb476=_0x54167d;this[_0x3eb476(0x4dc)][_0x3eb476(0x233)](_0x156df6),this['_effectsContainer'][_0x3eb476(0x4c4)](_0x156df6);for(const _0x101144 of _0x156df6[_0x3eb476(0x225)]){_0x101144['endAnimation']&&_0x101144[_0x3eb476(0x7ac)]();const _0x343764=this['getPointAnimationLayer']();if(_0x343764)_0x343764[_0x3eb476(0x4c4)](_0x101144);}_0x156df6[_0x3eb476(0x954)]();},Spriteset_Base[_0x54167d(0x4ec)]['removeAllPointAnimations']=function(){const _0x3efcb3=_0x54167d;for(const _0x2f2332 of this[_0x3efcb3(0x4dc)]){this[_0x3efcb3(0x874)](_0x2f2332);}},Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x9be)]=function(){const _0x44f79e=_0x54167d;return this[_0x44f79e(0x4dc)]['length']>0x0;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x373)]=Spriteset_Base['prototype'][_0x54167d(0x8e5)],Spriteset_Base[_0x54167d(0x4ec)][_0x54167d(0x8e5)]=function(){const _0x5bd745=_0x54167d;return VisuMZ[_0x5bd745(0x940)]['Spriteset_Base_isAnimationPlaying'][_0x5bd745(0x204)](this)||this[_0x5bd745(0x9be)]();},Spriteset_Map[_0x54167d(0x551)]=VisuMZ['CoreEngine'][_0x54167d(0x331)]['QoL'][_0x54167d(0x7f6)]||![],VisuMZ['CoreEngine']['Scene_Map_createSpriteset_detach']=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x7f0)],Scene_Map['prototype'][_0x54167d(0x7f0)]=function(){const _0x26bc40=_0x54167d;VisuMZ[_0x26bc40(0x940)][_0x26bc40(0x43e)][_0x26bc40(0x204)](this);if(!Spriteset_Map[_0x26bc40(0x551)])return;const _0x10d55e=this[_0x26bc40(0x6ae)];if(!_0x10d55e)return;this[_0x26bc40(0x57a)]=_0x10d55e[_0x26bc40(0x57a)];if(!this[_0x26bc40(0x57a)])return;this[_0x26bc40(0x45f)](this[_0x26bc40(0x57a)]);},Spriteset_Battle[_0x54167d(0x551)]=VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)]['QoL'][_0x54167d(0x595)]||![],VisuMZ[_0x54167d(0x940)]['Scene_Battle_createSpriteset_detach']=Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x7f0)],Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x7f0)]=function(){const _0x13fc6c=_0x54167d;VisuMZ['CoreEngine'][_0x13fc6c(0x5e3)][_0x13fc6c(0x204)](this);if(!Spriteset_Battle[_0x13fc6c(0x551)])return;const _0x565f16=this[_0x13fc6c(0x6ae)];if(!_0x565f16)return;this['_pictureContainer']=_0x565f16[_0x13fc6c(0x57a)];if(!this[_0x13fc6c(0x57a)])return;this[_0x13fc6c(0x45f)](this['_pictureContainer']);},Spriteset_Battle[_0x54167d(0x4ec)]['createBackground']=function(){const _0x40672b=_0x54167d;this[_0x40672b(0x214)]=new PIXI[(_0x40672b(0x6f6))][(_0x40672b(0x98b))](clamp=!![]),this[_0x40672b(0x420)]=new Sprite(),this[_0x40672b(0x420)][_0x40672b(0x228)]=SceneManager[_0x40672b(0x67d)](),this[_0x40672b(0x420)][_0x40672b(0x6f6)]=[this['_backgroundFilter']],this['_baseSprite'][_0x40672b(0x45f)](this['_backgroundSprite']);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x90a)]=Spriteset_Battle[_0x54167d(0x4ec)]['createEnemies'],Spriteset_Battle[_0x54167d(0x4ec)][_0x54167d(0x841)]=function(){const _0x9b937d=_0x54167d;this['coreEngineRepositionEnemies']()&&this[_0x9b937d(0xa12)](),VisuMZ[_0x9b937d(0x940)][_0x9b937d(0x90a)]['call'](this);},Spriteset_Battle[_0x54167d(0x4ec)]['coreEngineRepositionEnemies']=function(){const _0x396fd3=_0x54167d,_0x3782aa=VisuMZ['CoreEngine'][_0x396fd3(0x331)][_0x396fd3(0x8e2)];if(!_0x3782aa)return![];if(Utils['RPGMAKER_VERSION']>='1.3.0'&&!_0x3782aa[_0x396fd3(0x8cc)])return![];return _0x3782aa[_0x396fd3(0x575)];},Spriteset_Battle[_0x54167d(0x4ec)][_0x54167d(0xa12)]=function(){const _0x5bcc96=_0x54167d;for(member of $gameTroop[_0x5bcc96(0x451)]()){member[_0x5bcc96(0x2ff)]();}},VisuMZ['CoreEngine'][_0x54167d(0x6b7)]=Window_Base[_0x54167d(0x4ec)]['initialize'],Window_Base[_0x54167d(0x4ec)]['initialize']=function(_0x5a9a0b){const _0x46bae6=_0x54167d;_0x5a9a0b['x']=Math['round'](_0x5a9a0b['x']),_0x5a9a0b['y']=Math['round'](_0x5a9a0b['y']),_0x5a9a0b[_0x46bae6(0x281)]=Math[_0x46bae6(0x3ad)](_0x5a9a0b[_0x46bae6(0x281)]),_0x5a9a0b[_0x46bae6(0x3e1)]=Math['round'](_0x5a9a0b[_0x46bae6(0x3e1)]),this[_0x46bae6(0x3e9)](),VisuMZ[_0x46bae6(0x940)]['Window_Base_initialize'][_0x46bae6(0x204)](this,_0x5a9a0b),this['initCoreEasing']();},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x3e9)]=function(){const _0x417956=_0x54167d;this[_0x417956(0x794)]=VisuMZ[_0x417956(0x940)][_0x417956(0x331)]['QoL'][_0x417956(0x6bc)],this[_0x417956(0x475)]=VisuMZ['CoreEngine'][_0x417956(0x331)][_0x417956(0x2e9)][_0x417956(0x6a5)];},Window_Base['prototype'][_0x54167d(0x7c4)]=function(){const _0x42e1b6=_0x54167d;return VisuMZ[_0x42e1b6(0x940)][_0x42e1b6(0x331)][_0x42e1b6(0x3b6)]['LineHeight'];},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x46a)]=function(){const _0x404c9b=_0x54167d;return VisuMZ[_0x404c9b(0x940)][_0x404c9b(0x331)]['Window'][_0x404c9b(0x6b8)];},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x1fa)]=function(){const _0x5d07a9=_0x54167d;if($gameSystem[_0x5d07a9(0x840)])this[_0x5d07a9(0x7bd)]=$gameSystem['windowOpacity']();else{if(_0x5d07a9(0x761)!==_0x5d07a9(0x761))return _0x39aa59[_0x5d07a9(0x940)][_0x5d07a9(0x331)][_0x5d07a9(0x530)][_0x5d07a9(0x7fa)]||_0x5d07a9(0x290);else this[_0x5d07a9(0x7bd)]=VisuMZ['CoreEngine'][_0x5d07a9(0x331)][_0x5d07a9(0x3b6)]['BackOpacity'];}},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x958)]=function(){const _0x161046=_0x54167d;return VisuMZ['CoreEngine'][_0x161046(0x331)][_0x161046(0x3b6)]['TranslucentOpacity'];},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x473)]=function(){const _0x5a718b=_0x54167d;return VisuMZ[_0x5a718b(0x940)]['Settings'][_0x5a718b(0x3b6)][_0x5a718b(0x735)];},VisuMZ['CoreEngine'][_0x54167d(0x4db)]=Window_Base[_0x54167d(0x4ec)][_0x54167d(0x3b5)],Window_Base[_0x54167d(0x4ec)][_0x54167d(0x3b5)]=function(){const _0x384231=_0x54167d;VisuMZ[_0x384231(0x940)][_0x384231(0x4db)][_0x384231(0x204)](this),this[_0x384231(0x2df)]();},Window_Base[_0x54167d(0x4ec)]['updateOpen']=function(){const _0x4e1ecc=_0x54167d;if(this[_0x4e1ecc(0x432)]){this[_0x4e1ecc(0x51c)]+=this['openingSpeed']();if(this[_0x4e1ecc(0x88f)]()){if(_0x4e1ecc(0x3af)!==_0x4e1ecc(0x3af))return _0x401b43['CoreEngine'][_0x4e1ecc(0x331)][_0x4e1ecc(0x3b6)][_0x4e1ecc(0x6b8)];else this[_0x4e1ecc(0x432)]=![];}}},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x64a)]=function(){const _0x4489fd=_0x54167d;if(this[_0x4489fd(0x635)]){if(_0x4489fd(0x267)!==_0x4489fd(0x267)){_0x1fa465[_0x4489fd(0x4ec)]['update']['call'](this),this[_0x4489fd(0x26e)]();if(this[_0x4489fd(0x521)])this[_0x4489fd(0x821)]();else this[_0x4489fd(0x979)]!==''&&(this[_0x4489fd(0x979)]='');}else this[_0x4489fd(0x51c)]-=this[_0x4489fd(0x473)](),this[_0x4489fd(0x471)]()&&(this['_closing']=![]);}},VisuMZ[_0x54167d(0x940)]['Window_Base_drawText']=Window_Base[_0x54167d(0x4ec)][_0x54167d(0x2cc)],Window_Base[_0x54167d(0x4ec)][_0x54167d(0x2cc)]=function(_0x24ead8,_0x298325,_0x1251bd,_0x586cc7,_0x467a6f){const _0x2041d5=_0x54167d;if(this[_0x2041d5(0x796)]())_0x24ead8=VisuMZ[_0x2041d5(0x5da)](_0x24ead8);VisuMZ[_0x2041d5(0x940)][_0x2041d5(0x702)][_0x2041d5(0x204)](this,_0x24ead8,_0x298325,_0x1251bd,_0x586cc7,_0x467a6f);},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x796)]=function(){const _0x52a380=_0x54167d;return this[_0x52a380(0x794)];},VisuMZ[_0x54167d(0x940)]['Window_Base_createTextState']=Window_Base[_0x54167d(0x4ec)]['createTextState'],Window_Base[_0x54167d(0x4ec)]['createTextState']=function(_0xd8b8f9,_0x39ff42,_0x19013c,_0x1f0a3c){const _0x5a319b=_0x54167d;var _0x5ba9e6=VisuMZ[_0x5a319b(0x940)][_0x5a319b(0x2e8)][_0x5a319b(0x204)](this,_0xd8b8f9,_0x39ff42,_0x19013c,_0x1f0a3c);if(this[_0x5a319b(0x601)]())_0x5ba9e6['text']=VisuMZ[_0x5a319b(0x5da)](_0x5ba9e6['text']);return _0x5ba9e6;},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x601)]=function(){const _0x970ce2=_0x54167d;return this[_0x970ce2(0x475)];},Window_Base['prototype'][_0x54167d(0x2d8)]=function(_0x564370){this['_digitGrouping']=_0x564370;},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x77d)]=function(_0xb0ed5e){const _0x587595=_0x54167d;this[_0x587595(0x475)]=_0xb0ed5e;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x91d)]=Window_Base[_0x54167d(0x4ec)]['drawIcon'],Window_Base['prototype'][_0x54167d(0x84d)]=function(_0x15772a,_0x2001fb,_0x2442ea){const _0x38d025=_0x54167d;_0x2001fb=Math['round'](_0x2001fb),_0x2442ea=Math[_0x38d025(0x3ad)](_0x2442ea),VisuMZ[_0x38d025(0x940)][_0x38d025(0x91d)]['call'](this,_0x15772a,_0x2001fb,_0x2442ea);},VisuMZ[_0x54167d(0x940)]['Window_Base_drawFace']=Window_Base['prototype'][_0x54167d(0x9c2)],Window_Base[_0x54167d(0x4ec)][_0x54167d(0x9c2)]=function(_0x4c90bb,_0x2e13a3,_0xc41f6b,_0xda0d2b,_0x169413,_0x56518f){const _0x41886a=_0x54167d;_0x169413=_0x169413||ImageManager[_0x41886a(0x20e)],_0x56518f=_0x56518f||ImageManager[_0x41886a(0x86c)],_0xc41f6b=Math['round'](_0xc41f6b),_0xda0d2b=Math[_0x41886a(0x3ad)](_0xda0d2b),_0x169413=Math[_0x41886a(0x3ad)](_0x169413),_0x56518f=Math['round'](_0x56518f),VisuMZ[_0x41886a(0x940)][_0x41886a(0x990)][_0x41886a(0x204)](this,_0x4c90bb,_0x2e13a3,_0xc41f6b,_0xda0d2b,_0x169413,_0x56518f);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x2b8)]=Window_Base['prototype'][_0x54167d(0x70b)],Window_Base[_0x54167d(0x4ec)][_0x54167d(0x70b)]=function(_0x4b1a96,_0x4e7d66,_0x3d38c7,_0x5973a9){const _0x59fcae=_0x54167d;_0x3d38c7=Math[_0x59fcae(0x3ad)](_0x3d38c7),_0x5973a9=Math[_0x59fcae(0x3ad)](_0x5973a9),VisuMZ[_0x59fcae(0x940)][_0x59fcae(0x2b8)][_0x59fcae(0x204)](this,_0x4b1a96,_0x4e7d66,_0x3d38c7,_0x5973a9);},VisuMZ[_0x54167d(0x940)]['Window_Selectable_itemRect']=Window_Selectable[_0x54167d(0x4ec)]['itemRect'],Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x8ad)]=function(_0x417911){const _0x442949=_0x54167d;let _0x117710=VisuMZ[_0x442949(0x940)]['Window_Selectable_itemRect']['call'](this,_0x417911);return _0x117710['x']=Math[_0x442949(0x3ad)](_0x117710['x']),_0x117710['y']=Math['round'](_0x117710['y']),_0x117710[_0x442949(0x281)]=Math[_0x442949(0x3ad)](_0x117710[_0x442949(0x281)]),_0x117710['height']=Math[_0x442949(0x3ad)](_0x117710[_0x442949(0x3e1)]),_0x117710;},VisuMZ[_0x54167d(0x940)][_0x54167d(0x91a)]=Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x7b1)],Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x7b1)]=function(_0x269b02,_0x5ec458,_0x1e6a48){const _0xd952c7=_0x54167d;_0x5ec458=Math['round'](_0x5ec458),_0x1e6a48=Math[_0xd952c7(0x3ad)](_0x1e6a48),VisuMZ['CoreEngine'][_0xd952c7(0x91a)][_0xd952c7(0x204)](this,_0x269b02,_0x5ec458,_0x1e6a48);},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x383)]=function(){const _0x1f3e34=_0x54167d;this[_0x1f3e34(0x5b7)]={'duration':0x0,'wholeDuration':0x0,'type':_0x1f3e34(0x6e3),'targetX':this['x'],'targetY':this['y'],'targetScaleX':this[_0x1f3e34(0x81a)]['x'],'targetScaleY':this['scale']['y'],'targetOpacity':this['opacity'],'targetBackOpacity':this[_0x1f3e34(0x7bd)],'targetContentsOpacity':this[_0x1f3e34(0x24e)]};},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x2df)]=function(){const _0x4b1678=_0x54167d;if(!this[_0x4b1678(0x5b7)])return;if(this[_0x4b1678(0x5b7)][_0x4b1678(0x7f9)]<=0x0)return;this['x']=this[_0x4b1678(0x48c)](this['x'],this[_0x4b1678(0x5b7)][_0x4b1678(0x9c7)]),this['y']=this[_0x4b1678(0x48c)](this['y'],this['_coreEasing'][_0x4b1678(0x5c2)]),this[_0x4b1678(0x81a)]['x']=this['applyCoreEasing'](this[_0x4b1678(0x81a)]['x'],this[_0x4b1678(0x5b7)][_0x4b1678(0x2fb)]),this['scale']['y']=this['applyCoreEasing'](this[_0x4b1678(0x81a)]['y'],this[_0x4b1678(0x5b7)][_0x4b1678(0x31d)]),this[_0x4b1678(0x7de)]=this[_0x4b1678(0x48c)](this[_0x4b1678(0x7de)],this[_0x4b1678(0x5b7)][_0x4b1678(0xa11)]),this[_0x4b1678(0x7bd)]=this[_0x4b1678(0x48c)](this['backOpacity'],this[_0x4b1678(0x5b7)][_0x4b1678(0x5d6)]),this[_0x4b1678(0x24e)]=this[_0x4b1678(0x48c)](this[_0x4b1678(0x24e)],this[_0x4b1678(0x5b7)]['targetContentsOpacity']),this[_0x4b1678(0x5b7)]['duration']--;},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x48c)]=function(_0x24466d,_0x3fc832){const _0x3c09fb=_0x54167d;if(!this['_coreEasing'])return _0x3fc832;const _0x2e82ea=this[_0x3c09fb(0x5b7)][_0x3c09fb(0x7f9)],_0x549a13=this[_0x3c09fb(0x5b7)]['wholeDuration'],_0x28ccff=this[_0x3c09fb(0x9f9)]((_0x549a13-_0x2e82ea)/_0x549a13),_0x226148=this[_0x3c09fb(0x9f9)]((_0x549a13-_0x2e82ea+0x1)/_0x549a13),_0x46598e=(_0x24466d-_0x3fc832*_0x28ccff)/(0x1-_0x28ccff);return _0x46598e+(_0x3fc832-_0x46598e)*_0x226148;},Window_Base['prototype']['calcCoreEasing']=function(_0xd484b2){const _0x3241bd=_0x54167d;if(!this[_0x3241bd(0x5b7)])return _0xd484b2;return VisuMZ['ApplyEasing'](_0xd484b2,this[_0x3241bd(0x5b7)][_0x3241bd(0x337)]||'LINEAR');},Window_Base['prototype'][_0x54167d(0x22f)]=function(_0xc2b6ae,_0x4d8f0c){const _0x146ca4=_0x54167d;if(!this[_0x146ca4(0x5b7)])return;this['x']=this['_coreEasing']['targetX'],this['y']=this['_coreEasing'][_0x146ca4(0x5c2)],this['scale']['x']=this[_0x146ca4(0x5b7)][_0x146ca4(0x2fb)],this['scale']['y']=this[_0x146ca4(0x5b7)][_0x146ca4(0x31d)],this[_0x146ca4(0x7de)]=this[_0x146ca4(0x5b7)][_0x146ca4(0xa11)],this[_0x146ca4(0x7bd)]=this[_0x146ca4(0x5b7)][_0x146ca4(0x5d6)],this['contentsOpacity']=this[_0x146ca4(0x5b7)]['targetContentsOpacity'],this['setupCoreEasing'](_0xc2b6ae,_0x4d8f0c,this['x'],this['y'],this[_0x146ca4(0x81a)]['x'],this[_0x146ca4(0x81a)]['y'],this[_0x146ca4(0x7de)],this[_0x146ca4(0x7bd)],this[_0x146ca4(0x24e)]);},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x65a)]=function(_0x312051,_0x40e2cc,_0x56d829,_0x52da4f,_0x147c00,_0x310e75,_0x45f861,_0x4518c4,_0x1bf81a){const _0x1edfa5=_0x54167d;this[_0x1edfa5(0x5b7)]={'duration':_0x312051,'wholeDuration':_0x312051,'type':_0x40e2cc,'targetX':_0x56d829,'targetY':_0x52da4f,'targetScaleX':_0x147c00,'targetScaleY':_0x310e75,'targetOpacity':_0x45f861,'targetBackOpacity':_0x4518c4,'targetContentsOpacity':_0x1bf81a};},Window_Base['prototype']['drawCurrencyValue']=function(_0x1718bd,_0x149677,_0x45ba9b,_0x2d21b8,_0x275e4c){const _0x7bc035=_0x54167d;this['resetFontSettings'](),this[_0x7bc035(0x9a3)][_0x7bc035(0x79f)]=VisuMZ['CoreEngine']['Settings']['Gold'][_0x7bc035(0x929)];const _0x226810=VisuMZ['CoreEngine']['Settings']['Gold'][_0x7bc035(0x6f4)];if(_0x226810>0x0&&_0x149677===TextManager[_0x7bc035(0x925)]){if(_0x7bc035(0x99d)===_0x7bc035(0x99d)){const _0x302bb0=_0x2d21b8+(this[_0x7bc035(0x7c4)]()-ImageManager[_0x7bc035(0x814)])/0x2;this[_0x7bc035(0x84d)](_0x226810,_0x45ba9b+(_0x275e4c-ImageManager[_0x7bc035(0x28b)]),_0x302bb0),_0x275e4c-=ImageManager[_0x7bc035(0x28b)]+0x4;}else{if(_0x271ed7[_0x7bc035(0x940)][_0x7bc035(0x331)]['UI'][_0x7bc035(0x762)]){const _0x3630c3=_0x3e1380['width']-_0x3aae7f['boxWidth']-_0x3b1359[_0x7bc035(0x940)][_0x7bc035(0x331)]['UI'][_0x7bc035(0x3a0)]*0x2,_0x5265fa=_0x12de3d[_0x7bc035(0x4ec)][_0x7bc035(0x468)][_0x7bc035(0x204)](this)*0x4;if(_0x3630c3>=_0x5265fa)_0xbf3c32[_0x7bc035(0x87d)](!![]);}}}else{if('WryFI'!==_0x7bc035(0x82f))this[_0x7bc035(0x378)](ColorManager[_0x7bc035(0x636)]()),this[_0x7bc035(0x2cc)](_0x149677,_0x45ba9b,_0x2d21b8,_0x275e4c,_0x7bc035(0x231)),_0x275e4c-=this[_0x7bc035(0x705)](_0x149677)+0x6;else return _0x2dd392[_0x7bc035(0x940)][_0x7bc035(0x331)]['UI'][_0x7bc035(0x7c2)];}this['resetTextColor']();const _0x55e297=this['textWidth'](this[_0x7bc035(0x794)]?VisuMZ['GroupDigits'](_0x1718bd):_0x1718bd);_0x55e297>_0x275e4c?this[_0x7bc035(0x2cc)](VisuMZ['CoreEngine']['Settings'][_0x7bc035(0x67c)]['GoldOverlap'],_0x45ba9b,_0x2d21b8,_0x275e4c,'right'):this[_0x7bc035(0x2cc)](_0x1718bd,_0x45ba9b,_0x2d21b8,_0x275e4c,_0x7bc035(0x231)),this['resetFontSettings']();},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x404)]=function(_0x4c21ca,_0x3aa238,_0x1f6ca1,_0x224629,_0x13790){const _0x3f104b=_0x54167d,_0x9cfc99=ImageManager[_0x3f104b(0x498)]('IconSet'),_0x17b3c7=ImageManager[_0x3f104b(0x28b)],_0x38a84a=ImageManager[_0x3f104b(0x814)],_0x1a57fd=_0x4c21ca%0x10*_0x17b3c7,_0x3fa38a=Math[_0x3f104b(0x42f)](_0x4c21ca/0x10)*_0x38a84a,_0x1cec14=_0x224629,_0x47e826=_0x224629;this['contents'][_0x3f104b(0x76a)]['imageSmoothingEnabled']=_0x13790,this['contents'][_0x3f104b(0x46f)](_0x9cfc99,_0x1a57fd,_0x3fa38a,_0x17b3c7,_0x38a84a,_0x3aa238,_0x1f6ca1,_0x1cec14,_0x47e826),this[_0x3f104b(0x9a3)][_0x3f104b(0x76a)][_0x3f104b(0x7f8)]=!![];},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x2a5)]=function(_0x27602d,_0x76c2fc,_0x4e075,_0x376ade,_0x2fada6,_0x3c304a){const _0x559fa4=_0x54167d,_0x222c5a=Math[_0x559fa4(0x42f)]((_0x4e075-0x2)*_0x376ade),_0x1737d6=Sprite_Gauge['prototype'][_0x559fa4(0x668)][_0x559fa4(0x204)](this),_0x3bb94d=_0x76c2fc+this['lineHeight']()-_0x1737d6-0x2;this[_0x559fa4(0x9a3)][_0x559fa4(0x434)](_0x27602d,_0x3bb94d,_0x4e075,_0x1737d6,ColorManager['gaugeBackColor']()),this[_0x559fa4(0x9a3)]['gradientFillRect'](_0x27602d+0x1,_0x3bb94d+0x1,_0x222c5a,_0x1737d6-0x2,_0x2fada6,_0x3c304a);},Window_Selectable['prototype'][_0x54167d(0x663)]=function(_0x153ec5){const _0x533599=_0x54167d;let _0x1c8e3b=this[_0x533599(0x69d)]();const _0x47a85e=this['maxItems'](),_0x377c8c=this[_0x533599(0x5dc)]();if(this[_0x533599(0x260)]()&&(_0x1c8e3b<_0x47a85e||_0x153ec5&&_0x377c8c===0x1)){_0x1c8e3b+=_0x377c8c;if(_0x1c8e3b>=_0x47a85e)_0x1c8e3b=_0x47a85e-0x1;this['smoothSelect'](_0x1c8e3b);}else{if(!this[_0x533599(0x260)]()){if(_0x533599(0x304)==='BsNYr')return _0xe60a8a[_0x533599(0x556)][_0x533599(0x41a)][_0x533599(0x204)](this);else(_0x1c8e3b<_0x47a85e-_0x377c8c||_0x153ec5&&_0x377c8c===0x1)&&this[_0x533599(0x63f)]((_0x1c8e3b+_0x377c8c)%_0x47a85e);}}},VisuMZ['CoreEngine']['Window_Selectable_cursorDown']=Window_Selectable[_0x54167d(0x4ec)]['cursorDown'],Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x663)]=function(_0x5ba135){const _0x1781aa=_0x54167d;this[_0x1781aa(0x260)]()&&_0x5ba135&&this[_0x1781aa(0x5dc)]()===0x1&&this['index']()===this['maxItems']()-0x1?this[_0x1781aa(0x63f)](0x0):VisuMZ['CoreEngine'][_0x1781aa(0x6b1)][_0x1781aa(0x204)](this,_0x5ba135);},Window_Selectable[_0x54167d(0x4ec)]['cursorUp']=function(_0x8704b){const _0x38bf5f=_0x54167d;let _0x5b30fd=Math[_0x38bf5f(0x350)](0x0,this['index']());const _0x457da9=this[_0x38bf5f(0x7b4)](),_0x4a2c0b=this['maxCols']();if(this['isUseModernControls']()&&_0x5b30fd>0x0||_0x8704b&&_0x4a2c0b===0x1){if(_0x38bf5f(0x38d)===_0x38bf5f(0x264))_0x2d8561[_0x38bf5f(0x940)][_0x38bf5f(0x280)]['call'](this,_0x233cc1),this[_0x38bf5f(0x66a)](_0x124e7a);else{_0x5b30fd-=_0x4a2c0b;if(_0x5b30fd<=0x0)_0x5b30fd=0x0;this[_0x38bf5f(0x63f)](_0x5b30fd);}}else!this[_0x38bf5f(0x260)]()&&((_0x5b30fd>=_0x4a2c0b||_0x8704b&&_0x4a2c0b===0x1)&&this[_0x38bf5f(0x63f)]((_0x5b30fd-_0x4a2c0b+_0x457da9)%_0x457da9));},VisuMZ[_0x54167d(0x940)][_0x54167d(0x9e4)]=Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x9c4)],Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x9c4)]=function(_0x18cf9f){const _0x3a6b0c=_0x54167d;this[_0x3a6b0c(0x260)]()&&_0x18cf9f&&this['maxCols']()===0x1&&this[_0x3a6b0c(0x69d)]()===0x0?this[_0x3a6b0c(0x63f)](this['maxItems']()-0x1):VisuMZ['CoreEngine'][_0x3a6b0c(0x9e4)]['call'](this,_0x18cf9f);},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x260)]=function(){const _0x56726d=_0x54167d;return VisuMZ[_0x56726d(0x940)][_0x56726d(0x331)]['QoL']['ModernControls'];},VisuMZ['CoreEngine'][_0x54167d(0x74e)]=Window_Selectable['prototype']['processCursorMove'],Window_Selectable['prototype'][_0x54167d(0x430)]=function(){const _0x1e1578=_0x54167d;this[_0x1e1578(0x260)]()?(this['processCursorMoveModernControls'](),this[_0x1e1578(0x976)]()):_0x1e1578(0x524)!==_0x1e1578(0x9e5)?VisuMZ['CoreEngine'][_0x1e1578(0x74e)][_0x1e1578(0x204)](this):this['_forcedTroopView']='FV';},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x76c)]=function(){return!![];},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x69e)]=function(){const _0x5668d0=_0x54167d;if(this[_0x5668d0(0x318)]()){const _0x329e83=this[_0x5668d0(0x69d)]();Input[_0x5668d0(0x9e6)](_0x5668d0(0x83a))&&('yxfAK'!=='yxfAK'?_0x54003c[_0x5668d0(0x940)][_0x5668d0(0x596)][_0x5668d0(0x204)](this,_0x1da3c6):Input[_0x5668d0(0x7d2)](_0x5668d0(0x843))&&this[_0x5668d0(0x76c)]()?this['cursorPagedown']():this[_0x5668d0(0x663)](Input['isTriggered']('down')));if(Input[_0x5668d0(0x9e6)]('up')){if(_0x5668d0(0x5c5)===_0x5668d0(0x8ba)){if(_0x18d7ee===0x8)return![];return _0x2417ec[_0x5668d0(0x940)][_0x5668d0(0x6e6)]['call'](this,_0x1a17a8);}else Input['isPressed']('shift')&&this[_0x5668d0(0x76c)]()?_0x5668d0(0x7bf)===_0x5668d0(0x4a5)?this[_0x5668d0(0x45c)][_0x5668d0(0x6d0)](_0x1063d7[_0x5668d0(0x556)][_0x5668d0(0x9bd)]):this['cursorPageup']():this['cursorUp'](Input[_0x5668d0(0x54b)]('up'));}Input[_0x5668d0(0x9e6)]('right')&&this[_0x5668d0(0x465)](Input['isTriggered']('right')),Input[_0x5668d0(0x9e6)]('left')&&(_0x5668d0(0x650)===_0x5668d0(0x9ed)?_0x4d0415+=_0x581efb(_0x23e677):this[_0x5668d0(0xa0e)](Input['isTriggered'](_0x5668d0(0x750)))),!this[_0x5668d0(0x65b)]('pagedown')&&Input[_0x5668d0(0x9e6)](_0x5668d0(0x316))&&this[_0x5668d0(0x7a9)](),!this['isHandled'](_0x5668d0(0x5ae))&&Input[_0x5668d0(0x9e6)]('pageup')&&this[_0x5668d0(0x9f5)](),this[_0x5668d0(0x69d)]()!==_0x329e83&&this['playCursorSound']();}},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x976)]=function(){const _0x53ff82=_0x54167d;if(this[_0x53ff82(0x318)]()){const _0x195e5c=this[_0x53ff82(0x69d)]();Input[_0x53ff82(0x54b)](_0x53ff82(0x588))&&this[_0x53ff82(0x63f)](Math[_0x53ff82(0x3e0)](this['index'](),0x0)),Input[_0x53ff82(0x54b)](_0x53ff82(0x4dd))&&('EdjjB'===_0x53ff82(0x95c)?(this[_0x53ff82(0x6ae)]['update'](),this[_0x53ff82(0x3e7)][_0x53ff82(0x4fa)](),this[_0x53ff82(0x6c7)][_0x53ff82(0x572)]=![],_0x2fa886['snapForBackground']()):this['smoothSelect'](Math[_0x53ff82(0x350)](this[_0x53ff82(0x69d)](),this[_0x53ff82(0x7b4)]()-0x1))),this[_0x53ff82(0x69d)]()!==_0x195e5c&&this['playCursorSound']();}},VisuMZ['CoreEngine'][_0x54167d(0x51f)]=Window_Selectable['prototype'][_0x54167d(0x8fa)],Window_Selectable['prototype']['processTouch']=function(){const _0x2dc8a8=_0x54167d;if(this[_0x2dc8a8(0x260)]())this[_0x2dc8a8(0x5c1)]();else{if('vXufJ'===_0x2dc8a8(0x9db))VisuMZ['CoreEngine'][_0x2dc8a8(0x51f)]['call'](this);else return _0x34dd11[_0x2dc8a8(0x85e)][_0x2dc8a8(0x204)](this);}},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x5c1)]=function(){const _0x238592=_0x54167d;VisuMZ[_0x238592(0x940)][_0x238592(0x51f)]['call'](this);},Window_Selectable['prototype'][_0x54167d(0x6c4)]=function(){const _0x3e47f2=_0x54167d;return VisuMZ[_0x3e47f2(0x940)][_0x3e47f2(0x331)][_0x3e47f2(0x3b6)][_0x3e47f2(0x6f1)];},Window_Selectable[_0x54167d(0x4ec)][_0x54167d(0x4ab)]=function(){const _0x67b029=_0x54167d;return VisuMZ[_0x67b029(0x940)][_0x67b029(0x331)][_0x67b029(0x3b6)][_0x67b029(0x1f9)];},Window_Selectable[_0x54167d(0x4ec)]['itemHeight']=function(){const _0x287cf6=_0x54167d;return Window_Scrollable[_0x287cf6(0x4ec)][_0x287cf6(0x97d)][_0x287cf6(0x204)](this)+VisuMZ[_0x287cf6(0x940)]['Settings'][_0x287cf6(0x3b6)][_0x287cf6(0x49c)];;},VisuMZ[_0x54167d(0x940)]['Window_Selectable_drawBackgroundRect']=Window_Selectable['prototype']['drawBackgroundRect'],Window_Selectable[_0x54167d(0x4ec)]['drawBackgroundRect']=function(_0x4ebb30){const _0x514d1d=_0x54167d,_0x2db2a1=VisuMZ[_0x514d1d(0x940)][_0x514d1d(0x331)][_0x514d1d(0x3b6)];if(_0x2db2a1[_0x514d1d(0x4da)]===![])return;if(_0x2db2a1['DrawItemBackgroundJS']){if(_0x514d1d(0x839)===_0x514d1d(0x839))_0x2db2a1['DrawItemBackgroundJS'][_0x514d1d(0x204)](this,_0x4ebb30);else return _0x296a40;}else _0x514d1d(0x8ae)===_0x514d1d(0x8ae)?VisuMZ[_0x514d1d(0x940)]['Window_Selectable_drawBackgroundRect'][_0x514d1d(0x204)](this,_0x4ebb30):this[_0x514d1d(0x8b5)]['setBackgroundType'](_0x5b847a['layoutSettings'][_0x514d1d(0x342)]);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x99e)]=Window_Gold[_0x54167d(0x4ec)]['refresh'],Window_Gold[_0x54167d(0x4ec)][_0x54167d(0x7dd)]=function(){const _0x5096de=_0x54167d;this['isItemStyle']()?this[_0x5096de(0x739)]():'QjKWZ'===_0x5096de(0x9a4)?(_0x1ed905[_0x5096de(0x4ec)][_0x5096de(0x66b)][_0x5096de(0x204)](this),this[_0x5096de(0x8d9)]()):VisuMZ[_0x5096de(0x940)][_0x5096de(0x99e)][_0x5096de(0x204)](this);},Window_Gold[_0x54167d(0x4ec)]['isItemStyle']=function(){const _0x434c1b=_0x54167d;if(TextManager[_0x434c1b(0x925)]!==this[_0x434c1b(0x925)]())return![];return VisuMZ[_0x434c1b(0x940)][_0x434c1b(0x331)][_0x434c1b(0x67c)][_0x434c1b(0x819)];},Window_Gold[_0x54167d(0x4ec)]['drawGoldItemStyle']=function(){const _0x443d49=_0x54167d;this[_0x443d49(0x723)](),this[_0x443d49(0x9a3)][_0x443d49(0x531)](),this['contents'][_0x443d49(0x79f)]=VisuMZ[_0x443d49(0x940)][_0x443d49(0x331)][_0x443d49(0x67c)]['GoldFontSize'];const _0x2fefa4=VisuMZ[_0x443d49(0x940)][_0x443d49(0x331)][_0x443d49(0x67c)][_0x443d49(0x6f4)],_0x1fb479=this[_0x443d49(0x37d)](0x0);if(_0x2fefa4>0x0){if(_0x443d49(0x346)===_0x443d49(0x346)){const _0xe76650=_0x1fb479['y']+(this[_0x443d49(0x7c4)]()-ImageManager[_0x443d49(0x814)])/0x2;this[_0x443d49(0x84d)](_0x2fefa4,_0x1fb479['x'],_0xe76650);const _0x5a8d8f=ImageManager['iconWidth']+0x4;_0x1fb479['x']+=_0x5a8d8f,_0x1fb479['width']-=_0x5a8d8f;}else{var _0x513178=_0x11467b(_0x4d1608['$1']);_0x3247d5*=_0x513178;}}this['changeTextColor'](ColorManager['systemColor']()),this[_0x443d49(0x2cc)](this[_0x443d49(0x925)](),_0x1fb479['x'],_0x1fb479['y'],_0x1fb479['width'],'left');const _0x311e39=this[_0x443d49(0x705)](this[_0x443d49(0x925)]())+0x6;;_0x1fb479['x']+=_0x311e39,_0x1fb479[_0x443d49(0x281)]-=_0x311e39,this[_0x443d49(0x32c)]();const _0x4cc687=this[_0x443d49(0x570)](),_0x2c5f3b=this[_0x443d49(0x705)](this['_digitGrouping']?VisuMZ[_0x443d49(0x5da)](this[_0x443d49(0x570)]()):this[_0x443d49(0x570)]());_0x2c5f3b>_0x1fb479[_0x443d49(0x281)]?this[_0x443d49(0x2cc)](VisuMZ['CoreEngine'][_0x443d49(0x331)][_0x443d49(0x67c)]['GoldOverlap'],_0x1fb479['x'],_0x1fb479['y'],_0x1fb479[_0x443d49(0x281)],_0x443d49(0x231)):this[_0x443d49(0x2cc)](this[_0x443d49(0x570)](),_0x1fb479['x'],_0x1fb479['y'],_0x1fb479[_0x443d49(0x281)],_0x443d49(0x231)),this[_0x443d49(0x723)]();},Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x3b8)]=function(_0xb9012,_0x5bf864,_0x49b129,_0x49e62e,_0x42b192){const _0x5d101d=_0x54167d;_0x49e62e=String(_0x49e62e||'')[_0x5d101d(0x8dd)]();if(VisuMZ[_0x5d101d(0x940)][_0x5d101d(0x331)]['Param'][_0x5d101d(0x209)]){if('WkDdu'!==_0x5d101d(0x4e5))return this[_0x5d101d(0x475)];else{const _0x75cea7=VisuMZ[_0x5d101d(0x97a)](_0x49e62e);_0x42b192?_0x5d101d(0x715)!=='YjNvh'?_0x1cf053[_0x5d101d(0x460)][_0x5d101d(0x36a)]=_0x5d101d(0x292):(this[_0x5d101d(0x404)](_0x75cea7,_0xb9012,_0x5bf864,this['gaugeLineHeight']()),_0x49b129-=this['gaugeLineHeight']()+0x2,_0xb9012+=this[_0x5d101d(0x362)]()+0x2):(this[_0x5d101d(0x84d)](_0x75cea7,_0xb9012+0x2,_0x5bf864+0x2),_0x49b129-=ImageManager[_0x5d101d(0x28b)]+0x4,_0xb9012+=ImageManager[_0x5d101d(0x28b)]+0x4);}}const _0x28a8fb=TextManager[_0x5d101d(0x594)](_0x49e62e);this['resetFontSettings'](),this[_0x5d101d(0x378)](ColorManager['systemColor']()),_0x42b192?_0x5d101d(0x2c7)!==_0x5d101d(0x811)?(this[_0x5d101d(0x9a3)][_0x5d101d(0x79f)]=this[_0x5d101d(0x227)](),this[_0x5d101d(0x9a3)][_0x5d101d(0x2cc)](_0x28a8fb,_0xb9012,_0x5bf864,_0x49b129,this['gaugeLineHeight'](),'left')):this[_0x5d101d(0x5b7)]={'duration':_0x271c32,'wholeDuration':_0x26cf78,'type':_0x2b1b49,'targetX':_0x3969c2,'targetY':_0x3fbc1c,'targetScaleX':_0x2b20a8,'targetScaleY':_0x1385a9,'targetOpacity':_0x1ea89e,'targetBackOpacity':_0x10688e,'targetContentsOpacity':_0x11cb41}:this[_0x5d101d(0x2cc)](_0x28a8fb,_0xb9012,_0x5bf864,_0x49b129),this[_0x5d101d(0x723)]();},Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x227)]=function(){const _0x5f4ded=_0x54167d;return $gameSystem[_0x5f4ded(0x89c)]()-0x8;},Window_StatusBase['prototype'][_0x54167d(0x2e5)]=function(_0x2688b6,_0x1393b3,_0x394b47,_0x25e9fa){const _0x44a427=_0x54167d;_0x25e9fa=_0x25e9fa||0xa8,this['resetTextColor']();if(VisuMZ['CoreEngine'][_0x44a427(0x331)]['UI'][_0x44a427(0x7be)])this[_0x44a427(0x545)](_0x2688b6['currentClass']()[_0x44a427(0x614)],_0x1393b3,_0x394b47,_0x25e9fa);else{if(_0x44a427(0x845)!==_0x44a427(0x47a)){const _0x53d45d=_0x2688b6[_0x44a427(0x50c)]()[_0x44a427(0x614)][_0x44a427(0x3ed)](/\\I\[(\d+)\]/gi,'');this[_0x44a427(0x2cc)](_0x53d45d,_0x1393b3,_0x394b47,_0x25e9fa);}else _0x4145a0[_0x44a427(0x940)][_0x44a427(0x4b0)][_0x44a427(0x204)](this),this[_0x44a427(0x8d0)]();}},Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x756)]=function(_0x25b34b,_0x1634b2,_0x493ab2,_0x178ecb){const _0x13d509=_0x54167d;_0x178ecb=_0x178ecb||0x10e,this[_0x13d509(0x32c)]();if(VisuMZ[_0x13d509(0x940)][_0x13d509(0x331)]['UI'][_0x13d509(0x740)])this[_0x13d509(0x545)](_0x25b34b[_0x13d509(0x641)](),_0x1634b2,_0x493ab2,_0x178ecb);else{if(_0x13d509(0x97c)==='CazGT'){const _0x48e7ae=_0x25b34b[_0x13d509(0x641)]()[_0x13d509(0x3ed)](/\\I\[(\d+)\]/gi,'');this['drawText'](_0x25b34b[_0x13d509(0x641)](),_0x1634b2,_0x493ab2,_0x178ecb);}else{var _0x36cb6b=_0xc854d1(_0x1721aa['$1']);try{_0x11961d+=_0x4bfb0c(_0x36cb6b);}catch(_0x155a75){if(_0x483c17[_0x13d509(0x562)]())_0x5b9eb3[_0x13d509(0x262)](_0x155a75);}}}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x3eb)]=Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x2bb)],Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x2bb)]=function(_0x39609a,_0x3f39bc,_0xb9c0bf){const _0x4d8c68=_0x54167d;if(this[_0x4d8c68(0x6d9)]())this[_0x4d8c68(0x830)](_0x39609a,_0x3f39bc,_0xb9c0bf);VisuMZ[_0x4d8c68(0x940)][_0x4d8c68(0x3eb)][_0x4d8c68(0x204)](this,_0x39609a,_0x3f39bc,_0xb9c0bf);},Window_StatusBase[_0x54167d(0x4ec)]['isExpGaugeDrawn']=function(){const _0x55f984=_0x54167d;return VisuMZ[_0x55f984(0x940)][_0x55f984(0x331)]['UI']['LvExpGauge'];},Window_StatusBase[_0x54167d(0x4ec)][_0x54167d(0x830)]=function(_0x153d62,_0x4fe562,_0x5d73ba){const _0xad6a9d=_0x54167d;if(!_0x153d62)return;if(!_0x153d62['isActor']())return;const _0x33455d=0x80,_0x5a8079=_0x153d62[_0xad6a9d(0x552)]();let _0x3fedae=ColorManager[_0xad6a9d(0x491)](),_0x23c764=ColorManager['expGaugeColor2']();_0x5a8079>=0x1&&('nQJKx'!==_0xad6a9d(0x5a8)?(_0x3fedae=ColorManager[_0xad6a9d(0x6a7)](),_0x23c764=ColorManager[_0xad6a9d(0x5e2)]()):_0x3a89b5['playBuzzer']()),this[_0xad6a9d(0x2a5)](_0x4fe562,_0x5d73ba,_0x33455d,_0x5a8079,_0x3fedae,_0x23c764);},Window_EquipStatus['prototype'][_0x54167d(0x615)]=function(){const _0x1d1ea4=_0x54167d;let _0x4fffc3=0x0;for(const _0x567a9e of VisuMZ['CoreEngine'][_0x1d1ea4(0x331)][_0x1d1ea4(0x3fa)][_0x1d1ea4(0x70d)]){const _0x52e6ad=this[_0x1d1ea4(0x46a)](),_0x343583=this['paramY'](_0x4fffc3);this[_0x1d1ea4(0x793)](_0x52e6ad,_0x343583,_0x567a9e),_0x4fffc3++;}},Window_EquipStatus[_0x54167d(0x4ec)]['drawParamName']=function(_0xa0d154,_0x34cb05,_0x393fdb){const _0x576200=_0x54167d,_0x35bb8a=this['paramX']()-this[_0x576200(0x46a)]()*0x2;this[_0x576200(0x3b8)](_0xa0d154,_0x34cb05,_0x35bb8a,_0x393fdb,![]);},Window_EquipStatus[_0x54167d(0x4ec)]['drawCurrentParam']=function(_0x51b61d,_0x434e56,_0xbd041d){const _0x53321d=_0x54167d,_0x1f288a=this[_0x53321d(0x948)]();this['resetTextColor'](),this['drawText'](this[_0x53321d(0x521)][_0x53321d(0x4e4)](_0xbd041d,!![]),_0x51b61d,_0x434e56,_0x1f288a,'right');},Window_EquipStatus['prototype'][_0x54167d(0x5a2)]=function(_0x38632c,_0x35fe9c){const _0x93a18d=_0x54167d,_0x167a85=this[_0x93a18d(0x7a8)]();this[_0x93a18d(0x378)](ColorManager[_0x93a18d(0x636)]());const _0x35dec4=VisuMZ[_0x93a18d(0x940)][_0x93a18d(0x331)]['UI'][_0x93a18d(0x320)];this[_0x93a18d(0x2cc)](_0x35dec4,_0x38632c,_0x35fe9c,_0x167a85,_0x93a18d(0x68b));},Window_EquipStatus[_0x54167d(0x4ec)][_0x54167d(0x8b0)]=function(_0x27b2f1,_0x1bcf37,_0xb9ed40){const _0x2b7511=_0x54167d,_0x2e42b2=this[_0x2b7511(0x948)](),_0x20ee83=this[_0x2b7511(0x315)][_0x2b7511(0x4e4)](_0xb9ed40),_0x34e532=_0x20ee83-this['_actor'][_0x2b7511(0x4e4)](_0xb9ed40);this[_0x2b7511(0x378)](ColorManager['paramchangeTextColor'](_0x34e532)),this[_0x2b7511(0x2cc)](this[_0x2b7511(0x315)][_0x2b7511(0x4e4)](_0xb9ed40,!![]),_0x27b2f1,_0x1bcf37,_0x2e42b2,'right');},VisuMZ[_0x54167d(0x940)]['Window_EquipItem_isEnabled']=Window_EquipItem[_0x54167d(0x4ec)][_0x54167d(0x4b7)],Window_EquipItem['prototype'][_0x54167d(0x4b7)]=function(_0x4c9cf5){const _0x2c743a=_0x54167d;if(_0x4c9cf5&&this[_0x2c743a(0x521)])return this[_0x2c743a(0x521)][_0x2c743a(0x809)](_0x4c9cf5);else{if(_0x2c743a(0x759)!==_0x2c743a(0x759))_0x34b861=(0x1-_0x545f07(_0x484532['$1']))*-_0x7d9222;else return VisuMZ['CoreEngine'][_0x2c743a(0x34b)][_0x2c743a(0x204)](this,_0x4c9cf5);}},Window_StatusParams[_0x54167d(0x4ec)][_0x54167d(0x7b4)]=function(){const _0x10e0f6=_0x54167d;return VisuMZ[_0x10e0f6(0x940)][_0x10e0f6(0x331)][_0x10e0f6(0x3fa)][_0x10e0f6(0x70d)][_0x10e0f6(0x95b)];},Window_StatusParams[_0x54167d(0x4ec)][_0x54167d(0x793)]=function(_0x476208){const _0x3d51d1=_0x54167d,_0x1b1f78=this[_0x3d51d1(0x37d)](_0x476208),_0x397948=VisuMZ['CoreEngine'][_0x3d51d1(0x331)][_0x3d51d1(0x3fa)]['DisplayedParams'][_0x476208],_0x36e125=TextManager[_0x3d51d1(0x594)](_0x397948),_0x526cfc=this[_0x3d51d1(0x521)]['paramValueByName'](_0x397948,!![]);this[_0x3d51d1(0x3b8)](_0x1b1f78['x'],_0x1b1f78['y'],0xa0,_0x397948,![]),this[_0x3d51d1(0x32c)](),this[_0x3d51d1(0x2cc)](_0x526cfc,_0x1b1f78['x']+0xa0,_0x1b1f78['y'],0x3c,_0x3d51d1(0x231));};if(VisuMZ['CoreEngine']['Settings'][_0x54167d(0x8a6)][_0x54167d(0x257)]){VisuMZ[_0x54167d(0x940)][_0x54167d(0x331)][_0x54167d(0x8a6)]['QwertyLayout']&&(Window_NameInput[_0x54167d(0x7ea)]=['Q','W','E','R','T','Y','U','I','O','P','A','S','D','F','G','H','J','K','L','\x27','`','Z','X','C','V','B','N','M',',','.','q','w','e','r','t','y','u','i','o','p','a','s','d','f','g','h','j','k','l',':','~','z','x','c','v','b','n','m','\x22',';','1','2','3','4','5','6','7','8','9','0','!','@','#','$','%','^','&','*','(',')','<','>','[',']','-','_','/','\x20','Page','OK']);;VisuMZ[_0x54167d(0x940)][_0x54167d(0x927)]=Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x8d7)],Window_NameInput['prototype'][_0x54167d(0x8d7)]=function(_0x26f2b4){const _0x478c72=_0x54167d;this[_0x478c72(0x51e)]=this['defaultInputMode'](),VisuMZ[_0x478c72(0x940)][_0x478c72(0x927)][_0x478c72(0x204)](this,_0x26f2b4),this[_0x478c72(0x51e)]==='default'?this[_0x478c72(0x433)](0x0):_0x478c72(0x45b)!==_0x478c72(0x7d5)?(Input[_0x478c72(0x531)](),this[_0x478c72(0x505)]()):(_0x3cf783[_0x478c72(0x46e)]=![],_0x1e07fd[_0x478c72(0x438)]=!![]);},Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x9d0)]=function(){const _0x2e09aa=_0x54167d;if(Input[_0x2e09aa(0x599)]())return _0x2e09aa(0x646);return VisuMZ[_0x2e09aa(0x940)]['Settings'][_0x2e09aa(0x8a6)][_0x2e09aa(0x870)]||'keyboard';},VisuMZ[_0x54167d(0x940)]['Window_NameInput_processHandling']=Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x21c)],Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x21c)]=function(){const _0x26c603=_0x54167d;if(!this[_0x26c603(0x88f)]())return;if(!this[_0x26c603(0x935)])return;if(this[_0x26c603(0x51e)]===_0x26c603(0x97f)&&Input[_0x26c603(0x40e)]())'jnQMW'!==_0x26c603(0x4c1)?this['_inputWindow']['setBackgroundType'](_0x3cced1[_0x26c603(0x556)][_0x26c603(0x60b)]):this[_0x26c603(0x94e)]('default');else{if(Input['isSpecialCode']('backspace'))Input[_0x26c603(0x531)](),this[_0x26c603(0x621)]();else{if(Input['isTriggered'](_0x26c603(0x846))){Input['clear']();if(this['_mode']==='keyboard')'rXkAT'!=='rXkAT'?_0x330a43[_0x26c603(0x940)]['Game_Interpreter_command111'][_0x26c603(0x204)](this,_0x38cc97):this['switchModes'](_0x26c603(0x646));else{if(_0x26c603(0x458)!==_0x26c603(0x458)){const _0x26802a=this[_0x26c603(0x58e)](_0x2795af),_0x12e34e=new(_0x26802a?_0x14a061:_0xd11daa)(),_0x2562d3=this['makeTargetSprites'](_0xf45ddc);this['animationShouldMirror'](_0x3b0c55[0x0])&&(_0x525a79=!_0x229ae7),_0x12e34e[_0x26c603(0x225)]=_0xa0ce37,_0x12e34e[_0x26c603(0x82d)](_0x2562d3,_0x9c431a,_0x12d790,_0x55e9b0),_0x12e34e[_0x26c603(0x20f)](_0x214ad3),this['_effectsContainer'][_0x26c603(0x45f)](_0x12e34e),this[_0x26c603(0x755)][_0x26c603(0x398)](_0x12e34e);}else this[_0x26c603(0x94e)](_0x26c603(0x97f));}}else{if(this['_mode']==='keyboard'){if(_0x26c603(0x2b5)===_0x26c603(0x2b5))this[_0x26c603(0x606)]();else{if(!this[_0x26c603(0x629)])return;for(const _0x5bba67 of this[_0x26c603(0x629)]){_0x5bba67&&_0x5bba67[_0x26c603(0x3b5)]();}}}else Input[_0x26c603(0x623)](_0x26c603(0x3c9))?(Input['clear'](),this[_0x26c603(0x94e)](_0x26c603(0x97f))):_0x26c603(0x5fb)!==_0x26c603(0x5fb)?this[_0x26c603(0x53e)]=_0x4dae3b:VisuMZ[_0x26c603(0x940)]['Window_NameInput_processHandling'][_0x26c603(0x204)](this);}}}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x2c9)]=Window_NameInput['prototype'][_0x54167d(0x8fa)],Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x8fa)]=function(){const _0x178075=_0x54167d;if(!this['isOpenAndActive']())return;if(this['_mode']==='keyboard'){if(TouchInput[_0x178075(0x54b)]()&&this[_0x178075(0x8e1)]()){if(_0x178075(0x36f)===_0x178075(0x36f))this['switchModes']('default');else{if(!_0x3a0894['isPlaytest']())return;if(!_0x2d073b[_0x178075(0x303)]())return;_0x4fa823['ConvertParams'](_0x1ac5c7,_0x537b28);const _0x202c0f=_0x572e2e[_0x178075(0x77e)]||0x1;_0x12336a[_0x178075(0x9eb)]=_0x202c0f;}}else TouchInput[_0x178075(0x6e2)]()&&(_0x178075(0x5fd)===_0x178075(0x5fd)?this['switchModes'](_0x178075(0x646)):this[_0x178075(0x29e)][_0x178075(0x6d0)](_0x35d247[_0x178075(0x556)][_0x178075(0x585)]));}else VisuMZ[_0x178075(0x940)]['Window_NameInput_processTouch'][_0x178075(0x204)](this);},Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x606)]=function(){const _0x56d4ae=_0x54167d;if(Input[_0x56d4ae(0x623)]('enter'))_0x56d4ae(0x87e)===_0x56d4ae(0x593)?this[_0x56d4ae(0x3d0)]['add'](_0x4433bb[_0x284df9])?_0x4178e7[_0x56d4ae(0x5d9)]():_0x5e330a[_0x56d4ae(0x466)]():(Input[_0x56d4ae(0x531)](),this[_0x56d4ae(0x9b3)]());else{if(Input[_0x56d4ae(0x2f6)]!==undefined){if('DIGsh'!=='PrYSl'){let _0x50cc7f=Input[_0x56d4ae(0x2f6)],_0x1b0989=_0x50cc7f[_0x56d4ae(0x95b)];for(let _0x101b5a=0x0;_0x101b5a<_0x1b0989;++_0x101b5a){if('Tiisj'!==_0x56d4ae(0x757)){if(this['_editWindow'][_0x56d4ae(0x5e9)](_0x50cc7f[_0x101b5a]))SoundManager['playOk']();else{if('uptqY'!==_0x56d4ae(0x222))SoundManager[_0x56d4ae(0x466)]();else{const _0x434369=this[_0x56d4ae(0x614)](),_0x167a16=this['bitmapWidth'](),_0x4d0a40=this[_0x56d4ae(0x9b5)]();this[_0x56d4ae(0x832)](),this[_0x56d4ae(0x228)][_0x56d4ae(0x531)](),this['bitmap'][_0x56d4ae(0x232)](_0x434369,0x0,0x0,_0x167a16,_0x4d0a40,_0x56d4ae(0x750));}}}else return!![];}Input['clear']();}else _0x312de3+=_0x56d4ae(0x61a);}}},Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x94e)]=function(_0xde45bf){const _0x2ac58f=_0x54167d;let _0x232127=this['_mode'];this[_0x2ac58f(0x51e)]=_0xde45bf,_0x232127!==this[_0x2ac58f(0x51e)]&&(this[_0x2ac58f(0x7dd)](),SoundManager[_0x2ac58f(0x5d9)](),this[_0x2ac58f(0x51e)]==='default'?this[_0x2ac58f(0x433)](0x0):this[_0x2ac58f(0x433)](-0x1));},VisuMZ['CoreEngine']['Window_NameInput_cursorDown']=Window_NameInput['prototype']['cursorDown'],Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x663)]=function(_0x352cce){const _0xcbbff3=_0x54167d;if(this[_0xcbbff3(0x51e)]===_0xcbbff3(0x97f)&&!Input[_0xcbbff3(0x966)]())return;if(Input[_0xcbbff3(0x8e3)]())return;VisuMZ[_0xcbbff3(0x940)][_0xcbbff3(0x3d8)][_0xcbbff3(0x204)](this,_0x352cce),this[_0xcbbff3(0x94e)](_0xcbbff3(0x646));},VisuMZ[_0x54167d(0x940)]['Window_NameInput_cursorUp']=Window_NameInput['prototype']['cursorUp'],Window_NameInput[_0x54167d(0x4ec)]['cursorUp']=function(_0xdf283f){const _0x2d35e1=_0x54167d;if(this[_0x2d35e1(0x51e)]===_0x2d35e1(0x97f)&&!Input[_0x2d35e1(0x966)]())return;if(Input[_0x2d35e1(0x8e3)]())return;VisuMZ[_0x2d35e1(0x940)][_0x2d35e1(0x6ce)][_0x2d35e1(0x204)](this,_0xdf283f),this[_0x2d35e1(0x94e)](_0x2d35e1(0x646));},VisuMZ[_0x54167d(0x940)][_0x54167d(0x703)]=Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x465)],Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x465)]=function(_0x182600){const _0x6d75d8=_0x54167d;if(this['_mode']===_0x6d75d8(0x97f)&&!Input[_0x6d75d8(0x966)]())return;if(Input[_0x6d75d8(0x8e3)]())return;VisuMZ['CoreEngine']['Window_NameInput_cursorRight'][_0x6d75d8(0x204)](this,_0x182600),this[_0x6d75d8(0x94e)](_0x6d75d8(0x646));},VisuMZ[_0x54167d(0x940)][_0x54167d(0x368)]=Window_NameInput['prototype']['cursorLeft'],Window_NameInput['prototype'][_0x54167d(0xa0e)]=function(_0x58a978){const _0x1b7390=_0x54167d;if(this[_0x1b7390(0x51e)]===_0x1b7390(0x97f)&&!Input[_0x1b7390(0x966)]())return;if(Input[_0x1b7390(0x8e3)]())return;VisuMZ['CoreEngine'][_0x1b7390(0x368)]['call'](this,_0x58a978),this[_0x1b7390(0x94e)](_0x1b7390(0x646));},VisuMZ[_0x54167d(0x940)]['Window_NameInput_cursorPagedown']=Window_NameInput['prototype'][_0x54167d(0x7a9)],Window_NameInput[_0x54167d(0x4ec)][_0x54167d(0x7a9)]=function(){const _0x65d1be=_0x54167d;if(this['_mode']===_0x65d1be(0x97f))return;if(Input[_0x65d1be(0x8e3)]())return;VisuMZ['CoreEngine']['Window_NameInput_cursorPagedown'][_0x65d1be(0x204)](this),this[_0x65d1be(0x94e)](_0x65d1be(0x646));},VisuMZ['CoreEngine'][_0x54167d(0x75e)]=Window_NameInput['prototype'][_0x54167d(0x9f5)],Window_NameInput[_0x54167d(0x4ec)]['cursorPageup']=function(){const _0x363913=_0x54167d;if(this[_0x363913(0x51e)]===_0x363913(0x97f))return;if(Input[_0x363913(0x8e3)]())return;VisuMZ[_0x363913(0x940)][_0x363913(0x75e)][_0x363913(0x204)](this),this[_0x363913(0x94e)](_0x363913(0x646));},VisuMZ[_0x54167d(0x940)]['Window_NameInput_refresh']=Window_NameInput[_0x54167d(0x4ec)]['refresh'],Window_NameInput[_0x54167d(0x4ec)]['refresh']=function(){const _0x477c56=_0x54167d;if(this[_0x477c56(0x51e)]===_0x477c56(0x97f)){this['contents'][_0x477c56(0x531)](),this[_0x477c56(0x9cb)]['clear'](),this[_0x477c56(0x32c)]();let _0x25c782=VisuMZ[_0x477c56(0x940)][_0x477c56(0x331)][_0x477c56(0x8a6)]['NameInputMessage'][_0x477c56(0x913)]('\x0a'),_0x5b137b=_0x25c782[_0x477c56(0x95b)],_0x2d0a4b=(this[_0x477c56(0x869)]-_0x5b137b*this[_0x477c56(0x7c4)]())/0x2;for(let _0x3634d2=0x0;_0x3634d2<_0x5b137b;++_0x3634d2){let _0x4bceb4=_0x25c782[_0x3634d2],_0x5c456a=this['textSizeEx'](_0x4bceb4)[_0x477c56(0x281)],_0x1bfe46=Math[_0x477c56(0x42f)]((this[_0x477c56(0x9a3)][_0x477c56(0x281)]-_0x5c456a)/0x2);this[_0x477c56(0x545)](_0x4bceb4,_0x1bfe46,_0x2d0a4b),_0x2d0a4b+=this[_0x477c56(0x7c4)]();}}else VisuMZ[_0x477c56(0x940)][_0x477c56(0x2be)][_0x477c56(0x204)](this);};};VisuMZ[_0x54167d(0x940)][_0x54167d(0x853)]=Window_ShopSell['prototype']['isEnabled'],Window_ShopSell[_0x54167d(0x4ec)]['isEnabled']=function(_0x28d941){const _0x4a176b=_0x54167d;return VisuMZ[_0x4a176b(0x940)][_0x4a176b(0x331)][_0x4a176b(0x2e9)][_0x4a176b(0x75d)]&&DataManager['isKeyItem'](_0x28d941)?![]:VisuMZ[_0x4a176b(0x940)]['Window_ShopSell_isEnabled'][_0x4a176b(0x204)](this,_0x28d941);},Window_NumberInput[_0x54167d(0x4ec)][_0x54167d(0x260)]=function(){return![];};VisuMZ[_0x54167d(0x940)]['Settings'][_0x54167d(0x8a6)][_0x54167d(0x5b6)]&&(VisuMZ[_0x54167d(0x940)]['Window_NumberInput_start']=Window_NumberInput[_0x54167d(0x4ec)][_0x54167d(0x773)],Window_NumberInput[_0x54167d(0x4ec)]['start']=function(){const _0x2e7074=_0x54167d;VisuMZ[_0x2e7074(0x940)][_0x2e7074(0x3f5)]['call'](this),this[_0x2e7074(0x433)](this[_0x2e7074(0x412)]-0x1),Input[_0x2e7074(0x531)]();},VisuMZ[_0x54167d(0x940)][_0x54167d(0x9d1)]=Window_NumberInput['prototype'][_0x54167d(0x769)],Window_NumberInput['prototype'][_0x54167d(0x769)]=function(){const _0x53d6e0=_0x54167d;if(!this['isOpenAndActive']())return;if(Input[_0x53d6e0(0x8e3)]())this['processKeyboardDigitChange']();else{if(Input[_0x53d6e0(0x623)](_0x53d6e0(0x4b3))){if(_0x53d6e0(0x4b6)!==_0x53d6e0(0x9af))this[_0x53d6e0(0x21b)]();else{if(_0x40e3a1)_0x55f900['ParseStateNotetags'](_0x3887af);}}else{if(Input[_0x53d6e0(0x912)]===0x2e){if('WkhCN'!==_0x53d6e0(0x5bc))this[_0x53d6e0(0x8fc)]();else{const _0x17744f=_0x5b3f04['platform']==_0x53d6e0(0x2c3)?_0x53d6e0(0x592):_0x29a5a9[_0x53d6e0(0x25d)]==_0x53d6e0(0x8e7)?_0x53d6e0(0x773):'xdg-open';_0x71a35f(_0x53d6e0(0x3c1))[_0x53d6e0(0x238)](_0x17744f+'\x20'+_0x1893ab);}}else{if(Input['_inputSpecialKeyCode']===0x24)this['processKeyboardHome']();else Input['_inputSpecialKeyCode']===0x23?this[_0x53d6e0(0x633)]():VisuMZ[_0x53d6e0(0x940)][_0x53d6e0(0x9d1)][_0x53d6e0(0x204)](this);}}}},Window_NumberInput[_0x54167d(0x4ec)]['processCursorMove']=function(){const _0x3aef86=_0x54167d;if(!this[_0x3aef86(0x318)]())return;if(Input[_0x3aef86(0x8e3)]()){if('YveEE'!=='DPGcJ')this['processKeyboardDigitChange']();else{const _0x5b0c7f=this[_0x3aef86(0x7a8)]();this[_0x3aef86(0x378)](_0x2dd463[_0x3aef86(0x636)]());const _0x2c018f=_0x3ea5d8[_0x3aef86(0x940)][_0x3aef86(0x331)]['UI'][_0x3aef86(0x320)];this['drawText'](_0x2c018f,_0x2e71d4,_0x3037ea,_0x5b0c7f,'center');}}else Window_Selectable['prototype'][_0x3aef86(0x430)][_0x3aef86(0x204)](this);},Window_NumberInput[_0x54167d(0x4ec)][_0x54167d(0x976)]=function(){},Window_NumberInput[_0x54167d(0x4ec)][_0x54167d(0x772)]=function(){const _0x1a00e4=_0x54167d;if(String(this[_0x1a00e4(0x52d)])[_0x1a00e4(0x95b)]>=this[_0x1a00e4(0x412)])return;const _0x56938e=Number(String(this[_0x1a00e4(0x52d)])+Input[_0x1a00e4(0x2f6)]);if(isNaN(_0x56938e))return;this['_number']=_0x56938e;const _0x8158aa='9'['repeat'](this[_0x1a00e4(0x412)]);this[_0x1a00e4(0x52d)]=this[_0x1a00e4(0x52d)][_0x1a00e4(0x29b)](0x0,_0x8158aa),Input[_0x1a00e4(0x531)](),this[_0x1a00e4(0x7dd)](),SoundManager[_0x1a00e4(0x711)](),this[_0x1a00e4(0x433)](this[_0x1a00e4(0x412)]-0x1);},Window_NumberInput['prototype'][_0x54167d(0x21b)]=function(){const _0x2bad8a=_0x54167d;this['_number']=Number(String(this[_0x2bad8a(0x52d)])[_0x2bad8a(0x6c2)](0x0,-0x1)),this[_0x2bad8a(0x52d)]=Math[_0x2bad8a(0x350)](0x0,this[_0x2bad8a(0x52d)]),Input['clear'](),this[_0x2bad8a(0x7dd)](),SoundManager[_0x2bad8a(0x711)](),this[_0x2bad8a(0x433)](this[_0x2bad8a(0x412)]-0x1);},Window_NumberInput['prototype'][_0x54167d(0x8fc)]=function(){const _0x5ef67c=_0x54167d;this[_0x5ef67c(0x52d)]=Number(String(this['_number'])['substring'](0x1)),this[_0x5ef67c(0x52d)]=Math['max'](0x0,this[_0x5ef67c(0x52d)]),Input[_0x5ef67c(0x531)](),this[_0x5ef67c(0x7dd)](),SoundManager[_0x5ef67c(0x711)](),this[_0x5ef67c(0x433)](this['_maxDigits']-0x1);});;Window_TitleCommand[_0x54167d(0x921)]=VisuMZ['CoreEngine'][_0x54167d(0x331)][_0x54167d(0x312)],Window_TitleCommand['prototype'][_0x54167d(0x3a5)]=function(){const _0x26e7c1=_0x54167d;this[_0x26e7c1(0x7b0)]();},Window_TitleCommand[_0x54167d(0x4ec)]['makeCoreEngineCommandList']=function(){const _0x1634a8=_0x54167d;for(const _0x216e0d of Window_TitleCommand[_0x1634a8(0x921)]){if(_0x216e0d[_0x1634a8(0x48d)][_0x1634a8(0x204)](this)){const _0x495e4a=_0x216e0d['Symbol'];let _0x46d2c0=_0x216e0d['TextStr'];if(['',_0x1634a8(0x916)][_0x1634a8(0x9ef)](_0x46d2c0))_0x46d2c0=_0x216e0d['TextJS'][_0x1634a8(0x204)](this);const _0x321401=_0x216e0d[_0x1634a8(0x338)][_0x1634a8(0x204)](this),_0x1de8df=_0x216e0d[_0x1634a8(0x5c8)][_0x1634a8(0x204)](this);this['addCommand'](_0x46d2c0,_0x495e4a,_0x321401,_0x1de8df),this['setHandler'](_0x495e4a,_0x216e0d[_0x1634a8(0x406)][_0x1634a8(0x6ac)](this,_0x1de8df));}}},Window_GameEnd[_0x54167d(0x921)]=VisuMZ['CoreEngine'][_0x54167d(0x331)][_0x54167d(0x529)][_0x54167d(0x39d)]['CommandList'],Window_GameEnd[_0x54167d(0x4ec)][_0x54167d(0x3a5)]=function(){const _0x50c0bc=_0x54167d;this[_0x50c0bc(0x7b0)]();},Window_GameEnd[_0x54167d(0x4ec)][_0x54167d(0x7b0)]=function(){const _0x5e1cfd=_0x54167d;for(const _0xc23907 of Window_GameEnd[_0x5e1cfd(0x921)]){if(_0xc23907[_0x5e1cfd(0x48d)]['call'](this)){if(_0x5e1cfd(0x4ba)!==_0x5e1cfd(0x583)){const _0x137476=_0xc23907[_0x5e1cfd(0x221)];let _0x30bced=_0xc23907[_0x5e1cfd(0x20d)];if(['',_0x5e1cfd(0x916)][_0x5e1cfd(0x9ef)](_0x30bced))_0x30bced=_0xc23907[_0x5e1cfd(0x424)][_0x5e1cfd(0x204)](this);const _0x3c5610=_0xc23907[_0x5e1cfd(0x338)]['call'](this),_0x33c87f=_0xc23907[_0x5e1cfd(0x5c8)][_0x5e1cfd(0x204)](this);this[_0x5e1cfd(0x771)](_0x30bced,_0x137476,_0x3c5610,_0x33c87f),this[_0x5e1cfd(0x60e)](_0x137476,_0xc23907[_0x5e1cfd(0x406)][_0x5e1cfd(0x6ac)](this,_0x33c87f));}else _0x529055[_0x5e1cfd(0x940)]['Game_Picture_show']['call'](this,_0x7d1c3a,_0x27ee7c,_0x1954fd,_0x37dc54,_0x473b4c,_0x4c158,_0x782547,_0x4eaa5a),this['setAnchor']([{'x':0x0,'y':0x0},{'x':0.5,'y':0.5}][_0x46c14b]||{'x':0x0,'y':0x0});}}};function Window_ButtonAssist(){const _0x81ee95=_0x54167d;this[_0x81ee95(0x8d7)](...arguments);}Window_ButtonAssist[_0x54167d(0x4ec)]=Object[_0x54167d(0x66b)](Window_Base[_0x54167d(0x4ec)]),Window_ButtonAssist[_0x54167d(0x4ec)][_0x54167d(0x4a9)]=Window_ButtonAssist,Window_ButtonAssist['prototype']['initialize']=function(_0x46fa02){const _0x30b4bf=_0x54167d;this[_0x30b4bf(0x4ef)]={},Window_Base['prototype'][_0x30b4bf(0x8d7)][_0x30b4bf(0x204)](this,_0x46fa02),this[_0x30b4bf(0x6d0)](VisuMZ[_0x30b4bf(0x940)]['Settings'][_0x30b4bf(0x464)][_0x30b4bf(0x4a7)]||0x0),this['refresh']();},Window_ButtonAssist['prototype'][_0x54167d(0x89f)]=function(){const _0x467eaa=_0x54167d;this[_0x467eaa(0x9a3)]['fontSize']<=0x60&&(this[_0x467eaa(0x9a3)]['fontSize']+=0x6);},Window_ButtonAssist[_0x54167d(0x4ec)][_0x54167d(0x49b)]=function(){const _0x125dae=_0x54167d;this['contents'][_0x125dae(0x79f)]>=0x18&&(this['contents']['fontSize']-=0x6);},Window_ButtonAssist[_0x54167d(0x4ec)]['update']=function(){const _0x16cc95=_0x54167d;Window_Base[_0x16cc95(0x4ec)][_0x16cc95(0x3b5)]['call'](this),this[_0x16cc95(0x624)]();},Window_ButtonAssist[_0x54167d(0x4ec)][_0x54167d(0x511)]=function(){const _0x5bbaad=_0x54167d;this['padding']=SceneManager[_0x5bbaad(0x4ce)]['getButtonAssistLocation']()!==_0x5bbaad(0x926)?0x0:0x8;},Window_ButtonAssist[_0x54167d(0x4ec)][_0x54167d(0x624)]=function(){const _0x47a501=_0x54167d,_0x3c7daa=SceneManager[_0x47a501(0x4ce)];for(let _0xfcf2fd=0x1;_0xfcf2fd<=0x5;_0xfcf2fd++){if(this[_0x47a501(0x4ef)][_0x47a501(0x930)[_0x47a501(0x482)](_0xfcf2fd)]!==_0x3c7daa[_0x47a501(0x3bb)[_0x47a501(0x482)](_0xfcf2fd)]()){if(_0x47a501(0x250)!=='pHUlQ')return this[_0x47a501(0x7dd)]();else this['makeCoreEngineCommandList']();}if(this['_data']['text%1'[_0x47a501(0x482)](_0xfcf2fd)]!==_0x3c7daa[_0x47a501(0x22d)[_0x47a501(0x482)](_0xfcf2fd)]())return this[_0x47a501(0x7dd)]();}},Window_ButtonAssist['prototype'][_0x54167d(0x7dd)]=function(){const _0x4db21c=_0x54167d;this[_0x4db21c(0x9a3)][_0x4db21c(0x531)]();for(let _0x3b2d2e=0x1;_0x3b2d2e<=0x5;_0x3b2d2e++){if(_0x4db21c(0x215)!=='JFUTB')this[_0x4db21c(0x558)](_0x3b2d2e);else return _0x27b756[_0x4db21c(0x9bc)]()>=0x1;}},Window_ButtonAssist[_0x54167d(0x4ec)][_0x54167d(0x558)]=function(_0x1f8174){const _0x55e2f6=_0x54167d,_0x16c740=this['innerWidth']/0x5,_0x5a1809=SceneManager[_0x55e2f6(0x4ce)],_0x163bba=_0x5a1809[_0x55e2f6(0x3bb)['format'](_0x1f8174)](),_0x59a860=_0x5a1809[_0x55e2f6(0x22d)[_0x55e2f6(0x482)](_0x1f8174)]();this[_0x55e2f6(0x4ef)][_0x55e2f6(0x930)[_0x55e2f6(0x482)](_0x1f8174)]=_0x163bba,this['_data']['text%1'[_0x55e2f6(0x482)](_0x1f8174)]=_0x59a860;if(_0x163bba==='')return;if(_0x59a860==='')return;const _0x38199a=_0x5a1809[_0x55e2f6(0x49e)[_0x55e2f6(0x482)](_0x1f8174)](),_0x54815e=this[_0x55e2f6(0x46a)](),_0x1d6ad4=_0x16c740*(_0x1f8174-0x1)+_0x54815e+_0x38199a,_0xe9a34d=VisuMZ['CoreEngine'][_0x55e2f6(0x331)][_0x55e2f6(0x464)][_0x55e2f6(0x676)];this[_0x55e2f6(0x545)](_0xe9a34d[_0x55e2f6(0x482)](_0x163bba,_0x59a860),_0x1d6ad4,0x0,_0x16c740-_0x54815e*0x2);},VisuMZ[_0x54167d(0x940)]['Game_Interpreter_updateWaitMode']=Game_Interpreter[_0x54167d(0x4ec)][_0x54167d(0x943)],Game_Interpreter['prototype'][_0x54167d(0x943)]=function(){const _0x5326b0=_0x54167d;if($gameTemp[_0x5326b0(0x9eb)]!==undefined){if(_0x5326b0(0x481)!==_0x5326b0(0x5f7))return VisuMZ[_0x5326b0(0x940)][_0x5326b0(0x831)]();else this[_0x5326b0(0x8b5)]['setBackgroundType'](_0x47a985[_0x5326b0(0x556)][_0x5326b0(0x342)]);}return VisuMZ[_0x5326b0(0x940)][_0x5326b0(0x5df)][_0x5326b0(0x204)](this);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x831)]=function(){const _0x23c343=_0x54167d,_0x4aa6d0=$gameTemp[_0x23c343(0x9eb)]||0x0;if(_0x4aa6d0<0x0||_0x4aa6d0>0x64||TouchInput[_0x23c343(0x6e2)]()||Input[_0x23c343(0x54b)]('cancel')){if(_0x23c343(0x955)===_0x23c343(0x955))$gameTemp[_0x23c343(0x9eb)]=undefined,Input[_0x23c343(0x531)](),TouchInput['clear']();else{const _0xa50be1=_0x5ade79[_0x23c343(0x464)];_0xa50be1[_0x23c343(0x504)]=_0xa50be1[_0x23c343(0x504)]||_0x23c343(0x2d1),_0xa50be1['KeyTAB']=_0xa50be1[_0x23c343(0x8fb)]||_0x23c343(0x657);}}const _0x4490de=$gameScreen['picture'](_0x4aa6d0);return _0x4490de&&(_0x23c343(0x509)===_0x23c343(0x38b)?_0x291bc9['isTriggered'](_0x23c343(0x5cd))&&(_0x29fbf0['alwaysDash']=!_0x27ad82[_0x23c343(0x3de)],_0x126be4[_0x23c343(0x300)]()):(_0x4490de['_x']=TouchInput['_x'],_0x4490de['_y']=TouchInput['_y'])),VisuMZ[_0x23c343(0x940)][_0x23c343(0x2dd)](),$gameTemp[_0x23c343(0x9eb)]!==undefined;},VisuMZ['CoreEngine'][_0x54167d(0x2dd)]=function(){const _0x12c9f8=_0x54167d,_0x41bd19=SceneManager['_scene'];if(!_0x41bd19)return;!_0x41bd19[_0x12c9f8(0x478)]&&(SoundManager[_0x12c9f8(0x61b)](),_0x41bd19['_pictureCoordinatesWindow']=new Window_PictureCoordinates(),_0x41bd19[_0x12c9f8(0x45f)](_0x41bd19[_0x12c9f8(0x478)])),$gameTemp[_0x12c9f8(0x9eb)]===undefined&&(SoundManager[_0x12c9f8(0x94a)](),_0x41bd19['removeChild'](_0x41bd19[_0x12c9f8(0x478)]),_0x41bd19[_0x12c9f8(0x478)]=undefined);};function Window_PictureCoordinates(){const _0x326076=_0x54167d;this[_0x326076(0x8d7)](...arguments);}Window_PictureCoordinates[_0x54167d(0x4ec)]=Object['create'](Window_Base[_0x54167d(0x4ec)]),Window_PictureCoordinates[_0x54167d(0x4ec)][_0x54167d(0x4a9)]=Window_PictureCoordinates,Window_PictureCoordinates['prototype']['initialize']=function(){const _0x1a7ef9=_0x54167d;this['_lastOrigin']='nah',this[_0x1a7ef9(0x6b3)]='nah',this[_0x1a7ef9(0x6a4)]=_0x1a7ef9(0x297);const _0x2fc07c=this[_0x1a7ef9(0x7cc)]();Window_Base[_0x1a7ef9(0x4ec)][_0x1a7ef9(0x8d7)][_0x1a7ef9(0x204)](this,_0x2fc07c),this[_0x1a7ef9(0x6d0)](0x2);},Window_PictureCoordinates[_0x54167d(0x4ec)][_0x54167d(0x7cc)]=function(){const _0x1eaba1=_0x54167d;let _0x40ef7c=0x0,_0x4ce83a=Graphics[_0x1eaba1(0x3e1)]-this['lineHeight'](),_0x2ac828=Graphics['width'],_0x1ca8d5=this[_0x1eaba1(0x7c4)]();return new Rectangle(_0x40ef7c,_0x4ce83a,_0x2ac828,_0x1ca8d5);},Window_PictureCoordinates['prototype'][_0x54167d(0x511)]=function(){this['padding']=0x0;},Window_PictureCoordinates[_0x54167d(0x4ec)]['update']=function(){const _0x1fad88=_0x54167d;Window_Base[_0x1fad88(0x4ec)][_0x1fad88(0x3b5)]['call'](this),this['updateData']();},Window_PictureCoordinates[_0x54167d(0x4ec)][_0x54167d(0x3f7)]=function(){const _0xaef205=_0x54167d;if(!this[_0xaef205(0x8ed)]())return;this[_0xaef205(0x7dd)]();},Window_PictureCoordinates['prototype'][_0x54167d(0x8ed)]=function(){const _0x4ca435=_0x54167d,_0x19aca9=$gameTemp[_0x4ca435(0x9eb)],_0x55e64a=$gameScreen[_0x4ca435(0x217)](_0x19aca9);if(_0x55e64a){if(_0x4ca435(0x389)!==_0x4ca435(0x4f7))return this['_lastOrigin']!==_0x55e64a[_0x4ca435(0x1f7)]||this[_0x4ca435(0x6b3)]!==_0x55e64a['_x']||this[_0x4ca435(0x6a4)]!==_0x55e64a['_y'];else _0xf30477[_0x4ca435(0x940)][_0x4ca435(0x3f9)][_0x4ca435(0x204)](this),_0x36b326=null,_0x838e0c=null,_0x31fb30=null,_0x5e232b=null;}else{if(_0x4ca435(0x7d7)===_0x4ca435(0x70e))_0x34d9cb[_0x4ca435(0x940)]['Input_clear'][_0x4ca435(0x204)](this),this['_inputString']=_0x110fd4,this['_inputSpecialKeyCode']=_0x25d372,this['_gamepadWait']=_0x358d8a['keyRepeatWait'];else return![];}},Window_PictureCoordinates[_0x54167d(0x4ec)]['refresh']=function(){const _0x561fa4=_0x54167d;this[_0x561fa4(0x9a3)][_0x561fa4(0x531)]();const _0x5a19df=$gameTemp[_0x561fa4(0x9eb)],_0x308817=$gameScreen[_0x561fa4(0x217)](_0x5a19df);if(!_0x308817)return;this[_0x561fa4(0x42a)]=_0x308817[_0x561fa4(0x1f7)],this[_0x561fa4(0x6b3)]=_0x308817['_x'],this['_lastY']=_0x308817['_y'];const _0x508dc0=ColorManager[_0x561fa4(0x53a)]();this[_0x561fa4(0x9a3)][_0x561fa4(0x434)](0x0,0x0,this[_0x561fa4(0x499)],this[_0x561fa4(0x869)],_0x508dc0);const _0x3e4f1f=_0x561fa4(0x25b)[_0x561fa4(0x482)](_0x308817[_0x561fa4(0x1f7)]===0x0?_0x561fa4(0x9a6):_0x561fa4(0x998)),_0xf6c04e=_0x561fa4(0x4b2)[_0x561fa4(0x482)](_0x308817['_x']),_0x5e5bea=_0x561fa4(0x7e4)['format'](_0x308817['_y']),_0x5f089f=_0x561fa4(0x837)[_0x561fa4(0x482)](TextManager[_0x561fa4(0x9fd)](_0x561fa4(0x9a7)));let _0x189242=Math[_0x561fa4(0x42f)](this['innerWidth']/0x4);this['drawText'](_0x3e4f1f,_0x189242*0x0,0x0,_0x189242),this['drawText'](_0xf6c04e,_0x189242*0x1,0x0,_0x189242,_0x561fa4(0x68b)),this['drawText'](_0x5e5bea,_0x189242*0x2,0x0,_0x189242,'center');const _0x4a79bc=this['textSizeEx'](_0x5f089f)[_0x561fa4(0x281)],_0x13660e=this[_0x561fa4(0x499)]-_0x4a79bc;this[_0x561fa4(0x545)](_0x5f089f,_0x13660e,0x0,_0x4a79bc);},VisuMZ['ShowDevTools']=function(_0x1ed590){const _0x3da71b=_0x54167d;if(Utils['isOptionValid'](_0x3da71b(0x931))){if(_0x3da71b(0x807)!==_0x3da71b(0x807))this[_0x3da71b(0x93a)](_0x507eec);else{var _0x541b98=require(_0x3da71b(0x2a4))[_0x3da71b(0x3b6)][_0x3da71b(0x2b7)]();SceneManager[_0x3da71b(0x3fc)]();if(_0x1ed590)setTimeout(_0x541b98[_0x3da71b(0x924)][_0x3da71b(0x6ac)](_0x541b98),0x190);}}},VisuMZ[_0x54167d(0x9d5)]=function(_0x16e342,_0xdf6e51){const _0x4fbe00=_0x54167d;_0xdf6e51=_0xdf6e51['toUpperCase']();var _0x54b3c0=1.70158,_0x321f76=0.7;switch(_0xdf6e51){case _0x4fbe00(0x6e3):return _0x16e342;case _0x4fbe00(0x4c6):return-0x1*Math[_0x4fbe00(0x6fa)](_0x16e342*(Math['PI']/0x2))+0x1;case _0x4fbe00(0x47f):return Math[_0x4fbe00(0x98c)](_0x16e342*(Math['PI']/0x2));case _0x4fbe00(0x3b9):return-0.5*(Math['cos'](Math['PI']*_0x16e342)-0x1);case _0x4fbe00(0x407):return _0x16e342*_0x16e342;case _0x4fbe00(0x67e):return _0x16e342*(0x2-_0x16e342);case'INOUTQUAD':return _0x16e342<0.5?0x2*_0x16e342*_0x16e342:-0x1+(0x4-0x2*_0x16e342)*_0x16e342;case _0x4fbe00(0x263):return _0x16e342*_0x16e342*_0x16e342;case'OUTCUBIC':var _0x357cad=_0x16e342-0x1;return _0x357cad*_0x357cad*_0x357cad+0x1;case _0x4fbe00(0x6bf):return _0x16e342<0.5?0x4*_0x16e342*_0x16e342*_0x16e342:(_0x16e342-0x1)*(0x2*_0x16e342-0x2)*(0x2*_0x16e342-0x2)+0x1;case'INQUART':return _0x16e342*_0x16e342*_0x16e342*_0x16e342;case _0x4fbe00(0x4d2):var _0x357cad=_0x16e342-0x1;return 0x1-_0x357cad*_0x357cad*_0x357cad*_0x357cad;case _0x4fbe00(0x2d5):var _0x357cad=_0x16e342-0x1;return _0x16e342<0.5?0x8*_0x16e342*_0x16e342*_0x16e342*_0x16e342:0x1-0x8*_0x357cad*_0x357cad*_0x357cad*_0x357cad;case _0x4fbe00(0x240):return _0x16e342*_0x16e342*_0x16e342*_0x16e342*_0x16e342;case _0x4fbe00(0x85a):var _0x357cad=_0x16e342-0x1;return 0x1+_0x357cad*_0x357cad*_0x357cad*_0x357cad*_0x357cad;case _0x4fbe00(0x302):var _0x357cad=_0x16e342-0x1;return _0x16e342<0.5?0x10*_0x16e342*_0x16e342*_0x16e342*_0x16e342*_0x16e342:0x1+0x10*_0x357cad*_0x357cad*_0x357cad*_0x357cad*_0x357cad;case _0x4fbe00(0x799):if(_0x16e342===0x0)return 0x0;return Math[_0x4fbe00(0x9ba)](0x2,0xa*(_0x16e342-0x1));case _0x4fbe00(0x43d):if(_0x16e342===0x1)return 0x1;return-Math['pow'](0x2,-0xa*_0x16e342)+0x1;case'INOUTEXPO':if(_0x16e342===0x0||_0x16e342===0x1){if(_0x4fbe00(0x405)===_0x4fbe00(0x405))return _0x16e342;else this['_profileWindow'][_0x4fbe00(0x6d0)](_0x580c49['layoutSettings'][_0x4fbe00(0x48e)]);}var _0x565460=_0x16e342*0x2,_0x5b61c7=_0x565460-0x1;if(_0x565460<0x1){if(_0x4fbe00(0x25a)!==_0x4fbe00(0x25a))_0x4e96cb[_0x4fbe00(0x940)][_0x4fbe00(0x591)]['call'](this),this[_0x4fbe00(0x8d9)]();else return 0.5*Math[_0x4fbe00(0x9ba)](0x2,0xa*_0x5b61c7);}return 0.5*(-Math[_0x4fbe00(0x9ba)](0x2,-0xa*_0x5b61c7)+0x2);case _0x4fbe00(0x7ab):var _0x565460=_0x16e342/0x1;return-0x1*(Math[_0x4fbe00(0x69f)](0x1-_0x565460*_0x16e342)-0x1);case'OUTCIRC':var _0x357cad=_0x16e342-0x1;return Math[_0x4fbe00(0x69f)](0x1-_0x357cad*_0x357cad);case _0x4fbe00(0x2d7):var _0x565460=_0x16e342*0x2,_0x5b61c7=_0x565460-0x2;if(_0x565460<0x1)return-0.5*(Math[_0x4fbe00(0x69f)](0x1-_0x565460*_0x565460)-0x1);return 0.5*(Math[_0x4fbe00(0x69f)](0x1-_0x5b61c7*_0x5b61c7)+0x1);case _0x4fbe00(0x917):return _0x16e342*_0x16e342*((_0x54b3c0+0x1)*_0x16e342-_0x54b3c0);case _0x4fbe00(0x7db):var _0x565460=_0x16e342/0x1-0x1;return _0x565460*_0x565460*((_0x54b3c0+0x1)*_0x565460+_0x54b3c0)+0x1;break;case'INOUTBACK':var _0x565460=_0x16e342*0x2,_0xcfa780=_0x565460-0x2,_0x152bca=_0x54b3c0*1.525;if(_0x565460<0x1)return 0.5*_0x565460*_0x565460*((_0x152bca+0x1)*_0x565460-_0x152bca);return 0.5*(_0xcfa780*_0xcfa780*((_0x152bca+0x1)*_0xcfa780+_0x152bca)+0x2);case _0x4fbe00(0x818):if(_0x16e342===0x0||_0x16e342===0x1)return _0x4fbe00(0x326)!==_0x4fbe00(0x8a0)?_0x16e342:![];var _0x565460=_0x16e342/0x1,_0x5b61c7=_0x565460-0x1,_0x29180b=0x1-_0x321f76,_0x152bca=_0x29180b/(0x2*Math['PI'])*Math['asin'](0x1);return-(Math[_0x4fbe00(0x9ba)](0x2,0xa*_0x5b61c7)*Math[_0x4fbe00(0x98c)]((_0x5b61c7-_0x152bca)*(0x2*Math['PI'])/_0x29180b));case _0x4fbe00(0x637):var _0x29180b=0x1-_0x321f76,_0x565460=_0x16e342*0x2;if(_0x16e342===0x0||_0x16e342===0x1)return _0x16e342;var _0x152bca=_0x29180b/(0x2*Math['PI'])*Math['asin'](0x1);return Math[_0x4fbe00(0x9ba)](0x2,-0xa*_0x565460)*Math[_0x4fbe00(0x98c)]((_0x565460-_0x152bca)*(0x2*Math['PI'])/_0x29180b)+0x1;case _0x4fbe00(0x457):var _0x29180b=0x1-_0x321f76;if(_0x16e342===0x0||_0x16e342===0x1)return _0x16e342;var _0x565460=_0x16e342*0x2,_0x5b61c7=_0x565460-0x1,_0x152bca=_0x29180b/(0x2*Math['PI'])*Math[_0x4fbe00(0x728)](0x1);if(_0x565460<0x1)return-0.5*(Math[_0x4fbe00(0x9ba)](0x2,0xa*_0x5b61c7)*Math[_0x4fbe00(0x98c)]((_0x5b61c7-_0x152bca)*(0x2*Math['PI'])/_0x29180b));return Math['pow'](0x2,-0xa*_0x5b61c7)*Math[_0x4fbe00(0x98c)]((_0x5b61c7-_0x152bca)*(0x2*Math['PI'])/_0x29180b)*0.5+0x1;case'OUTBOUNCE':var _0x565460=_0x16e342/0x1;if(_0x565460<0x1/2.75)return _0x4fbe00(0x85b)===_0x4fbe00(0x85b)?7.5625*_0x565460*_0x565460:_0x43990a[_0x4fbe00(0x556)][_0x4fbe00(0x2b1)]['call'](this);else{if(_0x565460<0x2/2.75){if(_0x4fbe00(0x671)!==_0x4fbe00(0x671))_0x366df0[_0x4fbe00(0x351)]=_0x5add88[_0x4fbe00(0x3e0)](_0x150de2(_0x1688eb['$1']),_0x257292['maxLevel']);else{var _0xcfa780=_0x565460-1.5/2.75;return 7.5625*_0xcfa780*_0xcfa780+0.75;}}else{if(_0x565460<2.5/2.75){var _0xcfa780=_0x565460-2.25/2.75;return 7.5625*_0xcfa780*_0xcfa780+0.9375;}else{var _0xcfa780=_0x565460-2.625/2.75;return 7.5625*_0xcfa780*_0xcfa780+0.984375;}}}case _0x4fbe00(0x3b3):var _0x1ceb9a=0x1-VisuMZ[_0x4fbe00(0x9d5)](0x1-_0x16e342,_0x4fbe00(0x6e4));return _0x1ceb9a;case _0x4fbe00(0x3e6):if(_0x16e342<0.5){if(_0x4fbe00(0x805)===_0x4fbe00(0x805))var _0x1ceb9a=VisuMZ[_0x4fbe00(0x9d5)](_0x16e342*0x2,_0x4fbe00(0x6fb))*0.5;else this['_colorCache'][_0x28753c]=this[_0x4fbe00(0x423)](_0x2fa561(_0x1d7dd2));}else{if('XZacm'===_0x4fbe00(0x80f))var _0x1ceb9a=VisuMZ[_0x4fbe00(0x9d5)](_0x16e342*0x2-0x1,_0x4fbe00(0x6e4))*0.5+0.5;else return _0x5a7233[_0x4fbe00(0x940)][_0x4fbe00(0x331)][_0x4fbe00(0x3b6)][_0x4fbe00(0x559)];}return _0x1ceb9a;default:return _0x16e342;}},VisuMZ[_0x54167d(0x97a)]=function(_0x282f31){const _0x482279=_0x54167d;_0x282f31=String(_0x282f31)[_0x482279(0x8dd)]();const _0x508bb4=VisuMZ[_0x482279(0x940)][_0x482279(0x331)][_0x482279(0x3fa)];if(_0x282f31===_0x482279(0x578))return _0x508bb4[_0x482279(0x3b2)];if(_0x282f31===_0x482279(0x784))return _0x508bb4[_0x482279(0x82e)];if(_0x282f31===_0x482279(0x6ea))return _0x508bb4[_0x482279(0x63a)];if(_0x282f31===_0x482279(0x3ce))return _0x508bb4[_0x482279(0x31e)];if(_0x282f31==='MAT')return _0x508bb4[_0x482279(0x6c0)];if(_0x282f31===_0x482279(0x7e8))return _0x508bb4[_0x482279(0x24d)];if(_0x282f31===_0x482279(0x778))return _0x508bb4[_0x482279(0x8c9)];if(_0x282f31==='LUK')return _0x508bb4['IconParam7'];if(_0x282f31===_0x482279(0x8a9))return _0x508bb4['IconXParam0'];if(_0x282f31===_0x482279(0x2d9))return _0x508bb4[_0x482279(0x9a9)];if(_0x282f31===_0x482279(0x6e8))return _0x508bb4[_0x482279(0x2a0)];if(_0x282f31==='CEV')return _0x508bb4[_0x482279(0x658)];if(_0x282f31==='MEV')return _0x508bb4['IconXParam4'];if(_0x282f31===_0x482279(0x603))return _0x508bb4[_0x482279(0x39e)];if(_0x282f31===_0x482279(0x81e))return _0x508bb4[_0x482279(0x251)];if(_0x282f31==='HRG')return _0x508bb4[_0x482279(0x299)];if(_0x282f31===_0x482279(0x9de))return _0x508bb4['IconXParam8'];if(_0x282f31==='TRG')return _0x508bb4[_0x482279(0x72c)];if(_0x282f31===_0x482279(0x7b3))return _0x508bb4['IconSParam0'];if(_0x282f31===_0x482279(0xa0d))return _0x508bb4[_0x482279(0x995)];if(_0x282f31==='REC')return _0x508bb4[_0x482279(0x877)];if(_0x282f31==='PHA')return _0x508bb4[_0x482279(0x6ca)];if(_0x282f31==='MCR')return _0x508bb4['IconSParam4'];if(_0x282f31===_0x482279(0x5c3))return _0x508bb4[_0x482279(0x474)];if(_0x282f31===_0x482279(0x70a))return _0x508bb4[_0x482279(0x848)];if(_0x282f31===_0x482279(0x90d))return _0x508bb4[_0x482279(0x5ff)];if(_0x282f31===_0x482279(0x4b5))return _0x508bb4[_0x482279(0x3dd)];if(_0x282f31===_0x482279(0x282))return _0x508bb4[_0x482279(0x598)];if(VisuMZ[_0x482279(0x940)][_0x482279(0x377)][_0x282f31]){if(_0x482279(0x6cc)!==_0x482279(0x6cc))_0x3073fe*=_0x19c376(_0x4771d2);else return VisuMZ[_0x482279(0x940)][_0x482279(0x377)][_0x282f31]||0x0;}return 0x0;},VisuMZ[_0x54167d(0x774)]=function(_0x404dae,_0x110b5d,_0x357a72){const _0x179e1a=_0x54167d;if(_0x357a72===undefined&&_0x404dae%0x1===0x0)return _0x404dae;if(_0x357a72!==undefined&&[_0x179e1a(0x578),_0x179e1a(0x784),_0x179e1a(0x6ea),_0x179e1a(0x3ce),'MAT',_0x179e1a(0x7e8),_0x179e1a(0x778),_0x179e1a(0x7cf)]['includes'](String(_0x357a72)[_0x179e1a(0x8dd)]()[_0x179e1a(0x314)]()))return _0x404dae;_0x110b5d=_0x110b5d||0x0;if(VisuMZ['CoreEngine'][_0x179e1a(0x450)][_0x357a72]){if(_0x179e1a(0x675)!==_0x179e1a(0x71a))return VisuMZ[_0x179e1a(0x940)]['CustomParamType'][_0x357a72]===_0x179e1a(0x74f)?_0x179e1a(0x93d)!==_0x179e1a(0x93d)?_0x2eec56[_0x179e1a(0x940)][_0x179e1a(0x331)]['UI']['BottomHelp']:_0x404dae:String((_0x404dae*0x64)[_0x179e1a(0x382)](_0x110b5d))+'%';else{var _0x353e28=_0x623ba1(_0x40efa4['$1'])/0x64;_0x4dd499+=_0x353e28;}}return String((_0x404dae*0x64)[_0x179e1a(0x382)](_0x110b5d))+'%';},VisuMZ['GroupDigits']=function(_0x13729d){const _0xe77e08=_0x54167d;_0x13729d=String(_0x13729d);if(!_0x13729d)return _0x13729d;if(typeof _0x13729d!==_0xe77e08(0x510))return _0x13729d;const _0x725994=VisuMZ[_0xe77e08(0x940)]['Settings'][_0xe77e08(0x2e9)][_0xe77e08(0x477)]||_0xe77e08(0x825),_0x3f22a3={'maximumFractionDigits':0x6};_0x13729d=_0x13729d[_0xe77e08(0x3ed)](/\[(.*?)\]/g,(_0x439aee,_0x411957)=>{const _0x3f3f8d=_0xe77e08;if(_0x3f3f8d(0x2d2)!=='wSzUL')return VisuMZ['PreserveNumbers'](_0x411957,'[',']');else{const _0x2aa916=_0x20dd2f['Abbreviation'],_0x1fbc19=_0x4e8886[_0x3f3f8d(0x6fc)],_0x378567=_0x5a5f99[_0x3f3f8d(0x685)],_0x579e57=_0x43e0d5[_0x3f3f8d(0x89a)],_0xe3093b=new _0x42f03d(_0x2befc4['ValueJS']);_0x30fa45[_0x3f3f8d(0x940)][_0x3f3f8d(0x7d1)][_0x2aa916['toUpperCase']()[_0x3f3f8d(0x314)]()]=_0x1fbc19,_0x5d785f[_0x3f3f8d(0x940)][_0x3f3f8d(0x377)][_0x2aa916[_0x3f3f8d(0x8dd)]()[_0x3f3f8d(0x314)]()]=_0x378567,_0x3a31cd['CoreEngine'][_0x3f3f8d(0x6dc)][_0x2aa916['toUpperCase']()[_0x3f3f8d(0x314)]()]=_0x579e57,_0xa8ba41['CoreEngine'][_0x3f3f8d(0x450)][_0x2aa916[_0x3f3f8d(0x8dd)]()[_0x3f3f8d(0x314)]()]=_0x2aa916,_0x47f42c['defineProperty'](_0x4ae88a[_0x3f3f8d(0x4ec)],_0x2aa916,{'get'(){const _0x296123=_0x3f3f8d,_0x4316dc=_0xe3093b['call'](this);return _0x579e57===_0x296123(0x74f)?_0x26d002[_0x296123(0x3ad)](_0x4316dc):_0x4316dc;}});}}),_0x13729d=_0x13729d[_0xe77e08(0x3ed)](/<(.*?)>/g,(_0x157612,_0x4363a3)=>{const _0x4098e3=_0xe77e08;if('zBLqV'!==_0x4098e3(0x84b))return VisuMZ[_0x4098e3(0x45a)](_0x4363a3,'<','>');else{if(_0x20ab2f(this[_0x4098e3(0x52d)])[_0x4098e3(0x95b)]>=this[_0x4098e3(0x412)])return;const _0x3d75ab=_0x216756(_0x3c36a8(this['_number'])+_0x2e46ab[_0x4098e3(0x2f6)]);if(_0x598611(_0x3d75ab))return;this[_0x4098e3(0x52d)]=_0x3d75ab;const _0x108511='9'[_0x4098e3(0x779)](this[_0x4098e3(0x412)]);this['_number']=this['_number'][_0x4098e3(0x29b)](0x0,_0x108511),_0x14f9da['clear'](),this[_0x4098e3(0x7dd)](),_0x10bfd6[_0x4098e3(0x711)](),this[_0x4098e3(0x433)](this[_0x4098e3(0x412)]-0x1);}}),_0x13729d=_0x13729d[_0xe77e08(0x3ed)](/\{\{(.*?)\}\}/g,(_0x427743,_0x283dd8)=>{const _0x5193b4=_0xe77e08;return VisuMZ[_0x5193b4(0x45a)](_0x283dd8,'','');}),_0x13729d=_0x13729d[_0xe77e08(0x3ed)](/(\d+\.?\d*)/g,(_0x3817c3,_0x4857ca)=>{const _0x503014=_0xe77e08;if(_0x503014(0x208)!==_0x503014(0x270)){let _0x4e1df0=_0x4857ca;if(_0x4e1df0[0x0]==='0')return _0x4e1df0;if(_0x4e1df0[_0x4e1df0[_0x503014(0x95b)]-0x1]==='.')return Number(_0x4e1df0)[_0x503014(0x541)](_0x725994,_0x3f22a3)+'.';else return _0x4e1df0[_0x4e1df0[_0x503014(0x95b)]-0x1]===','?Number(_0x4e1df0)[_0x503014(0x541)](_0x725994,_0x3f22a3)+',':Number(_0x4e1df0)[_0x503014(0x541)](_0x725994,_0x3f22a3);}else _0x38b3ed[_0x503014(0x4c7)](!![]);});let _0x6fc19a=0x3;while(_0x6fc19a--){if(_0xe77e08(0x4be)===_0xe77e08(0x693)){let _0x535fb0=_0xe77e08(0x904)+_0x125209+'Total';if(this['checkCacheKey'](_0x535fb0))return this['_cache'][_0x535fb0];return this[_0xe77e08(0x74c)][_0x535fb0]=_0x4dde48['CoreEngine'][_0xe77e08(0x331)][_0xe77e08(0x3fa)][_0xe77e08(0x8cb)][_0xe77e08(0x204)](this,_0x469cec),this[_0xe77e08(0x74c)][_0x535fb0];}else _0x13729d=VisuMZ[_0xe77e08(0x617)](_0x13729d);}return _0x13729d;},VisuMZ['PreserveNumbers']=function(_0x572e67,_0x3e2706,_0xea2ea0){const _0x96cfeb=_0x54167d;return _0x572e67=_0x572e67[_0x96cfeb(0x3ed)](/(\d)/gi,(_0x2abbb1,_0xc594ce)=>_0x96cfeb(0x2da)[_0x96cfeb(0x482)](Number(_0xc594ce))),'%2%1%3'['format'](_0x572e67,_0x3e2706,_0xea2ea0);},VisuMZ[_0x54167d(0x617)]=function(_0x11546f){return _0x11546f=_0x11546f['replace'](/PRESERVCONVERSION\((\d+)\)/gi,(_0x5a7a92,_0x5c3cb8)=>Number(parseInt(_0x5c3cb8))),_0x11546f;},VisuMZ[_0x54167d(0x24c)]=function(_0x3aa8b3){const _0x26471c=_0x54167d;SoundManager[_0x26471c(0x5d9)]();if(!Utils[_0x26471c(0x303)]()){const _0x437c63=window[_0x26471c(0x592)](_0x3aa8b3,_0x26471c(0x62c));}else{const _0x32122e=process[_0x26471c(0x25d)]==_0x26471c(0x2c3)?'open':process[_0x26471c(0x25d)]==_0x26471c(0x8e7)?_0x26471c(0x773):_0x26471c(0x610);require(_0x26471c(0x3c1))['exec'](_0x32122e+'\x20'+_0x3aa8b3);}},Game_Picture['prototype'][_0x54167d(0x9b0)]=function(){const _0x26d9e8=_0x54167d;return this[_0x26d9e8(0x6d2)];},VisuMZ['CoreEngine'][_0x54167d(0x8ca)]=Game_Picture['prototype'][_0x54167d(0x202)],Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x202)]=function(){const _0x58d559=_0x54167d;VisuMZ['CoreEngine'][_0x58d559(0x8ca)]['call'](this),this['_anchor']={'x':0x0,'y':0x0},this[_0x58d559(0x53e)]={'x':0x0,'y':0x0};},VisuMZ[_0x54167d(0x940)][_0x54167d(0x4bd)]=Game_Picture[_0x54167d(0x4ec)]['updateMove'],Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x229)]=function(){const _0x5817fa=_0x54167d;this[_0x5817fa(0x885)]();const _0x3fe337=this[_0x5817fa(0x4ee)];VisuMZ[_0x5817fa(0x940)][_0x5817fa(0x4bd)]['call'](this);if(_0x3fe337>0x0&&this[_0x5817fa(0x4ee)]<=0x0){this['_x']=this[_0x5817fa(0x6d1)],this['_y']=this['_targetY'],this[_0x5817fa(0x8c2)]=this['_targetScaleX'],this[_0x5817fa(0x890)]=this[_0x5817fa(0x242)],this['_opacity']=this[_0x5817fa(0x360)];if(this['_anchor']){if(_0x5817fa(0x7a0)!=='nyhPc')this['_anchor']['x']=this[_0x5817fa(0x53e)]['x'],this[_0x5817fa(0x6d2)]['y']=this['_targetAnchor']['y'];else{if(_0x2c2f9c['isTriggered']()&&this[_0x5817fa(0x8e1)]())this['switchModes'](_0x5817fa(0x646));else _0x3fd112[_0x5817fa(0x6e2)]()&&this[_0x5817fa(0x94e)]('default');}}}},VisuMZ[_0x54167d(0x940)][_0x54167d(0x695)]=Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x5a3)],Game_Picture['prototype']['show']=function(_0x30d068,_0x3e7b4f,_0x3eeefd,_0x27c0af,_0x4376fe,_0x3124b0,_0x5c0e29,_0x51d653){const _0x2aa838=_0x54167d;VisuMZ[_0x2aa838(0x940)][_0x2aa838(0x695)][_0x2aa838(0x204)](this,_0x30d068,_0x3e7b4f,_0x3eeefd,_0x27c0af,_0x4376fe,_0x3124b0,_0x5c0e29,_0x51d653),this[_0x2aa838(0x748)]([{'x':0x0,'y':0x0},{'x':0.5,'y':0.5}][_0x3e7b4f]||{'x':0x0,'y':0x0});},VisuMZ[_0x54167d(0x940)][_0x54167d(0x7ef)]=Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x35d)],Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x35d)]=function(_0x4478d2,_0x5514fa,_0x365cd4,_0x5e04fa,_0x4d4f8c,_0x5ed94a,_0xd3d2e1,_0x316c49,_0x4cde29){const _0x8fd5b6=_0x54167d;VisuMZ['CoreEngine']['Game_Picture_move'][_0x8fd5b6(0x204)](this,_0x4478d2,_0x5514fa,_0x365cd4,_0x5e04fa,_0x4d4f8c,_0x5ed94a,_0xd3d2e1,_0x316c49,_0x4cde29),this[_0x8fd5b6(0xa1a)]([{'x':0x0,'y':0x0},{'x':0.5,'y':0.5}][_0x4478d2]||{'x':0x0,'y':0x0});},Game_Picture[_0x54167d(0x4ec)][_0x54167d(0x885)]=function(){const _0xfb9f57=_0x54167d;this[_0xfb9f57(0x4ee)]>0x0&&(this[_0xfb9f57(0x6d2)]['x']=this[_0xfb9f57(0x80d)](this[_0xfb9f57(0x6d2)]['x'],this['_targetAnchor']['x']),this['_anchor']['y']=this[_0xfb9f57(0x80d)](this[_0xfb9f57(0x6d2)]['y'],this['_targetAnchor']['y']));},Game_Picture['prototype']['setAnchor']=function(_0x34d7ef){const _0xe64550=_0x54167d;this[_0xe64550(0x6d2)]=_0x34d7ef,this[_0xe64550(0x53e)]=JsonEx[_0xe64550(0x419)](this[_0xe64550(0x6d2)]);},Game_Picture[_0x54167d(0x4ec)]['setTargetAnchor']=function(_0xeb460b){const _0x1bd5b6=_0x54167d;this[_0x1bd5b6(0x53e)]=_0xeb460b;},VisuMZ[_0x54167d(0x940)]['Sprite_Picture_updateOrigin']=Sprite_Picture[_0x54167d(0x4ec)][_0x54167d(0x4c9)],Sprite_Picture[_0x54167d(0x4ec)][_0x54167d(0x4c9)]=function(){const _0x1e456=_0x54167d,_0x1ddd4d=this['picture']();!_0x1ddd4d[_0x1e456(0x9b0)]()?VisuMZ[_0x1e456(0x940)]['Sprite_Picture_updateOrigin'][_0x1e456(0x204)](this):(this[_0x1e456(0x9b0)]['x']=_0x1ddd4d[_0x1e456(0x9b0)]()['x'],this['anchor']['y']=_0x1ddd4d[_0x1e456(0x9b0)]()['y']);},Game_Action[_0x54167d(0x4ec)]['setEnemyAction']=function(_0x4263c6){const _0x47112e=_0x54167d;if(_0x4263c6){if(_0x47112e(0x353)!==_0x47112e(0x968)){const _0x3b9d07=_0x4263c6[_0x47112e(0x75f)];if(_0x3b9d07===0x1&&this['subject']()[_0x47112e(0x6c1)]()!==0x1)this[_0x47112e(0x46c)]();else _0x3b9d07===0x2&&this['subject']()[_0x47112e(0x9f4)]()!==0x2?this[_0x47112e(0x4ad)]():this[_0x47112e(0x69c)](_0x3b9d07);}else this[_0x47112e(0x23e)][_0x47112e(0x6d0)](_0x351ef6[_0x47112e(0x556)][_0x47112e(0x701)]);}else{if(_0x47112e(0x6a8)!==_0x47112e(0x6a8))return 0x0;else this[_0x47112e(0x531)]();}},Game_Actor[_0x54167d(0x4ec)][_0x54167d(0x393)]=function(){const _0x5c86ba=_0x54167d;return this[_0x5c86ba(0x60c)]()[_0x5c86ba(0x64f)](_0x4f45b4=>this['canUse'](_0x4f45b4)&&this[_0x5c86ba(0x7aa)]()['includes'](_0x4f45b4[_0x5c86ba(0x605)]));},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x956)]=function(){const _0x25de50=_0x54167d;this[_0x25de50(0x63c)]=new Sprite(),this[_0x25de50(0x63c)][_0x25de50(0x228)]=new Bitmap(0x0,0x0),this[_0x25de50(0x63c)]['x']=0x0,this[_0x25de50(0x492)](this[_0x25de50(0x63c)]);},Window_Base[_0x54167d(0x4ec)][_0x54167d(0x47d)]=function(){const _0x4658cc=_0x54167d;if(this['_dimmerSprite']){if(_0x4658cc(0x31c)!==_0x4658cc(0x348)){const _0x53d68b=this[_0x4658cc(0x63c)][_0x4658cc(0x228)],_0x9d2c61=this['width'],_0x8e973a=this[_0x4658cc(0x3e1)],_0x13dbf2=this[_0x4658cc(0x7ee)],_0x250813=ColorManager['dimColor1'](),_0x4e7e81=ColorManager[_0x4658cc(0x59e)]();_0x53d68b[_0x4658cc(0x776)](_0x9d2c61,_0x8e973a),_0x53d68b['gradientFillRect'](0x0,0x0,_0x9d2c61,_0x13dbf2,_0x4e7e81,_0x250813,!![]),_0x53d68b['fillRect'](0x0,_0x13dbf2,_0x9d2c61,_0x8e973a-_0x13dbf2*0x2,_0x250813),_0x53d68b['gradientFillRect'](0x0,_0x8e973a-_0x13dbf2,_0x9d2c61,_0x13dbf2,_0x250813,_0x4e7e81,!![]),this[_0x4658cc(0x63c)][_0x4658cc(0x2bf)](0x0,0x0,_0x9d2c61,_0x8e973a);}else{const _0x4b8521=this[_0x4658cc(0x519)]();return _0x4b8521[_0x4658cc(0x59b)](/\/\/[ ]SCRIPT[ ]CALL/i)?this[_0x4658cc(0x9f6)](_0x4b8521):_0x39192b[_0x4658cc(0x940)][_0x4658cc(0x5c4)][_0x4658cc(0x204)](this,_0x1ede1f);}}},Game_Actor['prototype'][_0x54167d(0x72e)]=function(){const _0x22ac25=_0x54167d;for(let _0x436a39=0x0;_0x436a39<this['numActions']();_0x436a39++){const _0x42bce1=this[_0x22ac25(0x56f)]();let _0x4b2d37=Number[_0x22ac25(0x286)];this['setAction'](_0x436a39,_0x42bce1[0x0]);for(const _0x354f5b of _0x42bce1){const _0x44f312=_0x354f5b['evaluate']();_0x44f312>_0x4b2d37&&(_0x4b2d37=_0x44f312,this[_0x22ac25(0xa13)](_0x436a39,_0x354f5b));}}this[_0x22ac25(0x7a2)](_0x22ac25(0x7ec));},Window_BattleItem[_0x54167d(0x4ec)][_0x54167d(0x4b7)]=function(_0x5c6073){const _0x3ceeba=_0x54167d;if(BattleManager[_0x3ceeba(0x6d6)]()){if(_0x3ceeba(0x648)!==_0x3ceeba(0x718))return BattleManager[_0x3ceeba(0x6d6)]()[_0x3ceeba(0x49f)](_0x5c6073);else{if(!!_0x4448e7[_0x40c14e]){if(_0x5a45dc[_0x3ceeba(0x562)]())_0x482cee['log'](_0x3ceeba(0x6b4)[_0x3ceeba(0x482)](_0x34b14c));}const _0x2aa61e='\x0a\x20\x20\x20\x20\x20\x20\x20\x20try\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20%2\x0a\x20\x20\x20\x20\x20\x20\x20\x20}\x20catch\x20(e)\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20if\x20($gameTemp.isPlaytest())\x20{\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20console.log(\x27JS\x20Quick\x20Function\x20\x22%1\x22\x20Error!\x27);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20console.log(e);\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20return\x200;\x0a\x20\x20\x20\x20\x20\x20\x20\x20}\x0a\x20\x20\x20\x20'['format'](_0x251983,_0x2e62bf);_0x16b5e1[_0x4862a8]=new _0x493d2f(_0x2aa61e);}}else return Window_ItemList[_0x3ceeba(0x4ec)][_0x3ceeba(0x4b7)]['call'](this,_0x5c6073);},VisuMZ[_0x54167d(0x940)]['Scene_Map_createSpritesetFix']=Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x7f0)],Scene_Map[_0x54167d(0x4ec)][_0x54167d(0x7f0)]=function(){const _0x41114f=_0x54167d;VisuMZ[_0x41114f(0x940)][_0x41114f(0x9a2)]['call'](this);const _0x34d399=this[_0x41114f(0x6ae)][_0x41114f(0x36e)];if(_0x34d399)this['addChild'](_0x34d399);},VisuMZ[_0x54167d(0x940)][_0x54167d(0x527)]=Scene_Battle[_0x54167d(0x4ec)]['createSpriteset'],Scene_Battle[_0x54167d(0x4ec)][_0x54167d(0x7f0)]=function(){const _0x300ca1=_0x54167d;VisuMZ['CoreEngine'][_0x300ca1(0x527)][_0x300ca1(0x204)](this);const _0x3f7af1=this[_0x300ca1(0x6ae)]['_timerSprite'];if(_0x3f7af1)this['addChild'](_0x3f7af1);},Sprite_Actor[_0x54167d(0x4ec)][_0x54167d(0x3b5)]=function(){const _0x837dbd=_0x54167d;Sprite_Battler[_0x837dbd(0x4ec)]['update'][_0x837dbd(0x204)](this),this[_0x837dbd(0x26e)]();if(this[_0x837dbd(0x521)]){if(_0x837dbd(0x43c)!==_0x837dbd(0x43c)){var _0x41d8b9=_0x42ac62(_0x10cb9c['$1']);try{_0x40f73a+=_0x67629b(_0x41d8b9);}catch(_0xbbfc7e){if(_0x147e71[_0x837dbd(0x562)]())_0x167fc2[_0x837dbd(0x262)](_0xbbfc7e);}}else this[_0x837dbd(0x821)]();}else{if(this[_0x837dbd(0x979)]!==''){if(_0x837dbd(0x3cb)!==_0x837dbd(0x213))this[_0x837dbd(0x979)]='';else return _0x128918[_0x837dbd(0x940)][_0x837dbd(0x331)][_0x837dbd(0x2e9)][_0x837dbd(0x4a4)];}}},Window[_0x54167d(0x4ec)][_0x54167d(0x1f5)]=function(){const _0x332ad8=_0x54167d,_0x106184=this[_0x332ad8(0x376)],_0x303dc0=this['_height'],_0x2d9bb3=0x18,_0x18f5ce=_0x2d9bb3/0x2,_0x4237a1=0x60+_0x2d9bb3,_0x4ee4dd=0x0+_0x2d9bb3;this[_0x332ad8(0xa03)]['bitmap']=this[_0x332ad8(0x23a)],this['_downArrowSprite'][_0x332ad8(0x9b0)]['x']=0.5,this[_0x332ad8(0xa03)][_0x332ad8(0x9b0)]['y']=0.5,this[_0x332ad8(0xa03)][_0x332ad8(0x2bf)](_0x4237a1+_0x18f5ce,_0x4ee4dd+_0x18f5ce+_0x2d9bb3,_0x2d9bb3,_0x18f5ce),this[_0x332ad8(0xa03)][_0x332ad8(0x35d)](Math[_0x332ad8(0x3ad)](_0x106184/0x2),Math[_0x332ad8(0x3ad)](_0x303dc0-_0x18f5ce)),this[_0x332ad8(0x8e0)]['bitmap']=this[_0x332ad8(0x23a)],this[_0x332ad8(0x8e0)][_0x332ad8(0x9b0)]['x']=0.5,this[_0x332ad8(0x8e0)][_0x332ad8(0x9b0)]['y']=0.5,this['_upArrowSprite'][_0x332ad8(0x2bf)](_0x4237a1+_0x18f5ce,_0x4ee4dd,_0x2d9bb3,_0x18f5ce),this[_0x332ad8(0x8e0)][_0x332ad8(0x35d)](Math[_0x332ad8(0x3ad)](_0x106184/0x2),Math['round'](_0x18f5ce));},Window[_0x54167d(0x4ec)][_0x54167d(0x87a)]=function(){const _0x7a8bda=_0x54167d,_0x15f263=0x90,_0x1dc253=0x60,_0x4bd2d5=0x18;this[_0x7a8bda(0x561)][_0x7a8bda(0x228)]=this[_0x7a8bda(0x23a)],this[_0x7a8bda(0x561)][_0x7a8bda(0x9b0)]['x']=0.5,this[_0x7a8bda(0x561)][_0x7a8bda(0x9b0)]['y']=0x1,this[_0x7a8bda(0x561)]['move'](Math[_0x7a8bda(0x3ad)](this[_0x7a8bda(0x376)]/0x2),this[_0x7a8bda(0x79d)]),this[_0x7a8bda(0x561)][_0x7a8bda(0x2bf)](_0x15f263,_0x1dc253,_0x4bd2d5,_0x4bd2d5),this[_0x7a8bda(0x561)][_0x7a8bda(0x4e2)]=0xff;},Window[_0x54167d(0x4ec)][_0x54167d(0x4f4)]=function(){const _0x3c67a8=_0x54167d,_0x47fcf2=this[_0x3c67a8(0x9dd)]['worldTransform']['apply'](new Point(0x0,0x0)),_0x4fa598=this[_0x3c67a8(0x9dd)][_0x3c67a8(0x7c3)];_0x4fa598['x']=_0x47fcf2['x']+this[_0x3c67a8(0x2ad)]['x'],_0x4fa598['y']=_0x47fcf2['y']+this[_0x3c67a8(0x2ad)]['y'],_0x4fa598[_0x3c67a8(0x281)]=Math[_0x3c67a8(0xa10)](this[_0x3c67a8(0x499)]*this[_0x3c67a8(0x81a)]['x']),_0x4fa598[_0x3c67a8(0x3e1)]=Math['ceil'](this[_0x3c67a8(0x869)]*this[_0x3c67a8(0x81a)]['y']);},Window[_0x54167d(0x4ec)][_0x54167d(0x801)]=function(){const _0x36c514=_0x54167d,_0x2fa46d=this[_0x36c514(0x6db)],_0x6abe70=Math['max'](0x0,this[_0x36c514(0x376)]-_0x2fa46d*0x2),_0x159e8c=Math[_0x36c514(0x350)](0x0,this[_0x36c514(0x79d)]-_0x2fa46d*0x2),_0x3ad146=this[_0x36c514(0x4d3)],_0x2df427=_0x3ad146[_0x36c514(0xa1b)][0x0];_0x3ad146[_0x36c514(0x228)]=this[_0x36c514(0x23a)],_0x3ad146[_0x36c514(0x2bf)](0x0,0x0,0x60,0x60),_0x3ad146[_0x36c514(0x35d)](_0x2fa46d,_0x2fa46d),_0x3ad146['scale']['x']=_0x6abe70/0x60,_0x3ad146[_0x36c514(0x81a)]['y']=_0x159e8c/0x60,_0x2df427[_0x36c514(0x228)]=this[_0x36c514(0x23a)],_0x2df427[_0x36c514(0x2bf)](0x0,0x60,0x60,0x60),_0x2df427['move'](0x0,0x0,_0x6abe70,_0x159e8c),_0x2df427['scale']['x']=0x1/_0x3ad146['scale']['x'],_0x2df427[_0x36c514(0x81a)]['y']=0x1/_0x3ad146[_0x36c514(0x81a)]['y'],_0x3ad146[_0x36c514(0x852)](this['_colorTone']);},Game_Temp[_0x54167d(0x4ec)][_0x54167d(0x800)]=function(){const _0x418e3b=_0x54167d;this[_0x418e3b(0x569)]=[],this[_0x418e3b(0x532)]=[],this[_0x418e3b(0x89e)]=[],this[_0x418e3b(0x7a5)]=[];},VisuMZ['CoreEngine'][_0x54167d(0x747)]=Scene_Base[_0x54167d(0x4ec)][_0x54167d(0x8a2)],Scene_Base['prototype'][_0x54167d(0x8a2)]=function(){const _0x2ec46d=_0x54167d;if($gameTemp)$gameTemp[_0x2ec46d(0x800)]();VisuMZ['CoreEngine'][_0x2ec46d(0x747)]['call'](this);},Bitmap[_0x54167d(0x4ec)][_0x54167d(0x4d5)]=function(_0x397eef){const _0x24c79c=_0x54167d,_0x5b17a3=this['context'];_0x5b17a3['save'](),_0x5b17a3[_0x24c79c(0x416)]=this[_0x24c79c(0x60a)]();const _0x19b05b=_0x5b17a3[_0x24c79c(0x83d)](_0x397eef)['width'];return _0x5b17a3[_0x24c79c(0x4cf)](),_0x19b05b;},Window_Message['prototype'][_0x54167d(0x705)]=function(_0x3bc0de){const _0x315ded=_0x54167d;return this[_0x315ded(0x1f6)]()?this[_0x315ded(0x9a3)][_0x315ded(0x4d5)](_0x3bc0de):_0x315ded(0x441)===_0x315ded(0x356)?_0x35c2ca[_0x315ded(0x940)][_0x315ded(0x331)][_0x315ded(0x530)][_0x315ded(0x456)][_0x315ded(0x204)](this,_0x2f6750):Window_Base[_0x315ded(0x4ec)]['textWidth'][_0x315ded(0x204)](this,_0x3bc0de);},Window_Message[_0x54167d(0x4ec)][_0x54167d(0x1f6)]=function(){const _0x304bbc=_0x54167d;return VisuMZ[_0x304bbc(0x940)]['Settings'][_0x304bbc(0x2e9)]['FontWidthFix']??!![];},VisuMZ[_0x54167d(0x940)]['Game_Action_numRepeats']=Game_Action[_0x54167d(0x4ec)]['numRepeats'],Game_Action[_0x54167d(0x4ec)][_0x54167d(0x6c6)]=function(){const _0x10d137=_0x54167d;return this[_0x10d137(0x787)]()?'IIjnP'!==_0x10d137(0x5aa)?VisuMZ[_0x10d137(0x940)]['Game_Action_numRepeats'][_0x10d137(0x204)](this):_0x5adf1e&&this[_0x10d137(0x521)]?this[_0x10d137(0x521)]['canEquip'](_0x3b8f94):_0x2d1096[_0x10d137(0x940)][_0x10d137(0x34b)][_0x10d137(0x204)](this,_0x3baaef):_0x10d137(0x942)===_0x10d137(0x942)?0x0:this['item']()[_0x10d137(0x93b)]*0.01;},VisuMZ['CoreEngine'][_0x54167d(0x90b)]=Game_Action['prototype']['setAttack'],Game_Action[_0x54167d(0x4ec)][_0x54167d(0x46c)]=function(){const _0x3f9ff4=_0x54167d;this[_0x3f9ff4(0x4de)]()&&this[_0x3f9ff4(0x4de)]()[_0x3f9ff4(0x584)]()?_0x3f9ff4(0x534)===_0x3f9ff4(0x534)?VisuMZ[_0x3f9ff4(0x940)][_0x3f9ff4(0x90b)][_0x3f9ff4(0x204)](this):this[_0x3f9ff4(0x8d7)](...arguments):this[_0x3f9ff4(0x531)]();},Sprite_Name[_0x54167d(0x4ec)][_0x54167d(0x9b5)]=function(){return 0x24;},Sprite_Name[_0x54167d(0x4ec)][_0x54167d(0x5e7)]=function(){const _0x332a01=_0x54167d,_0x161866=this[_0x332a01(0x614)](),_0x36835b=this['bitmapWidth'](),_0x5d5ff0=this[_0x332a01(0x9b5)]();this['setupFont'](),this[_0x332a01(0x228)][_0x332a01(0x531)](),this[_0x332a01(0x228)]['drawTextTopAligned'](_0x161866,0x0,0x0,_0x36835b,_0x5d5ff0,_0x332a01(0x750));},Bitmap[_0x54167d(0x4ec)][_0x54167d(0x232)]=function(_0x32364a,_0x20c8c2,_0x27e8ab,_0x586f71,_0x3cc14e,_0x54ba6f){const _0x5e554d=_0x54167d,_0x1853bf=this[_0x5e554d(0x61d)],_0x2a49c4=_0x1853bf[_0x5e554d(0x79a)];_0x586f71=_0x586f71||0xffffffff;let _0xc60ed5=_0x20c8c2,_0x3dba8d=Math['round'](_0x27e8ab+0x18/0x2+this[_0x5e554d(0x79f)]*0.35);_0x54ba6f===_0x5e554d(0x68b)&&(_0xc60ed5+=_0x586f71/0x2),_0x54ba6f===_0x5e554d(0x231)&&(_0xc60ed5+=_0x586f71),_0x1853bf['save'](),_0x1853bf['font']=this[_0x5e554d(0x60a)](),_0x1853bf[_0x5e554d(0x487)]=_0x54ba6f,_0x1853bf[_0x5e554d(0x804)]=_0x5e554d(0x4b8),_0x1853bf['globalAlpha']=0x1,this[_0x5e554d(0x4b4)](_0x32364a,_0xc60ed5,_0x3dba8d,_0x586f71),_0x1853bf['globalAlpha']=_0x2a49c4,this[_0x5e554d(0x8db)](_0x32364a,_0xc60ed5,_0x3dba8d,_0x586f71),_0x1853bf['restore'](),this[_0x5e554d(0x3d2)][_0x5e554d(0x3b5)]();},VisuMZ['CoreEngine'][_0x54167d(0x40f)]=BattleManager['checkSubstitute'],BattleManager[_0x54167d(0x9b9)]=function(_0x56e46){const _0x355992=_0x54167d;if(this['_action'][_0x355992(0x851)]())return![];return VisuMZ[_0x355992(0x940)][_0x355992(0x40f)][_0x355992(0x204)](this,_0x56e46);};